<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred func action"
	xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:sw			="http://www.swsoft.com/xsl/cp"
	xmlns:action	="http://www.swsoft.com/xsl/cp/action"
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"
	xmlns:cred  	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:vzenv		="http://www.swsoft.com/xsl/cp/vzenv"	
	xmlns:func		="http://exslt.org/functions"	
	xmlns:xsi					="http://www.w3.org/2001/XMLSchema-instance" 
	xmlns:vzarelocator	="http://www.swsoft.com/webservices/vza/4.0.0/vzarelocator"
>

	<!-- Import required modules -->
	<sw:include href="/lib/core/action-funcs.xsl"/>	
	<sw:include href="/lib/vz/vzenv-net-core.xsl"/>
	<!-- Import required modules -->

	<xsl:output method="xml"/>
	
	<!--
		/data
			/src-env
				eid
				hn-eid
			/new-ve
				ve-id
				hn-eid
				name
				hostname
				/user
					name
					password
				/net
			/start
	-->
	<xsl:template match="/">
	
		<xsl:variable name="src-env" select="/data/src-env"/>
		<xsl:variable name="src-eid" select="/data/src-env/eid"/>
		<xsl:variable name="ve" select="/data/new-ve"/>
		<xsl:variable name="new-hn-eid" select="/data/new-ve/hn-eid"/>	
		<xsl:variable name="data" select="/data"/>
	
		<xsl:if test="action:start('relocator.clone', $src-eid)"/>

		<!-- Run clone -->
		<xsl:variable name="clone-res" select="
			action:run-child(
				local:clone-ve($data),
				'Clone Container','clone_ve',$src-eid
			)
		"/>
			

		<xsl:if test="$clone-res">	
		
			<xsl:variable name="new-eid" select="$clone-res/packet/data/vzarelocator/eid_list/eid"/>
			<xsl:if test="sw:sesputstr('local-eid',$new-eid)"/>	
		
			<xsl:choose>
				<!-- Set Root Password -->
				<xsl:when test="$ve/user/password!='' and not(
					action:run-child(local:set-ve-password($new-eid,$ve,$new-hn-eid),'Set Container Root Password','vzaenvm.set',$new-eid)
				)"/>					
				<!-- Setup VE -->
				<xsl:when test="not(
					action:run-child(local:setup-ve($new-eid,$src-env,$ve,$new-hn-eid),'Setup Container','vzaenvm.set',$new-eid)
				)"/>					
				<!-- Start VE -->
				<xsl:when test="$data/start and not(
					action:run-child(local:start-ve($new-eid,$new-hn-eid),'Start Container','vzaenvm.start',$new-eid)
				)"/>
			</xsl:choose>

		</xsl:if>
			
		<xsl:copy-of select="action:complete('relocator.clone', $src-eid)"/>

	</xsl:template>

	
	<func:function name="local:start-ve">
		<xsl:param name="eid"/>
		<xsl:param name="hn-eid"/>		
		
		<func:result>
			<packet log="on">
				<target>vzaenvm</target>
				<xsl:copy-of select="sw:env-dst($hn-eid)"/>
        <cookie>
          <operation>xsl-child.start_ve</operation>
        </cookie>			
				<data>
					<vzaenvm>
						<start>
							<eid><xsl:value-of select="$eid"/></eid>
						</start>
					</vzaenvm>
				</data>
			</packet>
		</func:result>
	</func:function>

	<func:function name="local:set-ve-password">
		<xsl:param name="eid"/>
		<xsl:param name="ve"/>
		<xsl:param name="hn-eid"/>		
		<func:result>
			<packet log="on">
				<target>vzaenvm</target>
				<xsl:copy-of select="sw:env-dst($hn-eid)"/>
        <cookie>
          <operation>xsl-child.set_ve</operation>
        </cookie>			
				<data>
					<vzaenvm>
						<set_user_password>
							<eid><xsl:value-of select="$eid"/></eid>
							<password><xsl:value-of select="sw:base64-encode($ve/user/password)"/></password>
						</set_user_password>
					</vzaenvm>
				</data>
				<vzcpauth/>
			</packet>
		</func:result>
	</func:function>
	
	<func:function name="local:setup-ve">
		<xsl:param name="eid"/>
		<xsl:param name="src-ve"/>		
		<xsl:param name="ve"/>
		<xsl:param name="hn-eid"/>				

		<func:result>
			<packet log="on">
				<target>vzaenvm</target>
				<xsl:copy-of select="sw:env-dst($hn-eid)"/>
        <cookie>
          <operation>xsl-child.set_ve_net</operation>
        </cookie>			
				<data>
					<vzaenvm>
						<set>
							<eid><xsl:value-of select="$eid"/></eid>
							<config>
								<name><xsl:value-of disable-output-escaping="yes" select="$ve/name"/></name>
								<hostname><xsl:value-of select="$ve/hostname"/></hostname>
								<xsl:copy-of select="vzenv:net2config($ve/net,$src-ve/platform)"/>
								<offline_management>
									<!-- don't change to "not 'disable'" - will break windows compat -->
									<xsl:value-of
										select="sw:if(($ve/offline_type = 'default') or ($ve/offline_type = 'custom'),'1','0')"
									/>
								</offline_management>
								<xsl:if test="$ve/offline_type = 'custom'">
									<xsl:for-each select="$ve/selected_offline_service/value">
										<offline_service>
											<xsl:value-of select="string(.)"/>
										</offline_service>
									</xsl:for-each>
								</xsl:if>								
							</config>
							<xsl:if test="$ve/offline_type = 'default'">
								<default>offline_service</default>
							</xsl:if>
						</set>
					</vzaenvm>
				</data>
				<!-- Impersonate local VE setup -->
				<vzcpauth/>
			</packet>
		</func:result>
	</func:function>

	<func:function name="local:clone-ve">
		<xsl:param name="data"/>
		
		<func:result>
			<packet 
				xmlns:xsi					="http://www.w3.org/2001/XMLSchema-instance" 
				xmlns:vzarelocator	="http://www.swsoft.com/webservices/vza/4.0.0/vzarelocator"
				log="on"
			>
				<target>vzarelocator</target>
				<xsl:copy-of select="sw:hn-dst($data/src-env/eid)"/>
        <cookie>
          <operation>xsl-child.clone_ve</operation>
        </cookie>			
				<data>
					<vzarelocator>
						<clone>
							<eid><xsl:value-of select="$data/src-env/eid"/></eid>							
							<count>1</count>
							<xsl:if test="$data/new-ve/ve-id!=''">
								<options xsi:type="vzarelocator:clone_optionsType">
									<veid><xsl:value-of select="$data/new-ve/ve-id"/></veid>
								</options>
							</xsl:if>
						</clone>
					</vzarelocator>
				</data>
			</packet>
		</func:result>
		
	</func:function>
	
	<sw:include href="/lib/common.xsl"/>
</xsl:stylesheet>