<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred func action"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" 
	xmlns:action="http://www.swsoft.com/xsl/cp/action"
	xmlns:local="http://www.swsoft.com/xsl/cp/local" 
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:vzenv="http://www.swsoft.com/xsl/cp/vzenv" 
	xmlns:vzapackagem="http://www.swsoft.com/xsl/cp/vzapackagem" 
	xmlns:func="http://exslt.org/functions"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:vzarelocator="http://www.swsoft.com/webservices/vza/4.0.0/vzarelocator">

	<!-- Import required modules -->
	<sw:include href="/lib/core/action-funcs.xsl"/>
	<sw:include href="/lib/vza/vzapackagem.xsl"/>

	<xsl:output method="xml"/>
	
	<xsl:template match="/">
		<xsl:variable name="eid" select="/data/eid"/>
		<xsl:if test="action:start('vzaenvm.configure', $eid)"/>
		
		<xsl:variable name="set-result" 
			select="not(/data/vzaenvm) or 
						action:run-child(local:set-config($eid, /data/vzaenvm), 'Configure Container', 'vzaenvm.set', $eid)"/>
		<xsl:if test="$set-result and /data/vzapackagem">
			<xsl:if test="action:run-child(local:set-os($eid, /data/vzapackagem), 'Change Container OS version', 'vzapackagem.install', $eid)"/>
		</xsl:if>
		
		<xsl:if test="action:complete('vzaenvm.configure', $eid)"/>
	</xsl:template>
	
	<func:function name="local:set-config">
		<xsl:param name="eid"/>
		<xsl:param name="data"/>
		
		<func:result>
			<packet log="on">
				<target>vzaenvm</target>
				<xsl:copy-of select="sw:hn-dst($eid)"/>
				<data>
					<vzaenvm>
						<set>
							<eid>
								<xsl:value-of select="$data/eid"/>
							</eid>
							<!--<set_mode>ignore</set_mode>-->
							<config>
								<xsl:if test="not($data/gen/name = '')">
									<name>
										<xsl:value-of disable-output-escaping="yes" select="$data/gen/name"/>
									</name>
								</xsl:if>
								<description>
									<xsl:value-of select="sw:base64-encode($data/gen/description)"/>
								</description>
								<on_boot>
									<xsl:value-of select="sw:if(string($data/gen/start_after_boot)='1','1','0')"/>
								</on_boot>
								<offline_management>
									<!-- don't change to "not 'disable'" - will break windows compat -->
									<xsl:value-of
										select="sw:if(($data/gen/offline_type = 'default') or ($data/gen/offline_type = 'custom'),'1','0')"
									/>
								</offline_management>
								<xsl:if test="$data/gen/offline_type = 'custom'">
									<xsl:for-each select="$data/gen/selected_offline_service/value">
										<offline_service>
											<xsl:value-of select="string(.)"/>
										</offline_service>
									</xsl:for-each>
								</xsl:if>
								<ts_mode>
									<xsl:value-of select="$data/gen/tsmode"/>
								</ts_mode>
								<xsl:choose>
									<xsl:when test="$data/gen/tslicservers/tslicserver">
										<xsl:for-each select="$data/gen/tslicservers/tslicserver">
											<ts_license_server>
												<xsl:value-of select="."/>
											</ts_license_server>										
										</xsl:for-each>
									</xsl:when>
									<xsl:otherwise>
										<ts_license_server/>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:if test="$data/ve-id!=1">
									<!-- don`t change for Service VE -->
									<disabled>
										<xsl:value-of select="sw:if(string($data/gen/disabled)='1','1','0')"/>
									</disabled>
								</xsl:if>
								<!-- post Capabilities-->
								<xsl:copy-of select="$data/capabilities/*"/>
							</config>
							<xsl:if test="$data/gen/offline_type = 'default'">
								<default>offline_service</default>
							</xsl:if>											
						</set>
					</vzaenvm>
				</data>
			</packet>
		</func:result>
	</func:function>
	
	<func:function name="local:set-os">
		<xsl:param name="eid"/>
		<xsl:param name="data"/>
		
		<func:result>
			<xsl:call-template name="vzapackagem:chain-packet">
				<xsl:with-param name="commands" select="$data"/>
				<xsl:with-param name="hn-eid" select="$data/hn-eid[1]"/>
				<xsl:with-param name="target-eid" select="$data/eid[1]"/>
			</xsl:call-template>
		</func:result>
	</func:function>
</xsl:stylesheet>
