<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred env-samplem func action requests ips env vt vzenv securitym"
	xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:sw			="http://www.swsoft.com/xsl/cp"
	xmlns:action	="http://www.swsoft.com/xsl/cp/action"
	xmlns:env			="http://www.swsoft.com/xsl/cp/env"
	xmlns:env-samplem	 ="http://www.swsoft.com/xsl/cp/env-samplem"
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"
	xmlns:cred  	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:requests="http://www.swsoft.com/xsl/cp/requests"
	xmlns:func		="http://exslt.org/functions"	
	xmlns:authm		="http://www.swsoft.com/xsl/cp/authm"
	xmlns:ips			="http://www.swsoft.com/xsl/cp/ips"
	xmlns:vzenv		="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:vz			="http://www.swsoft.com/xsl/cp/vz"
	xmlns:vt			="http://www.swsoft.com/xsl/cp/vt"
	xmlns:securitym="http://www.swsoft.com/xsl/cp/securitym"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:units			="http://www.swsoft.com/xsl/cp/units"
>
	<!-- Import required modules -->		
	<sw:include href="/lib/core/action-funcs.xsl"/>	
	<sw:include href="/lib/core/units-core.xsl"/>	
	<sw:include href="/lib/swa/swa-mailer.xsl"/>
	<sw:include href="/lib/swa/env-samplem.xsl"/>
	<sw:include href="/lib/swa/securitym.xsl"/>	
	<sw:include href="/lib/swa/authm.xsl"/>	
	<sw:include href="/lib/vz/ips.xsl"/>
	<sw:include href="/lib/vt/core.xsl"/>
	<sw:include href="/lib/vz/core.xsl"/>
	<sw:include href="/lib/vz/vzenv-net-core.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>
	<!-- /Import required modules -->
	
	<xsl:output method="xml"/>		
	
	<!--
		/data									
			/hn
				/eid
				/name
				/platform
			/def
			/multiple
				/hostname-template
				/name-template
	-->
	<xsl:template match="/">
		
		<xsl:variable name="data" select="/data"/>
		<xsl:variable name="is-windows" select="vt:is-platform-windows($data/hn/platform)"/>
		<xsl:variable name="is-linux" select="vt:is-platform-linux($data/hn/platform)"/>
		<xsl:variable name="hn-eid" select="$data/hn/eid"/>		
		
		<xsl:if test="sw:sesput('request-env',/data/env)"/>
	
		<xsl:if test="action:start('vzaenvm.create')"/>
		
		<!-- Process Request -->
		<xsl:variable name="order-processing" select="$data/def/order-id and local:set-request-processing($data)"/>

		<!-- Create VE -->
		<!-- Check error after order processing-->
		<xsl:if test="error:is-empty()">
				
			<xsl:variable name="info" select="local:create-ve($data)"/>
			<xsl:variable name="eid" select="string($info/eid)"/>
			<xsl:variable name="envinfo" select="$info/parameter"/>
			
			<xsl:if test="sw:sesputtree('local-env-info',$envinfo)"/>
			
			<xsl:choose>
				
				<!-- Check error after VPS creation -->
				<xsl:when test="error:has-errors()">	
				</xsl:when>				
				
				<!-- Add to Folder  -->
				<xsl:when test="$data/parent-folder and 
					not( action:run-child(local:add-folder($eid,$data),'Add to folder','infrastructurem.add_env', /.., $envinfo) )
				"/>				
				
				<!-- Setup VE -->
				<xsl:when test="$data/envs-count!=1 and 
					not( action:run-child(local:setup-ve($hn-eid,$eid,$data),'Setup Container','vzaenvm.set', /.., $envinfo) )
				"/>
				
				<!-- Set permissions -->
				<xsl:when test="($data/permissions/permission) and not(
					local:set-ve-permissions($hn-eid,$eid,$data)
				)"/>
				
				<!-- Set password -->
				<xsl:when test="($data/gen/root_pwd!='') and not(
					action:run-child(local:set-ve-password($hn-eid,$eid,$data),'Set Container Password','vzaenvm.set', /.., $envinfo)
				)"/>
				
				<!-- Start VE -->
				<xsl:when test="$data/gen/start_after_create=1 
					and not(env:get-env($eid,false(),$hn-eid)/env/status/state=$env-state/running)
					and not(
					action:run-child(local:start-ve($hn-eid,$eid),'Start Container','vzaenvm.start', /.., $envinfo)
				)"/>
				
				<!-- Complete creation -->
				<xsl:when test="$data/def/order-id">
					<xsl:if test="local:complete-order($eid,$data)"/>
				</xsl:when>
				<!-- /Complete creation -->
				
			</xsl:choose>
		</xsl:if>
		
		<!-- Get env info of created ENV -->	
		<xsl:variable name="envinfo" select="sw:sesgettree('local-env-info')"/>
		
		<!-- Complete creation -->
		<xsl:if test="$data/def/order-id and $order-processing">
			<xsl:if test="error:has-errors()">
				<xsl:value-of select="local:reopen-order($eid, string($envinfo/eid))"/>
			</xsl:if>
		</xsl:if>
		
		<xsl:copy-of select="action:complete('vzaenvm.create', /.., $envinfo)"/>
				
	</xsl:template>

	<func:function name="local:set-request-processing">
		<xsl:param name="data"/>
				
		<xsl:variable name="error" select="requests:set-processing($data/def/order-id)"/>
		<xsl:choose>
			<xsl:when test="$error!=''">
				<xsl:if test="action:log-error(concat('Can`t process request',$error))"/>
				<func:result select="false()"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="action:log-message('Change request status to processing')"/>
				<func:result select="true()"/>
			</xsl:otherwise>
		</xsl:choose>		
		
	</func:function>

	<func:function name="local:add-folder">		
		<xsl:param name="eid"/>
		<xsl:param name="data"/>
				
		<func:result>
			<packet log="on">
				<target>infrastructurem</target>        
				<data>
					<infrastructurem>
						<add_env>
							<name><xsl:value-of disable-output-escaping="yes" select="units:decode-dn($data/parent-folder/dn)"/></name>
							<eid><xsl:value-of select="$eid"/></eid>							
						</add_env>
					</infrastructurem>
				</data>
			</packet>
		</func:result>
		
	</func:function>
	
	<func:function name="local:complete-order">		
		<xsl:param name="eid"/>
		<xsl:param name="data"/>
				
		<xsl:variable name="error" select="requests:complete-order($data/def/order-id,$eid)"/>
		<xsl:choose>
			<xsl:when test="$error!=''">
				<xsl:if test="action:log-error(concat('Can`t complete request.',' ',$error),'',$eid)"/>
				<func:result select="false()"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="action:log-message('Change request status to completed','',$eid)"/>
				<xsl:variable name="request-config" select="requests:get-config()"/>
				<func:result select="true()"/>
			</xsl:otherwise>
		</xsl:choose>		
		
	</func:function>
	
	<func:function name="local:reopen-order">
		<xsl:param name="eid"/>
		<xsl:param name="data"/>
				
		<xsl:variable name="error" select="requests:reopen-order($data/def/order-id)"/>
		<xsl:choose>
			<xsl:when test="$error!=''">
				<xsl:if test="action:log-error(concat('Can`t reopen request. ',$error),'',$eid)"/>
				<func:result select="false()"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="action:log-message('Change request status to open.','',$eid)"/>
				<func:result select="true()"/>
			</xsl:otherwise>
		</xsl:choose>		
		
	</func:function>

	<func:function name="local:get-ve-title">
		<xsl:param name="ve" />
		<func:result select="env:title(
			sw:if($ve/virtual_config/name!='',$ve/virtual_config/name,$ve/config/name),
			sw:if($ve/virtual_config/hostname!='',$ve/virtual_config/hostname,$ve/config/hostname),	
			$ve/virtual_config/veid
		)"/>
	</func:function>

	<func:function name="local:ve-progress-info">
		<xsl:param name="ve" />

		<xsl:variable name="info">
			<eid><xsl:value-of select="$ve/eid" /></eid>
			<parameter>
				<message><xsl:value-of select="sw:base64-encode('%title%')"/></message>
				<name>env</name>
				<translate/>
				<parameter>
					<message><xsl:value-of select="sw:base64-encode($ve/eid)" /></message>
					<name>eid</name>
					<translate/>
				</parameter>
				<parameter>
					<message><xsl:value-of select="sw:base64-encode(local:get-ve-title($ve))" /></message>
					<name>title</name>
					<translate/>
				</parameter>
				<parameter>
					<message><xsl:value-of select="sw:base64-encode($ve/virtual_config/type)" /></message>
					<name>type</name>
					<translate/>
				</parameter>
			</parameter>
		</xsl:variable>
		
		<func:result select="exsl:node-set($info)" />
	</func:function>

	<func:function name="local:create-ve">
		<xsl:param name="data"/>
		<xsl:variable name="is-windows" select="vt:is-platform-windows($data/hn/platform)"/>
		<xsl:variable name="is-linux" select="vt:is-platform-linux($data/hn/platform)"/>
		<xsl:variable name="newpkgm" select="sw:is-ez-package($data/os_template/name)"/>
		<xsl:variable name="sample" select="env-samplem:get-sample($data/gen/config)"/>
		
		<xsl:variable name="req">
			<packet log="on">
				<target>vzaenvm</target>
				<dst> 			  	
					<host><xsl:value-of select="$data/hn/eid"/></host>
				</dst>
	      <cookie>
	        <operation>create</operation>
	      </cookie>
	      <data>
	       <vzaenvm>
						<create>
							<config>
								<!-- Set common ENV config -->							
								<type>virtuozzo</type>
								<name>
									<xsl:value-of disable-output-escaping="yes" select="$data/gen/name"/>
								</name>
								<description><xsl:value-of select="sw:base64-encode($data/gen/description)"/></description>
								<xsl:copy-of select="vzenv:net2config($data/net,$data/hn/platform)"/>
								<base_sample_id>
									<xsl:value-of select="$data/gen/config"/>
								</base_sample_id>
								<!-- /Set common ENV config -->
								<!-- Set VZ VE config -->
								<xsl:if test="$data/gen/ve_id!='' and $data/gen/ve_id!='0'">
									<veid><xsl:value-of select="$data/gen/ve_id"/></veid>
								</xsl:if>
								<!--
								<ve_type>
									<xsl:copy-of select="$sample/env_config/type"/>
								</ve_type>
								-->
								<os_template>
									<name><xsl:value-of select="$data/os_template/name"/></name>
									<xsl:if test="$data/os_template/version!='00000001' and $data/os_template/version!=''">
										<version><xsl:value-of select="$data/os_template/version"/></version>
									</xsl:if>									
								</os_template>
								<on_boot>
									<xsl:value-of select="sw:if(string($data/gen/start_after_boot)='1','1','0')"/>
								</on_boot>
								<xsl:if test="$is-linux and $data/qos/slm-mode!=''">
									<slm_mode><xsl:value-of select="$data/qos/slm-mode"/></slm_mode>
								</xsl:if>		
								<offline_management>
									<!-- don't change to "not 'disable'" - will break wubdows compat -->
									<xsl:value-of select="sw:if(($data/gen/offline_type = 'default') or ($data/gen/offline_type = 'custom'),'1','0')"/>
								</offline_management>
								<xsl:if test="$data/gen/offline_type = 'custom'">
									<xsl:for-each select="$data/gen/selected_offline_service/value">
										<offline_service>
											<xsl:value-of select="string(.)"/>
										</offline_service>
									</xsl:for-each>
								</xsl:if>
								<!-- terminal server settings -->
								<ts_mode>
									<xsl:value-of select="$data/gen/tsmode"/>
								</ts_mode>
								<xsl:for-each select="$data/gen/tslicservers/tslicserver">
									<ts_license_server>
										<xsl:value-of select="."/>
									</ts_license_server>										
								</xsl:for-each>
								<xsl:for-each select="$data/qos/res">
									<xsl:if test="soft!='' or hard!=''">
										<qos>
											<xsl:copy-of select="id"/>
											<xsl:if test="soft!=''">
												<xsl:copy-of select="soft"/>
											</xsl:if>
											<xsl:if test="hard!=''">
												<xsl:copy-of select="hard"/>
											</xsl:if>
										</qos>
									</xsl:if>
								</xsl:for-each>
								<!-- post Capabilities-->
								<xsl:copy-of select="$data/capabilities/*"/>
								<xsl:choose>
									<xsl:when test="$data/apps/app">
										<xsl:for-each select="$data/apps/app">
											<template>
												<name><xsl:value-of select="name"/></name>
												<xsl:if test="not($newpkgm)">
													<xsl:copy-of select="version"/>
												</xsl:if>
											</template>
										</xsl:for-each>								
									</xsl:when>
									<xsl:otherwise>
										<template/>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:copy-of select="$sample/env_config/*[not(
									self::hostname or self::base_set or self::os_template
									or self::type or self::net_device or self::nameserver or self::search_domain
									or self::on_boot or self::qos
									or self::ip or self::template
									or self::offline_management or self::offline_service
								)]"/>
								<!-- /Set VZ VE config -->
							</config>							
						</create>
					</vzaenvm>
	      </data>
			</packet>
		</xsl:variable>

		<xsl:variable name="res" select="action:run-child($req,'Create Container','vzaenvm.create')"/>

		<!-- Check creation errors and return env-info of the new ENV or empty node-set in case of error -->
		<xsl:choose>
			<xsl:when	test="not($res)">
				<func:result select="/.."/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="local:ve-progress-info($res/packet/data/vzaenvm/env)" />
			</xsl:otherwise>
		</xsl:choose>
		
	</func:function>
	
	
	<func:function name="local:setup-ve">
		<xsl:param name="hn-eid"/>
		<xsl:param name="eid"/>
		<xsl:param name="data"/>
		
		<xsl:variable name="env" select="env:get-env($eid,false(),$hn-eid)/env"/>
		<xsl:variable name="ve-id" select="$env/virtual_config/veid"/>
		
		<func:result>
			<packet log="on">
				<target>vzaenvm</target>
				<dst> 			  	
					<host><xsl:value-of select="$hn-eid"/></host>
				</dst>
        <cookie>
          <operation>xsl-child.setup_ve</operation>
        </cookie>			
				<data>
					<vzaenvm >
						<set>
							<eid><xsl:value-of select="$eid"/></eid>
							<config>
								<!-- Assign name -->
								<xsl:if test="$data/multiple/name-template!=''">
									<name>
										<xsl:value-of select="
											concat(
												substring-before($data/multiple/name-template,'&lt;veid&gt;'),
												$ve-id,
												substring-after($data/multiple/name-template,'&lt;veid&gt;')
											)
										"/>										
									</name>
								</xsl:if>
								<!-- /Assign name -->
								<!-- Assign hostname -->
								<xsl:if test="$data/multiple/hostname-template!=''">
									<hostname>
										<xsl:value-of select="
											concat(
												substring-before($data/multiple/hostname-template,'&lt;veid&gt;'),
												$ve-id,
												substring-after($data/multiple/hostname-template,'&lt;veid&gt;')
											)
										"/>										
									</hostname>
								</xsl:if>
								<!-- /Assign hostname -->
							</config>
						</set>
					</vzaenvm >
				</data>
				<!-- Impersonate local VE setup -->
				<vzcpauth/>
			</packet>
		</func:result>
	</func:function>

	<func:function name="local:set-ve-password">
		<xsl:param name="hn-eid"/>
		<xsl:param name="eid"/>
		<xsl:param name="data"/>
		
		<func:result>
			<packet log="on">
				<target>vzaenvm</target>
				<dst> 			  	
					<host><xsl:value-of select="$hn-eid"/></host>
				</dst>
        <cookie>
          <operation>xsl-child.set_ve_password</operation>
        </cookie>			
				<data>
					<vzaenvm >
						<set_user_password>
							<eid><xsl:value-of select="$eid"/></eid>
							<password><xsl:value-of select="sw:base64-encode($data/gen/root_pwd)"/></password>
						</set_user_password>
					</vzaenvm >
				</data>
				<vzcpauth/>
			</packet>
		</func:result>
	</func:function>
	
	
	<!--
		data/
			permissions/
				permission[]/
					user
					role
	-->
	<func:function name="local:set-ve-permissions">
		<xsl:param name="hn-eid"/>
		<xsl:param name="eid"/>
		<xsl:param name="data"/>
		
		
		<xsl:for-each select="$data/permissions/permission[user!='' and role!='']">
			
			<xsl:if test="error:is-empty()">
				<xsl:variable name="result" select="
					securitym:add-role-assignment( 
						securitym:role-assignment(role,user)/role_assignment,
						securitym:env-scope($eid) 
				)"/>
				<xsl:variable name="error" select="$result[self::error]"/>
				<xsl:choose>
					<xsl:when test="$error">
						<xsl:if test="action:log-error('Can`t add the permission. ','permission.add',$eid)"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="action:log-message('Permission is added successfully.','permission.add',$eid)"/>
					</xsl:otherwise>
				</xsl:choose>		
			</xsl:if>
		</xsl:for-each>
	
		<func:result select="error:is-empty()"/>
	</func:function>
		
	<func:function name="local:start-ve">
		<xsl:param name="hn-eid"/>
		<xsl:param name="eid"/>
		<func:result>
			<packet log="on">
				<target>vzaenvm</target>
				<dst> 			  	
					<host><xsl:value-of select="$hn-eid"/></host>
				</dst>
        <cookie>
          <operation>xsl-child.start_ve</operation>
        </cookie>			
				<data>
					<vzaenvm>
						<start>
							<eid><xsl:value-of select="$eid"/></eid>
						</start>
					</vzaenvm>
				</data>
			</packet>
		</func:result>
	</func:function>
	
	<func:function name="local:stop-ve">
		<xsl:param name="hn-eid"/>
		<xsl:param name="eid"/>
		<func:result>
			<packet log="on">
				<target>vzaenvm</target>
				<dst> 			  	
					<host><xsl:value-of select="$hn-eid"/></host>
				</dst>
        <cookie>
          <operation>xsl-child.stop_ve</operation>
        </cookie>			
				<data>
					<vzaenvm>
						<stop>
							<eid><xsl:value-of select="$eid"/></eid>
						</stop>
					</vzaenvm>
				</data>
			</packet>
		</func:result>
	</func:function>
	
	<func:function name="local:install-apps">
		<xsl:param name="hn-eid"/>
		<xsl:param name="eid"/>
		<xsl:param name="data"/>
		<func:result>
			<packet log="on">
				<target>tem</target>
				<dst> 			  	
					<host><xsl:value-of select="$hn-eid"/></host>
				</dst>
        <cookie>
          <operation>xsl-child.add_apps</operation>
        </cookie>			
				<data>
					<tem>
						<add>
							<eid><xsl:value-of select="$eid"/></eid>
							<xsl:for-each select="$data/apps/app">
								<package>
									<name><xsl:value-of select="name"/></name>
									<version><xsl:value-of select="version"/></version>
								</package>
							</xsl:for-each>
						</add>
					</tem>
				</data>
			</packet>
		</func:result>
	</func:function>
	
	<sw:include href="/lib/vt/envrequests.xsl"/>

	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/globals.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	
</xsl:stylesheet>
