<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred hwm env func action vzenv"
	xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:sw			="http://www.swsoft.com/xsl/cp"
	xmlns:action	="http://www.swsoft.com/xsl/cp/action"
	xmlns:hwm			="http://www.swsoft.com/xsl/cp/hwm"
	xmlns:env			="http://www.swsoft.com/xsl/cp/env"
	xmlns:vzenv		="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"
	xmlns:cred  	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:func		="http://exslt.org/functions"	
	xmlns:vt  		="http://www.swsoft.com/xsl/cp/vt"
>
	<sw:include href="/lib/core/action-funcs.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vz/vzenv-core.xsl"/>

	<xsl:output method="xml"/>
	
	<!--
		/data
			/env
				/eid
				/title				
			/apply
				/sample-id
				/selected-res
				/restart
				/slm-mode
	-->
	<xsl:template match="/">
	
		<xsl:variable name="envs" select="/data/env"/>
		<xsl:variable name="data" select="/data"/>
		
		<xsl:if test="action:start('ve.groupchange.apply', $envs/eid)"/>

		<xsl:for-each select="$envs">
			<xsl:choose>
				<!-- Apply VE Sample -->
				<xsl:when test="not(
					action:run-child(local:apply($data,eid),concat('Apply Container Sample to Container ',title),'vzenvm.set',.)
				)"/>	
			</xsl:choose>
		</xsl:for-each>
		<xsl:copy-of select="action:complete('ve.groupchange.apply', $envs/eid)"/>

	</xsl:template>

	
	<func:function name="local:start-ve">
		<xsl:param name="eid"/>
		<func:result>
			<packet log="on">
				<target>vzaenvm</target>
				<xsl:copy-of select="sw:hn-dst($eid)"/>
        <cookie>
          <operation>xsl-child.start_ve</operation>
        </cookie>			
				<data>
					<vzaenvm>
						<start>
							<eid><xsl:value-of select="$eid"/></eid>
						</start>
					</vzaenvm>
				</data>
			</packet>
		</func:result>
	</func:function>

	<func:function name="local:apply">
		<xsl:param name="data"/>
		<xsl:param name="eid"/>
		
		<xsl:variable name="apply-slm" select="$data/apply/selected-res/res[id='slmmemorylimit'] or $data/apply/slm-mode='ubc'"/>
		
		<func:result>
			<packet log="on">
				<target>vzaenvm</target>
				<xsl:copy-of select="sw:hn-dst($eid)"/>
        <cookie>
          <operation>xsl-child.set_ve</operation>
        </cookie>			
				<data>
					<vzaenvm>
						<set>
							<eid><xsl:value-of select="$eid"/></eid>
							<xsl:if test="vt:is-platform-linux($data/platform)">
								<set_mode>
									<xsl:choose>
										<xsl:when test="$data/apply/restart='1'">restart</xsl:when>
										<xsl:otherwise>ignore</xsl:otherwise>
									</xsl:choose>
								</set_mode>
							</xsl:if>
							<apply_config>
								<sample_conf><xsl:value-of select="$data/apply/sample-id"/></sample_conf>
								<xsl:for-each select="$data/apply/selected-res/res">
									<xsl:variable name="res-id" select="id"/>
									<parameter><xsl:value-of select="$res-id"/></parameter>
								</xsl:for-each>
								<!--<config_customized>
									<xsl:choose>
										<xsl:when test="count($data/apply/qos)=$data/apply/qos-total">
											<xsl:value-of select="0"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="1"/>
										</xsl:otherwise>
									</xsl:choose>
								</config_customized>-->
								<xsl:if test="$apply-slm">
									<parameter>slm_mode</parameter>
								</xsl:if>
							</apply_config>
						</set>
					</vzaenvm>
				</data>
			</packet>
		</func:result>
	</func:function>

	<sw:include href="/lib/common.xsl"/>
</xsl:stylesheet>
