<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred hwm tem func env action"
	xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:sw			="http://www.swsoft.com/xsl/cp"
	xmlns:action	="http://www.swsoft.com/xsl/cp/action"
	xmlns:hwm			="http://www.swsoft.com/xsl/cp/hwm"
	xmlns:tem			="http://www.swsoft.com/xsl/cp/tem"
	xmlns:env			="http://www.swsoft.com/xsl/cp/env"
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"
	xmlns:cred  	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:func		="http://exslt.org/functions"	
>
	<sw:include href="/lib/core/action-funcs.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>


	<xsl:output method="xml"/>
	
	<!--
		/data
			/ve-eid[]
			/ve-up-eid[]
			/apps
				/force
				/app
					name
					version
					ve-eid
	-->
	<xsl:template match="/">
	
		<xsl:variable name="ve-list" select="/data/ve-eid"/>
		<xsl:variable name="data" select="/data"/>
		<xsl:if test="action:start('ve.groupchange.apps', $ve-list)"/>

		<xsl:for-each select="$ve-list">
			<xsl:variable name="ve-eid" select="."/>
			<xsl:variable name="env" select="env:get-env($ve-eid)/env"/> 
			<xsl:variable name="ve-id" select="$env/virtual_config/veid"/> 
			<xsl:variable name="ve-apps" select="$data/apps/app[ve-eid=$ve-eid and (version!='' or sw:is-ez-package(os)) ]"/>
			<xsl:variable name="newpgm" select="sw:is-ez-package($ve-apps/os[1])"/>
			<xsl:variable name="ve-up" select="$data/apps/ve-up-eid[.=$ve-eid]"/>
			
			<xsl:if test="$ve-apps">
			  
					<!-- Start VE  -->
					<xsl:if test="$ve-up">
						<xsl:if test="action:run-child(local:start-ve(.),concat('Start Container #',$ve-id),'vzaenvm.start',.)"/>
				  </xsl:if>
				  
					<!-- Upgrade VE(s) -->
					<xsl:choose>
					  <xsl:when test="$newpgm">
					      <xsl:if test="action:run-child(local:upgrade-new($data,.,$ve-apps),concat('Upgrade Container #',$ve-id),'vzapackagem.update',.)"/>
						</xsl:when>
						
					  <xsl:when test="not($newpgm)">
						  <xsl:if test="action:run-child(local:upgrade-old($data,.,$ve-apps),concat('Upgrade Container #',$ve-id),'vzapackagem.update',.)"/>
						</xsl:when>
					</xsl:choose>
					
					<!-- Stop VE  -->
					<xsl:if test="$ve-up">
						<xsl:if test="action:run-child(local:stop-ve(.),concat('Stop Container #',$ve-id),'vzaenvm.stop',.)"/>
          </xsl:if>
          
			</xsl:if>
		</xsl:for-each>
		<xsl:copy-of select="action:complete('ve.groupchange.apps', $ve-list)"/>

	</xsl:template>
	
	<func:function name="local:upgrade-old">
		<xsl:param name="data"/>
		<xsl:param name="eid"/>
		<xsl:param name="ve-apps"/>
		<func:result>
			<packet log="on">
				<target>tem</target>
				<xsl:copy-of select="sw:hn-dst($eid)"/>
        <cookie>
          <operation>xsl-child.tem.add</operation>
        </cookie>			
				<data>
					<tem>
						<add>
							<eid><xsl:value-of select="$eid"/></eid>
							<xsl:for-each select="$ve-apps">
								<package>
									<xsl:copy-of select="name"/>
									<xsl:copy-of select="version"/>
								</package>
							</xsl:for-each>
							<xsl:if test="$data/apps/force='1'">
								<force/>
							</xsl:if>							
							<xsl:if test="$data/apps/jump='1'">
								<jump/>
							</xsl:if>							
						</add>
					</tem>
				</data>
			</packet>
		</func:result>
	</func:function>
	
	<func:function name="local:upgrade-new">
		<xsl:param name="data"/>
		<xsl:param name="eid"/>
		<xsl:param name="ve-apps"/>
		<func:result>
			<packet log="on">
				<target>vzapackagem</target>
				<xsl:copy-of select="sw:hn-dst($eid)"/>
        <cookie>
          <operation>vzapackagem.update</operation>
        </cookie>			
				<data>
					<vzapackagem>
						<update>
							<eid><xsl:value-of select="$eid"/></eid>
							<xsl:for-each select="$ve-apps">
								<package>
									<type>rpm</type>
									<xsl:copy-of select="name"/>
									<distributive><xsl:value-of select="os"/></distributive>
								</package>
							</xsl:for-each>
							<options>
								<xsl:if test="$data/apps/force='1'">
									<force/>
								</xsl:if>							
							</options>
						</update>
					</vzapackagem>
				</data>
			</packet>
		</func:result>
	</func:function>
	
	<func:function name="local:start-ve">
		<xsl:param name="eid"/>
		<func:result>
			<packet log="on">
				<target>vzaenvm</target>
				<xsl:copy-of select="sw:hn-dst($eid)"/>
        <cookie>
          <operation>xsl-child.start_ve</operation>
        </cookie>			
				<data>
					<vzaenvm>
						<start>
							<eid><xsl:value-of select="$eid"/></eid>
						</start>
					</vzaenvm>
				</data>
			</packet>
		</func:result>
	</func:function>
	
	<func:function name="local:stop-ve">
		<xsl:param name="eid"/>
		<func:result>
			<packet log="on">
				<target>vzaenvm</target>
				<xsl:copy-of select="sw:hn-dst($eid)"/>
        <cookie>
          <operation>xsl-child.stop_ve</operation>
        </cookie>			
				<data>
					<vzaenvm>
						<stop>
							<eid><xsl:value-of select="$eid"/></eid>
						</stop>
					</vzaenvm>
				</data>
			</packet>
		</func:result>
	</func:function>

	<sw:include href="/lib/vza/hwm.xsl"/>
	<sw:include href="/lib/common.xsl"/>
</xsl:stylesheet>