<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred hwm env tem func action vzapackagem"
	xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:sw			="http://www.swsoft.com/xsl/cp"
	xmlns:action	="http://www.swsoft.com/xsl/cp/action"
	xmlns:hwm			="http://www.swsoft.com/xsl/cp/hwm"
	xmlns:env			="http://www.swsoft.com/xsl/cp/env"
	xmlns:tem			="http://www.swsoft.com/xsl/cp/tem"
	xmlns:vzapackagem		="http://www.swsoft.com/xsl/cp/vzapackagem"
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"
	xmlns:cred  	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:func		="http://exslt.org/functions"	
>
	<sw:include href="/lib/core/action-funcs.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>


	<xsl:output method="xml"/>
	
	<!--
		/data
			/eid[]
			/start
			/force
	-->
	<xsl:template match="/">
	
		<xsl:variable name="env-list" select="/data/env"/>
		<xsl:variable name="data" select="/data"/>
		<xsl:variable name="do-start" select="/data/start='true'"/>
		<xsl:if test="action:start('ve.groupchange.apps', $env-list/eid)"/>

		<xsl:for-each select="$env-list">
			<!-- get VE data -->
			<xsl:variable name="eid" select="eid"/>
			<xsl:variable name="ve-info" select="env:get-env(eid)/env"/>
			<xsl:variable name="ve-os" select="$ve-info/virtual_config/os_template"/>
			<xsl:variable name="newpgm" select="sw:is-ez-package($ve-os/name)"/>
			<xsl:variable name="ve-up" select="$ve-info/status/state=$env-state/running and not($ve-info/status/transition!='')"/>
			<xsl:variable name="ve-down" select="
				($ve-info/status/state=$env-state/down or $ve-info/status/state=$env-state/mounted)
				and not($ve-info/status/transition!='')
			"/>
			<xsl:variable name="title" select="env:env2title($ve-info)"/>
			
			<!-- /get VE data -->
			<!-- process VE -->
			<xsl:choose>
				<!-- Skip stopped VE -->
				<xsl:when test="(not($ve-up) and not($do-start))">
					<xsl:variable name="message">
						<sw:text lang="C">
							<xsl:with-param name="name" select="$title"/>
							Container %{name} is not running.
						</sw:text>
					</xsl:variable>
					<xsl:if test="action:log-message($message,'',$eid)"/>
				</xsl:when>
				<!-- Error - VE in transition -->
				<xsl:when test="not($ve-up) and not($ve-down)">
					<xsl:if test="action:log-env-error(concat('Can not start Container ', $title),'vzaenvm.start',$eid, 4, $ve-info/status)"/>
				</xsl:when>
				<!-- Start stopped VE -->
				<xsl:when test="not($ve-up) and not(
					action:run-child(local:start-ve($eid),concat('Start Container ', $title), 'vzaenvm.start', $eid)
				)"/>
				<!-- Upgrade VE -->
				<xsl:when test="not(
					local:upgrade-ve($eid, $title, $data)
				)"/>
				<!-- Stop started VE -->
			</xsl:choose>
			<xsl:if test="$do-start and not($ve-up) and not(
					action:run-child(local:stop-ve($eid), concat('Stop Container ', $title), 'vzaenvm.stop', $eid)
				)"/>
			<!-- /process VE -->
							
		</xsl:for-each>
		<xsl:copy-of select="action:complete('ve.groupchange.apps', $env-list/eid)"/>

	</xsl:template>	
	
	<func:function name="local:start-ve">
		<xsl:param name="eid"/>
		<func:result>
			<packet log="on">
				<target>vzaenvm</target>
				<xsl:copy-of select="sw:hn-dst($eid)"/>
        <cookie>
          <operation>xsl-child.start_ve</operation>
        </cookie>			
				<data>
					<vzaenvm>
						<start>
							<eid><xsl:value-of select="$eid"/></eid>
						</start>
					</vzaenvm>
				</data>
			</packet>
		</func:result>
	</func:function>
	
	<func:function name="local:upgrade-ve">
		<xsl:param name="eid"/>
		<xsl:param name="title"/>
		<xsl:param name="data"/>
		
		<xsl:variable name="packet">
			<xsl:call-template name="vzapackagem:update-ve-packet">
				<xsl:with-param name="eid" select="$eid" />
				<xsl:with-param name="cookie">
					<cookie>
						<operation>vzapackagem.update</operation>
					</cookie>
				</xsl:with-param>
				<xsl:with-param name="force" select="$data/force='true'" />
				<xsl:with-param name="log" select="true()" />
			</xsl:call-template>
		</xsl:variable>
		<xsl:choose>
			<xsl:when test="exsl:node-set($packet)//data">
				<func:result select="action:run-child(
							$packet, 
							concat('Upgrade Container ', $title), 
							'vzapackagem.update', 
							$eid)"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="message">
					<sw:text lang="C">
						<xsl:with-param name="name" select="$title"/>
						Container %{name} is up-to-date.
					</sw:text>
				</xsl:variable>
				<xsl:if test="action:log-message($message, '', $eid)"/>
				<func:result select="true()"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	
	<func:function name="local:stop-ve">
		<xsl:param name="eid"/>
		<func:result>
			<packet log="on">
				<target>vzaenvm</target>
				<xsl:copy-of select="sw:hn-dst($eid)"/>
        <cookie>
          <operation>xsl-child.stop_ve</operation>
        </cookie>			
				<data>
					<vzaenvm>
						<stop>
							<eid><xsl:value-of select="$eid"/></eid>
						</stop>
					</vzaenvm>
				</data>
			</packet>
		</func:result>
	</func:function>

	<sw:include href="/lib/vza/vzapackagem.xsl"/>
	<sw:include href="/lib/vza/tem.xsl"/>
	<sw:include href="/lib/vza/hwm.xsl"/>
	<sw:include href="/lib/common.xsl"/>
</xsl:stylesheet>