<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred vzenv env func action ips"
	xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:sw			="http://www.swsoft.com/xsl/cp"
	xmlns:action	="http://www.swsoft.com/xsl/cp/action"	
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"
	xmlns:cred  	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:func		="http://exslt.org/functions"
	xmlns:env	  	="http://www.swsoft.com/xsl/cp/env"	
	xmlns:ve	  	="http://www.swsoft.com/xsl/cp/ve"	
	xmlns:vzenv	  	="http://www.swsoft.com/xsl/cp/vzenv"	
	xmlns:ips			="http://www.swsoft.com/xsl/cp/ips"
>

	<!-- Import required modules -->
	<sw:include href="/lib/core/action-funcs.xsl"/>
	<sw:include href="/lib/vz/ips.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vt/ve-core.xsl"/>
	<sw:include href="/lib/vz/vzenv-core.xsl"/>
	<sw:include href="/lib/vz/vzenv-net-core.xsl"/>
	
	<!-- /Import required modules -->

	<xsl:output method="xml"/>
	
	<!--
		/data
			/src/
				eid
				platform
			/env
				name
				hostname
				platform
				net
			/start
	-->
	<xsl:template match="/">
	
		<xsl:variable name="eids" select="/data/env/src/eid"/>
		<xsl:variable name="data" select="/data"/>
	
		<xsl:if test="action:start('ve.groupchange.clone', $eids)"/>

		<xsl:for-each select="$data/env">
			<xsl:variable name="env-data" select="."/>
			
			<xsl:variable name="old-eid" select="$env-data/src/eid"/>									
			<xsl:variable name="old-env" select="env:get-env($old-eid)/env"/>						
			<xsl:variable name="new-hn-eid" select="$old-env/parent_eid"/>						

			<xsl:variable name="packet-target-relocator" select="env:get-target($old-eid,'relocator')"/>
			<xsl:variable name="packet-target-envm" 		select="env:get-target($old-eid)"/>

			<!-- Run clone -->
			<xsl:variable name="clone-res" select="
				action:run-child(
					local:clone-ve($data,$env-data,$packet-target-relocator),
					'Clone Container','clone_ve',$old-eid
				)
			"/>
			
			<!-- Run some post-clone operations -->
			<xsl:if test="$clone-res">
				<xsl:variable name="new-eid" select="$clone-res/packet/data/*[name() = $packet-target-relocator]/eid_list/eid"/>
				<xsl:if test="sw:sesputstr('local-eid',$new-eid)"/>						

				<xsl:choose>
					<!-- Setup VE -->
					<xsl:when test="($packet-target-envm = 'vzaenvm') and not(
						action:run-child(local:setup-ve($new-eid,$new-hn-eid,$env-data),'Setup Container','vzenvm.set',$new-eid)
					)"/>
					<!-- /Setup VE -->
					<!-- Start VE -->
					<xsl:when test="$data/start and not(
						action:run-child(local:start-ve($new-eid,$new-hn-eid,$packet-target-envm),'Start Container','vzenvm.start',$new-eid)
					)"/>
					<!-- /Start VE -->
				</xsl:choose>
			</xsl:if>
			<!-- /Run some post-clone operations -->
		</xsl:for-each>

		<!-- Get EID of created ENV -->	
		<xsl:variable name="eid" select="sw:sesgetstr('local-eid')"/>

		<xsl:copy-of select="action:complete('ve.groupchange.clone', $eids)"/>

	</xsl:template>

	
	<func:function name="local:start-ve">
		<xsl:param name="ve-eid"/>
		<xsl:param name="hn-eid"/>		
		<xsl:param name="packet-target"/>
		<func:result>
			<packet log="on">
				<target><xsl:value-of select="$packet-target"/></target>
				<xsl:copy-of select="sw:env-dst($hn-eid)"/>
        <cookie>
          <operation>xsl-child.start_ve</operation>
        </cookie>			
				<data>
					<xsl:element name="{$packet-target}">
						<start>
							<eid><xsl:value-of select="$ve-eid"/></eid>
						</start>
					</xsl:element>
				</data>
			</packet>
		</func:result>
	</func:function>

	<func:function name="local:setup-ve">
		<xsl:param name="ve-eid"/>
		<xsl:param name="hn-eid"/>		
		<xsl:param name="env-data"/>
		<func:result>
			<packet log="on">
				<target>vzaenvm</target>
				<xsl:copy-of select="sw:env-dst($hn-eid)"/>
        <cookie>
          <operation>xsl-child.set_ve_net</operation>
        </cookie>			
				<data>
					<vzaenvm>
						<set>
							<eid><xsl:value-of select="$ve-eid"/></eid>
							<config>
								<xsl:if test="$env-data/hostname!=''">
									<hostname><xsl:value-of select="$env-data/hostname"/></hostname>
								</xsl:if>
								<xsl:if test="$env-data/name!=''">
									<name><xsl:value-of disable-output-escaping="yes" select="$env-data/name"/></name>
								</xsl:if>
								<xsl:if test="$env-data/net[routed/to-edit or bridged/iface/to-edit]">
									<xsl:copy-of select="vzenv:net2config($env-data/net,$env-data/src/platform)"/>
								</xsl:if>
							</config>
						</set>
					</vzaenvm>
				</data>
				<!-- Impersonate local VE setup -->
				<vzcpauth/>
			</packet>
		</func:result>
	</func:function>

	<func:function name="local:clone-ve">
		<xsl:param name="data"/>
		<xsl:param name="env-data"/>
		<xsl:param name="packet-target"/>		
		
		<func:result>
			<packet log="on">
				<target><xsl:value-of select="$packet-target"/></target>
				<xsl:copy-of select="sw:hn-dst($env-data/src/eid)"/>
        <cookie>
          <operation>xsl-child.clone_ve</operation>
        </cookie>			
				<data>
					<xsl:element name="{$packet-target}">
						<clone>
							<eid><xsl:value-of select="$env-data/src/eid"/></eid>								
							<count>1</count>
						</clone>
					</xsl:element>
				</data>
			</packet>
		</func:result>
		
	</func:function>
	
	<sw:include href="/lib/common.xsl"/>
</xsl:stylesheet>
