<!--
		 Copyright (c) SWsoft, 1999-2007
		 All rights reserved.
	-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred hwm env vzenv func action voc"
	xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:sw			="http://www.swsoft.com/xsl/cp"
	xmlns:action	="http://www.swsoft.com/xsl/cp/action"
	xmlns:hwm			="http://www.swsoft.com/xsl/cp/hwm"
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"
	xmlns:cred  	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:voc  		="http://www.swsoft.com/xsl/cp/voc"
	xmlns:env  		="http://www.swsoft.com/xsl/cp/env"
	xmlns:vt  		="http://www.swsoft.com/xsl/cp/vt"
	xmlns:vzenv  	="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:func		="http://exslt.org/functions"	
 	xmlns:res			="http://www.swsoft.com/xsl/cp/res"		
>
	<sw:include href="/lib/core/action-funcs.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vz/vzenv-qos.xsl"/>
	<sw:include href="/lib/vz/vzenv-core.xsl"/>

	<xsl:output method="xml"/>
	
	<!--
		/data
			/platform
			/env
				/eid
				/hostname				
				/num-id
			/quota
				/method
				/set
					/value
					/unit
				/add
					/value
					/unit
				/dec
					/value
					/unit
			/inodes
				/method
				/newdelta
				/set
					/value
	-->
	<xsl:template match="/">
	
		<xsl:variable name="envs" select="/data/env"/>
		<xsl:variable name="data" select="/data"/>
	
		<xsl:if test="action:start('ve.groupchange.disk', $envs/eid)"/>
		
		<xsl:variable name="env-data-list" select="env:get-env($envs/eid)"/>

		<xsl:for-each select="$envs">
			
			<xsl:variable name="env-info" select="."/>
			<xsl:variable name="env-data" select="$env-data-list/env[eid=$env-info/eid]"/>
			<xsl:variable name="voc" select="local:get-voc($env-data/parent_eid)"/>
			
			<xsl:choose>
				<xsl:when test="not(
					action:run-child(local:set($data,$env-info/eid,$env-data,$voc),
						concat('Change disk quota for Container ',env:env2title($env-data))
					,'vzaenvm.set',.)
				)"/>	
			</xsl:choose>
		</xsl:for-each>
		<xsl:copy-of select="action:complete('ve.groupchange.disk', $envs/eid)"/>

	</xsl:template>
	
	<func:function name="local:set">
		<xsl:param name="data"/>
		<xsl:param name="eid"/>
		<xsl:param name="env-data"/>
		<xsl:param name="voc"/>
		
		<xsl:variable name="voc-diskspace" select="$voc[id='diskspace']"/>
		<xsl:variable name="voc-diskinodes" select="$voc[id='diskinodes']"/>
		<xsl:variable name="disk-curr" select="$env-data/virtual_config/qos[id='diskspace']"/>
		<xsl:variable name="inodes-curr" select="$env-data/virtual_config/qos[id='diskinodes']"/>
		<xsl:variable name="disk-unlimited" select="res:param2hard($voc-diskspace/unlimited)=$disk-curr/hard"/>
		<xsl:variable name="inodes-unlimited" select="res:param2hard($voc-diskinodes/unlimited)=$inodes-curr/hard"/>
		
		<xsl:variable name="quota-rtf">
			<qos>
				<xsl:choose>
					<xsl:when test="$data/quota/method='set'">
						<xsl:copy-of select="local:txt2res($data/quota/set/value,$data/quota/set/unit)"/>
					</xsl:when>
					<!-- Leave old values -->
					<xsl:when test="$data/quota/method='oldvalue'">
						<xsl:copy-of select="$disk-curr/soft"/>
						<xsl:copy-of select="$disk-curr/hard"/>
					</xsl:when>
					<!-- Set unlimited -->
					<xsl:when test="$data/quota/method='unlim'">
						<soft><xsl:value-of select="res:param2soft($voc-diskspace/unlimited)"/></soft>
						<hard><xsl:value-of select="res:param2hard($voc-diskspace/unlimited)"/></hard>
					</xsl:when>
					<!-- Leave unlimited disk quota nonchanged -->
					<xsl:when test="$disk-unlimited">
						<xsl:copy-of select="$disk-curr/soft"/>
						<xsl:copy-of select="$disk-curr/hard"/>
					</xsl:when>
					<!-- Add some disk space -->
					<xsl:when test="$data/quota/method='add'">
						<xsl:copy-of select="local:res-add-txt($disk-curr,$data/quota/add/value,$data/quota/add/unit)"/>
					</xsl:when>
					<!-- Decrement disk space -->
					<xsl:when test="$data/quota/method='dec'">
						<xsl:copy-of select="local:res-dec-txt($disk-curr,$data/quota/dec/value,$data/quota/dec/unit)"/>
					</xsl:when>
				</xsl:choose>
			</qos>
		</xsl:variable>		
		<xsl:variable name="quota" select="exsl:node-set($quota-rtf)/qos"/>
		
		<xsl:variable name="inodes-rtf">
			<qos>
				<xsl:choose>
					<xsl:when test="$data/inodes/method='set'">
						<xsl:copy-of select="local:txt2res($data/inodes/set/value,1)"/>
					</xsl:when>
					<xsl:when test="$data/inodes/method='newdelta'">
						<xsl:copy-of select="local:inodes-newdelta2res($quota,$data/inodes/newdelta,$data/inodes/newdelta)"/>
					</xsl:when>
					<!-- Set unlimited -->
					<xsl:when test="$data/inodes/method='unlim'">
						<soft><xsl:value-of select="res:param2soft($voc-diskinodes/unlimited)"/></soft>
						<hard><xsl:value-of select="res:param2hard($voc-diskinodes/unlimited)"/></hard>
					</xsl:when>
					<xsl:when test="$data/inodes/method='oldvalue' or $inodes-unlimited">
						<xsl:copy-of select="$inodes-curr/soft"/>
						<xsl:copy-of select="$inodes-curr/hard"/>
					</xsl:when>
					<xsl:when test="$data/inodes/method='olddelta'">
						<xsl:copy-of select="local:inodes-newdelta2res($quota,$inodes-curr/soft div $disk-curr/soft,$inodes-curr/hard div $disk-curr/hard)"/>
					</xsl:when>
				</xsl:choose>
			</qos>
		</xsl:variable>	
		<xsl:variable name="inodes" select="exsl:node-set($inodes-rtf)/qos"/>
		
		<func:result>
			<packet log="on">
				<target>vzaenvm</target>
				<xsl:copy-of select="sw:hn-dst($eid)"/>
        <cookie>
          <operation>xsl-child.set_ve</operation>
        </cookie>			
				<data>
					<vzaenvm>
						<set>
							<eid><xsl:value-of select="$eid"/></eid>
							<config>
								<qos>
									<id>diskspace</id>
									<xsl:copy-of select="$quota/soft"/>
									<xsl:copy-of select="$quota/hard"/>
								</qos>
								<xsl:if test="vt:is-platform-linux($data/platform)">
									<qos>
										<id>diskinodes</id>
										<xsl:copy-of select="$inodes/soft"/>
										<xsl:copy-of select="$inodes/hard"/>
									</qos>
								</xsl:if>
							</config>
						</set>
					</vzaenvm>
				</data>
			</packet>
		</func:result>
	</func:function>
	
	<!-- Add string to nodeset with resource limits  -->
	<func:function name="local:res-add-txt">
		<xsl:param name="res"/>
		<xsl:param name="txt"/>
		<xsl:param name="mult" select="1"/>
		
		<func:result>
			<xsl:choose>
				<xsl:when test="contains($txt,':')">
					<soft><xsl:value-of select="round($res/soft + number(substring-before($txt,':'))*$mult)"/></soft>
					<hard><xsl:value-of select="round($res/hard + number(substring-after($txt,':'))*$mult)"/></hard>
				</xsl:when>
				<xsl:otherwise>
					<soft><xsl:value-of select="round($res/soft + number($txt)*$mult)"/></soft>
					<hard><xsl:value-of select="round($res/hard + number($txt)*$mult)"/></hard>
				</xsl:otherwise>
			</xsl:choose>
		</func:result>
	
	</func:function>	
	
	<!-- Convert string to nodeset with resource limits -->
	<func:function name="local:txt2res">
		<xsl:param name="txt"/>
		<xsl:param name="mult" select="1"/>
		
		<func:result>
			<xsl:choose>
				<xsl:when test="contains($txt,':')">
					<soft><xsl:value-of select="round(number(substring-before($txt,':'))*$mult)"/></soft>
					<hard><xsl:value-of select="round(number(substring-after($txt,':'))*$mult)"/></hard>
				</xsl:when>
				<xsl:otherwise>
					<soft><xsl:value-of select="round(number($txt)*$mult)"/></soft>
					<hard><xsl:value-of select="round(number($txt)*$mult)"/></hard>
				</xsl:otherwise>
			</xsl:choose>
		</func:result>
	
	</func:function>	
	
	<!-- Decrement string to nodeset with resource limits  -->
	<func:function name="local:res-dec-txt">
		<xsl:param name="res"/>
		<xsl:param name="txt"/>
		<xsl:param name="mult" select="1"/>
		
		<func:result>
			<xsl:choose>
				<xsl:when test="contains($txt,':')">
					<xsl:variable name="soft" select="$res/soft - number(substring-before($txt,':'))*$mult"/>
					<xsl:variable name="hard" select="$res/hard - number(substring-after($txt,':'))*$mult"/>
					<soft><xsl:value-of select="sw:if($soft>0,round($soft),0)"/></soft>
					<hard><xsl:value-of select="sw:if($hard>0,round($hard),0)"/></hard>
				</xsl:when>
				<xsl:otherwise>
					<xsl:variable name="soft" select="$res/soft - number($txt)*$mult"/>
					<xsl:variable name="hard" select="$res/hard - number($txt)*$mult"/>
					<soft><xsl:value-of select="sw:if($soft>0,round($soft),0)"/></soft>
					<hard><xsl:value-of select="sw:if($hard>0,round($hard),0)"/></hard>
				</xsl:otherwise>
			</xsl:choose>
		</func:result>
	
	</func:function>
	
	<!-- Calc new inodes limits by multiply quota to new density value -->
	<func:function name="local:inodes-newdelta2res">
		<xsl:param name="res"/>
		<xsl:param name="soft-delta"/>
		<xsl:param name="hard-delta"/>
		
		<func:result>
			<xsl:variable name="soft" select="$res/soft * $soft-delta"/>
			<xsl:variable name="hard" select="$res/hard * $hard-delta"/>
			<soft><xsl:value-of select="round($soft)"/></soft>
			<hard><xsl:value-of select="round($hard)"/></hard>
		</func:result>
	
	</func:function>
	
	
	<func:function name="local:get-voc"> 		
		<xsl:param name="hn-eid"/>
 		<xsl:variable name="args">
			<category>quota</category>
		</xsl:variable>
		<func:result select="voc:get($args, env:make-platform-ref($hn-eid))"/>
 	</func:function> 

	<sw:include href="/lib/vza/hwm.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	
</xsl:stylesheet>
