<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred func action env vzenv"
	xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:sw			="http://www.swsoft.com/xsl/cp"
	xmlns:action	="http://www.swsoft.com/xsl/cp/action"		
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"
	xmlns:cred  	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:func		="http://exslt.org/functions"	
	xmlns:env			="http://www.swsoft.com/xsl/cp/env"
	xmlns:global			="http://www.swsoft.com/xsl/cp/global"	
	xmlns:vzenv			="http://www.swsoft.com/xsl/cp/vzenv"
>
	<sw:include href="/lib/core/action-funcs.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vz/vzenv-core.xsl"/>
	<sw:include href="/lib/common.xsl"/>

	<xsl:output method="xml"/>
	
	<!-- Migrate specifed VE(s)	
		/data
			/migrate
				/hn
					src
					dst
				/options
					/zero=''|1
					/clean=''|1
					/notstart=''|1
					/force=''|1
			/hn
				eid
				hostname
			/env
				eid
				hostname
				hn-eid
				num-id
		
	-->
	<xsl:template match="/">
	
		<xsl:variable name="data" select="/data"/>
		<xsl:variable name="env-eids" select="/data/env/eid"/>
	
		<xsl:if test="action:start('relocator.migrate_v2v', $env-eids)"/>
				
		<xsl:for-each select="/data/env">
			<xsl:variable name="env" select="."/>
			<xsl:variable name="env-info" select="env:get-env($env/eid)/env"/> 
			<xsl:variable name="title" select="env:env2title($env-info)"/> 
			
			<xsl:choose>
				<!-- Skin VE in transition -->
				<xsl:when test="$env-info/status/transition!='' and $env-info/status/transition!=$env-trans/none">
					<xsl:if test="action:log-env-error(
						'Can not migrate Container in transition state',
						'relocator.migrate_v2v',
						$env/eid,
						$global:task-failed,
						$env-info/status
					)"/>
				</xsl:when>
				<!-- Run migration-->
				<xsl:when test="not(
					action:run-child(local:migrate($data,$env),concat('Migrate Container ',$title),'relocator.migrate_v2v',$env/eid)
				)"/>				
			</xsl:choose>
		</xsl:for-each>
		
		<xsl:copy-of select="action:complete('relocator.migrate_v2v', $env-eids)"/>
	</xsl:template>
	
	<func:function name="local:migrate">
		<xsl:param name="data"/>
		<xsl:param name="env"/>
		
		<xsl:variable name="road" select="/data/migrate/hn[src=$env/hn-eid]"/>
		
		<func:result>
			<packet log="on" type="16">
				<target>relocator</target>
        <cookie>
          <operation>xsl-child.relocator_migrate_v2v</operation>
        </cookie>			
				<data>
					<relocator>
						<migrate_v2v>
							<eid_list>
								<xsl:copy-of select="$env/eid"/>
							</eid_list>
							<dst>
								<protocol>agent</protocol>
								<address><xsl:value-of select="$road/dst"/></address>
							</dst>
							<options>
								<xsl:if test="$data/migrate/options/zero=1">
									<type>3</type>
								</xsl:if>
								<xsl:if test="$data/migrate/options/clean=1">
									<remove/>
								</xsl:if>
								<xsl:if test="$data/migrate/options/notstart=1">
									<nostart/>
								</xsl:if>
								<xsl:if test="$data/migrate/options/force=1">
									<force/>
								</xsl:if>
							</options>
						</migrate_v2v>
					</relocator>
				</data>
			</packet>
		</func:result>
	</func:function>
	
		
</xsl:stylesheet>
