<!--
		 Copyright (c) SWsoft, 1999-2007
		 All rights reserved.
	-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred env vzenv func action voc"
	xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:sw			="http://www.swsoft.com/xsl/cp"
	xmlns:action	="http://www.swsoft.com/xsl/cp/action"
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"
	xmlns:cred  	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:voc  		="http://www.swsoft.com/xsl/cp/voc"
	xmlns:env  		="http://www.swsoft.com/xsl/cp/env"
	xmlns:vt  		="http://www.swsoft.com/xsl/cp/vt"
	xmlns:res  	="http://www.swsoft.com/xsl/cp/res"	
	xmlns:vzenv  	="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:func		="http://exslt.org/functions"	
 	xmlns:vzve	="http://www.swsoft.com/xsl/cp/vzve"	
>
	<sw:include href="/lib/core/action-funcs.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vz/res-funcs.xsl"/>	
	<sw:include href="/lib/vz/vzenv-qos.xsl"/>
	<sw:include href="/lib/vz/vzenv-core.xsl"/>

	<xsl:output method="xml"/>
	
	<!--
		/data
			/platform
			/env
				/eid
				/hostname				
				/num-id
			/res
				/slm-method
				/data
					/res
						/id
						/soft
						/hard
						/action
	-->
	<xsl:template match="/">
	
		<xsl:variable name="envs" select="/data/env"/>
		<xsl:variable name="data" select="/data"/>
	
		<xsl:if test="action:start('ve.groupchange.res', $envs/eid)"/>
		
		<xsl:variable name="env-data-list" select="env:get-env($envs/eid)"/>

		<xsl:for-each select="$envs">
			
			<xsl:variable name="env-info" select="."/>
			<xsl:variable name="env-data" select="$env-data-list/env[eid=$env-info/eid]"/>
			<xsl:variable name="voc" select="local:get-voc($env-data/parent_eid)"/>
			
			<xsl:choose>
				<xsl:when test="not(
					action:run-child(local:set($data,$env-info/eid,$env-data,$voc),
						concat('Change resources settingd for Container ',env:env2title($env-data))
					,'vzaenvm.set',.)
				)"/>	
			</xsl:choose>
		</xsl:for-each>
		<xsl:copy-of select="action:complete('ve.groupchange.res', $envs/eid)"/>

	</xsl:template>
	
	<func:function name="local:set">
		<xsl:param name="data"/>
		<xsl:param name="eid"/>
		<xsl:param name="env-data"/>
		<xsl:param name="voc"/>
		
		<xsl:variable name="is-linux" select="vt:is-platform-linux($data/platform)"/>
				
		<xsl:variable name="new-res-rtf">
			<xsl:for-each select="$data/res/data/res">
				<xsl:variable name="id" select="string(id)"/>	
				<xsl:variable name="res-curr" select="$env-data/virtual_config/qos[id=$id]"/>
				<qos>
					<id><xsl:value-of select="id"/></id>
					<xsl:choose>
						<!-- Set new values -->					
						<xsl:when test="action='limited' or action='unlimited'">
							<xsl:if test="soft!=''">
								<soft><xsl:value-of select="soft"/></soft>
							</xsl:if>
							<hard><xsl:value-of select="hard"/></hard>
						</xsl:when>
						<!-- Increase -->
						<xsl:when test="action='increase'">
							<xsl:if test="soft!=''">
								<soft>
									<xsl:value-of select="local:increase-res(soft,res:param2soft($voc[id=$id]/max),$res-curr/soft)"/>
								</soft>
							</xsl:if>
							<hard>
								<xsl:value-of select="local:increase-res(hard,res:param2hard($voc[id=$id]/max),$res-curr/hard)"/>
							</hard>
						</xsl:when>
						<!-- Decrease -->
						<xsl:when test="action='decrease'">
							<xsl:if test="soft!=''">
								<soft>
									<xsl:value-of select="local:decrease-res(soft,res:param2soft($voc[id=$id]/min),$res-curr/soft)"/>
								</soft>
							</xsl:if>
							<hard>
								<xsl:value-of select="local:decrease-res(hard,res:param2hard($voc[id=$id]/min),$res-curr/hard)"/>
							</hard>
						</xsl:when>
					</xsl:choose>
				</qos>
			</xsl:for-each>
		</xsl:variable>		
		
		<func:result>
			<packet log="on">
				<target>vzaenvm</target>
				<xsl:copy-of select="sw:hn-dst($eid)"/>
        <cookie>
          <operation>xsl-child.set_ve</operation>
        </cookie>			
				<data>
					<vzaenvm>
						<set>
							<eid><xsl:value-of select="$eid"/></eid>
							<set_mode>restart</set_mode>
							<config>
								<xsl:if test="$is-linux and $data/res/slm-mode!=''">
									<slm_mode><xsl:value-of select="$data/res/slm-mode"/></slm_mode>
								</xsl:if>			
								<xsl:copy-of select="$new-res-rtf"/>
							</config>
						</set>
					</vzaenvm>
				</data>
			</packet>
		</func:result>
	</func:function>

	<func:function name="local:increase-res"> 		
		<xsl:param name="delta"/>	
		<xsl:param name="max"/>			
		<xsl:param name="curr"/>
		
		<xsl:choose>
			<xsl:when test="not($max!='')">	
				<func:result select="$curr + $delta"/>
			</xsl:when>
			<xsl:when test="($max - $curr) &lt; $delta">	
				<func:result select="$max"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="format-number($curr + $delta,'#')"/>
			</xsl:otherwise>
		</xsl:choose>
		
	</func:function>

	<func:function name="local:decrease-res"> 		
		<xsl:param name="delta"/>	
		<xsl:param name="min"/>			
		<xsl:param name="curr"/>
		
		<xsl:choose>
			<xsl:when test="not($min!='') and ($curr &lt;= $delta)">	
				<func:result select="1"/>
			</xsl:when>
			<xsl:when test="$min!='' and ($curr &lt;= $delta)">	
				<func:result select="$min"/>
			</xsl:when>
			<xsl:otherwise>	
				<func:result select="format-number($curr - $delta,'#')"/>
			</xsl:otherwise>
		</xsl:choose>
		
	</func:function>
	
	<func:function name="local:get-voc"> 		
		<xsl:param name="hn-eid"/>
		<func:result select="vzve:voc-qos(env:make-platform-ref($hn-eid))"/>
 	</func:function> 

	<sw:include href="/lib/common.xsl"/>
	
</xsl:stylesheet>
