<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred hwm func action ips xsi"
  xmlns:xsi     ="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:sw			="http://www.swsoft.com/xsl/cp"
	xmlns:action	="http://www.swsoft.com/xsl/cp/action"
	xmlns:authm		="http://www.swsoft.com/xsl/cp/authm"	
	xmlns:hwm			="http://www.swsoft.com/xsl/cp/hwm"
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"
	xmlns:cred  	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:func		="http://exslt.org/functions"	
	xmlns:ips			="http://www.swsoft.com/xsl/cp/ips"
	xmlns:vzenv		="http://www.swsoft.com/xsl/cp/vzenv"		
	xmlns:vzarelocator	="http://www.swsoft.com/webservices/vza/4.0.0/vzarelocator"		
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
>

	<!-- Import required modules -->
	<sw:include href="/lib/swa/authm.xsl"/>	
	<sw:include href="/lib/core/action-funcs.xsl"/>	
	<sw:include href="/lib/vz/ips.xsl"/>
	<sw:include href="/lib/vz/vzenv-net-core.xsl"/>	
	<!-- Import required modules -->

	<xsl:output method="xml"/>
		
	<!--
		/data
			/hn
				/eid
				/platform
			/ve
				name
				hostname,...
				net
			/ve-qos
				<res>..
			/start[1,0]
			/node
				/connect-id
				/stop-services
					/srv
				/ip
				/user
				/password
				/exclude-paths
				/distr
				/quota
					/partition
		 /ve-other/*
	-->
	<xsl:template match="/">
	
		<xsl:variable name="data" select="/data"/>
	
		<xsl:if test="action:start('vzarelocator.migrate_p2v','')"/>

		<xsl:variable name="eid" select="local:import-ve($data)"/>			
		<xsl:if test="sw:sesputstr('local-eid',$eid)"/>

		<xsl:choose>

			<!-- Check error after VPS importing -->
			<xsl:when test="error:has-errors()">	
			</xsl:when>				
						
			<!-- Set Root Password -->
			<xsl:when test="not(
				action:run-child(local:set-ve-password($data,$eid),'Set Container Root Password','vzenmv.set',$eid)
			)"/>	
			
			<!-- Clean&(or)Stop Node -->
			<xsl:when test="not(
				action:run-child(local:cleanup-node($data),'Clean up Server','system.uninstall')
			)"/>

			<!-- Stop Node -->
			<!--
			<xsl:when test="$data/start='1' and not(
				action:run-child(local:stop-node($data),'Stop server','hwm.shutdown')
			)"/>
			-->
		
			<!-- Start VE -->
			<xsl:when test="$data/start='1' and not(
				action:run-child(local:start-ve($data/hn/eid,$eid),'Start Container','vzaenvm.start',$eid)
			)"/>
		</xsl:choose>
		
		<!-- Clean up-->
		<!-- commented, wait VZA #48774 resolving  -->
		<!--
		<xsl:if test="
				action:run-child(local:uninstall($data),'Clean up server','system.uninstall')
		"/>
		-->
		
		<xsl:copy-of select="action:complete('vzarelocator.migrate_p2v', $eid)"/>

	</xsl:template>

	
	
	<func:function name="local:start-ve">
		<xsl:param name="hn-eid"/>
		<xsl:param name="eid"/>
		<func:result>
			<packet log="on">
				<target>vzaenvm</target>
				<xsl:copy-of select="sw:env-dst($hn-eid)"/>
        <cookie>
          <operation>xsl-child.start_ve</operation>
        </cookie>			
				<data>
					<vzaenvm>
						<start>
							<eid><xsl:value-of select="$eid"/></eid>
						</start>
					</vzaenvm>
				</data>
			</packet>
		</func:result>
	</func:function>

	<func:function name="local:stop-node">
		<xsl:param name="data"/>
		<func:result>
			<packet log="on">
				<target>hwm</target>
				<dst>
					<host><xsl:value-of select="$data/node/connect-id"/></host>
				</dst>
        <cookie>
          <operation>xsl-child.hwm.shutdown</operation>
        </cookie>			
				<data>
					<hwm>
						<reboot>
							<shutdown/>
						</reboot>
					</hwm>
				</data>
				<vzcpauth/>
			</packet>
		</func:result>
	</func:function>

	<func:function name="local:cleanup-node">
		<xsl:param name="data"/>
		<func:result>
			<packet log="on" progress="on">
				<target><xsl:value-of select="$data/node/connect-id"/></target>
				<dst>
					<target>system</target>
				</dst>
        <cookie>
          <operation>xsl-child.system.uninstall</operation>
        </cookie>			
				<data>
					<system>
						<uninstall>
							<xsl:if test="$data/start='1'">
								<shutdown/>
							</xsl:if>
						</uninstall>
					</system>					
				</data>
				<vzcpauth/>
			</packet>
		</func:result>
	</func:function>

	<func:function name="local:set-ve-password">
		<xsl:param name="data"/>
		<xsl:param name="eid"/>
		<func:result>
			<packet log="on">
				<target>vzaenvm</target>
				<xsl:copy-of select="sw:env-dst($data/hn/eid)"/>				
        <cookie>
          <operation>xsl-child.set_ve</operation>
        </cookie>			
				<data>
					<vzaenvm>
						<set_user_password>
							<eid><xsl:value-of select="$eid"/></eid>
							<name><xsl:value-of select="$data/node/user"/></name>
							<password><xsl:value-of select="sw:base64-encode($data/node/password)"/></password>
						</set_user_password>
					</vzaenvm>
				</data>
				<vzcpauth/>
			</packet>
		</func:result>
	</func:function>

	
	<func:function name="local:import-ve">
		<xsl:param name="data"/>

		<xsl:variable name="packet">
			<packet log="on" 
				xmlns:ns1="http://www.swsoft.com/webservices/vzl/4.0.0/types"
				xmlns:xsi					="http://www.w3.org/2001/XMLSchema-instance" 			
				xmlns:vzarelocator	="http://www.swsoft.com/webservices/vza/4.0.0/vzarelocator"	
			>
				<target>vzarelocator</target>
				<xsl:copy-of select="sw:env-dst($data/hn/eid)"/>
        <cookie>
          <operation>xsl-child.import_ve</operation>
        </cookie>			
				<data>
					<vzarelocator>
						<migrate_p2v>
							<src xsi:type="ns1:connection_infoType">
								<address><xsl:value-of select="$data/node/ip"/></address>
								<login	xsi:type="ns1:auth_nameType">
									<xsl:copy-of select="authm:auth-name($data/node/user)"/>
									<realm>00000000-0000-0000-0000-000000000000</realm>
								</login>
								<password><xsl:value-of select="sw:base64-encode($data/node/password)"/></password>
							</src>
							<options xsi:type="vzarelocator:p2v_migrate_optionsType">
								<xsl:if test="$data/node/quota/partition!=''">
									<quota>
										<partition>
											<name><xsl:value-of select="$data/node/quota/partition"/></name>
										</partition>
									</quota>
								</xsl:if>
								<xsl:if test="$data/node/exclude-paths/path">
									<exclude>
										<xsl:for-each select="$data/node/exclude-paths/path">
											<path><xsl:value-of select="sw:base64-encode(.)"/></path>
										</xsl:for-each>
									</exclude>
								</xsl:if>
								<xsl:for-each select="$data/node/stop-services/srv">
									<service>
										<name><xsl:value-of select="."/></name>
									</service>
								</xsl:for-each>
								<config>
									<name><xsl:value-of select="$data/ve/name"/></name>
									<xsl:if test="$data/ve/ve_id!=''">																	
										<veid><xsl:value-of select="$data/ve/ve_id"/></veid>						
									</xsl:if>
									<xsl:copy-of select="$data/ve-other/*"/>
									<!--<on_boot>
										<xsl:value-of select="1"/>
									</on_boot>		
									<offline_management>
										<xsl:value-of select="1"/>
									</offline_management>
									<disabled>
										<xsl:value-of select="0"/>
									</disabled>-->
									<hostname><xsl:value-of select="$data/ve/hostname"/></hostname>
									<xsl:if test="$data/ve/os_template/name!=''">
										<os_template>
											<name><xsl:value-of select="$data/ve/os_template/name"/></name>
											<xsl:if test="$data/ve/os_template/version!=''">
												<xsl:copy-of select="$data/ve/os_template/version"/>
											</xsl:if>
										</os_template>
									</xsl:if>
									<distribution>
										<xsl:variable name="distr-info" select="sw:split($data/node/distr,'-','o')"/>
										<name><xsl:value-of select="$distr-info[1]"/></name>
										<xsl:if test="$distr-info[2]!=''">
											<version><xsl:value-of select="$distr-info[2]"/></version>
										</xsl:if>
									</distribution>
									<xsl:for-each select="$data/ve-qos/res">
										<xsl:if test="soft!='' or hard!=''">
											<qos>
												<xsl:copy-of select="id"/>
												<xsl:if test="soft!=''">
													<xsl:copy-of select="soft"/>
												</xsl:if>
												<xsl:if test="hard!=''">
													<xsl:copy-of select="hard"/>
												</xsl:if>
											</qos>
										</xsl:if>
									</xsl:for-each>
									<xsl:copy-of select="vzenv:net2config($data/ve/net,$data/hn/platform)"/>								
									<xsl:for-each select="$data/apps/app">
										<template>
											<name><xsl:value-of select="base"/></name>
											<xsl:copy-of select="version"/>
										</template>
									</xsl:for-each>								
								</config>
							</options>
						</migrate_p2v>
					</vzarelocator>
				</data>
				<vzcpauth/>
			</packet>
		</xsl:variable>
		
		<xsl:variable name="res" select="action:run-child($packet,'Import Container','vzarelocator.migrate_p2v')"/>
		<xsl:variable name="res-eid">
			<xsl:choose>
				<xsl:when	test="not($res)">
					<xsl:value-of	select="''"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of	select="$res/packet/data/vzarelocator/eid"/>				
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<!-- Check creation errors and return EID of the new ENV or empty string in case of errorr -->
		<xsl:choose>
			<xsl:when test="$res-eid!=''">
				<func:result select="$res-eid"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="''"/>
			</xsl:otherwise>
		</xsl:choose>
		
		
	</func:function>
	
	
	<sw:include href="/lib/vza/hwm.xsl"/>
	<sw:include href="/lib/common.xsl"/>
</xsl:stylesheet>
