<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred func action vzenv"
	xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:func		="http://exslt.org/functions"	
	xmlns:sw			="http://www.swsoft.com/xsl/cp"
	xmlns:action	="http://www.swsoft.com/xsl/cp/action"
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"
	xmlns:cred  	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:vzenv	  	="http://www.swsoft.com/xsl/cp/vzenv"
 	xmlns:global		="http://www.swsoft.com/xsl/cp/global"  		
>
	<sw:include href="/lib/core/action-funcs.xsl"/>
	<sw:include href="/lib/utils/action.xsl"/>
	<sw:include href="/lib/vz/vzenv-core.xsl"/>

	<xsl:output method="xml"/>		

	<!--
		/data
	-->
	<xsl:template match="/">
		
		<xsl:variable name="data" select="/data"/>
	
		<xsl:if test="sw:sesput('request-env',/data/env)"/>
		
		<xsl:if test="action:start('ve.multicreate')"/>
		
		<xsl:variable name="creation-result-rtf">
			<xsl:for-each select="$data/multiple-set/ve">			
				<xsl:variable name="ve-info" select="."/>			
				<xsl:variable name="index" select="position()"/>			
				
				<!-- Prepare some VE data -->
				<!-- Prepare VE ID -->
				<xsl:variable name="ve-id">
					<xsl:choose>
						<xsl:when test="$data/multiple/ids-rule='auto'">
							<!-- VZA will assign VE ID -->
						</xsl:when>
						<xsl:when test="$data/multiple/ids-rule='set'">
							<xsl:value-of select="$ve-info/id"/>
						</xsl:when>
						<xsl:when test="$data/multiple/ids-rule='from'">
							<xsl:value-of select="$data/multiple-set/ids-from + $index - 1"/>
						</xsl:when>
						<xsl:otherwise>
							<sw:die>
								Uknown ids-rule '<xsl:value-of select="$data/multiple/ids-rule"/>'
							</sw:die>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>		
				<!-- /Prepare VE ID -->
				<!-- Prepare VE name -->
				<xsl:variable name="ve-name">			
					<xsl:choose>					
						<xsl:when test="$data/multiple/names-rule='set'">
							<xsl:value-of select="$ve-info/name"/>
						</xsl:when>
					</xsl:choose>
				</xsl:variable>
				<!-- /Prepare VE name -->
				<!-- Prepare VE hostname -->
				<xsl:variable name="ve-hostname">			
					<xsl:choose>
						<xsl:when test="$data/multiple/hostnames-rule='set'">
							<xsl:value-of select="$ve-info/hostname"/>
						</xsl:when>
					</xsl:choose>
				</xsl:variable>
				<!-- /Prepare VE hostname -->
				<!-- /Prepare some VE data -->
				
				<!-- Prepare data for single creation -->
				<xsl:variable name="ve-data-rtf">
					<xsl:copy-of select="$data/*[
						not(self::multiple-set or self::multiple or self::gen or self::net)
					]"/>
					<!-- Inject some gen settings -->
					<gen>
						<xsl:copy-of select="$data/gen/*[
							not(self::hostname or self::name or self::ask_veid or self::ve_id)
						]"/>
						<!-- Inject name -->
						<xsl:if test="$ve-name!=''">
							<name>
								<xsl:value-of select="$ve-name"/>
							</name>
						</xsl:if>
						<!-- /Inject name -->
						<!-- Inject VE ID -->
						<xsl:if test="$ve-id!=''">
							<ve_id><xsl:value-of select="$ve-id"/></ve_id>
							<ask_veid>1</ask_veid>
						</xsl:if>
						<!-- /Inject VE ID -->
					</gen>
					<!-- /Inject some gen settings -->
					<net>
						<!-- Inject hostname -->
						<xsl:if test="$ve-hostname!=''">
							<hostname>
								<xsl:value-of select="$ve-hostname"/>
							</hostname>
						</xsl:if>
						<!-- /Inject hostname -->
						<xsl:call-template name="local:post-net">
							<xsl:with-param name="data" select="$data"/>
							<xsl:with-param name="ve-index" select="$index"/>							
						</xsl:call-template>
					</net>
					<!-- Inject some net settings -->				
					
					<!-- /Inject some net settings -->								
				</xsl:variable>
				<!-- /Prepare data for single creation -->
				
				<!-- Send packet -->
				<xsl:variable name="res" select="action:run-child(
					local:create-ve-packet(
						$data,$ve-data-rtf
					),'Create Container','vzaenvm.create'
				)"/>
				<xsl:choose>
					<xsl:when test="$res[self::error]">
						<xsl:copy-of select="$res"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="$res/data/eid"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Send packet -->
				
			</xsl:for-each>
		</xsl:variable>
		
		<xsl:variable name="creation-result" select="exsl:node-set($creation-result-rtf)"/>
		<xsl:variable name="result-status" select="sw:if($creation-result/error,$global:task-failed,$global:task-completed)"/>
		<xsl:copy-of select="action:complete('ve.multicreate', $creation-result/eid, /.., $result-status)"/>

	</xsl:template>
	
	<xsl:template name="local:post-net">
		<xsl:param name="data"/>
		<xsl:param name="ve-index"/>
		<xsl:copy-of select="$data/net/*[not(self::routed or self::bridged)]"/>
		<routed>
			<xsl:copy-of select="$data/net/routed/*[self::enabled or self::id]"/>		
			<xsl:for-each select="$data/net/routed">
				<xsl:if test="enabled='true'">
					<xsl:copy-of select="*[not(self::ips or self::ip-rule or self::ve-ip or self::id or self::first-ip)]"/>
					<!-- Transform IP rule to IP address -->
					<xsl:choose>
						<!-- Get IP from Global IP Pool -->
						<xsl:when test="ip-rule='pool'">
							<ips>
								<ip>
									<address><xsl:value-of select="$def-ip-auto-vzcp"/></address>
									<netmask><xsl:value-of select="$global:ip-default-netmask"/></netmask>
								</ip>
							</ips>
						</xsl:when>
						<!-- Get IP from custom range -->
						<xsl:when test="ip-rule='range'">
							<ips>
								<ip>
									<address><xsl:value-of select="sw:number2ip(sw:ip2number(first-ip/address)+$ve-index - 1)"/></address>
									<netmask><xsl:value-of select="first-ip/netmask"/></netmask>
								</ip>
							</ips>
						</xsl:when>
						<!-- Set IP manually -->
						<xsl:when test="ip-rule='set'">
							<ips>
								<ip>
									<xsl:copy-of select="ve-ip[position()=$ve-index]/*"/>
								</ip>
							</ips>
						</xsl:when>
					</xsl:choose>
				</xsl:if>
			</xsl:for-each>
		</routed>
		<bridged>
			<xsl:copy-of select="$data/net/bridged/enabled"/>				
			<xsl:variable name="ip-rule" select="$data/net/bridged/ip-rule"/>
			<xsl:for-each select="$data/net/bridged[enabled='true']/iface">
				<xsl:variable name="iface-index" select="position()"/>
				<iface>
					<xsl:copy-of select="*[not(self::ips or self::ve-ip)]"/>
					<!-- Transform IP rule to IP address -->
					<xsl:choose>
						<!-- Get IP from Global IP Pool -->
						<xsl:when test="$ip-rule='dhcp'">
							<dhcp>true</dhcp>
						</xsl:when>	
						<!-- Get IP from Global IP Pool -->
						<xsl:when test="$ip-rule='pool'">
							<ips>
								<ip>
									<address><xsl:value-of select="$def-ip-auto-vzcp"/></address>
									<netmask><xsl:value-of select="$global:ip-default-netmask"/></netmask>
								</ip>
							</ips>
						</xsl:when>
						<!-- Get IP from custom range -->
						<xsl:when test="$ip-rule='range'">
							<ips>
								<ip>
									<address><xsl:value-of select="sw:number2ip(sw:ip2number(first-ip/address)+$ve-index - 1)"/></address>
									<netmask><xsl:value-of select="first-ip/netmask"/></netmask>
								</ip>
							</ips>
						</xsl:when>
						<!-- Set IP manually -->
						<xsl:when test="$ip-rule='set'">
							<ips>
								<ip>
									<xsl:copy-of select="ve-ip[position()=$ve-index]/*"/>
								</ip>
							</ips>
						</xsl:when>
					</xsl:choose>
				</iface>
			</xsl:for-each>
		</bridged>
	</xsl:template>
	
	
	<func:function name="local:create-ve-packet">
		<xsl:param name="request-data"/>
		<xsl:param name="ve-data-rtf"/>
		
		<func:result>
			<xsl:call-template name="action:make-packet">
				<xsl:with-param name="ticket-param" select="$request-data/env/ticket"/>
				<xsl:with-param name="client-ip-param" select="$request-data/env/client-ip"/>
				<xsl:with-param name="run-async" select="false()"/>
				<xsl:with-param name="path" select="'actions/vzdir/infrman/envs/create.xsl'"/>
				<xsl:with-param name="cookie">
					<msg>
						<sched><sw:text>The creation of the Container(s) has been scheduled.</sw:text></sched>
						<error><sw:text>Failed to create the Container.</sw:text></error>
					</msg>
					<operation>ve_create</operation>
					<redirect-prev/>
				</xsl:with-param>
				<xsl:with-param name="input">
					<data>
						<xsl:copy-of select="$ve-data-rtf"/>
						<xsl:copy-of select="$request-data/env"/>					
						<multiple>
							<xsl:if test="$request-data/multiple/hostnames-rule='mask'">
								<hostname-template>
									<xsl:value-of select="$request-data/multiple-set/hostname"/>
								</hostname-template>
							</xsl:if>
							<xsl:if test="$request-data/multiple/names-rule='mask'">
								<name-template>
									<xsl:value-of select="$request-data/multiple-set/name"/>
								</name-template>
							</xsl:if>
						</multiple>
					</data>
				</xsl:with-param>
			</xsl:call-template>
		</func:result>
	</func:function>

	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/globals.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	
</xsl:stylesheet>
