<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred hwm env func action"
	xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:sw			="http://www.swsoft.com/xsl/cp"
	xmlns:action	="http://www.swsoft.com/xsl/cp/action"
	xmlns:hwm			="http://www.swsoft.com/xsl/cp/hwm"
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"
	xmlns:cred  	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:env  	="http://www.swsoft.com/xsl/cp/env"
	xmlns:func		="http://exslt.org/functions"	
>

	<sw:include href="/lib/core/action-funcs.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>

	<xsl:output method="xml"/>
	
	<!--
		/data
			/eid
			/data-oper (reinstall or preserve)
			/password-oper (reset or reset)
			/password
		
	-->
	<xsl:template match="/">
	
		<xsl:variable name="eid" select="data/eid"/>
		<xsl:variable name="data" select="/data"/>
		<xsl:variable name="old-env" select="env:get-env($eid,'status')/env"/>
		<xsl:variable name="ve-id" select="$old-env/virtual_config/veid"/>
		<xsl:variable name="was-running" select="$old-env/status[state=$env-state/running]"/>
		<xsl:variable name="old-state" select="$old-env/status/state"/> 
	
		<xsl:if test="action:start('ve.reinstall', $eid)"/>
		
		<!-- Stop VE -->
		<xsl:if test="$was-running">
			<xsl:if test="action:run-child(local:stop-ve($eid),'Stop Container','vzaenvm.stop',$eid)"/>	
		</xsl:if>
		
		<!-- Unmount mounted stopped VE -->
		<xsl:if test="$old-state='mounted'">
			<xsl:if test="action:run-child(local:unmount-ve($eid),concat('Unmount Container #',$ve-id),'vem.unmount',$eid)"/>	
		</xsl:if>
		
		<!-- Reinstall VE -->
		<xsl:if test="action:run-child(local:reinstall-ve($eid,$data),'Reinstall Container','vem.reinstall',$eid)"/>	
		
		<!-- Start VE -->
		<xsl:if test="$was-running">
			<xsl:if test="action:run-child(local:start-ve($eid),'Start Container','vzaenvm.start',$eid)"/>	
		</xsl:if>
	
		<xsl:copy-of select="action:complete('ve.reinstall', $eid)"/>
		
	</xsl:template>

	<func:function name="local:reinstall-ve">
		<xsl:param name="eid" />
		<xsl:param name="data" />
		<func:result>
			<packet log="on">
				<target>vzaenvm</target>
				<xsl:copy-of select="sw:hn-dst($eid)" />
				<cookie>
					<operation>recover_template</operation>
				</cookie>
				<data>
					<vzaenvm>
						<recover_template>
							<eid><xsl:value-of select="$eid"/></eid>
							<xsl:if test="$data/password-oper='reset'">
								<password><xsl:value-of select="sw:base64-encode($data/password)"/></password>
							</xsl:if>
							<xsl:choose>
								<xsl:when test="$data/data-oper = 'reinstall'">
									<clean/>
									<skipbackup/>
								</xsl:when>
								<xsl:when test="$data/data-oper = 'preserve'">
									<clean/>
								</xsl:when>
							</xsl:choose>
							<xsl:for-each select="$data/custom-scripts-selected/id">
								<script>
									<xsl:value-of select="sw:base64-decode(.)"/>
								</script>
							</xsl:for-each>
						</recover_template>
					</vzaenvm>
				</data>
			</packet>
		</func:result>
	</func:function>

	<func:function name="local:stop-ve">
		<xsl:param name="eid"/>
		<func:result>
			<packet log="on">
				<target>vzaenvm</target>
				<xsl:copy-of select="sw:hn-dst($eid)"/>
        <cookie>
          <operation>xsl-child.stop_ve</operation>
        </cookie>			
				<data>
					<vzaenvm>
						<stop>
							<eid><xsl:value-of select="$eid"/></eid>
						</stop>
					</vzaenvm>
				</data>
			</packet>
		</func:result>
	</func:function>
	
	<func:function name="local:unmount-ve">
		<xsl:param name="eid"/>
		<func:result>
			<packet log="on">
				<target>vzaenvm</target>
				<xsl:copy-of select="sw:hn-dst($eid)"/>
        <cookie>
          <operation>xsl-child.unmount_ve</operation>
        </cookie>			
				<data>
					<vzaenvm>
						<umount>
							<eid><xsl:value-of select="$eid"/></eid>
						</umount>
					</vzaenvm>
				</data>
			</packet>
		</func:result>
	</func:function>
		
	<func:function name="local:start-ve">
		<xsl:param name="eid"/>
		<func:result>
			<packet log="on">
				<target>vzaenvm</target>
				<xsl:copy-of select="sw:hn-dst($eid)"/>
        <cookie>
          <operation>xsl-child.start_ve</operation>
        </cookie>			
				<data>
					<vzaenvm>
						<start>
							<eid><xsl:value-of select="$eid"/></eid>
						</start>
					</vzaenvm>
				</data>
			</packet>
		</func:result>
	</func:function>

	<sw:include href="/lib/vza/hwm.xsl"/>
	<sw:include href="/lib/common.xsl"/>
</xsl:stylesheet>
