<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl action func networkm vznet"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" 
	xmlns:action="http://www.swsoft.com/xsl/cp/action"
	xmlns:networkm="http://www.swsoft.com/xsl/cp/networkm"
	xmlns:local="http://www.swsoft.com/xsl/cp/local" 
	xmlns:func="http://exslt.org/functions"
	xmlns:vznet="http://www.swsoft.com/xsl/cp/vznet"
>

	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/core/action-funcs.xsl"/>	
	<sw:include href="/lib/vz/vznet-vn.xsl"/>

	<!--
		/data/vn-info
					|_network_id
					|_description
					|_conn_type
					|_interface
					|_network_type
		/data/hn-info - see env:eid2info
	-->
	<xsl:template match="/">
		<xsl:variable name="vn-info" select="/data/vn-info"/>
		<xsl:variable name="hn-info" select="/data/hn-info"/>

		<xsl:if test="action:start('vn.add',$hn-info/eid)"/>
		<xsl:variable name="msg">
			<sw:text>
				<xsl:with-param name="title" select="$vn-info/network_id"/>
				Creating virtual network '%{title}'
			</sw:text>
		</xsl:variable>
		<xsl:if test="action:log-message($msg,'vn.add',$hn-info/eid)"/>		
		<xsl:variable name="result-rtf">
			<xsl:choose>
				<xsl:when test="$vn-info/conn_type = $vznet:not-connected">
					<xsl:copy-of select="vznet:add-vn($vn-info)/*"/>
				</xsl:when>
				<xsl:when test="$vn-info/conn_type = $vznet:connected-switch">
					<xsl:copy-of select="vznet:add-vn-bridged($hn-info/eid,$vn-info)/*"/>
				</xsl:when>
				<xsl:when test="$vn-info/conn_type = $vznet:connected-iface">
					<xsl:copy-of 
						select="vznet:add-vn-connected($hn-info/eid,$vn-info,$vn-info/interface,$hn-info/linux)/*"/>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="result" select="exsl:node-set($result-rtf)"/>
		<xsl:if test="$result/error">
			<xsl:if test="action:log-error($result/error,'vn.add',$hn-info/eid)"/>
		</xsl:if>
		<xsl:copy-of select="action:complete('vn.add',$hn-info/eid)"/>
	</xsl:template>
</xsl:stylesheet>
