<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
	extension-element-prefixes="sw exsl action func networkm"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" 
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" 
	xmlns:action="http://www.swsoft.com/xsl/cp/action"
	xmlns:networkm="http://www.swsoft.com/xsl/cp/networkm"
	xmlns:vznet="http://www.swsoft.com/xsl/cp/vznet" 
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:func="http://exslt.org/functions"
	xmlns:vza_networkm="http://www.swsoft.com/webservices/vzl/4.0.0/networkm"
>

	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/core/action-funcs.xsl"/>	
	<sw:include href="/lib/vza/networkm.xsl"/>
	<sw:include href="/lib/vz/vznet-core.xsl"/>

	<!--
		/data
			/hw_id
			/network
				/network_id
			/network
				/network_id
			...
	-->
	<xsl:template match="/">
		<xsl:variable name="hw_id" select="/data/hw_id"/>
		<xsl:variable name="vn-list" select="/data/network/network_id"/>
		<xsl:variable name="all-interfaces" select="vznet:list-devices($hw_id,/..)"/>

		<xsl:if test="action:start('vn.disconnect', $vn-list)"/>
		<xsl:for-each select="/data/network">
			<xsl:variable name="network_id" select="sw:base64-encode(network_id)"/>
			<xsl:for-each
				select="$all-interfaces[(sw:split(@xsi:type,':')[last()] = 'net_nicType' or sw:split(@xsi:type,':')[last()] = 'net_vlanType') and network_id = $network_id]">
				<xsl:if
					test="action:run-child(local:disconnect-device($hw_id,.),concat('Disconnect interface #',id),'networkm.disconnect',id)"
				/>
			</xsl:for-each>
			<xsl:for-each
				select="$all-interfaces[sw:split(@xsi:type,':')[last()] = 'net_bridgeType' and network_id = $network_id]">
				<!-- TODO make interface uniform, there should not be additional variable -->
				<xsl:variable name="dev_to_delete">
					<vza_networkm:net_device xsi:type="vza_networkm:net_bridgeType">
						<id>
							<xsl:value-of select="id"/>
						</id>
						<network_id>
							<xsl:value-of select="sw:base64-decode($network_id)"/>
						</network_id>
					</vza_networkm:net_device>
				</xsl:variable>
				<xsl:if
					test="action:run-child(
							local:delete-device($hw_id,exsl:node-set($dev_to_delete)),
												concat('Disconnect network ',sw:base64-decode($network_id)),
							'networkm.delete',id)"
				/>
			</xsl:for-each>
		</xsl:for-each>
		<xsl:copy-of select="action:complete('vn.disconnect', $hw_id)"/>
	</xsl:template>

	<func:function name="local:delete-device">
		<xsl:param name="hw_id"/>
		<xsl:param name="device"/>
		<func:result select="exsl:node-set(networkm:cmd-delete($hw_id,$device))"/>
	</func:function>

	<func:function name="local:disconnect-device">
		<xsl:param name="hw_id"/>
		<xsl:param name="device"/>
		<func:result select="exsl:node-set(networkm:cmd-disconnect($hw_id,$device))"/>
	</func:function>
</xsl:stylesheet>
