<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred vz func action"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" 
	xmlns:action="http://www.swsoft.com/xsl/cp/action"
	xmlns:local="http://www.swsoft.com/xsl/cp/local" 
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:func="http://exslt.org/functions"
	xmlns:vz="http://www.swsoft.com/xsl/cp/vz"
	xmlns:vzapackagem="http://www.swsoft.com/xsl/cp/vzapackagem"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:vzhn="http://www.swsoft.com/xsl/cp/vzhn"
	xmlns:templates="http://www.swsoft.com/xsl/cp/templates"
>
	
	<sw:include href="/lib/common.xsl" />
	<sw:include href="/lib/core/action-funcs.xsl"/>	
	<sw:include href="/lib/vz/apps.xsl" />
	<sw:include href="/lib/vt/env-core.xsl" />
	<sw:include href="/lib/vz/vzhn-core.xsl" />
	<sw:include href="/lib/vza/vzapackagem.xsl" />
	<sw:include href="/lib/vzdir/infrman/templates/group-actions.xsl"/>
	
	<xsl:output method="xml" />
	
	<!--
		/data
			/eid
			/app
				/id
				/platform
				/..
	-->
	<xsl:template match="/">
		<xsl:if test="action:start('apps.uninstall.group', /data/eid)" />
		
		<xsl:variable name="results">
			<xsl:for-each select="/data/eid">
				<xsl:variable name="ve" select="env:get-env(.)/env" />
				
				<xsl:variable name="message">
					Uninstalling templates from VE <xsl:value-of select="env:env2title($ve)" />
				</xsl:variable>
				<xsl:if test="action:log-message($message,'apps.uninstall.group', .)" />

				<xsl:for-each select="/data/app">
					<xsl:call-template name="local:process-app">
						<xsl:with-param name="app" select="."/>
						<xsl:with-param name="ve" select="$ve"/>
					</xsl:call-template>
				</xsl:for-each>
			</xsl:for-each>
		</xsl:variable>
		
		<xsl:copy-of select="action:complete('apps.uninstall.group', /data/eid)" />
	</xsl:template>

	<!-- Create packets metadata -->
	<xsl:template name="local:process-app">
		<xsl:param name="app"/>
		<xsl:param name="ve"/>
		
		<xsl:variable name="package" select="vzapackagem:id2package($app/id)"/>


		<xsl:apply-templates mode="results"
			select="templates:run-child(local:action($app, $ve), 
					sw:if(vzapackagem:is-os($package), 
						'Uninstall OS Template', 
						'Uninstall Application Template'), 'vzapackagem.remove', $ve/eid)"/>
	</xsl:template>
	
	<!-- deinstall EZ template -->
	<func:function name="local:action">
		<xsl:param name="app"/>
		<xsl:param name="ve"/>

		<func:result>
			<xsl:call-template name="vzapackagem:action-packet">
				<xsl:with-param name="command" select="'remove'"/>
				<xsl:with-param name="app-id" select="$app/id"/>
				<xsl:with-param name="hn-eid" select="$ve/parent_eid"/>
				<xsl:with-param name="target-eid" select="$ve/eid"/>
				<xsl:with-param name="options">
					<xsl:if test="/data/force">
						<options>
							<force>1</force>
						</options>
					</xsl:if>
				</xsl:with-param>
				<xsl:with-param name="cookie">
					<cookie>
						<operation>xsl-child.tmpl_deinstall</operation>
					</cookie>
				</xsl:with-param>
			</xsl:call-template>
		</func:result>
	</func:function>

</xsl:stylesheet>