<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred vz func action"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:exsl="http://exslt.org/common"
	xmlns:set="http://exslt.org/sets"
	xmlns:sw="http://www.swsoft.com/xsl/cp" 
	xmlns:action="http://www.swsoft.com/xsl/cp/action"
	xmlns:local="http://www.swsoft.com/xsl/cp/local" 
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:func="http://exslt.org/functions"
	xmlns:vz="http://www.swsoft.com/xsl/cp/vz"
	xmlns:vzapackagem="http://www.swsoft.com/xsl/cp/vzapackagem"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:vzhn="http://www.swsoft.com/xsl/cp/vzhn"
	xmlns:templates="http://www.swsoft.com/xsl/cp/templates"
>
	
	<sw:include href="/lib/common.xsl" />
	<sw:include href="/lib/core/action-funcs.xsl"/>	
	<sw:include href="/lib/vz/apps.xsl" />
	<sw:include href="/lib/vza/vzapackagem.xsl" />
	<sw:include href="/lib/vt/env-core.xsl" />
	<sw:include href="/lib/vt/hn-list.xsl" />
	<sw:include href="/lib/vzdir/infrman/templates/group-actions.xsl"/>
	
	<xsl:output method="xml" />
	<xsl:variable name="targets" select="local:get-targets()" />
	
	<func:function name="local:installed">
		<xsl:param name="hn-eid"/>
		
		<func:result select="vz:list-group-templates($hn-eid)/pager/row_set/row/packages"/>
	</func:function>
	

	<!--
		/data
			/eid
			/app
				/id
				/..
	-->
	<xsl:template match="/">
		<xsl:if test="action:start('apps.install-app.group', /data/eid)" />
		
		<xsl:variable name="results">
			<xsl:apply-templates select="set:distinct($targets/hn-eid)" mode="hn-packets">
				<xsl:with-param name="apps" select="/data/app"/>
			</xsl:apply-templates>
		</xsl:variable>

		<xsl:copy-of select="action:complete('apps.install-app.group', /data/eid)" />
	</xsl:template>

	<!-- Create packets metadata -->
	<xsl:template match="hn-eid" mode="hn-packets">
		<xsl:param name="apps"/>
		
		<xsl:variable name="hn" select="env:get-env(.)/env" />
		<xsl:variable name="installed" select="local:installed($hn/eid)" />
				
		<xsl:variable name="message">
			Installing templates to Containers on <xsl:value-of select="env:env2title($hn)" />
		</xsl:variable>
		<xsl:if test="action:log-message($message,'apps.install-app.group', .)" />

		<xsl:call-template name="local:process-apps">
			<xsl:with-param name="apps" select="$apps"/>
			<xsl:with-param name="hn" select="$hn"/>
			<xsl:with-param name="installed" select="$installed"/>
		</xsl:call-template>
	</xsl:template>
	
	<!-- Create packets metadata -->
	<xsl:template name="local:process-apps">
		<xsl:param name="apps"/>
		<xsl:param name="hn"/>
		<xsl:param name="installed"/>
		
		<xsl:variable name="installed-ids" select="vzapackagem:generate-ids($installed)"/>
		
		<xsl:for-each select="$apps[not(string(id)=$installed-ids)]">
			<xsl:variable name="message-app">
					Template '<xsl:value-of select="sw:app-id2title(vzapackagem:id2package(id)/name)" />' is not installed on target HN.
				</xsl:variable>
				<xsl:if test="action:log-error($message-app,'apps.install-app.group', $hn/eid)" />
		</xsl:for-each>
		
		
		<!-- send packets per VE -->
		<xsl:for-each select="$targets[hn-eid=$hn/eid]/eid">
			<xsl:variable name="env" select="env:get-env(.)/env"/>
				
			<!-- filter only compatible templates -->
			<xsl:variable name="compatible" select="$apps[string(id)=$installed-ids and local:compatible(id, $env)]"/>
			
			<!-- report uncompatible -->
			<xsl:for-each select="$apps[not(string(id)=$compatible/id)]">
				<xsl:if test="local:report-uncompatible(string(id), $env)"/>			
			</xsl:for-each>			
			
			<!-- install templates -->
			<xsl:if test="$compatible">
				<xsl:apply-templates mode="results"
					select="local:install($compatible, $hn, $env, 'Install Application Templates')"/>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>
	
	<func:function name="local:report-uncompatible">
		<xsl:param name="app-id" />
		<xsl:param name="env" />
		
		<xsl:variable name="message">
			Template '<xsl:value-of select="vzapackagem:id2package($app-id)/name" />' is not compatible with VE <xsl:value-of select="env:env2title($env)" />
		</xsl:variable>
		
		<func:result select="action:log-message($message, 'apps.install-app.group', $env/eid)"/>
	</func:function>
	
	<func:function name="local:compatible">
		<xsl:param name="app-id" />
		<xsl:param name="env" />
		
		<func:result select="vz:compatible-template($app-id, $env)" />
	</func:function>
	
	<func:function name="local:install">
		<xsl:param name="apps" />
		<xsl:param name="hn" />
		<xsl:param name="ve" />
		<xsl:param name="message" />
		
		<func:result select="templates:run-child(local:action($apps, $hn, $ve), $message, 'vzapackagem.install', $ve/eid)" /> 
	</func:function>
	
	<!-- migrate/install EZ template -->
	<func:function name="local:action">
		<xsl:param name="apps" />
		<xsl:param name="hn" />
		<xsl:param name="ve" />
		
		<func:result>
			<xsl:call-template name="vzapackagem:action-packet">
				<xsl:with-param name="command" select="'install'"/>
				<xsl:with-param name="app-id" select="$apps/id"/>
				<xsl:with-param name="hn-eid" select="$hn/eid"/>
				<xsl:with-param name="target-eid" select="$ve/eid"/>
				<xsl:with-param name="cookie">
					<cookie>
						<operation>xsl-child.tmpl_install_app</operation>
					</cookie>
				</xsl:with-param>
			</xsl:call-template>
		</func:result>
	</func:function>
	
	<func:function name="local:get-targets">
		<xsl:variable name="targets-rtf">
			<xsl:for-each select="/data/eid">
				<target>
					<xsl:copy-of select="." />
					<hn-eid><xsl:value-of select="env:get-env(.)/env/parent_eid" /></hn-eid>
				</target>
			</xsl:for-each>
		</xsl:variable>
		<func:result select="exsl:node-set($targets-rtf)/target" />
	</func:function>

</xsl:stylesheet>