<xsl:stylesheet
	version="1.0"
	extension-element-prefixes="sw exsl cred vz func action"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:set="http://exslt.org/sets"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:action="http://www.swsoft.com/xsl/cp/action"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:func="http://exslt.org/functions"
	xmlns:vz="http://www.swsoft.com/xsl/cp/vz"
	xmlns:vzapackagem="http://www.swsoft.com/xsl/cp/vzapackagem"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:vzenv="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:vt="http://www.swsoft.com/xsl/cp/vt"
	xmlns:templates="http://www.swsoft.com/xsl/cp/templates"
	xmlns:vzhn="http://www.swsoft.com/xsl/cp/vzhn"
>

	<xsl:output method="xml"/>

	<sw:include href="/lib/core/action-funcs.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/vz/apps.xsl"/>
	<sw:include href="/lib/vza/vzapackagem.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vz/vzenv-core.xsl"/>
	<sw:include href="/lib/vt/hn-list.xsl"/>
	<sw:include href="/lib/vzdir/infrman/templates/group-actions.xsl"/>
	<!--
		/data
		/hw
		/type
		/local_path
		/remote_path
	-->

	<xsl:template match="/">
		<xsl:variable name="data" select="/data"/>

		<!-- upload template file -->
		<xsl:variable name="remote" select="concat('$SESSION$/', $data/remote_path)"/>
		
		<!-- Copy file to safe place (/tmp)-->
		<xsl:variable name="dst" select="concat($data/local_path, '.copy')"/>
		<xsl:variable name="sve-eid" select="vzenv:sve-eid(sw:master-eid())"/>
		<xsl:variable name="copy-result" select="local:copy-file($data/local_path, $dst, $sve-eid)"/>
		
		<xsl:if test="action:start('hw.apps.app-add',$data/hn)"/>
		
		<xsl:choose>
			<xsl:when test="$copy-result">
				<xsl:if test="sw:sesput('error', $copy-result)"/>
				<xsl:if test="action:log-error($copy-result, 'hw.apps.app-add', $data/hn)"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="action:log-message(sw:text('Uploading template file'), 'hw.apps.app-add', $data/hn)"/>
				<xsl:variable name="res" select="sw:upload-file($dst, $remote, $data/hn)"/>
				<xsl:choose>
					<xsl:when test="$res=''">
						<xsl:variable name="ok">
							<sw:text>The file has been uploaded.</sw:text>
						</xsl:variable>
						<xsl:if test="action:log-message($ok, 'hw.apps.app-add', $data/hn)"/>

						<xsl:apply-templates mode="results"
							select="templates:run-child(local:set($data, $remote), 'Install Template', 'vzapackagem.install',
										$data/hn)"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:message>
							Template upload failed with error: <xsl:value-of select="$res"/>
						</xsl:message>
						<xsl:variable name="error">
							<sw:text>
								<xsl:with-param name="name" select="$data/remote_path"/>
								Failed to upload template file %{name}.
							</sw:text>
						</xsl:variable>
						<xsl:if test="sw:sesput('error', $error)"/>
						<xsl:if test="action:log-error($error, 'hw.apps.app-add', $data/hn)"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>

		<!-- Remove temporary files -->		
		<xsl:if test="local:delete-file($dst, $sve-eid)"/>
		
		<xsl:copy-of select="action:complete('hw.apps.app-add',$data/hn)"/>
	</xsl:template>


	<func:function name="local:set">
		<xsl:param name="data"/>
		<xsl:param name="remote"/>
		
		<xsl:variable name="type">
			<xsl:choose>
				<xsl:when test="$data/type='auto'">
					<xsl:value-of select="sw:if(contains($data/remote_path, '-ez-'), 'ez', 'std')"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$data/type"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<xsl:variable name="pkg">
			<installation_package>
				<path><xsl:value-of select="sw:base64-encode($remote)"/></path>
			</installation_package>
		</xsl:variable>
		<func:result>
			<xsl:call-template name="vzapackagem:action-packet">
				<xsl:with-param name="command" select="sw:if($type='ez', 'update', 'install')"/>
				<xsl:with-param name="app-id" select="exsl:node-set($pkg)/installation_package"/>
				<xsl:with-param name="hn-eid" select="$data/hn"/>
				<xsl:with-param name="options">
					<xsl:if test="$data/force">
						<options>
							<force/>
						</options>
					</xsl:if>
				</xsl:with-param>
				<xsl:with-param name="cookie">
					<cookie>
						<operation>xsl-child.tmpl_install_new</operation>
					</cookie>
				</xsl:with-param>
			</xsl:call-template>
		</func:result>
	</func:function>
	
	<func:function name="local:copy-file">
		<xsl:param name="src"/>
		<xsl:param name="dst"/>
		<xsl:param name="eid"/>
		
		<!--|-->
		<xsl:variable name="req">
			<packet>
				<target>filer</target>
				<xsl:copy-of select="sw:env-dst($eid)"/>
				<data>
					<filer>
						<copy>
							<cwd></cwd>
							<path><xsl:value-of select="sw:base64-encode($src)"/></path>
							<dst_path><xsl:value-of select="sw:base64-encode($dst)"/></dst_path>
							<force/>
						</copy>
					</filer>
				</data>
				<vzcpauth/>
			</packet>
		</xsl:variable>
		
		<xsl:variable name="res" select="sw:xchg($req)/packet"/>
		
		<func:result select="$res//error"/>		
	</func:function>
	
	<func:function name="local:delete-file">
		<xsl:param name="path"/>
		<xsl:param name="eid"/>
		
		<!--|-->
		<xsl:variable name="req">
			<packet>
				<target>filer</target>
				<xsl:copy-of select="sw:env-dst($eid)"/>
				<data>
					<filer>
						<remove>
							<path><xsl:value-of select="sw:base64-encode($path)"/></path>
							<force/>
						</remove>
					</filer>
				</data>
				<vzcpauth/>
			</packet>
		</xsl:variable>
		
		<xsl:variable name="res" select="sw:xchg($req)/packet"/>
		
		<func:result select="$res//error"/>		
	</func:function>
	
	<sw:include href="/lib/common.xsl"/>
</xsl:stylesheet>