<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred vz func action"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:exsl="http://exslt.org/common"
	xmlns:set="http://exslt.org/sets"
	xmlns:sw="http://www.swsoft.com/xsl/cp" 
	xmlns:action="http://www.swsoft.com/xsl/cp/action"
	xmlns:local="http://www.swsoft.com/xsl/cp/local" 
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:func="http://exslt.org/functions"
	xmlns:vz="http://www.swsoft.com/xsl/cp/vz"
	xmlns:vzapackagem="http://www.swsoft.com/xsl/cp/vzapackagem"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:vzhn="http://www.swsoft.com/xsl/cp/vzhn"
	xmlns:templates="http://www.swsoft.com/xsl/cp/templates"
>
	
	<sw:include href="/lib/common.xsl" />
	<sw:include href="/lib/core/action-funcs.xsl"/>	
	<sw:include href="/lib/vt/env-core.xsl"/>	
	<sw:include href="/lib/vza/vzapackagem.xsl"/>
	<sw:include href="/lib/vzdir/infrman/templates/group-actions.xsl"/>
	
	<xsl:output method="xml" />
	<!--
		/data
			/action
			/env
				/eid
				/hn-eid
				/app-id
	-->
	<xsl:template match="/">
		<xsl:if test="action:start('apps.install-app.group', /data/env/eid)" />
		<xsl:for-each select="/data/env">
			<xsl:variable name="env" select="env:get-env(eid)/env"/>
			<xsl:variable name="state" select="$env/status/state"/>
			<xsl:variable name="is-down" select="$state=$env-state/down or $state=$env-state/mounted"/>
			
			<xsl:choose>
				<xsl:when test="$is-down and ../start">
					<xsl:apply-templates mode="results"
							select="templates:run-child(local:start-ve(hn-eid, eid), 
								concat('Start Container ', env:env2title($env)), 'vzaenvm.start', eid)"/>
					<xsl:apply-templates mode="results"
							select="local:install(app-id, hn-eid, eid, 'Install Application Templates')"/>
					<xsl:apply-templates mode="results"
							select="templates:run-child(local:stop-ve(hn-eid, eid), 
								concat('Stop Container ', env:env2title($env)), 'vzaenvm.stop', eid)"/> 
				</xsl:when>
				<xsl:when test="$is-down">
					<xsl:if test="action:log-error(concat('Can not install templates to the stopped Container ',env:env2title($env)),'apps.install-app.group',eid)"/>					
				</xsl:when>
				<xsl:otherwise>	
					<xsl:apply-templates mode="results"
							select="local:install(app-id, hn-eid, eid, 'Install Application Templates')"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>
		
		<xsl:copy-of select="action:complete('apps.install-app.group', /data/env/eid)" />
	</xsl:template>
	
	
	<func:function name="local:start-ve">
		<xsl:param name="hn-eid"/>
		<xsl:param name="eid"/>
		<func:result>
			<packet log="on">
				<target>vzaenvm</target>
				<xsl:copy-of select="sw:hn-dst($hn-eid)"/>
				<cookie>
					<operation>xsl-child.start_ve</operation>
				</cookie>
				<data>
					<vzaenvm>
						<start>
							<eid><xsl:value-of select="$eid"/></eid>
						</start>
					</vzaenvm>
				</data>
			</packet>
		</func:result>
	</func:function>
	
	<func:function name="local:stop-ve">
		<xsl:param name="hn-eid"/>
		<xsl:param name="eid"/>
		<func:result>
			<packet log="on">
				<target>vzaenvm</target>
				<xsl:copy-of select="sw:hn-dst($hn-eid)"/>
				<cookie>
					<operation>xsl-child.stop_ve</operation>
				</cookie>
				<data>
					<vzaenvm>
						<stop>
							<eid><xsl:value-of select="$eid"/></eid>
						</stop>
					</vzaenvm>
				</data>
			</packet>
		</func:result>
	</func:function>

	<func:function name="local:install">
		<xsl:param name="apps"/>
		<xsl:param name="hn-eid"/>
		<xsl:param name="ve-eid"/>
		<xsl:param name="message"/>
		
		<func:result select="templates:run-child(local:action($apps, $hn-eid, $ve-eid), $message, 'vzapackagem.install',
			 					$ve-eid)"/> 
	</func:function>
	
	<!-- migrate/install EZ template -->
	<func:function name="local:action">
		<xsl:param name="apps"/>
		<xsl:param name="hn-eid"/>
		<xsl:param name="ve-eid"/>
		
		<func:result>
			<xsl:call-template name="vzapackagem:action-packet">
				<xsl:with-param name="command" select="'install'"/>
				<xsl:with-param name="app-id" select="$apps"/>
				<xsl:with-param name="hn-eid" select="$hn-eid"/>
				<xsl:with-param name="target-eid" select="$ve-eid"/>
				<xsl:with-param name="cookie">
					<cookie>
						<operation>xsl-child.tmpl_install_app</operation>
					</cookie>
				</xsl:with-param>
			</xsl:call-template>
		</func:result>
	</func:function>
	
</xsl:stylesheet>
