<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred hwm vem func action update"
	xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:sw			="http://www.swsoft.com/xsl/cp"
	xmlns:action	="http://www.swsoft.com/xsl/cp/action"
	xmlns:hwm			="http://www.swsoft.com/xsl/cp/hwm"
	xmlns:vem			="http://www.swsoft.com/xsl/cp/vem"
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"
	xmlns:cred  	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:update  	="http://www.swsoft.com/xsl/cp/update"
	xmlns:vt	  	="http://www.swsoft.com/xsl/cp/vt"
	xmlns:func		="http://exslt.org/functions"	
>
	<sw:include href="/lib/core/action-funcs.xsl"/>

	<xsl:output method="xml"/>
	
	<!--
		/data
			/hw
			/eztemplates|templates
				/os
					/uid
				/application
					/os
					/uid
	-->
	<xsl:template match="/">
		<xsl:if test="action:start('vzaup2date.install.template', /data/hw)"/>

		<xsl:if test="/data/templates/*">
			<xsl:call-template name="local:do-install-actions">
				<xsl:with-param name="data" select="/data/templates" />
				<xsl:with-param name="hw-eid" select="/data/hw" />
			</xsl:call-template>
		</xsl:if>

		<xsl:copy-of select="action:complete('vzaup2date.install.template', /data/hw)"/>
	</xsl:template>
	
	<xsl:template name="local:do-install-actions">
		<xsl:param name="data" />
		<xsl:param name="hw-eid" />
		
		<xsl:choose>
			<xsl:when test="not($data/update[update:is-update(.)]|$data/update/app_template[update:is-update(.)])">
				<xsl:if test="action:log-error('No templates selected for installation.', 'vzaup2date.install.template', $hw-eid)"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="res">
					<xsl:if test="not($data/update[update:is-update(.)]) or
									local:install-run($hw-eid, update:action-update(local:filter-os($data/update), 
										$hw-eid), 'Install OS Template Updates')">
						
						<xsl:if test="not($data/update/app_template[update:is-update(.)]) or
									local:install-run($hw-eid, update:action-update($data, 
										$hw-eid), 'Install Application Template Updates')">
							<true/>
						</xsl:if>
					</xsl:if>
				</xsl:variable>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<func:function name="local:filter-os">
		<xsl:param name="updates"/>
		
		<xsl:variable name="res">
			<xsl:for-each select="$updates[self::update and update:is-update(.)]">
				<xsl:copy>
					<xsl:copy-of select="@*"/>
					<xsl:copy-of select="*[not(self::app_template)]"/>
				</xsl:copy>
			</xsl:for-each>
		</xsl:variable>
		
		<func:result select="exsl:node-set($res)"/>
	</func:function>
	
	
	<func:function name="local:install-run">
		<xsl:param name="hw"/>
		<xsl:param name="data"/>
		<xsl:param name="msg"/>		
		
		<xsl:variable name="res"
			select="action:run-child(exsl:node-set($data)/node(), $msg, 'vzaup2date.install.template', $hw)" />

		<xsl:variable name="status">
			<xsl:if test="vt:is-local-platform-linux() and $res and not($res/packet//error)">
<!--				<xsl:if test="action:run-child(local:cache-tem($hw),'Cache Templates','vzatem.cache')">-->
					<true />
<!--				</xsl:if>-->
			</xsl:if>
		</xsl:variable>
		
		<func:result select="exsl:node-set($status)/true" />
	</func:function>
	
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/update.xsl"/>
</xsl:stylesheet>