<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func"
  xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl			="http://exslt.org/common"
  xmlns:sw				="http://www.swsoft.com/xsl/cp"
	xmlns:fwm-util	="http://www.swsoft.com/xsl/cp/fwm-util"
	xmlns:func			="http://exslt.org/functions"
  >

	<!-- string for all/any -->
	<xsl:variable name="all-addr" select="sw:text('any')"/>
	<xsl:variable name="all-port" select="sw:text('any')"/>	
	<xsl:variable name="all-proto" select="sw:text('any')"/>	

	<xsl:variable name="fwm-protocol-rtf">
		<protocol>
			<value>
				<xsl:value-of select="'udp'"/>
			</value>
			<title>
				<xsl:value-of select="sw:text('udp')"/>
			</title>
		</protocol>
		<protocol>
			<value>
				<xsl:value-of select="'tcp'"/>
			</value>
			<title>
				<xsl:value-of select="sw:text('tcp')"/>
			</title>
		</protocol>
	</xsl:variable>
	<xsl:variable name="fwm-protocol" select="exsl:node-set($fwm-protocol-rtf)"/>

	<xsl:variable name="fwm-policy-rtf">
		<policy>
			<value>
				<xsl:value-of select="'ACCEPT'"/>
			</value>
			<title>
				<xsl:value-of select="sw:text('Accept')"/>
			</title>
		</policy>
		<policy>
			<value>
				<xsl:value-of select="'REJECT'"/>
			</value>
			<title>
				<xsl:value-of select="sw:text('Reject')"/>
			</title>
		</policy>
		<policy>
			<value>
				<xsl:value-of select="'DROP'"/>
			</value>
			<title>
				<xsl:value-of select="sw:text('Drop')"/>
			</title>
		</policy>
	</xsl:variable>
	<xsl:variable name="fwm-policy" select="exsl:node-set($fwm-policy-rtf)"/>

	<xsl:variable name="fwm-default-policy-rtf">
		<policy>
			<value>
				<xsl:value-of select="'ACCEPT'"/>
			</value>
			<title>
				<xsl:value-of select="sw:text('Accept')"/>
			</title>
		</policy>
		<policy>
			<value>
				<xsl:value-of select="'DROP'"/>
			</value>
			<title>
				<xsl:value-of select="sw:text('Drop')"/>
			</title>
		</policy>
	</xsl:variable>
	<xsl:variable name="fwm-default-policy" select="exsl:node-set($fwm-default-policy-rtf)"/>

	<xsl:variable name="fwm-chain-rtf">
		<chain>
			<tab>input</tab>
			<list-screen-id>
				<xsl:value-of select="'03.02.01.18.01'"/>
			</list-screen-id>
			<title>
				<xsl:value-of select="sw:text('Input')"/>	
			</title>
			<chain-name>
				<xsl:value-of select="'INPUT'"/>	
			</chain-name>
		</chain>
		<chain>
			<tab>output</tab>
			<list-screen-id>
				<xsl:value-of select="'03.02.01.18.02'"/>
			</list-screen-id>
			<title>
				<xsl:value-of select="sw:text('Output')"/>	
			</title>				
			<chain-name>
				<xsl:value-of select="'OUTPUT'"/>	
			</chain-name>
		</chain>
		<chain>
			<tab>forward</tab>
			<list-screen-id>
				<xsl:value-of select="'03.02.01.18.03'"/>
			</list-screen-id>
			<title>
				<xsl:value-of select="sw:text('Forward')"/>	
			</title>
      <chain-name>  
      	<xsl:value-of select="'FORWARD'"/>
      </chain-name>
		</chain>
	</xsl:variable>
	<xsl:variable name="fwm-chain" select="exsl:node-set($fwm-chain-rtf)"/>

	<xsl:template name="fwm-calc-rules">
		<xsl:variable name="raw-rules" select="fwm:get()"/>
		<xsl:variable name="rules-group-by-chain-rtf">
			<xsl:for-each select="$fwm-chain/chain">
				<xsl:variable name="chain-name" select="chain-name"/>
				<chain>
					<name><xsl:value-of select="$chain-name"/></name>
					<xsl:for-each select="$raw-rules/rule[chain = $chain-name]">
						<rule>
							<xsl:copy-of select="./*"/>
								<fwm-rule-id><xsl:value-of select="position()"/></fwm-rule-id>
								<fwm-rule-uniq-id><xsl:value-of select="generate-id()"/></fwm-rule-uniq-id>
						</rule>
					</xsl:for-each>
				</chain>
			</xsl:for-each>
		</xsl:variable>
		<xsl:if test="sw:sesputtree('fwm-rules',$rules-group-by-chain-rtf)"/>		
		<xsl:copy-of select="$rules-group-by-chain-rtf"/>
 	</xsl:template>

	<func:function name="fwm-util:get-mode">
		<xsl:variable name="mode" select="sw:get-private()/vzcp/fwm-mode"/>
		<func:result select="sw:if(not($mode != ''),$config/vzcpcon/defines/firewall/mode,$mode)"/>        
	</func:function>

	<func:function name="fwm-util:set-mode">
		<xsl:param name="mode"/>
		<xsl:variable name="for-save-in-private">
			<fwm-mode>
				<xsl:value-of select="$mode"/>
			</fwm-mode>
		</xsl:variable>
		<xsl:variable name="old-private" select="sw:get-private()"/>
		<xsl:variable name="new-private"> 
			<xsl:choose>
				<xsl:when test="not($old-private != '')">
					<!-- no private file exists, create new -->
					<vzcp>
						<xsl:copy-of select="$for-save-in-private"/>
					</vzcp>
				</xsl:when>
				<xsl:otherwise>
					<xsl:variable name="remove-private" select="sw:del-child($old-private, '//vzcp/fwm-mode')"/>
					<xsl:copy-of select="sw:add-child($remove-private,'//vzcp',$for-save-in-private)"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<func:result select="sw:put-private(exsl:node-set($new-private))"/>
	</func:function>

	<xsl:template name="fwm-calc-simple-rules">
		<xsl:variable name="rules-in-system-rtf">
			<xsl:call-template name="fwm-calc-rules"/>
		</xsl:variable>
		<xsl:variable name="rules-in-system" select="exsl:node-set($rules-in-system-rtf)"/>
		<xsl:variable name="defined-rulesets" select="sw:document('fwm-simple-ruleset.xml')/sets/set"/>

		<xsl:variable name="found-rulesets-rtf">"
			<xsl:for-each select="$defined-rulesets">
				<!-- calc total count of rules in ruleset (per chain) -->
				<xsl:variable name="total-input-count-rules-in-set" select="count(rule[chain = 'INPUT'])"/>
				<xsl:variable name="total-output-count-rules-in-set" select="count(rule[chain = 'OUTPUT'])"/>
				<xsl:variable name="total-forward-count-rules-in-set" select="count(rule[chain = 'FORWARD'])"/>
				<xsl:variable name="ruleset-check-rtf">
					<xsl:for-each select="rule">
						<xsl:variable name="rule" select="."/>
						<xsl:variable name="match-rule" select="$rules-in-system/chain/rule[
							name = $rule/name and chain = $rule/chain and policy = $rule/policy and
							allowed = $rule/allowed and protocol = $rule/protocol and 
							(string(src_addr/host) = string($rule/src_addr/host)) and 
							(string(src_addr/mask) = string($rule/src_addr/mask)) and 
							(string(src_ports/first_port) = string($rule/src_ports/first_port)) and 
							(string(src_ports/last_port) = string($rule/src_ports/last_port)) and 
							(string(dst_addr/host) = string($rule/dst_addr/host)) and 
							(string(dst_addr/mask) = string($rule/dst_addr/mask)) and 
							(string(dst_ports/first_port) = string($rule/dst_ports/first_port)) and 
							(string(dst_ports/last_port) = string($rule/dst_ports/last_port))
						]"/>
						<xsl:choose>
							<xsl:when test="$match-rule/chain = 'INPUT'">
								<input>
									<xsl:value-of select="$match-rule/fwm-rule-id"/>									
								</input>
							</xsl:when>
							<xsl:when test="$match-rule/chain = 'OUTPUT'">
								<output>
									<xsl:value-of select="$match-rule/fwm-rule-id"/>									
								</output>
							</xsl:when>
							<xsl:when test="$match-rule/chain = 'FORWARD'">
								<forward>
									<xsl:value-of select="$match-rule/fwm-rule-id"/>									
								</forward>
							</xsl:when>
						</xsl:choose>
						<rule>
						<xsl:choose>
							<xsl:when test="string($match-rule) != ''">
								<xsl:copy-of select="$match-rule/*"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:copy-of select="$rule/*"/>
							</xsl:otherwise>
						</xsl:choose>
						</rule>
					</xsl:for-each>
				</xsl:variable>

				<xsl:variable name="ruleset-check" select="exsl:node-set($ruleset-check-rtf)"/>
				<!-- calc count of rules from current ruleset found in total firewall rules (per chain) -->
				<xsl:variable name="found-input-count-rules-in-set" select="count($ruleset-check/input)"/>
				<xsl:variable name="found-output-count-rules-in-set" select="count($ruleset-check/output)"/>
				<xsl:variable name="found-forward-count-rules-in-set" select="count($ruleset-check/forward)"/>

				<!-- calc that rule in ruleset followed one by one, whithout holes (per chain) -->
				<xsl:variable name="input-continue">
				  <xsl:choose>
				  	<xsl:when test="count($ruleset-check/input) = 0">1</xsl:when>
					  <xsl:otherwise>
					  	<xsl:value-of select="sw:if(($ruleset-check/input[last()] - $ruleset-check/input[1] + 1) = $total-input-count-rules-in-set,1,0)"/>
					  </xsl:otherwise>
					</xsl:choose>	
				</xsl:variable>
				<xsl:variable name="output-continue">
				  <xsl:choose>
				  	<xsl:when test="count($ruleset-check/output) = 0">1</xsl:when>
					  <xsl:otherwise>
					  	<xsl:value-of select="sw:if(($ruleset-check/output[last()] - $ruleset-check/output[1] + 1) = $total-output-count-rules-in-set,1,0)"/>
					  </xsl:otherwise>
					</xsl:choose>	
				</xsl:variable>
				<xsl:variable name="forward-continue">
				  <xsl:choose>
				  	<xsl:when test="count($ruleset-check/forward) = 0">1</xsl:when>
					  <xsl:otherwise>
					  	<xsl:value-of select="sw:if(($ruleset-check/forward[last()] - $ruleset-check/forward[1] + 1) = $total-forward-count-rules-in-set,1,0)"/>
					  </xsl:otherwise>
					</xsl:choose>	
				</xsl:variable>
				<set>
					<xsl:copy-of select="$ruleset-check/rule"/>
					<xsl:copy-of select="*[not(self::rule)]"/>
					<fwm-simple-rule-id><xsl:value-of select="position()"/></fwm-simple-rule-id>
					<fwm-simple-rule-uniq-id><xsl:value-of select="generate-id()"/></fwm-simple-rule-uniq-id>
					
					<xsl:if test="
						($found-input-count-rules-in-set = $total-input-count-rules-in-set) and
						($found-output-count-rules-in-set = $total-output-count-rules-in-set) and
						($found-forward-count-rules-in-set = $total-forward-count-rules-in-set) and 
						($input-continue = 1 and $output-continue = 1 and $forward-continue = 1)
					"> 
						<!-- ruleset is correct if:
									number of found rules equal to total number of rules in ruleset (per chain)
									all rules followed one by one, whiout holes.
									Example: (for chain INPUT)
									a)
										In system firewall found 3 rules with id 5,6,8
										In ruleset must be 4 rules.
										Ruleset not valid (not all rules found)
									b) 
										In system firewall found 3 rules with id 5,6,8
										In ruleset must be 3 rules
										Ruleset not valid (all rules found but rules has hole)
									c) 
										In system firewall found 3 rules with id 5,6,7
										In ruleset must be 3 rules
										Ruleset is valid (all rules found and rules has no hole)
						-->	
						<selected/>
					</xsl:if>					
				</set>
			</xsl:for-each>
		</xsl:variable>
		<xsl:if test="sw:sesputtree('fwm-simple-rules',$found-rulesets-rtf)"/>
    <xsl:copy-of select="$found-rulesets-rtf"/>   
	</xsl:template>

</xsl:stylesheet>
