<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl date math func"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:date="http://exslt.org/dates-and-times"
	xmlns:math="http://exslt.org/math" xmlns:func="http://exslt.org/functions">
	
	<sw:include href="common.xsl"/>
	<sw:include href="vzatime.xsl"/>

	<!-- get logs of requested type -->
	<xsl:template name="getlog">
		<xsl:param name="eid" select="sw:ve-eid()"/>
		<xsl:param name="period"/>
		<xsl:param name="class-name"/>
		<xsl:variable name="req">
			<packet>
				<target>res_log</target>
				<xsl:copy-of select="sw:hn-dst(sw:hn-eid())"/>
				<data>
					<res_log>
						<get_log>
							<!-- provide EID, sigle or multiple -->
							<xsl:for-each select="exsl:node-set($eid)">
								<eid><xsl:value-of select="."/></eid>
							</xsl:for-each>
							<class>
								<name>
									<xsl:copy-of select="$class-name"/>
								</name>
							</class>
							<xsl:copy-of select="$period"/>
							<report_empty/>
						</get_log>
					</res_log>
				</data>
			</packet>
		</xsl:variable>
		<xsl:copy-of select="sw:xchg($req)/packet/data/res_log/data[class/name = $class-name]"/>
	</xsl:template>
	
	<xsl:template name="getlog-for-period">
		<xsl:param name="class-name" select="''"/>
		<xsl:param name="start-date" select="date:date()"/>
		<xsl:param name="period" select="'month'" />
		<xsl:param name="from-date" select="date:date()"/>
		<xsl:param name="to-date" select="date:date()"/>
		<xsl:param name="eid" select="sw:ve-eid()"/>

		<xsl:choose>
			<xsl:when test="$period = 'from-to'">
				<xsl:variable name="period-for-agent" select="sw:vzagent-time-interval($from-date, $to-date)"/>
				<xsl:variable name="log-stat-rtf">
					<xsl:for-each select="$period-for-agent">
						<xsl:call-template name="getlog">
							<xsl:with-param name="period" select="current()/*"/>
							<xsl:with-param name="class-name" select="$class-name"/>
							<xsl:with-param name="eid" select="$eid"/>
						</xsl:call-template>
					</xsl:for-each>
				</xsl:variable>
				<xsl:variable name="log-stat" select="exsl:node-set($log-stat-rtf)"/>
				<!-- convert vzagent answer to xml time and restore current TZ -->
				<xsl:for-each select="$log-stat/*[class/name = $class-name]">
					<one-log-record>
						<start_time>
							<xsl:value-of select="sw:vzatime2time(interval/start_time)"/>
						</start_time>
						<!-- end time probably not need, but for equal data structure -->
						<end_time>
							<xsl:value-of select="sw:vzatime2time(interval/end_time)"/>
						</end_time>
						<xsl:copy-of select="current()"/>
					</one-log-record>
				</xsl:for-each>
			</xsl:when>

			<xsl:when test="$period = 'day'">
				<xsl:variable name="period-for-agent" select="sw:vzagent-date-interval('day', $start-date)"/>
				<xsl:variable name="log-stat-rtf">
					<xsl:for-each select="$period-for-agent">
						<xsl:call-template name="getlog">
							<xsl:with-param name="period" select="current()/*"/>
							<xsl:with-param name="class-name" select="$class-name"/>
							<xsl:with-param name="eid" select="$eid"/>
						</xsl:call-template>
					</xsl:for-each>
				</xsl:variable>
				<xsl:variable name="log-stat" select="exsl:node-set($log-stat-rtf)"/>
				<!-- convert vzagent answer to xml time and restore current TZ -->
				<xsl:for-each select="$log-stat/*[class/name = $class-name]">
					<one-log-record>
						<start_time>
							<xsl:value-of select="sw:vzatime2time(interval/start_time)"/>
						</start_time>
						<!-- end time probably not need, but for equal data structure -->
						<end_time>
							<xsl:value-of select="sw:vzatime2time(interval/end_time)"/>
						</end_time>
						<xsl:copy-of select="current()"/>
					</one-log-record>
				</xsl:for-each>
			</xsl:when>

			<xsl:when test="$period = 'month'">
				<xsl:variable name="period-for-agent" select="sw:vzagent-date-interval('month', $start-date)"/>
				<xsl:variable name="log-stat-rtf">
					<xsl:for-each select="$period-for-agent">
						<xsl:call-template name="getlog">
							<xsl:with-param name="period" select="current()/*"/>
							<xsl:with-param name="class-name" select="$class-name"/>
							<xsl:with-param name="eid" select="$eid"/>
						</xsl:call-template>
					</xsl:for-each>
				</xsl:variable>
				<xsl:variable name="log-stat" select="exsl:node-set($log-stat-rtf)"/>

				<!-- convert vzagent answer to xml time and restore current TZ -->
				<xsl:for-each select="$log-stat/*[class/name = $class-name]">
					<one-log-record>
						<start_time>
							<xsl:value-of select="sw:vzatime2time(interval/start_time)"/>
						</start_time>
						<!-- end time probably not need, but for equal data structure -->
						<end_time>
							<xsl:value-of select="sw:vzatime2time(interval/end_time)"/>
						</end_time>
						<xsl:copy-of select="current()"/>
					</one-log-record>
				</xsl:for-each>
			</xsl:when>

			<xsl:when test="$period = 'year'">
				<xsl:variable name="period-for-agent" select="sw:vzagent-date-interval('year', $start-date)"/>
				<xsl:variable name="log-stat-rtf">
					<xsl:for-each select="$period-for-agent">
						<xsl:variable name="log-one-month-rtf">
							<xsl:call-template name="getlog">
								<xsl:with-param name="period" select="current()/*"/>
								<xsl:with-param name="class-name" select="$class-name"/>
								<xsl:with-param name="eid" select="$eid"/>
							</xsl:call-template>
						</xsl:variable>
						<xsl:variable name="log-one-month"
							select="exsl:node-set($log-one-month-rtf)"/>
						<xsl:choose>
							<xsl:when test="$log-one-month/*[class/name = $class-name]">
								<xsl:copy-of select="$log-one-month"/>
							</xsl:when>
							<xsl:otherwise>
								<!-- no node log from vzagent, no log for such month. -->
								<xsl:element name="{$class-name}" use-attribute-sets="empty">
									<interval>
										<start_time>
											<xsl:value-of select="start_time"/>
										</start_time>
										<end_time>
											<xsl:value-of select="end_time"/>
										</end_time>
									</interval>
								</xsl:element>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
				</xsl:variable>
				<xsl:variable name="log-stat" select="exsl:node-set($log-stat-rtf)"/>
				<!-- convert vzagent answer to xml time and restore current TZ -->
				<xsl:for-each select="$log-stat/*[not(@empty)]">
					<one-log-record>
						<start_time>
							<xsl:value-of select="sw:vzatime2time(interval/start_time)"/>
						</start_time>
						<end_time>
							<xsl:value-of select="sw:vzatime2time(interval/end_time)"/>
						</end_time>
						<xsl:copy-of select="current()"/>
					</one-log-record>
				</xsl:for-each>
			</xsl:when>
		</xsl:choose>

	</xsl:template>

	
</xsl:stylesheet>
