<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl format func"
	xmlns:xsl				="http://www.w3.org/1999/XSL/Transform" 
	xmlns:exsl			="http://exslt.org/common"
	xmlns:sw				="http://www.swsoft.com/xsl/cp" 
	xmlns:local			="http://www.swsoft.com/xsl/cp/local"
	xmlns:top				="http://www.swsoft.com/xsl/cp/top"
	xmlns:env				="http://www.swsoft.com/xsl/cp/env"
	xmlns:ve				="http://www.swsoft.com/xsl/cp/ve"
	xmlns:vzaconfig	="http://www.swsoft.com/xsl/cp/vzaconfig"
	xmlns:func			="http://exslt.org/functions"
	xmlns:vt		="http://www.swsoft.com/xsl/cp/vt"
	xmlns:format="http://www.swsoft.com/xsl/cp/format"
	>

	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/utils/format-resusage.xsl"/>
	<sw:include href="/lib/vzatime.xsl"/>
	<sw:include href="/lib/vzaconfig.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vt/ve-core.xsl"/>
	<sw:include href="/lib/vt/env-quota.xsl"/>
	<sw:include href="/lib/vzaconfig.xsl"/>	

	<func:function name="top:return-init-structure">
		<!-- "tab" - linked for tab's id  from etc/tab -->
		<!-- "step" - wizards step -->
		<!-- "group" - internal node for grouping screen by it -->
		<!-- "id" defined as "id" from vzagent in category "top_counters" -->
		<func:result>
			<top>
				<id>counter_cpu_used</id>				
				<tab>cpu</tab>
				<step>cpu</step>				
				<hn-resource-name>cpu</hn-resource-name>
				<title><sw:text>On this screen you can see detailed information on the Hardware Node CPU usage.</sw:text></title>
				<msg>
					<not-present>
						<sw:text>No information on the Container CPU usage has been reported for the selected period.</sw:text>
					</not-present>
					<present>
						<sw:text>Top CPU usage by Container</sw:text>
					</present>
				</msg>
				<absolute>
					<sw:text>CPU Time</sw:text>
				</absolute>
				<relative>
					<sw:text>Relative CPU share</sw:text>
				</relative>
			</top>
			<top>
				<id>counter_memory_used</id>
				<tab>memtotal</tab>
				<step>memtotal</step>				
				<hn-resource-name>mem</hn-resource-name>
				<title><sw:text>On this screen you can see detailed information on the Hardware Node memory usage.</sw:text></title>
				<msg>
					<not-present>
						<sw:text>No information on the Container memory usage has been reported for the selected period.</sw:text>
					</not-present>
					<present>
						<sw:text>Top total memory usage by Container</sw:text>
					</present>
				</msg>
				<absolute>
					<sw:text>Used Memory</sw:text>
				</absolute>
				<relative>
					<sw:text>Used Memory Share</sw:text>
				</relative>
				<details>
					<sw:text>Total memory</sw:text>
				</details>
				<instant/>
			</top>
			<top>
				<id>counter_disk_used</id>
				<tab>disk</tab>
				<step>disk</step>				
				<hn-resource-name>diskspace</hn-resource-name>
				<hn-resource-name>diskinodes</hn-resource-name>
				<title><sw:text>On this screen you can see detailed information on the Hardware Node disk space usage.</sw:text></title>
				<msg>
					<not-present>
						<sw:text>No information on the Container disk space usage has been reported for the selected period.</sw:text>
					</not-present>
					<present>
						<sw:text>Top disk usage by Container</sw:text>
					</present>
				</msg>
				<absolute>
					<sw:text>Used Disk</sw:text>
				</absolute>
				<relative>
					<sw:text>Used Disk Share</sw:text>
				</relative>
				<details>
					<sw:text>Disk space</sw:text>
				</details>
				<instant/>
			</top>
			<top>
				<id>counter_net_outgoing_bytes</id>
				<tab>traffic</tab>
				<step>netout</step>				
				<group>traffic</group>
				<title><sw:text>On this screen you can see detailed information on the Hardware Node outgoing traffic.</sw:text></title>
				<msg>
					<not-present>
						<sw:text>No information on the Container outgoing traffic has been reported for the selected period.</sw:text>
					</not-present>
					<present>
						<sw:text>Top outgoing traffic by Container</sw:text>
					</present>
				</msg>
				<absolute>
					<sw:text>Outgoing Traffic</sw:text>
				</absolute>
				<relative>
					<sw:text>Outgoing Traffic Share</sw:text>
				</relative>
				<details>
					<sw:text>Outgoing traffic</sw:text>
				</details>
			</top>
			<top>
				<id>counter_net_incoming_bytes</id>
				<tab>traffic</tab>
				<step>netin</step>
				<group>traffic</group>				
				<title><sw:text>On this screen you can see detailed information on the Hardware Node incoming traffic.</sw:text></title>
				<msg>
					<not-present>
						<sw:text>No information on the Container incoming traffic has been reported for the selected period.</sw:text>
					</not-present>
					<present>
						<sw:text>Top incoming traffic by Container</sw:text>
					</present>
				</msg>
				<absolute>
					<sw:text>Incoming Traffic</sw:text>
				</absolute>
				<relative>
					<sw:text>Incoming Traffic Share</sw:text>
				</relative>
				<details>
					<sw:text>Incoming traffic</sw:text>
				</details>
			</top>
		</func:result>
	</func:function>

	<!-- local variable for measure oomguarpages -->
	<xsl:variable name="local-page-size">
		<xsl:variable name="voc-args">
			<parameter>oomguarpages</parameter>
		</xsl:variable>
		<xsl:variable name="voc-measure" select="voc:get($voc-args, env:make-platform-ref(sw:hn-eid()))/measure"/>
		<xsl:choose>
			<xsl:when test="sw:lc($voc-measure) = '16kb pages'">
				<xsl:value-of select="16384"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="4096"/>
			</xsl:otherwise>
		</xsl:choose>			
	</xsl:variable>

	<!-- get from agent additional info about counters () -->	
	<func:function name="top:get-counters-info">
		<xsl:variable name="req">
			<packet log="on">
				<target>res_log</target>
				<xsl:copy-of select="sw:hn-dst(sw:hn-eid())"/>
				<data>
					<res_log>
						<get_log_info/>
					</res_log>
				</data>
			</packet>
		</xsl:variable>
		<xsl:variable name="res" select="sw:xchg($req)/packet"/>
		<xsl:if test="$res/error|$res/data/error">
			<xsl:if test="error:put($res/error|$res/data/error, '', '')"/>
		</xsl:if>
		<func:result select="$res/data/res_log/log_info"/>		
	</func:function>

	<!-- get counters with  category "top_counters", add period and  
		   return new synthetic node top:counters -->
	<func:function name="top:get-counters">
		<xsl:variable name="platform-ref" select="env:make-platform-ref(sw:hn-eid())"/>
		<xsl:variable name="linux" select="vt:is-platform-linux($platform-ref/platform)"/>
		<xsl:variable name="counters" select="voc:get('top_counters', $platform-ref)"/>
		<xsl:variable name="counters-info" select="top:get-counters-info()"/>
		<xsl:variable name="res-rtf">
			<xsl:for-each select="$counters[category='top_counters']">
				<top:counter>
					<xsl:copy-of select="id|measure"/>
					<xsl:variable name="name" select="string(category[text()!='top_counters'])"/>
					<period>
						<xsl:choose>
							<xsl:when test="$counters-info[class=$name]/period">
								<xsl:value-of select="$counters-info[class=$name]/period"/>
							</xsl:when>
							<xsl:otherwise>3600</xsl:otherwise>
						</xsl:choose>
					</period>
					<xsl:if test="(not($linux) and $name='counters_memory') 
						or ($linux and ($name='counters_memory' or $name='counters_disk'))">
						<instant>yes</instant>
					</xsl:if>
				</top:counter>
			</xsl:for-each>
		</xsl:variable>
		<func:result select="exsl:node-set($res-rtf)/top:counter"/>
	</func:function>

	<!-- get NOT INSTANT stat, by res_log/get_top, For VE in all states  -->
	<xsl:template name="top:get-top-packet">
		<xsl:param 	name="data"/>
		<xsl:variable name="cur-date-end" 	select="date:date-time()"/>
		<xsl:variable name="cur-date-start" select="date:add($cur-date-end, concat('-', date:duration($data/interval)))"/>
		<xsl:variable name="eids" select="local:list-envs('show-running-and-stopped')"/>
		
		<xsl:choose>
			<xsl:when test="$eids">
		 		<packet log="on">
					<target>res_log</target>
					<xsl:copy-of select="sw:hn-dst(sw:hn-eid())"/>
					<cookie>
						<msg>
							<error>
								<sw:text>Failed to get the statistics for the requested period.</sw:text>
							</error>
						</msg>
					</cookie>
					<data>
						<res_log>
							<get_top>
								<parameter>
									<xsl:value-of select="$data/id"/>
								</parameter>
								<descending/>
								<start_time>
									<xsl:value-of select="sw:time2vzatime($cur-date-start)"/>
								</start_time>
								<end_time>
									<xsl:value-of select="sw:time2vzatime($cur-date-end)"/>
								</end_time>
								<eid_list>
									<xsl:copy-of select="$eids"/>
								</eid_list>						
								<count>
									<xsl:value-of select="$data/records"/>
								</count>
							</get_top>
						</res_log>
					</data>
				</packet>
			</xsl:when>
			<xsl:otherwise>
				<packet/>
			</xsl:otherwise>
		</xsl:choose>
		
	</xsl:template>
	
	<!-- get INSTANT stat, by perf_mon -->
	<xsl:template name="top:get-mem-instant-packet">
		<xsl:param  name="data"/>
		<xsl:variable name="eids" select="local:list-envs('')"/>
		
		<xsl:variable name="ubcs-rtf">
			<packet>
				<xsl:copy-of select="sw:hn-dst(sw:hn-eid())"/>
				<target>perf_mon</target>
				<data>
					<perf_mon>
						<get>
							<class>
								<name>counters_vz_memory</name>
							</class>
							<eid_list>
								<xsl:copy-of select="$eids"/>
							</eid_list>
						</get>
					</perf_mon>
				</data>
			</packet>
		</xsl:variable>
		<xsl:choose>
			<xsl:when test="$eids">
				<xsl:variable name="ubcs" select="sw:xchg($ubcs-rtf)/packet/data/perf_mon/data"/>
				<xsl:variable name="res">
					<xsl:for-each select="$ubcs">
						<set>
							<xsl:copy-of select="eid"/>
							<xsl:for-each select="class/instance">
								<value>
									<xsl:copy-of select="local:calculate-instant-vmemory(counter)"/>
								</value>
							</xsl:for-each>
						</set>
					</xsl:for-each>
				</xsl:variable>
				<xsl:call-template name="local:filter-data">
					<xsl:with-param name="data" select="exsl:node-set($res)/set"/>
					<xsl:with-param name="records" select="$data/records"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<packet/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- get INSTANT stat, for disk, by ve_quota -->
	<xsl:template name="top:get-disk-instant-packet">
		<xsl:param  name="data"/>
		<xsl:variable name="ref">
			<xsl:for-each select="local:list-envs()">
				<set>
					<eid>
						<xsl:value-of select="."/>
					</eid>
					<xsl:variable name="ve-quota" select="env:get-quota(.)/ve_quota"/>
					<value>
						<xsl:value-of select="$ve-quota/diskspace/cur * 1024"/>
					</value>
				</set>
			</xsl:for-each>
		</xsl:variable>
		<xsl:call-template name="local:filter-data">
			<xsl:with-param name="data" select="exsl:node-set($ref)/set"/>
			<xsl:with-param name="records" select="$data/records"/>
		</xsl:call-template>
	</xsl:template>

	<!-- format value -->
	<func:function name="top:format-value">
		<xsl:param name="value"/>
		<xsl:param name="measure"/>
		<func:result>
			<xsl:choose>
				<xsl:when test="string(number($value)) = 'NaN'"/>
				<xsl:when test="$measure = 'bytes'">
					<xsl:value-of select="format:int2bytes($value, 'mbytes', 'yes', '#,##0.00')"/>
				</xsl:when>
				<xsl:when test="$measure = '1K-blocks'">
					<xsl:value-of select="format:int2bytes($value * 1024, 'mbytes', 'yes', '#,##0.00')"/>
				</xsl:when>
				<xsl:when test="$measure = 'percent'">
					<xsl:value-of select="format-number(number($value) div 100, '0.00%')"/>
				</xsl:when>
				<xsl:when test="$measure='tiks'">
					<xsl:variable name="format-time" select="local:split-time(number($value) 
						div sw:if(vt:is-local-platform-windows(), 10000000, 100)
					)"/>
					<xsl:value-of select="local:time-string($format-time)"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="format-number(number($value), '#,##0')"/>
				</xsl:otherwise>
			</xsl:choose>
		</func:result>
	</func:function>

	<!-- list preset intervals -->
	<func:function name="top:get-interval-reference">
		<xsl:variable name="interval-object-rtf">
			<interval>
				<id>instant</id>
				<title>
					<xsl:value-of select="sw:text('Instant')"/>
				</title>
				<value>
					<xsl:value-of select="0"/>
				</value>
			</interval>
			<interval>
				<id>short</id>
				<title>
					<xsl:value-of select="concat('5 ', sw:text('minutes'))"/>
				</title>
				<value>
					<xsl:value-of select="300"/>
				</value>
			</interval>
			<interval>
				<id>long</id>
				<title>
					<xsl:value-of select="concat('30 ', sw:text('minutes'))"/>
				</title>
				<value>
					<xsl:value-of select="1800"/>
				</value>
			</interval>
			<interval>
				<id>hour</id>
				<title>
					<xsl:value-of select="concat('1 ', sw:text('hour'))"/>
				</title>
				<value>
					<xsl:value-of select="3600"/>
				</value>
			</interval>
			<interval>
				<id>day</id>
				<title>
					<xsl:value-of select="concat('1 ', sw:text('day'))"/>
				</title>
				<value>
					<xsl:value-of select="86400"/>
				</value>
			</interval>
			<interval>
				<id>week</id>
				<title>
					<xsl:value-of select="concat('1 ', sw:text('week'))"/>
				</title>
				<value>
					<xsl:value-of select="604800"/>
				</value>
			</interval>
		</xsl:variable>
		<func:result select="exsl:node-set($interval-object-rtf)/interval"/>
	</func:function>

	<!-- INTERNAL FUNCTIONS AND TEMPLATE BELOW -->	
	<!-- split time in sec, return node-set with day,hour,min,sec nodes -->
	<func:function name="local:split-time">
		<xsl:param name="raw-time"/>
		<xsl:variable name="days" select="$raw-time div 86400"/>
		<xsl:variable name="hrs" select="($raw-time mod 86400) div 3600"/>
		<xsl:variable name="mins" select="(($raw-time mod 86400) mod 3600) div 60"/>
		<xsl:variable name="secs" select="(($raw-time mod 86400) mod 3600) mod 60"/>
		<xsl:variable name="format-time">
			<day>
				<xsl:value-of select="sw:if($days &lt; 0, 0, floor($days))"/>
			</day>
			<hr>
				<xsl:value-of select="sw:if($hrs &lt; 0, 0, floor($hrs))"/>
			</hr>
			<min>
				<xsl:value-of select="sw:if($mins &lt; 0, 0, floor($mins))"/>
			</min>
			<sec>
				<xsl:value-of select="sw:if($secs &lt; 0, 0, $secs)"/>
			</sec>
		</xsl:variable>
		<func:result select="exsl:node-set($format-time)"/>
	</func:function>

	<func:function name="local:time-string">
		<xsl:param name="node-time"/>
		<xsl:variable name="day" select="$node-time/day"/>
		<xsl:variable name="hr" select="$node-time/hr"/>
		<xsl:variable name="min" select="$node-time/min"/>
		<xsl:variable name="sec" select="$node-time/sec"/>
		<xsl:variable name="string-time">
			<sw:text-plural>
				<sw:text-zero />
				<sw:text-single>%{num} day&#160;</sw:text-single>
				<sw:text-multiple>%{num} days&#160;</sw:text-multiple>
				<xsl:with-param name="num" select="$day"/>
			</sw:text-plural>
			<xsl:value-of select="format-number($hr, '00')"/>:<xsl:value-of select="format-number($min,'00')"/>:<xsl:value-of select="format-number($sec,'00.00')"/>
		</xsl:variable>
		<func:result select="$string-time"/>
	</func:function>
	
	<func:function name="local:calculate-instant-vmemory">
		<xsl:param name="counter"/>
		<func:result select="$counter[name = 'counter_memory_used']/value/cur"/>
	</func:function>

	<xsl:template name="local:filter-data">
		<xsl:param name="data"/>
		<xsl:param name="records" select="10"/>
		<packet>
			<cookie>
				<data>
					<res_log>
						<top>
							<total>
								<xsl:value-of select="sum($data/value)"/>
							</total>
							<xsl:for-each select="$data">
								<xsl:sort select="value" data-type="number" order="descending"/>
								<xsl:if test="position() &lt; ($records + 1)">
									<xsl:copy-of select="."/>
								</xsl:if>
							</xsl:for-each>
						</top>
					</res_log>
				</data>
			</cookie>
		</packet>
	</xsl:template>
	
	<func:function name="local:list-envs">
		<xsl:param name="show-all" select="'yes'"/>
		<xsl:variable name="hn-eid" select="sw:hn-eid()"/>
		<xsl:variable name="query">
			<fields>
				<env.eid/>
			</fields>
			<where>
				pager.env.vconfig.type='virtuozzo' 
				<xsl:if test="$show-all = ''">
					and (pager.env.state=<xsl:value-of select="$env-state/running"/> 
						or pager.env.state=<xsl:value-of select="$env-state/repairing"/>)
				</xsl:if>
				and pager.env.parent_eid='<xsl:value-of select="$hn-eid"/>'
				<xsl:if test="not(vzaconfig:show-sve())">
					and <xsl:copy-of select="ve:get-veid-range-filter($hn-eid)"/>
				</xsl:if>
			</where>
		</xsl:variable>
		<func:result select="sw:xchg-sql($query)/pager/row_set/row/env/eid"/>
	</func:function>

	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
