<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred local func proc voc"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:proc="http://www.swsoft.com/xsl/cp/proc"
	xmlns:voc="http://www.swsoft.com/xsl/cp/voc"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"	
>

	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="../lib/common.xsl"/>

	<xsl:template name="proc:post-browse">
		<xsl:param name="plain" select="false()"/>
		<xsl:param name="simple" select="false()"/>
		
		<xsl:variable name="voc-sign" select="voc:get('signal', env:make-platform-ref(sw:ve-parent(sw:ve-eid())))"/>
		<xsl:variable name="old-default-signal" select="sw:sesgetstr('default-signal')"/>		
		<xsl:variable name="default-signal">
			<xsl:choose>
				<xsl:when test="$voc-sign/data = $old-default-signal">
					<!-- default signal present in new signal set, use old default -->
					<xsl:value-of select="$old-default-signal"/>
				</xsl:when>
				<xsl:otherwise>
					<!-- vzcp get new signal set, dig new default signal -->
					<xsl:value-of select="$voc-sign[1]/data"/>					
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
	
		<xsl:variable name="signals">
			<xsl:for-each select="$voc-sign">
				<xsl:sort select="data"/>
				<option value="{data}">
					<xsl:value-of select="string(id)"/>
				</option>
			</xsl:for-each>
		</xsl:variable>

		<xsl:variable name="filter" select="local:get-filter($plain)"/>

		<xsl:if test="not($plain)">
			<ui:block>
				<ui:rows>
					<ui:row>
						<xsl:choose>
							<xsl:when test="$simple">
								<ui:hidden name="signal" id="signal" value="{$default-signal}"/>
							</xsl:when>
							<xsl:otherwise>
								<ui:cell-list width="150" name="signal" id="signal" value="{$default-signal}">
									<xsl:for-each select="exsl:node-set($signals)/option">
										<ui:list-item id="{@value}" title="{.}">
											<xsl:if test=". = $default-signal">
												<xsl:attribute name="selected">1</xsl:attribute>
											</xsl:if>
										</ui:list-item>
									</xsl:for-each>
								</ui:cell-list>
							</xsl:otherwise>
						</xsl:choose>
						<ui:cell-buttons cell-width="100%">
							<ui:button type="submit" name="kill" id="kill" html-class="FormButton"
								tip="send_signal">
								<xsl:choose>
									<xsl:when test="$simple">
										<sw:text>End Process</sw:text>
									</xsl:when>
									<xsl:otherwise>
										<sw:text>Send Signal</sw:text>
									</xsl:otherwise>
								</xsl:choose>
							</ui:button>
							<ui:button type="submit" name="auto" id="btn_refresh" html-class="FormButton125"
								tip="switch_proc_refresh" onclick="switchRefresh(null);return false;">
								<sw:text>Enable Autorefresh</sw:text>
							</ui:button>
						</ui:cell-buttons>
					</ui:row>
				</ui:rows>
			</ui:block>
			<ui:hidden name="timerOn" value="0"/>
		</xsl:if>

		<ui:browse title="{sw:text('System Processes')}">

			<ui:filter>
				<xsl:copy-of select="$filter"/>
			</ui:filter>

			<ui:browse-empty-msg stop-sign="yes">
				<sw:text>
					No information on the Container processes can be retrieved. <br/> The Container is probably misconfigured or short of resources.
				</sw:text>
			</ui:browse-empty-msg>
		</ui:browse>

	</xsl:template>

	<func:function name="local:get-filter">
		<xsl:param name="plain" select="false()"/>

		<xsl:variable name="eid" select="sw:ve-eid()"/>

		<!-- get info about processes in VE -->
		<xsl:variable name="browse_request">
			<packet>
				<!-- check premissions before execute request -->
				<xsl:if test="cred:check-env('vzcp.env.manage.services_and_files',$eid)">
					<target>vzaproc_info</target>
					<xsl:copy-of select="sw:hn-dst($eid)"/>
					<data>
						<vzaproc_info>
							<get>
								<eid><xsl:value-of select="$eid"/></eid>
							</get>
						</vzaproc_info>
					</data>
				</xsl:if>
			</packet>
		</xsl:variable>
		<xsl:variable name="browse_result" select="sw:xchg($browse_request)"/>
		<!-- /get info about processes in VE -->

		<!-- mix in one node next info: 
				-short name of params from vocabular (for print in titles), 
				-position of param in ps_info structure (for referrer while values printed)
		 -->
		<xsl:variable name="voc-ps" select="voc:get('ps', env:make-platform-ref(sw:ve-parent($eid)))"/>
		<xsl:variable name="params-definition-rtf">
			<xsl:for-each select="$browse_result/packet/data/vzaproc_info/ps_info/param_id">
				<param-def>
					<xsl:variable name="def" select="$voc-ps[id = current()]"/>
					<short-desc>
						<xsl:value-of select="$def/short"/>
					</short-desc>
					<xsl:copy-of select="$def/type"/>
					<xsl:copy-of select="$def/id"/>
					<xsl:copy-of select="$def/search"/>
					<position>
						<xsl:value-of select="position()"/>
					</position>
				</param-def>
			</xsl:for-each>
		</xsl:variable>
		<xsl:variable name="params-definition" select="exsl:node-set($params-definition-rtf)"/>
		<!-- /end of mix -->

		<xsl:variable name="filter_init_">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="proc" url="/vzdir/infrman/envs/procs"
						items-title="{sw:text('Processes')}">
						<xsl:if test="$plain">
							<xsl:attribute name="hide-filter-controls">true</xsl:attribute>
							<xsl:attribute name="post-only-rows">true</xsl:attribute>
						</xsl:if>
						<xsl:if test="not($plain)">
							<xsl:attribute name="div-rows-id">div_browse</xsl:attribute>
						</xsl:if>
						<xsl:attribute name="select-js">
							switchRefresh(0);
						</xsl:attribute>
					</ui:browse-setup>
					<ui:cols sorting-direction="asc">
						<ui:column id="pid" nav-type="id" show-url="no" data-type="int" title="{sw:text('PID')}"
							filter="auto" for-select="yes"/>
						<xsl:for-each select="$params-definition/param-def">
							<xsl:variable name="title">
								<sw:text domain="vzagent-vocabulary" select="string(short-desc)"/>
							</xsl:variable>
							<ui:column id="param-{current()/position}" title="{$title}">
								<!-- Define column type -->
								<xsl:choose>
									<xsl:when test="type='int'">
										<xsl:attribute name="data-type">int</xsl:attribute>
									</xsl:when>
									<xsl:when test="type='float'">
										<xsl:attribute name="data-type">float</xsl:attribute>
									</xsl:when>
								</xsl:choose>
								<!--/-->
								<!-- Define filter -->
								<xsl:if test="search">
									<xsl:attribute name="filter">auto</xsl:attribute>
								</xsl:if>
								<!--/-->
							</ui:column>
						</xsl:for-each>
					</ui:cols>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="filter">
			<xsl:call-template name="browse:fill-filter">
				<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
				<xsl:with-param name="rows">
					<ui:browse-rows>
						<xsl:for-each select="$browse_result/packet/data/vzaproc_info/ps_info/process">
							<ui:row>
								<xsl:if test="pid = 1">
									<!-- disable checkbox for init -->
									<xsl:attribute name="disable-checkbox">yes</xsl:attribute>
								</xsl:if>
								<xsl:copy-of select="pid"/>
								<xsl:variable name="process" select="."/>

								<xsl:for-each select="$params-definition/param-def">
									<xsl:element name="param-{current()/position}">
										<xsl:value-of
											select="sw:base64-decode($process/param[position() = current()/position])"/>
									</xsl:element>
								</xsl:for-each>

							</ui:row>
						</xsl:for-each>
					</ui:browse-rows>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<func:result select="$filter"/>
	</func:function>

	<sw:include href="../lib/core/browse-filter-raw.xsl"/>

	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
