<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func vzenv"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl	="http://exslt.org/common"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:func	="http://exslt.org/functions"
	xmlns:vzenv ="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:sb		="http://www.swsoft.com/xsl/cp/sb"
	xmlns:reg32	="http://www.swsoft.com/xsl/cp/reg32"
	xmlns:env		="http://www.swsoft.com/xsl/cp/env"
	xmlns:vt		="http://www.swsoft.com/xsl/cp/vt"	
>

	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vz/vzenv-offline.xsl"/>	
	<sw:include href="/lib/reg32.xsl"/>

  <!-- Detect precense of sb, installed only  by template -->
	<func:function name="sb:is-service-allowed">
		<xsl:param name="ve-id" select="sw:ve-eid()"/>
		<xsl:variable name="env" select="env:get-env($ve-id)/env"/>
		<xsl:variable name="platform" select="env:env2platform($env)"/>
		<xsl:choose>
			<xsl:when test="vt:is-platform-windows($platform)">
				<!-- Check offline service configuration -->
				<xsl:variable name="service" select="'vzpp-sb'"/>
				<xsl:variable name="service-status" select="exsl:node-set(vzenv:ve-offline-status($service,$ve-id))"/>

				<!-- ask registry	about sb installation -->
				<xsl:variable name="reg-path" select="'Software\SWSoft\Virtuozzo\Shared\SiteBuilder'"/>
				<xsl:variable name="request-for-shared">
					<sb-version>
						<pattern>Version REG_SZ</pattern>
					</sb-version>
					<sb-address>
						<pattern>Address REG_SZ</pattern>
					</sb-address>
				</xsl:variable>
				<xsl:variable name="sb-status" select="reg32:get($reg-path,$request-for-shared)"/>

				<xsl:variable name="reg-path-vps" select="'Software\SWSoft\Virtuozzo\SiteBuilder'"/>
				<xsl:variable name="request-for-vps">
					<reseller-keys>
						<pattern>ResellerKeys REG_SZ</pattern>
					</reseller-keys>
				</xsl:variable>

				<xsl:variable name="sb-status-vps" select="reg32:get($reg-path-vps,$request-for-vps)"/>
				<xsl:variable name="sb-status-vps-reseller-keys-rtf">
					<xsl:choose>
						<xsl:when test="$sb-status-vps/error">
							<error/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:copy-of select="sw:split($sb-status-vps/output/reseller-keys,':')"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<xsl:variable name="sb-status-vps-reseller-keys" select="exsl:node-set($sb-status-vps-reseller-keys-rtf)"/>

				<xsl:variable name="service-login-result-rtf">
					<xsl:choose>
						<xsl:when test="$sb-status/error or $sb-status-vps/error">
							<!-- fail call registry -->
							<rc>100</rc>
							<rc-string> 
								<sw:text>Failed to call the registry.</sw:text>
							</rc-string>
						</xsl:when>   
						<xsl:when test="$service-status/service-global-present = 0">
							<!-- no offline service on HW node -->
							<rc>1</rc>
							<rc-string>
								<sw:text>Offline management is not enabled for vzpp-sb.</sw:text>
							</rc-string>
						</xsl:when>
						<xsl:when test="$service-status/service-present = 0">
							<!-- offline service disable for VPS -->
							<xsl:value-of select="2"/>
							<rc>2</rc>
							<rc-string>
								<sw:text>The vzpp-sb offline management service is not enabled for this Container.</sw:text>
							</rc-string>
						</xsl:when>
						<xsl:when test="not($service-status/ip-address != '')">
							<!-- VPS no has IP address -->
							<xsl:value-of select="3"/>  
							<rc>3</rc>
							<rc-string>
								<sw:text>The Container has no host-routed IP address assigned.</sw:text>
							</rc-string>
						</xsl:when>
						<xsl:when test="not($sb-status/output/sb-version != '') or not($sb-status/output/sb-address != '')">
							<!-- SB vps has not sb template inside -->
							<rc>4</rc>
							<rc-string>
								<sw:text>Sitebuilder is not installed.</sw:text>
							</rc-string>
						</xsl:when>						
						<xsl:when test="$env/status/state != $env-state/running">
							<!-- VE not running -->
							<rc>5</rc>
							<rc-string>
								<sw:text>The Container is not running.</sw:text>
							</rc-string>
						</xsl:when>
						<xsl:when test="not($sb-status-vps-reseller-keys/*[1] != '') or not($sb-status-vps-reseller-keys/*[2] != '')">
							<!-- SB vps has not creds inside  -->
							<rc>6</rc>
							<rc-string>
								<sw:text>No reseller is configured in the Container.</sw:text>
							</rc-string>
						</xsl:when>
						<xsl:otherwise>
							<!-- login allowed -->
							<rc>0</rc>
							<rc-string/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<func:result select="exsl:node-set($service-login-result-rtf)"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="service-login-result-rtf">
					<!-- Linux not suport SB -->
					<rc>7</rc>
					<rc-string>
						<sw:text>Sitebuilder is not supported on non-Windows platforms.</sw:text>
					</rc-string>
				</xsl:variable>
				<func:result select="exsl:node-set($service-login-result-rtf)"/>	
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

</xsl:stylesheet>
