<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw func form check vzenv voc vem local traffic"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
  xmlns:error	="http://www.swsoft.com/xsl/cp/error"
  xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
  xmlns:vzenv	="http://www.swsoft.com/xsl/cp/vzenv"
  xmlns:vem		="http://www.swsoft.com/xsl/cp/vem"
  xmlns:traffic		="http://www.swsoft.com/xsl/cp/traffic"
  xmlns:form	="http://www.swsoft.com/xsl/cp/form"
  xmlns:func	="http://exslt.org/functions"
  xmlns:check	="http://www.swsoft.com/xsl/cp/check"
  xmlns:local	="http://www.swsoft.com/xsl/cp/local"
  xmlns:voc		="http://www.swsoft.com/xsl/cp/voc"
  xmlns:set		="http://exslt.org/sets"
  xmlns:math	="http://exslt.org/math"
  xmlns:env		="http://www.swsoft.com/xsl/cp/env"
>
	<sw:include href="/lib/core/check-funcs.xsl" />
	<sw:include href="../layout/forms-list.xsl" />
	<sw:include href="vz/vzenv-net.xsl"/>
	<xsl:param name="min-class-id" select="0"/>
	<xsl:param name="max-class-id" select="15"/>	

	<func:function name="traffic:restore-hw-interface-ranges">
		<xsl:variable name="res-rtf">
			<xsl:call-template name="form:restore-list">
				<xsl:with-param name="code" select="'ranges'" />
				<xsl:with-param name="row-node-name" select="'range'" />
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="res" select="exsl:node-set($res-rtf)/range" />
		<func:result>
			<xsl:for-each select="$res">
				<range>
					<class_id>
						<xsl:value-of select="id"/>
					</class_id>
					<xsl:variable name="split" select="sw:split(prefix, '/')" />
					<ip_address>
						<xsl:if test="$split[1]">
							<ip>
								<xsl:value-of select="$split[1]" />
							</ip>
						</xsl:if>
						<xsl:choose>
							<xsl:when test="$split[2]">
								<netmask>
									<xsl:value-of select="$split[2]" />
								</netmask>
							</xsl:when>
							<xsl:otherwise>
								<netmask>255.255.255.255</netmask>
							</xsl:otherwise>
						</xsl:choose>
					</ip_address>
				</range>
			</xsl:for-each>
		</func:result>
	</func:function>

	<func:function name="traffic:check-hw-interface-ranges">
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>		
		<xsl:param name="data"/>
		<xsl:variable	name="check-classes" select="$data/config/shaping"/>
		<xsl:for-each select="$data/config/range">
			<xsl:variable name="pos" select="position()"/>
			<xsl:variable name="id" select="number(class_id)"/>
			<xsl:variable name="current-ip" select="ip_address/ip"/>				
			<xsl:variable name="current-netmask" select="ip_address/netmask"/>
			<xsl:if test="check:nan($id) or ($id &lt; $min-class-id) or ($id &gt; $max-class-id)">
				<xsl:variable name="error-report">
					<sw:text>
						<xsl:with-param name="min-class" select="$min-class-id"/>
						<xsl:with-param name="max-class" select="$max-class-id"/>
						Please correct the class ID. It should be a number ranging from %{min-class} to %{max-class}.
					</sw:text>
				</xsl:variable>						
				<xsl:if test="error:put($error-report,'',concat('id_ranges_',$pos))"/>
			</xsl:if>
			<xsl:if test="not(check:ip($current-ip))">
				<xsl:if test="error:put( sw:text('Please correct the network address.'),'',concat('prefix_ranges_',$pos))"/>
			</xsl:if>
			<xsl:if test="not(check:ip($current-netmask))">
				<xsl:if test="error:put( sw:text('Please correct the network mask.'),'',concat('prefix_ranges_',$pos))"/>
			</xsl:if>				
			<xsl:if test="$data/config/range[not(position()=$pos)][ip_address/ip=$current-ip and ip_address/netmask=$current-netmask]">
				<xsl:if test="error:put( sw:text('Duplicate class definition.'),'', concat('id_ranges_', $pos) )" />
			</xsl:if>
		</xsl:for-each>
		
		<xsl:if test="$check-classes">
			<xsl:call-template name="local:check-class-in-env">
				<xsl:with-param name="hn-eid" select="$hn-eid"/>
				<xsl:with-param name="class-id" select="$data/config/range/class_id"/>
			</xsl:call-template>
			<xsl:for-each select="$data/config/class">
				<!-- check that class not defined in rate  -->
				<xsl:variable name="iface-class"	select="id"/>
				<xsl:if test="not($data/config/range[class_id = $iface-class])">
					<xsl:variable name="err-string">
						<sw:text>
							<xsl:with-param name="id" select="$iface-class"/>
							You should define Class %id. The total rate and rate guarantee are configured for this class.
						</sw:text>
					</xsl:variable>
					<xsl:if test="error:put($err-string,'', '')"/>
				</xsl:if>
			</xsl:for-each>
		</xsl:if>
		<func:result/>
	</func:function>
	
	<func:function name="local:get-class-used-in-env">
		<xsl:param name="env-configs"/>
		<xsl:param name="ids"/>
		<!-- collect all class , used in ve , but not defined in class -->
		<xsl:variable name="used-in-env-but-not-defined">
			<xsl:for-each select="set:distinct($env-configs/virtual_config/interface_rate[not(class_id = $ids)]/class_id)">
				<xsl:sort select="."/>
				<xsl:copy-of select="."/>
			</xsl:for-each>
		</xsl:variable>
		<func:result select="exsl:node-set($used-in-env-but-not-defined)/class_id"/>
	</func:function>
	
	<func:function name="local:get-env-configs">
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>
		<xsl:variable name="packet">
			<packet log="on">
				<target>server_group</target>
				<xsl:copy-of select="sw:hn-dst($hn-eid)"/>
				<data>
					<server_group>
				  	<get_info>
				      <config/>
						</get_info>
					</server_group>
				</data>
			</packet>
		</xsl:variable>
		<func:result select="sw:xchg($packet)/packet/data/server_group/env[parent_eid = $hn-eid]"/>
	</func:function>

	<xsl:template name="local:check-class-in-env">
		<xsl:param name="hn-eid"/>	
		<xsl:param name="class-id"/>
		<xsl:variable name="env-configs" select="local:get-env-configs($hn-eid)" />
		<xsl:for-each select="local:get-class-used-in-env($env-configs, $class-id)">
			<xsl:variable name="id" select="."/>
			<xsl:variable name="env-with-class" select="set:distinct($env-configs[virtual_config/interface_rate/class_id=$id]/eid)"/>
			<xsl:variable name="err-string">
				<sw:text-plural>
					<sw:text-zero/>
					<sw:text-single>You should define Class %id. There is a Container with its traffic shaping enabled for this class.</sw:text-single>
					<sw:text-multiple>You should define Class %id. There are Containers with their traffic shaping enabled for this class.</sw:text-multiple>
					<xsl:with-param name="num" select="count($env-with-class)"/>
					<xsl:with-param name="id" select="$id"/>
				</sw:text-plural>
			</xsl:variable>
			<xsl:variable name="err">
				<sw:text-plural>
					<sw:text-zero/>
					<sw:text-single>Shaping for this class is configured for the following Container:</sw:text-single>
					<sw:text-multiple>Shaping for this class is configured for the following Containers:</sw:text-multiple>
					<xsl:with-param name="num" select="count($env-with-class)"/>
				</sw:text-plural>
				<xsl:for-each select="$env-with-class">
					<xsl:if test="position() &gt; 1">,</xsl:if>
					<xsl:text>&#160;</xsl:text>
					<xsl:value-of select="env:env2title(env:get-env(.)/env)"/>
				</xsl:for-each>
			</xsl:variable>
			<xsl:if test="error:put( $err-string, $err, '')" />
		</xsl:for-each>
	</xsl:template>

	<func:function name="traffic:show-hw-interface-ranges">
		<xsl:param name="ranges"/>
		<func:result>
			<xsl:call-template name="form:show-list">
				<xsl:with-param name="config">
					<code>ranges</code>
					<add_label>
						<sw:text>Add a new 'Class ID/Network' pair.</sw:text>
					</add_label>
					<remove_label>
						<sw:text>Remove this 'Class ID/Network' pair.</sw:text>
					</remove_label>
					<xsl:for-each select="$ranges">
						<xsl:variable name="ip" 			select="ip_address/ip"/>
						<xsl:variable name="netmask"	select="ip_address/netmask"/>						
						<ui:row>
							<ui:cell>
								<nobr>
									<sw:text>Class ID</sw:text>
								</nobr>
							</ui:cell>
							<ui:cell-input nowrap="1" maxlength="3" id="id" value="{class_id}"
								tip="ip_class" onmouseout="callTip()" width="3" />
							<ui:cell cell-width="10" label=""/>
							<ui:cell>
								<nobr>
									&#160;
									<sw:text>Network</sw:text>
								</nobr>
							</ui:cell>
							<ui:cell-input nowrap="1" maxlength="32" id="prefix"
								value="{sw:if($netmask = '255.255.255.255', $ip, concat($ip, '/', $netmask))}"
								tip="network_prefix" width="32">
							</ui:cell-input>
							<ui:cell cell-width="100%" label=""/>
						</ui:row>
					</xsl:for-each>
					<ui:new-row>
						<ui:cell>
							<nobr>
								<sw:text>Class ID</sw:text>
							</nobr>
						</ui:cell>
						<ui:cell-input nowrap="1" maxlength="3" id="id" tip="ip_class" width="3"/>
						<ui:cell cell-width="10" label=""/>
						<ui:cell label="prefix">
							<nobr>
								&#160;
								<sw:text>Network</sw:text>
							</nobr>
						</ui:cell>
						<ui:cell-input nowrap="1" maxlength="32" id="prefix" tip="network_prefix" width="32"/>
						<ui:cell cell-width="100%" label=""/>
					</ui:new-row>
				</xsl:with-param>
			</xsl:call-template>
		</func:result>
	</func:function>

	<func:function name="traffic:check-interface-shaping">
		<xsl:param name="data"/>
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>		
		<xsl:for-each select="$data/config/class">
			<xsl:variable name="class-id" select="id"/>
			<xsl:if test="(check:nan(totalrate)) or not(check:num(totalrate,true()))">
				<xsl:if test="error:put( sw:text('Please correct the total rate. It should be a positive value.'),'',concat('totalrate_', $class-id))"/>
			</xsl:if>
			<xsl:if test="$data/hn/linux and ((check:nan(rate)) or not(check:num(rate,true())))">
				<xsl:if test="error:put( sw:text('Please correct the rate gurantee. It should be a non-negative integer value.'),'',concat('rate_', $class-id))"/>
			</xsl:if>
		</xsl:for-each>
		<xsl:call-template name="local:check-class-in-env">
    	<xsl:with-param name="hn-eid" select="$hn-eid"/>
      <xsl:with-param name="class-id" select="$data/config/class/id"/>
		</xsl:call-template>
		<func:result/>
	</func:function>

	<!-- validate vzanetworkm/net_config/interfcae.
			input: data is  vzanetworkm/net_config/interface node 
	-->
	<func:function name="traffic:check-interface-bandwith">
		<xsl:param name="data"/>
		<xsl:variable name="interface" select="$data/net_device_id"/>
		<xsl:variable name="bandwidth" select="$data/bandwidth"/>
		<xsl:variable name="label" select="concat($interface, '_')" />
		<xsl:variable name="invalid-band" select="(check:nan($bandwidth))  or not(check:num($bandwidth,true()))"/>
		<xsl:if test="$invalid-band = true()">
			<xsl:variable name="error-string">
				<sw:text>
					<xsl:with-param name="iface" select="$interface"/>
						Please correct the bandwidth for interface %{iface}. It should be a positive integer value.
				</sw:text>
			</xsl:variable>
			<xsl:if test="error:put( $error-string,'',concat($interface, '_bandwidth'))"/>
		</xsl:if>
		<func:result/>
	</func:function>

	<func:function name="traffic:filter-by-class">
		<xsl:param name="id"/>
		<func:result select="sw:if($id &gt;= $min-class-id, true(), false())"/>
	</func:function>

	<!-- input  node:
				 ve/interface_rate
			 							class_id
			 							rate
			 what do: 
			 	Check that rate is valid: number or NOTDEFINED (means that no shaping for such class_id),
			 output: none, set error in case check fail
	-->
	<func:function name="traffic:check-env-shaping">
		<xsl:param name="data"/>
		<xsl:for-each select="$data/interface_rate">
			<xsl:variable name="class-id" select="class_id"/>
			<xsl:if test="(check:nan(rate)) or not(check:num(rate,true()))">
				<xsl:if test="error:put( sw:text('Please correct the Container rate gurantee. It should be a non-negative integer value.'),'',concat('rate_', $class-id))"/>
			</xsl:if>
		</xsl:for-each>
		<func:result/>
	</func:function>

</xsl:stylesheet>
