<!--
	Copyright (c) SWsoft, 1999-2007
	All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func error voc hw hwm action update local date"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:vzenv="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:vzpp="http://www.swsoft.com/xsl/cp/vzpp" xmlns:func="http://exslt.org/functions"
	xmlns:hw="http://www.swsoft.com/xsl/cp/hw" xmlns:hwm="http://www.swsoft.com/xsl/cp/hwm"
	xmlns:update="http://www.swsoft.com/xsl/cp/update" xmlns:voc="http://www.swsoft.com/xsl/cp/voc"
	xmlns:local="http://www.swsoft.com/xsl/cp/local" xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:user="http://www.swsoft.com/xsl/cp/user"
	xmlns:vzapackagem="http://www.swsoft.com/xsl/cp/vzapackagem"
	xmlns:date="http://exslt.org/dates-and-times"
	xmlns:action="http://www.swsoft.com/xsl/cp/action"
	xmlns:set="http://exslt.org/sets" 
	xmlns:vzaup2date="http://www.swsoft.com/webservices/vza/4.0.0/vzaup2date"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
	
	<sw:include href="/lib/vz/vzenv-core.xsl" />
	<sw:include href="/lib/vza/vzapackagem.xsl" />
	<sw:include href="/lib/core/user-attrs.xsl" />
	<sw:include href="/lib/common.xsl" />
	<sw:include	href="/lib/vt/core.xsl"/>
	
	<func:function name="update:install-types">
		<xsl:variable name="local:install-types">
			<type id="automatic">
				<sw:text>Automatic</sw:text>
			</type>
			<type id="auto_download">
				<sw:text>Download only</sw:text>
			</type>
			<type id="manual">
				<sw:text>Manual</sw:text>
			</type>
			<type id="disabled">
				<sw:text>Disabled</sw:text>
			</type>
		</xsl:variable>
		<func:result select="exsl:node-set($local:install-types)/type" />
	</func:function>
	
	<func:function name="update:proxy-types">
		<xsl:variable name="local:proxy-types">
			<type id="no_proxy">
				<sw:text>Do not use proxy server</sw:text>
			</type>
			<type id="explorer" auth="true">
				<sw:text>Load Internet Explorer proxy settings</sw:text>
			</type>
			<type id="custom" auth="true" url="true">
				<sw:text>Specify a proxy server</sw:text>
			</type>
		</xsl:variable>
		<func:result select="exsl:node-set($local:proxy-types)/type" />
	</func:function>
	
	<func:function name="update:is-new">
		<xsl:param name="update"/>
		<func:result select="not($update/product) and (not($update/installed_version) or string($update/installed_version)='')"/>
	</func:function>
	
	<func:function name="update:is-update">
		<xsl:param name="update"/>
		<xsl:choose>
			<xsl:when test="$update/product">
				<func:result select="not($update/installed_version)"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="string($update/installed_version)!=string($update/version) 
										and string($update/installed_version)!='unknown'"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	
	<!-- Create aliases mapping for vzagent update classes -->
	<xsl:variable name="update:types" select="update:enumerate-types()"/>
	
	<func:function name="update:enumerate-types">
		<xsl:variable name="update-types-rtf">
			<types>
				<system>system_updateType</system>
				<windows>windows_system_updateType</windows>
				<all-templates>template_updateType</all-templates>
				<os-templates>os_template_updateType</os-templates>
				<ez-os-templates>ez_template_updateType</ez-os-templates>
				<app-templates>app_template_updateType</app-templates>
			</types>
		</xsl:variable>
		<func:result select="exsl:node-set($update-types-rtf)/types"/>
	</func:function>
	
	<xsl:template name="update:generate-update">
		<xsl:param name="type" />
		<xsl:param name="id" select="/.." />
		<xsl:param name="content" select="/.." />
		<xsl:param name="node" select="'update'" />

		<xsl:choose>
			<xsl:when test="$node='update'">
				<update xmlns:vzaup2date="http://www.swsoft.com/webservices/vza/4.0.0/vzaup2date">
					<xsl:attribute name="type" namespace="http://www.w3.org/2001/XMLSchema-instance">vzaup2date:<xsl:value-of
							select="$type" />
					</xsl:attribute>
					<xsl:if test="$id">
						<id>
							<xsl:value-of select="$id" />
						</id>
					</xsl:if>
					<xsl:copy-of select="$content" />
				</update>
			</xsl:when>
			<xsl:when test="$node ='app_template'">
				<app_template xmlns:vzaup2date="http://www.swsoft.com/webservices/vza/4.0.0/vzaup2date">
					<xsl:attribute name="type" namespace="http://www.w3.org/2001/XMLSchema-instance">vzaup2date:<xsl:value-of
							select="$type" />
					</xsl:attribute>
					<xsl:if test="$id">
						<id>
							<xsl:value-of select="$id" />
						</id>
					</xsl:if>
					<xsl:copy-of select="$content" />
				</app_template>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<func:function name="update:generate-update">
		<xsl:param name="type"/>
		<xsl:param name="update-id" select="/.."/>
		<xsl:param name="content" select="/.."/>
		<xsl:param name="node" select="'update'"/>
		
		<xsl:variable name="res">
			<xsl:call-template name="update:generate-update">
				<xsl:with-param name="type" select="$type"/>
				<xsl:with-param name="id" select="$update-id"/>
				<xsl:with-param name="content" select="$content"/>
				<xsl:with-param name="node" select="$node"/>
			</xsl:call-template>
		</xsl:variable>

		<func:result select="exsl:node-set($res)/update"/>
	</func:function>
	
	<func:function name="update:type">
		<xsl:param name="update"/>
		
		<func:result>
			<xsl:for-each select="$update/@*">
			 	<xsl:if test="contains(name(.), 'type')">
			 		<xsl:value-of select="substring-after(., ':')"/>
			 	</xsl:if>
			</xsl:for-each>
		 </func:result>
	</func:function>
	
	<func:function name="update:generate-id">
		<xsl:param name="update"/>
		<xsl:param name="force-type" select="/.."/>
		
		<xsl:choose>
			<xsl:when test="not($update) or exsl:object-type($update)!='node-set' or not($update/*)">
				<func:result select="$update"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="type" select="sw:if($forced-type, $forced-type, update:type($update))"/>
				<func:result select="concat($type, '/', $update/id)"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	
	<func:function name="update:data-id">
		<func:result select="'vzaup2date_selected'" />
	</func:function>
	
	<func:function name="update:cache-template-update-list">
		<xsl:param name="updates" />
		<xsl:param name="eid" select="sw:hn-eid()"/>

		<xsl:variable name="old" select="update:get-cached-update-list($eid)" />
		
		<xsl:variable name="types" select="local:get-types($updates)"/>

		<xsl:variable name="new-private">
			<vzaup2date>
				<xsl:copy-of select="$old/update[not($types=update:type(.))]|virtuozzo"/>
				
				<xsl:choose>
					<xsl:when test="not($updates)">
						<xsl:copy-of select="update:generate-update($update:types/os-template)"/>
						<xsl:copy-of select="update:generate-update($update:types/ez-os-template)"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="$updates"/>
					</xsl:otherwise>
				</xsl:choose>
				<timestamp>
					<xsl:value-of select="sw:time2vzatime(date:date-time())" />
				</timestamp>
			</vzaup2date>
		</xsl:variable>

		<func:result select="local:save-cache($new-private, $eid)" />
	</func:function>
	
	<func:function name="local:get-types">
		<xsl:param name="updates"/>
		
		<xsl:variable name="types">
			<xsl:for-each select="$updates">
				<type><xsl:value-of select="update:type(.)"/></type>
			</xsl:for-each> 
		</xsl:variable>
		
		<func:result select="set:distinct(exsl:node-set($types)/type)"/>		
	</func:function>
	
	<func:function name="update:cache-major-update-list">
		<xsl:param name="updates"/>
		<xsl:param name="eid" select="sw:hn-eid()"/>
		
		<xsl:variable name="old" select="update:get-cached-update-list($eid)"/>
		
		<xsl:variable name="types" select="local:get-types($updates)"/>
		
		<xsl:variable name="new-private">
			<vzaup2date>
				<xsl:copy-of select="$old/update[($update:types/os-template|$update:types/ez-os-template)=update:type(.)]|templates"/>
				<xsl:choose>
					<xsl:when test="not($updates)">
						<xsl:copy-of select="update:generate-update($update:types/system)"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="$updates"/>
					</xsl:otherwise>
				</xsl:choose>
				<timestamp>
					<xsl:value-of select="sw:time2vzatime(date:date-time())" />
				</timestamp>
			</vzaup2date>
		</xsl:variable>
		
		<func:result select="local:save-cache($new-private, $eid)" />
	</func:function>
	
	<func:function name="update:clear-cached-template-update-list">
		<xsl:param name="eid" select="sw:hn-eid()"/>
		
		<xsl:variable name="new-private">
			<vzaup2date>
				<xsl:variable name="old" select="update:get-cached-update-list($eid)" />
				<xsl:copy-of select="$old/update[not(
													($update:types/os-templates|$update:types/ez-os-templates|$update:types/all-templates)=update:type(.)
												)]|virtuozzo"/>
				<timestamp>
					<xsl:value-of select="sw:time2vzatime(date:date-time())" />
				</timestamp>
			</vzaup2date>
		</xsl:variable>
		<func:result select="local:save-cache($new-private, $eid)" />
	</func:function>
	
	<func:function name="update:clear-cached-major-update-list">
		<xsl:param name="eid" select="sw:hn-eid()"/>
		<xsl:variable name="new-private">
			<vzaup2date>
				<xsl:variable name="old" select="update:get-cached-update-list($eid)" />
				<xsl:copy-of select="$old/update[not(
													($update:types/system|$update:types/windows)=update:type(.)
												)]|templates"/>
				<timestamp>
					<xsl:value-of select="sw:time2vzatime(date:date-time())" />
				</timestamp>
			</vzaup2date>
		</xsl:variable>
		<func:result select="local:save-cache($new-private, $eid)" />
	</func:function>
	
	<func:function name="local:save-cache">
		<xsl:param name="new-private" />
		<xsl:param name="eid" select="sw:hn-eid()"/>
		
		
		<xsl:if test="local:update-profile($new-private, $eid)" />
		<xsl:variable name="to-save">
			<hn>
				<eid><xsl:value-of select="$eid" /></eid>
				<xsl:copy-of select="$new-private" />
			</hn>
		</xsl:variable>
		<func:result select="sw:put-private(exsl:node-set($new-private), vzenv:veid-to-eid(1), concat('vzaup2date.', $eid))"/>
	</func:function>
	
	<func:function name="local:get-cache">
		<xsl:param name="eid" select="sw:hn-eid()"/>
		<func:result select="sw:get-private(vzenv:veid-to-eid(1), concat('vzaup2date.', $eid))/vzaup2date" />
	</func:function>
	
	<func:function name="update:get-last-update-profile">
		<xsl:param name="eid" select="sw:hn-eid()"/>
		<func:result select="sw:get-private(vzenv:veid-to-eid(1), concat('vzaup2date.profile.', $eid))/profile"/>
	</func:function>
	
	<func:function name="local:update-profile">
		<xsl:param name="new-private" />
		<xsl:param name="eid" select="sw:hn-eid()"/>
		
		<xsl:variable name="data" select="exsl:node-set($new-private)/vzaup2date" />
		
		<!-- detect major updates -->
		<xsl:variable name="major-updates"
			select="count($data/update[category='virtuozzo'][update:is-update(.)])"/>
		<!-- count minor updates -->
		<xsl:variable name="minor-updates"
			select="count($data/update[category='tools' or category='core'][update:is-update(.)])"/>
		
		
		<xsl:variable name="tmpls" select="$data/update[
						($update:types/os-templates|$update:types/ez-os-templates)=update:type(.)
					]"/>
		<!-- count template updates -->
		<xsl:variable name="tmpl-updates"
			select="count($tmpls[update:is-update(.) and not(update:is-new(.))]|$tmpls/app-template[update:is-update(.) and not(update:is-new(.))])"/>
		
		<xsl:variable name="env-profile">
			<profile>
				<xsl:if test="$data/update[($update:types/system|$update:types/windows)=update:type(.)]">
					<major><xsl:value-of select="$major-updates" /></major>
					<minor><xsl:value-of select="$minor-updates" /></minor>
					<xsl:if test="$data/update[category='core'][update:is-update(.)]">
						<latest-kernel>
							<xsl:value-of select="$data/update[category='core'][last()]/id" />
						</latest-kernel>
					</xsl:if>
				</xsl:if>
				<xsl:if test="$tmpls">
					<templates><xsl:value-of select="$tmpl-updates" /></templates>
				</xsl:if>
				<xsl:copy-of select="$data/timestamp" />
			</profile>
		</xsl:variable>
		
		<!-- save attributes to profile -->
		<func:result select="sw:put-private(exsl:node-set($env-profile), vzenv:veid-to-eid(1), concat('vzaup2date.profile.', $eid))" />
	</func:function>
	
	<func:function name="update:is-clear-cache">
		<xsl:param name="cache" />
		<xsl:param name="type" select="false()"/>
		
		<func:result select="not($cache) or ($type and not($cache/update[$type=update:type(.)]))" />
	</func:function>
	
	<func:function name="update:major-cache-needs-refresh">
		<xsl:param name="cache" />
		
		<xsl:variable name="time" select="date:seconds(sw:vzatime2time($cache/timestamp))" />
		<func:result
			select="update:is-clear-cache($cache, $update:types/system|$update:types/windows) 
					or $time=0 
					or (date:seconds() - $time) &gt; update:get-cached-period()" />
	</func:function>
	
	<func:function name="update:template-cache-needs-refresh">
		<xsl:param name="cache" />
		
		<xsl:variable name="time" select="date:seconds(sw:vzatime2time($cache/timestamp))" />
		<xsl:variable name="tmpl" select="$update:types/os-templates|$update:types/ez-os-templates"/>
		
		<func:result
			select="update:is-clear-cache($cache, $tmpl) 
					or $time=0 
					or (date:seconds() - $time) &gt; update:get-cached-period()" />
	</func:function>

	<func:function name="update:cache-update-list-errors">
		<xsl:param name="errors" />
		<xsl:param name="type"/>
		<xsl:param name="eid" select="sw:hn-eid()"/>
		<xsl:variable name="new-private">
			<vzaup2date>
				<xsl:element name="{$type}">
					<xsl:copy-of select="$errors" />
				</xsl:element>			
				<timestamp>
					<xsl:value-of select="sw:time2vzatime(date:date-time())" />
				</timestamp>
			</vzaup2date>
		</xsl:variable>
		<func:result select="local:save-cache($new-private, $eid)" />
	</func:function>
	
	<func:function name="update:get-cached-period">
		<func:result select="24 * 60 * 60" />
	</func:function>

	<func:function name="update:get-cached-update-list">
		<xsl:param name="eid" select="sw:hn-eid()"/>
		<func:result select="local:get-cache($eid)" />
	</func:function>

	<!-- 
		Get vzaup2date server config
	-->
	<func:function name="update:get-config">
		<xsl:param name="eid" select="sw:hn-eid()"/>
		<func:result select="update:filter-error(local:process($eid, 'get_config'), true())" />
	</func:function>

	<func:function name="update:set-config">
		<xsl:param name="filter" />
		<xsl:param name="eid" select="sw:hn-eid()"/>
		
		<func:result select="update:filter-error(local:process($eid, 'set_config', $filter), true())" />
	</func:function>
	
	<func:function name="update:list">
		<xsl:param name="type" select="/.."/>
		<xsl:param name="installed" select="false()"/>
		<xsl:param name="eid" select="sw:hn-eid()"/>
		
		<xsl:variable name="filter">
			<xsl:if test="$type">
				<xsl:call-template name="update:generate-update">
					<xsl:with-param name="type" select="$type"/>
					<xsl:with-param name="content">
						<xsl:if test="$installed">
							<installed/>
						</xsl:if>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
		</xsl:variable>
		
		<func:result select="update:filter-error(local:process($eid, 'list', $filter))"/>
	</func:function>

	<func:function name="update:list-system">
		<xsl:param name="category"/>
		<xsl:param name="type"/>
		<xsl:param name="eid" select="sw:hn-eid()"/>
		
		<xsl:variable name="updates" select="update:list($update:types/system)"/>
		<xsl:choose>
			<xsl:when test="$type">
				<func:result select="$updates[category=$category and type=$type]"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="$updates[category=$category]"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	
	<func:function name="update:list-templates">
		<xsl:param name="eid" select="sw:hn-eid()"/>
		
		<xsl:variable name="filter">
			<xsl:for-each select="$update:types/os-templates|$update:types/ez-os-templates">
				<xsl:call-template name="update:generate-update">
					<xsl:with-param name="type" select="."/>
					<xsl:with-param name="content">
						<xsl:call-template name="update:generate-update">
							<xsl:with-param name="type" select="$update:types/app-templates"/>
							<xsl:with-param name="node" select="'app_template'"/>
						</xsl:call-template>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:for-each>
		</xsl:variable>
		
		<func:result select="update:filter-error(local:process($eid, 'list', $filter))"/>
	</func:function>
	
	<func:function name="update:packet">
		<xsl:param name="eid"/>
		<xsl:param name="command" />
		<xsl:param name="filter" select="''" />
		<xsl:param name="header" select="false()" />
		<xsl:param name="log" select="false()" />
		<xsl:param name="progress" select="false()" />

		<func:result>
			<packet>
				<xsl:if test="$log">
					<xsl:attribute name="log">on</xsl:attribute>
				</xsl:if>
				<xsl:if test="$progress">
					<xsl:attribute name="progress">on</xsl:attribute>
				</xsl:if>
				<target>vzaup2date</target>
				<xsl:copy-of select="sw:hn-dst($eid)" />
				<xsl:if test="$header">
					<xsl:copy-of select="$header" />
				</xsl:if>
				<data>
					<vzaup2date>
						<xsl:element name="{$command}">
							<xsl:if test="$filter">
								<xsl:copy-of select="$filter" />
							</xsl:if>
						</xsl:element>
					</vzaup2date>
				</data>
			</packet>
		</func:result>
	</func:function>
	
	<func:function name="update:action-update">
		<xsl:param name="info" />
		<xsl:param name="eid" select="sw:hn-eid()"/>

		<xsl:variable name="header">
			<msg>
				<sched>Virtuozzo updates installation is scheduled.</sched>
				<error>Failed to install Virtuozzo updates.</error>
			</msg>
			<operation>vzaup2date</operation>
		</xsl:variable>
		<func:result select="update:packet($eid, 'install', local:action-filter($info), $header, true())" />
	</func:function>

	<func:function name="local:action-filter">
		<xsl:param name="info" />
		<xsl:variable name="updates" select="exsl:node-set($info)" />
		<func:result select="$updates/update|$updates/selected/update|$updates/no_reboot|$updates/no_boot_loader"/>
	</func:function>

	<func:function name="update:get-errors">
		<xsl:param name="data" />
		<func:result select="sw:if($data, $data[name()='error']|$data/error|$data/vzaup2date/error, /..)" />
	</func:function>
	
	<func:function name="update:filter-error">
		<xsl:param name="data"/>
		<xsl:param name="report" select="false()"/>
		
		<xsl:choose>
			<xsl:when test="$data/error">
				<xsl:if test="not($report) or error:put(sw:text('Error processing the request to vzup2date.'),$data/error/message,'')"/>
				<func:result select="$data/error"/>
			</xsl:when>
			<xsl:when test="$data/vzaup2date/error">
				<xsl:if test="not($report) or error:put(sw:text('An error occurred in the vzup2date system.'),$data/vzaup2date/error/message,'')" />
				<func:result select="$data/vzaup2date/error"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="$data/vzaup2date/*"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<func:function name="local:process">
		<xsl:param name="eid"/>
		<xsl:param name="command" />
		<xsl:param name="filter" select="''" />

		<xsl:variable name="result" select="sw:xchg(update:packet($eid, $command, $filter))" />
		
		<func:result select="$result/packet/data" />
	</func:function>
	
	<func:function name="local:xchg">
		<xsl:param name="pkt"/>
		
		<xsl:variable name="packet" select="exsl:node-set($pkt)"/>
		
		<xsl:choose>
			<xsl:when test="not($packet/packet/@id)">
				<func:result select="local:xchg(sw:xchg($packet))"/>
			</xsl:when>
			<xsl:when test="not($packet/packet/data/progress)">
				<func:result select="$packet"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="local:xchg(sw:recv($packet/packet/@id))"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	

	<func:function name="update:get-list-with-deps">
		<xsl:param name="data" />
		<xsl:param name="uid" />

		<xsl:variable name="update" select="$data/update[uid=$uid]" />
		<xsl:variable name="cat" select="$update/category" />
		<xsl:variable name="updates"
			select="$data/update[uid=$uid and category!='major-update']/preceding-sibling::node()[name()='update' and category=$cat]" />

		<xsl:variable name="res">
			<xsl:if test="$update">
				<xsl:call-template name="local:reverse">
					<xsl:with-param name="data" select="$update|$updates" />
				</xsl:call-template>
			</xsl:if>
		</xsl:variable>
		<func:result select="exsl:node-set($res)/update" />
	</func:function>

	<xsl:template name="local:reverse">
		<xsl:param name="data" />

		<xsl:if test="$data">
			<xsl:variable name="d" select="$data[position()=last()]" />
			<xsl:copy-of select="$d" />
			<xsl:call-template name="local:reverse">
				<xsl:with-param name="data"
					select="$data/preceding-sibling::node()[name()='update' and category=$d/category]" />
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	
	<func:function name="update:get-task">
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>
		
		<func:result select="local:get-task('vzaup2date.install', $hn-eid)" />
	</func:function>
	
	
	<func:function name="local:get-task">
		<xsl:param name="name" />
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>
		
		<xsl:variable name="browse_request">
			<packet>
				<xsl:copy-of select="sw:hn-dst($hn-eid)"/>
				<target>op_log</target>
				<data>
					<op_log>
						<get_ops>
							<eid><xsl:value-of select="$hn-eid"/></eid>
							<status/>
							<current/>
							<op><xsl:value-of select="$name"/></op>
						</get_ops>
					</op_log>
				</data>
			</packet>
		</xsl:variable>

		<xsl:variable name="browse_result" select="sw:xchg($browse_request)"/>
		
		<xsl:variable name="task" select="$browse_result/packet/data/op_log/progress"/>
		
		<xsl:variable name="ret">
			<task>
				<xsl:copy-of select="$task/op|$task/id|$task/status"/>
			</task>
		</xsl:variable>
		
		<func:result select="exsl:node-set($ret)/task"/>
	</func:function>
	
	<!-- Filter template updates data by removing updates that don't match list of templates  -->
	<func:function name="update:filter-template-updates">
		<xsl:param name="updates"/>
		<xsl:param name="templates"/>
		
		<xsl:variable name="oses" select="$templates[vzapackagem:is-os(.)]"/>
		<xsl:variable name="apps" select="$templates[not(vzapackagem:is-os(.))]"/>
		
		<xsl:variable name="os-names" select="set:distinct($oses/name|$apps/os/name)"/>
		
		<xsl:variable name="res">
			<xsl:for-each select="$os-names">
				<xsl:variable name="os" select="string(.)"/>
				<xsl:variable name="os-apps" select="$apps[os/name=$os]"/>
				
				<xsl:choose>
					<xsl:when test="sw:is-ez-package(.)">
						<xsl:variable name="name" select="concat(substring-after(., '.'), '-ez')"/>
						
						<xsl:for-each select="$updates[id=$name and update:type(.)=$update:types/ez-os-templates]">
							<xsl:call-template name="update:generate-update">
								<xsl:with-param name="type" select="$update:types/ez-os-templates"/>
								<xsl:with-param name="id" select="id" />
								<xsl:with-param name="content">
									<xsl:if test="$oses[name=$os]">
										<xsl:copy-of select="*[not(self::id or self::app_template)]"/>
									</xsl:if>
									<xsl:variable name="app-updates" select="app_template"/>
									<xsl:for-each select="$os-apps">
										<xsl:copy-of select="$app-updates[id=concat(substring-after(., '.'), '-', $name)]"/>
									</xsl:for-each>									
								</xsl:with-param>
							</xsl:call-template>
						</xsl:for-each>
					</xsl:when>
					<xsl:otherwise>
						<xsl:for-each select="$updates[id=$os and update:type(.)=$update:types/os-templates]">
							<xsl:call-template name="update:generate-update">
								<xsl:with-param name="type" select="$update:types/os-templates"/>
								<xsl:with-param name="id" select="id" />
								<xsl:with-param name="content">
									<xsl:if test="$oses[name=$os]">
										<xsl:copy-of select="*[not(self::id or self::app_template)]"/>
									</xsl:if>
									<xsl:variable name="app-updates" select="app_template"/>
									<xsl:for-each select="$os-apps">
										<xsl:copy-of select="$app-updates[id=name]"/>
									</xsl:for-each>									
								</xsl:with-param>
							</xsl:call-template>
						</xsl:for-each>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
		</xsl:variable>
		<func:result select="exsl:node-set($res)/update"/>
	</func:function>
	
	
	<func:function name="update:list-hns">
		<xsl:variable name="hns-query">				
			<fields>
				<env.eid/>
				<env.state />
				<env.config.hostname/>								
				<env.config.ip_text/>
				<env.config.os.platform/>
				<env.config.architecture/>
			</fields>
			<where>
				pager.env.config.type='generic'
				and pager.env.state='<xsl:value-of select="$env-state/running"/>'											
			</where>
		</xsl:variable>
				

		<xsl:variable name="result-rtf">				
			<hns>
				<xsl:for-each select="sw:xchg-sql($hns-query)/pager/row_set/row/env">
					<xsl:variable name="update-profile" select="update:get-last-update-profile(eid)"/>
					<hn>
						<eid><xsl:value-of select="eid"/></eid>
						<hostname><xsl:value-of select="config/hostname"/></hostname>
						<ip><xsl:value-of select="config/ip_text"/></ip>
						<platform><xsl:value-of select="hn:vza2platform(config/os/platform)"/></platform>
						<status><xsl:value-of select="state" /></status>
						<tech>vz.vt</tech>
						<system-up2date>
							<xsl:copy-of select="$update-profile/major|$update-profile/minor|$update-profile/templates"/>
						</system-up2date>
						<last-update-time>
							<xsl:copy-of select="$update-profile/timestamp"/>
						</last-update-time>
					</hn>
				</xsl:for-each>
			</hns>
		</xsl:variable>
		
		<func:result select="exsl:node-set($result-rtf)/hns"/>
		
	</func:function>

</xsl:stylesheet>
