<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred vz func voc tem local"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:func		="http://exslt.org/functions"
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
	xmlns:browse	="http://www.swsoft.com/xsl/cp/browse"
	xmlns:cred		="http://www.swsoft.com/xsl/cp/cred"
	xmlns:vz		="http://www.swsoft.com/xsl/cp/vz"
	xmlns:voc		="http://www.swsoft.com/xsl/cp/voc"
	xmlns:tem		="http://www.swsoft.com/xsl/cp/tem"
	xmlns:vzapackagem	="http://www.swsoft.com/xsl/cp/vzapackagem"
	xmlns:vzhn		="http://www.swsoft.com/xsl/cp/vzhn"
	xmlns:vzenv		="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"
	xmlns:units		="http://www.swsoft.com/xsl/cp/units"
	xmlns:vt		="http://www.swsoft.com/xsl/cp/vt"
	xmlns:hn		="http://www.swsoft.com/xsl/cp/hn"
	xmlns:math		="http://exslt.org/math"
	xmlns:set		="http://exslt.org/sets">

	<sw:include href="/lib/vz/core.xsl" />
	<sw:include href="/lib/vt/env-core.xsl" />
	<sw:include href="/lib/vza/vzapackagem.xsl" />
	<sw:include href="/lib/core/units-core.xsl"/>
	
	<func:function name="vz:get-old-win-os-name">
		<func:result select="'w2k3'"/>
	</func:function>
	
	<!-- This function is needed to determine special case - old windows OS(w2k3) template name in samples, and
		avoid warnings, effectively selecting first available windows OS template.
		
		name    : OS template name specified in sample
		platform-ref : HN platform data
	 -->
	<func:function name="vz:is-old-win-os-name">
		<xsl:param name="name"/>
		<xsl:param name="platform-ref"/>
		
		<xsl:choose>
			<xsl:when test="vt:is-platform-linux($platform-ref/platform)">
				<func:result select="false()"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="old-os-name" select="vz:get-old-win-os-name()"/>
				<func:result select="not(string($name)='') and string($name)=string($old-os-name)"/>
			</xsl:otherwise>
		</xsl:choose>		
	</func:function>
	
	<func:function name="vz:has-ve-updates">
		<xsl:param name="eid"/>
		
		<xsl:variable name="pkg" select="vzapackagem:eid2os-template($eid)"/>
		
		<xsl:choose>
			<xsl:when test="sw:is-ez-package($pkg/name)">
				<xsl:variable name="list" select="vzapackagem:list4env($eid, 'os')/packet/data/vzapackagem/packages/package"/>
				<func:result select="not(string($list[vzapackagem:equals(self::package, $pkg)]/uptodate)='1')"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="list" select="vzapackagem:eid2templates($eid)"/>
				<func:result select="vzapackagem:find-ve-updates($list, vz:list-templates-for-select(sw:ve-parent($eid), 
										$list[vzapackagem:is-os(.)][1], 'all', /.., 
										cred:check-env('vzcp.env.manage.properties.application', $eid)))"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	
	<func:function name="local:get-os-ref">
 		<xsl:param name="os"/>
 		<xsl:param name="platform"/>
 		
 		<xsl:variable name="os-ref">
 			<package>
 				<xsl:copy-of select="$os/name"/>
 				<xsl:choose>
 					<xsl:when test="$os/version">
 						<xsl:copy-of select="$os/version"/>
 					</xsl:when>
 					<xsl:otherwise>
 						<version/>
 					</xsl:otherwise>
 				</xsl:choose>
 				<os>
 					<platform><xsl:value-of select="vt:platform2vza($platform)"/></platform>
 				</os>
 				<arch><xsl:value-of select="vzapackagem:vza-arch2pkg(
 										vt:platform2vza-architecture($platform)
 									)"/></arch>
 				<os_template>1</os_template>
 			</package>
 		</xsl:variable>
 		<func:result select="exsl:node-set($os-ref)/package"/>
 	</func:function>
	
	<!--
		Load applications available on specified HW

		Requires:
			lib/vza/tem.xsl
			lib/vza/vzapackagem.xsl
	-->
	<func:function name="vz:load-hw-apps">
		<xsl:param name="os" />
		<xsl:param name="platform-ref"/>
		<xsl:param name="type" select="'all'"/><!-- all/app/os-->
		<xsl:param name="auth" select="false()"/>
		
		<xsl:variable name="os-ref" select="local:get-os-ref($os, 
												sw:if(string($platform-ref/platform)='', 
													vt:platform-linux(),
													$platform-ref/platform))"/>
		
		<xsl:variable name="is-w2k3" select="vz:is-old-win-os-name($os/name, $platform-ref)"/>
		
		<xsl:choose>
			<xsl:when test="sw:is-ez-package($os/name) or string($platform-ref/hn-eid)='' 
								or $is-w2k3">
				<xsl:variable name="pkgs" select="vz:list-templates-for-select($platform-ref/hn-eid, $os-ref, $type, /.., $auth)"/>
				<xsl:if test="$pkgs[self::error]">
					<sw:die>
						An error occurred during the templates retrieval.
						<xsl:value-of select="$pkgs[self::error]/message"/>
					</sw:die>
				</xsl:if>
		
				<func:result select="$pkgs"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="pkgs" select="vzapackagem:list-compatible4os($os-ref, $platform-ref/hn-eid, $type, true(), $auth)"/>
				<xsl:if test="$pkgs/packet/data/error|$pkgs/packet/data/vzapackagem/error">
					<sw:die>
						An error occurred during the templates retrieval.
						<xsl:value-of select="($pkgs/packet/data/error|$pkgs/packet/data/vzapackagem/error)/message"/>
					</sw:die>
				</xsl:if>
		
				<func:result select="$pkgs/packet/data/vzapackagem/packages/package"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	
	<func:function name="local:enumerate-architectures">
		<xsl:param name="platform-ref"/>
		
		<xsl:variable name="archs-rtf">
			<xsl:for-each select="vt:platforms()/platform[vt:platform-backwards-compatible($platform-ref, @id)]">
				<arch>
					<xsl:value-of select="vzapackagem:vza-arch2pkg(vt:platform2vza-architecture(@id))"/>
				</arch>
			</xsl:for-each>
		</xsl:variable>
		
		<func:result select="set:distinct(exsl:node-set($archs-rtf)/arch)"/>
	</func:function>

	<func:function name="vz:list-templates-for-select">
		<xsl:param name="hn-eid" select="''"/>
		<!-- os or platform reference -->
		<xsl:param name="os" select="/.."/>
		<xsl:param name="type" select="'all'"/>
		<xsl:param name="filter-dn" select="/.."/>
		<xsl:param name="auth" select="false()"/>
		
		<xsl:variable name="req">
			<fields>
				<env.eid/>
				<env.state/>
				<packages.name/>
				<packages.summary/>
				<packages.arch/>
				<packages.os.name/>
				<packages.os.platform/>
				<packages.os_template/>
				<packages.version/>
				<packages.cached/>
				<packages.base/>
				<packages.technology/>
			</fields>

			<xsl:variable name="pkg" select="vzapackagem:vztemplate-packages($os)"/>
			<xsl:variable name="platform-ref"
				select="string(sw:if(not(string($pkg/os/platform)=''), 
							$pkg/os/platform, 
							$os/platform))"/>
														

			<xsl:variable name="type-selector" select="sw:if($type='all', '', sw:if($type='os', '1', '0'))"/>
			
			<where>
				<xsl:variable name="pkg-filter">
					<xsl:choose>
						<xsl:when test="string($pkg/name)=vz:get-old-win-os-name()">
							<xsl:copy-of select="local:where('lower(pager.packages.os.platform)', sw:lc($pkg/os/platform))"/>
						</xsl:when>
						<xsl:when test="not(string($pkg/name)='')">
							( (
							<xsl:copy-of
								select="local:where('pager.packages.os.name', $pkg/name,
											local:where('lower(pager.packages.os.platform)', sw:lc($pkg/os/platform)))"/>
							) or (
							<xsl:variable name="os-platform" 
								select="vt:vza2platform($pkg/os/platform, vzapackagem:pkg-arch2vza($pkg/arch))"/>
								
							<xsl:copy-of
								select="local:where('pager.packages.name', $pkg/name,
											local:where('lower(pager.packages.os.platform)', sw:lc($pkg/os/platform),
												local:where-one-of('pager.packages.arch', 
													local:enumerate-architectures($os-platform))))"/>
							) )
						</xsl:when>
						<xsl:when test="not($platform-ref='')">
							<xsl:copy-of select="local:where('lower(pager.packages.os.platform)', 
													sw:lc(vt:platform2vza($platform-ref)), 
														local:where-one-of('pager.packages.arch', 
															local:enumerate-architectures($platform-ref)))"/>
						</xsl:when>
					</xsl:choose>
				</xsl:variable>

				<xsl:copy-of select="local:where('pager.packages.os_template', $type-selector,
										local:where-unit('pager.env.eid', units:decode-dn($filter-dn),
										local:where('pager.env.state', $env-state/running,
										local:where('pager.env.eid', $hn-eid, $pkg-filter))))"/>
			</where>
		</xsl:variable>
		
		<xsl:variable name="res" select="sw:xchg-sql($req, $auth)"/>
		<xsl:choose>
			<xsl:when test="$res/error|$res/pager/error">
				<func:result select="$res/error|$res/pager/error"/>
			</xsl:when>
			<xsl:when test="$hn-eid=''">
				<xsl:variable name="found">
					<xsl:for-each select="set:distinct($res/pager/row_set/row/packages/name)">
						<xsl:sort select="."/>
						<xsl:variable name="name" select="."/>
						<xsl:for-each select="set:distinct($res/pager/row_set/row/packages/version)">
							<xsl:sort select="."/>
							<xsl:variable name="version" select="."/>
							<xsl:variable name="pre" select="$res/pager/row_set/row/packages[string(name)=$name and version=$version]"/>
							
							<xsl:choose>
								<xsl:when test="$pre[cached='1']">
									<xsl:copy-of select="$pre[cached='1'][1]"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:copy-of select="$pre[1]"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
					</xsl:for-each>
				</xsl:variable>
				<func:result select="exsl:node-set($found)/packages"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="$res/pager/row_set/row/packages"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<func:function name="vz:find-template">
		<xsl:param name="app-id"/>
		<xsl:param name="hn-eid" select="''"/>
		<xsl:param name="filter-dn" select="''"/>
		
		<xsl:choose>
			<xsl:when test="string($app-id)=''">
				<func:result select="/.."/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="pkg" select="vzapackagem:vztemplate-packages($app-id)"/>

				<xsl:variable name="req">
					<fields>
						<env.eid/>
						<env.state/>
						<packages.name/>
						<packages.arch/>
						<packages.os.name/>
						<packages.os.platform/>
						<packages.os_template/>
						<packages.version/>
						<packages.technology/>
					</fields>
		
					<where>
						<xsl:variable name="pkg-filter" select="local:where('pager.packages.version', $pkg/version,
																	local:where('pager.packages.name', $pkg/name,
																	local:where('pager.packages.os.name', $pkg/os/name,
																	local:where('lower(pager.packages.os.platform)', 
																	sw:lc($pkg/os/platform)))))"/>
						<xsl:copy-of select="local:where-unit('pager.env.eid', units:decode-dn($filter-dn),
												local:where('pager.env.state', $env-state/running,
												local:where('pager.env.eid', $hn-eid, $pkg-filter)))"/>
					</where>
				</xsl:variable>
		
				<xsl:variable name="found" select="sw:xchg-sql($req)/pager/row_set/row" />
				
				<xsl:variable name="latest" select="not(sw:is-ez-package($pkg/name)) and string($pkg/version)=''"/>

				<xsl:choose>
					<xsl:when test="not($found)">
						<func:result select="/.."/>
					</xsl:when>
					<xsl:when test="$latest">
						<xsl:variable name="version" select="math:max(set:distinct($found/packages/version))"/>
						<func:result select="$found[packages/version=$version][1]"/>
					</xsl:when>
					<xsl:otherwise>
						<func:result select="$found[1]"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<func:function name="vz:list-group-templates">
		<xsl:param name="hn-eid" select="''" />
		<xsl:param name="app-id" select="''" />
		<xsl:param name="filter-dn" select="''" />

		<xsl:variable name="req">
			<fields>
				<env.eid/>
				<env.state/>
				<env.config.hostname/>
				<env.config.ip_text/>
				<packages.name/>
				<packages.summary/>
				<packages.arch/>
				<packages.os.name/>
				<packages.os.platform/>
				<packages.os_template/>
				<packages.cached/>
				<packages.path/>
				<packages.uptodate/>
				<packages.base/>
				<packages.version/>
				<packages.technology/>
			</fields>

			<xsl:variable name="pkg" select="sw:if(string($app-id)='', /.., vzapackagem:vztemplate-packages($app-id))"/>

			<xsl:if test="$pkg or $hn-eid!='' or string($filter-dn)!=''">
				<where>
					<xsl:copy-of select="local:where('pager.packages.version', $pkg/version,
													local:where('pager.packages.name', $pkg/name,
													local:where-unit('pager.env.eid', units:decode-dn($filter-dn),
													local:where('pager.env.eid', $hn-eid, ''))))"/>
				</where>
			</xsl:if>
		</xsl:variable>
		<func:result select="sw:xchg-sql($req)" />
	</func:function>
	
	<func:function name="vz:get-templates-platform">
		<xsl:param name="app-ids"/>

		<xsl:variable name="pkg" select="vzapackagem:vztemplate-packages($app-ids)"/>
		<xsl:variable name="req">
			<fields>
				<packages.name/>
				<packages.arch/>
				<packages.os.name/>
				<packages.os.platform/>
				<packages.os_template/>
				<packages.technology/>
			</fields>

			<where>
				(
				<xsl:for-each select="set:distinct($pkg[vzapackagem:is-os(.)]/name|$pkg[not(vzapackagem:is-os(.))]/os/name)">
					<xsl:if test="position() &gt; 1"> or </xsl:if>
					<xsl:copy-of select="local:where('pager.packages.name', ., '')"/>
				</xsl:for-each>
				)
			</where>
		</xsl:variable>

		<xsl:variable name="res" select="sw:xchg-sql($req)/pager/row_set/row/packages"/>
		<xsl:variable name="platforms">
			<xsl:for-each select="$pkg">
				<data>
					<app><xsl:value-of select="vzapackagem:generate-id(.)"/></app>
					<xsl:variable name="name" select="sw:if(vzapackagem:is-os(.), name, os/name)"/>
					<xsl:variable name="found" select="$res[name=$name][1]"/>
					<platform><xsl:value-of select="vt:vza2platform($found/os/platform, vzapackagem:pkg-arch2vza($found/arch))"/></platform>
				</data>
			</xsl:for-each>
		</xsl:variable>
		
		<func:result select="exsl:node-set($platforms)/data"/>
	</func:function>
	
	<func:function name="local:ves-request">
		<xsl:param name="pkg"/>
		<xsl:param name="hn-eids"/>
		
		<func:result>
			<fields>
				<env.eid/>
				<env.parent_eid/>
				<env.vconfig.os_template.name/> 
				<env.vconfig.os_template.version/> 
				<env.vconfig.template.name/>
				<env.vconfig.template.version/>
			</fields>
			<count>1</count>
			<where>
				<xsl:if test="$hn-eids">
				(
					<xsl:for-each select="$hn-eids">
						<xsl:if test="position() &gt; 1"> or </xsl:if>
						pager.env.parent_eid='<xsl:value-of select="."/>' 
					</xsl:for-each>
				) and 
				</xsl:if>
				(
				<xsl:choose>
					<xsl:when test="$pkg[vzapackagem:is-os(.)]">
						<xsl:copy-of select="local:where('pager.env.vconfig.os_template.name', $pkg/name, 
												local:where('pager.env.vconfig.os_template.version', $pkg/version, ''))"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="local:where('pager.env.vconfig.template.name', $pkg/name, 
												local:where('pager.env.vconfig.template.version', $pkg/version, 
												local:where('pager.env.vconfig.os_template.name', $pkg/os/name, '')))"/>
					</xsl:otherwise>
				</xsl:choose>
				)
			</where>
		</func:result>		
	</func:function>
	
	<func:function name="vz:get-templates-ves-count">
		<xsl:param name="app-ids"/>
		<xsl:param name="hn-eids" select="/.."/>

		<xsl:variable name="pkg" select="vzapackagem:vztemplate-packages($app-ids)"/>
		<xsl:variable name="eids-rtf">
			<xsl:for-each select="exsl:node-set($hn-eids)">
				<hn-eid><xsl:value-of select="."/></hn-eid>
			</xsl:for-each>
		</xsl:variable>
		
		<xsl:variable name="eids" select="exsl:node-set($eids-rtf)/hn-eid"/>
		
		<xsl:variable name="ves">
			<xsl:for-each select="$pkg">
				<xsl:variable name="res" select="sw:xchg-sql(local:ves-request(., $eids))/pager/row_set/count"/>
				<data>
					<app><xsl:value-of select="vzapackagem:generate-id(.)"/></app>
					<ve-count><xsl:value-of select="$res"/></ve-count>
				</data>
			</xsl:for-each>
		</xsl:variable>
		
		<func:result select="exsl:node-set($ves)/data"/>
	</func:function>
	
	<func:function name="local:where-one-of">
		<xsl:param name="key"/>
		<xsl:param name="values"/>
		<xsl:param name="result" select="/.."/>

		<xsl:choose>
			<xsl:when test="string($values)=''">
				<func:result select="$result"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result>
					<xsl:if test="normalize-space(string($result))!=''">
						<xsl:copy-of select="$result"/>
						and
					</xsl:if>
					<xsl:variable name="v" select="$values[string(.)!='']"/>
					<xsl:if test="count($v) &gt; 1">
						(
					</xsl:if>
					<xsl:for-each select="$v">
						<xsl:if test="position() &gt; 1">
							or
						</xsl:if>
						<xsl:value-of select="$key"/>='<xsl:value-of select="sw:sql-escape(.)"/>'
					</xsl:for-each>
					<xsl:if test="count($v) &gt; 1">
						)
					</xsl:if>
				</func:result>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<func:function name="local:where">
		<xsl:param name="key"/>
		<xsl:param name="value"/>
		<xsl:param name="result" select="/.."/>

		<xsl:choose>
			<xsl:when test="string($value)=''">
				<func:result select="$result"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result>
					<xsl:if test="normalize-space(string($result))!=''">
						<xsl:copy-of select="$result"/>
						and
					</xsl:if>
					<xsl:value-of select="$key"/>='<xsl:value-of select="sw:sql-escape($value)"/>'
				</func:result>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<func:function name="local:where-unit">
		<xsl:param name="key"/>
		<xsl:param name="unit"/>
		<xsl:param name="result" select="/.."/>

		<xsl:choose>
			<xsl:when test="string($unit)=''">
				<func:result select="$result"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result>
					<xsl:if test="normalize-space(string($result))!=''">
						<xsl:copy-of select="$result"/>
						and
					</xsl:if>
					<xsl:value-of select="$key"/> in (unit '<xsl:value-of select="sw:sql-escape($unit)"/>',recursive)
				</func:result>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>


	<func:function name="vz:compatible-template">
		<!-- as found in vz:list-group-templates//row/packages  -->
		<xsl:param name="app-id" />
		<!-- target env -->
		<xsl:param name="env" />
		
		<xsl:variable name="pkg" select="vzapackagem:id2package($app-id)"/>
		<xsl:variable name="is-ve" select="$env/virtual_config/*"/>
		
		<xsl:variable name="hn" select="sw:if($is-ve, env:get-env($env/parent_eid)/env, $env)"/>
		
		<xsl:variable name="hn-platform" select="hn:hn2platform($hn)"/>
		<xsl:variable name="app-platform" select="vt:vza2platform($pkg/os/platform, vzapackagem:pkg-arch2vza($pkg/arch))"/>
		
		<xsl:choose>
			<xsl:when test="vzapackagem:is-os($pkg) and not(vt:platform-backwards-compatible($hn-platform, $app-platform))">
				<func:result select="false()"/>
			</xsl:when>
			<!-- compatible std OS templates for VE -->
			<xsl:when test="$is-ve and vzapackagem:is-os($pkg) and not(sw:is-ez-package($pkg/name))
					 and string($pkg/name)=string($env/virtual_config/os_template/name)">
				<func:result select="true()"/>
			</xsl:when>
			<!-- compatible app templates for VE -->
			<xsl:when test="$is-ve and (vt:is-platform-windows($hn-platform) or (not(vzapackagem:is-os($pkg)) and string($pkg/os/name)=string($env/virtual_config/os_template/name)))">
				<func:result select="true()"/>
			</xsl:when>
			<!-- HN is always compatible if platform is the same, VE compatible cases were fully specified earlier -->
			<xsl:otherwise>
				<func:result select="not($is-ve)"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

</xsl:stylesheet>
