<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred vz func voc dev filem"
  xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl			="http://exslt.org/common"
  xmlns:func			="http://exslt.org/functions"
  xmlns:sw				="http://www.swsoft.com/xsl/cp"
  xmlns:ui				="http://www.swsoft.com/xsl/cp/ui"   
  xmlns:browse		="http://www.swsoft.com/xsl/cp/browse"   
	xmlns:cred			="http://www.swsoft.com/xsl/cp/cred"
	xmlns:vz				="http://www.swsoft.com/xsl/cp/vz"
	xmlns:voc				="http://www.swsoft.com/xsl/cp/voc"	
	xmlns:dev				="http://www.swsoft.com/xsl/cp/dev"	
	xmlns:env				="http://www.swsoft.com/xsl/cp/env"	
	xmlns:vt				="http://www.swsoft.com/xsl/cp/vt"		
	xmlns:filem			="http://www.swsoft.com/xsl/cp/filem"	
>
	<sw:include href="../vt/env-core.xsl"/>
	
	
	
	<!-- 
		Returns rtf-text with HN devices listing, ready for ui:cell-list
		
		Requires:
			lib/vza/dev.xsl	
			lib/vza/filem.xsl	
	-->
	<func:function name="vz:get-devices">
		<xsl:param name="hw-id"/>

		<xsl:variable name="hn-platform" select="env:env2platform(env:get-env($hw-id)/env)"/>
		
		<xsl:choose>
			<!-- On Linux -->
			<xsl:when test="vt:is-platform-linux($hn-platform)">
				<xsl:variable name="info" select="dev:get-devices($hw-id)"/>
				
				<xsl:variable name="res">
					<xsl:choose>
						<xsl:when test="$info/dev/device_info">
							<xsl:for-each select="$info/dev/device_info">
								<ui:list-item id="{device}" title="{device}"/>
							</xsl:for-each>
						</xsl:when>
						<xsl:otherwise>
							<ui:list-item id="" title="{sw:text('No devices available')}"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>				
				<func:result select="$res"/>
			</xsl:when>
			<!-- /On Linux -->
			<!-- On Windows -->
			<xsl:when test="vt:is-platform-windows($hn-platform)">
				<xsl:variable name="fm-list-input">
					<info><name/></info><follow_links/>
				</xsl:variable>
				<xsl:variable name="hw-root" select="
					filem:list('',$hw-id,$fm-list-input,'')/file
				"/>
				
				<xsl:variable name="res">
					<xsl:choose>
						<xsl:when test="$hw-root">
							<xsl:for-each select="$hw-root">
								<xsl:variable name="name" select="sw:base64-decode(name)"/>
								<ui:list-item id="{$name}" title="{$name}"/>
							</xsl:for-each>
						</xsl:when>	
						<xsl:otherwise>
							<ui:list-item id="" title="{sw:text('No devices available.')}"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				
				<func:result select="$res"/>
			</xsl:when>
			<!-- On Windows -->
		</xsl:choose>
		
	</func:function>
	
	<!-- 
		Returns rtf-text with VE Volume listing, ready for ui:cell-list
		Only for WINDOWS platform.
		
		Requires:
			lib/vza/dev.xsl	
	-->
	<func:function name="vz:ve-drive-selector">
		<xsl:param name="eid"/>
		
		<xsl:variable name="mounts" select="dev:get-mounts($eid)"/>
		<xsl:variable name="drives-rtf">
			<drive>a:</drive><drive>b:</drive><drive>c:</drive><drive>d:</drive>
			<drive>e:</drive><drive>f:</drive><drive>g:</drive><drive>h:</drive>
			<drive>i:</drive><drive>j:</drive><drive>k:</drive><drive>l:</drive>
			<drive>m:</drive><drive>n:</drive><drive>o:</drive><drive>p:</drive>
			<drive>r:</drive><drive>s:</drive><drive>t:</drive><drive>u:</drive>
			<drive>v:</drive><drive>w:</drive><drive>x:</drive><drive>y:</drive>
			<drive>z:</drive>
		</xsl:variable>
		
		<xsl:variable name="res">			
			<xsl:for-each select="exsl:node-set($drives-rtf)/drive">
				<xsl:variable name="drive" select="sw:uc(.)"/>
				<xsl:choose>
					<xsl:when test="$mounts/dev/mount[point=$drive]">
						<ui:list-item id="" title="{concat(' ',$drive,' ',sw:text('(Mounted)'))}" disabled="true"/>
					</xsl:when>
					<xsl:otherwise>
						<ui:list-item id="{$drive}" title="{concat(' ',$drive)}"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
		</xsl:variable>
				
		<func:result select="$res"/>
		
	</func:function>

</xsl:stylesheet>
