<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw func form check voc vzenv"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
  xmlns:error		="http://www.swsoft.com/xsl/cp/error"
  xmlns:ui	="http://www.swsoft.com/xsl/cp/ui"
  xmlns:env		="http://www.swsoft.com/xsl/cp/env"
  xmlns:vzenv		="http://www.swsoft.com/xsl/cp/vzenv"
  xmlns:vt		="http://www.swsoft.com/xsl/cp/vt"
  xmlns:form	="http://www.swsoft.com/xsl/cp/form"
  xmlns:func	="http://exslt.org/functions"
  xmlns:check	="http://www.swsoft.com/xsl/cp/check"
  xmlns:voc		="http://www.swsoft.com/xsl/cp/voc"
>

 	<sw:include href="/lib/vocabulary.xsl"/>
 	<sw:include href="/lib/vt/core.xsl"/>
 	<sw:include href="/lib/vt/env-core.xsl"/>
 	<sw:include href="../../layout/forms-list.xsl"/>
 	

	<xsl:template name="vzenv:show-bridged-iface-header">
		<xsl:param name="index"/>
		<xsl:param name="iface"/>
		<xsl:param name="networks"/>
		<xsl:param name="env-platform"/>
		
		<xsl:variable name="allow-empty-network" select="vt:is-platform-linux($env-platform)"/>
		
		<!-- Label -->
		<ui:row>
			<ui:cell-text offset="">
				<img src="/{$theme}/icons/virtualswitch_16.gif" width="16" height="16"/>&#160;
				<sw:text>
					<xsl:with-param name="id" select="$iface/id"/>
					Virtual Ethernet Interface %{id}
				</sw:text>
			</ui:cell-text>
			<ui:cell-text align="right">
				<div id="div_bridged_iface_remove{$index}">
					<xsl:if test="position()=last()">
						<a style="cursor:hand; cursor:pointer" onclick="addBridgedIface()">
							<img 
								onmouseover="callTip('add_bridged_iface',event)"
								onmouseout="callTip('')"
								width="16" height="16" src="/{$theme}/icons/item_add.gif"
							>
							</img>
						</a>&#160;
						<a href="#" onclick="addBridgedIface('');return false;"><sw:text>Add New Interface</sw:text></a>		
						<xsl:if test="last()!=1">	
							&#160;&#160;
						</xsl:if>
					</xsl:if>
					<xsl:if test="last()!=1">
						<a style="cursor:hand; cursor:pointer" onclick="removeBridgedIface('{id}')">
							<img 
								onmouseover="callTip('remove_bridged_iface',event)"
								onmouseout="callTip('')"
								width="16" height="16" src="/{$theme}/icons/item_delete.gif"
							>
							</img>
						</a>&#160;
						<a href="#" onclick="removeBridgedIface('{id}');return false;"><sw:text>Remove</sw:text></a>						
					</xsl:if>
				</div>
			</ui:cell-text>
		</ui:row>
		
		<!-- Virtual Network -->
		<ui:row>
			<ui:cell-label offset="3">
				<xsl:if test="not($allow-empty-network)">
					<xsl:attribute name="show-aster">true</xsl:attribute>
				</xsl:if>
				<sw:text>Connect to</sw:text>
			</ui:cell-label>
			<ui:cell-list id="bridged_net_id{$index}" value="{$iface/net-id}"  selected="{$iface/net-id}">
				<xsl:choose>
					<xsl:when test="not($networks)">
						<ui:list-item id="" title="{sw:text('No Virtual Networks')}" disabled="true"/>
					</xsl:when>
					<xsl:otherwise>
						<ui:list-item id="" title="{sw:text('Not Connected')}"/>		
						<ui:list-item id="" title="{sw:text('-- Select Virtual Network --')}" disabled="true"/>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:for-each select="$networks">
					<xsl:choose>
						<xsl:when test="error">
							<ui:list-item id="{id}" title="{title}" disabled="true" color="red"/>
						</xsl:when>
						<xsl:otherwise>
							<ui:list-item id="{id}" title="{title}"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:for-each>
				<!-- Place unexisted network, workaround for #82952 -->
				<xsl:if test="$iface/net-id!='' and not($networks[id=$iface/net-id])">
					<ui:list-item id="{$iface/net-id}" title="{$iface/net-id}"/>
				</xsl:if>
				<!--/-->
			</ui:cell-list>
		</ui:row>
		
		<!--
		<xsl:if test="$iface/net-id!='' and not($networks[id=$iface/net-id])">
			<ui:row>
				<ui:cell-label offset="3"/>
				<ui:cell-text>
					<img src="/{$theme}/icons/alert_yellow.gif" width="16" height="16"/>&#160;
						<sw:text>
							<xsl:with-param name="net" select="$iface/net-id"/>
							Attention! The Container was bridged to the <b>%{net}</b> virtual network, which is no longer available on this Hardware Node.
						</sw:text>
				</ui:cell-text>
			</ui:row>
		</xsl:if>
		-->

		
	</xsl:template>
	
	<xsl:template name="vzenv:show-bridged-iface-footer">
		<xsl:param name="index"/>
		<xsl:param name="iface"/>
		<xsl:param name="env-platform"/>
		<xsl:param name="is-last"/>
		<xsl:param name="bridged-ip-rule" select="''"/>
				
		<xsl:variable name="windows" select="vt:is-platform-windows($env-platform)"/>		
		
		<!-- DNS and Search domains -->
		<xsl:if test="$windows">
			<xsl:copy-of select="vzenv:show-net-dns($iface/dns_ips,$env-platform,concat('bridged_dns_ips',$index),3)"/> 
			<xsl:copy-of select="vzenv:show-net-wins($iface/wins_servers,concat('bridged_wins_servers',$index),3)"/> 		
		</xsl:if>
		<xsl:if test="not($bridged-ip-rule='dhcp')">
			<ui:div id="div_bridged_gateway{$index}" hidden="{boolean($iface/dhcp='true' and (string($bridged-ip-rule)=''))}">
				<xsl:copy-of select="vzenv:show-net-gateway($iface/default_gateway,concat('bridged_default_gateway',$index),3)"/>
			</ui:div>
		</xsl:if>

		<xsl:if test="not($is-last)">
			<ui:row>
				<ui:cell-text offset="3"/>
				<ui:cell-text cell-style="border-bottom: 1px dashed #CCCCCC;" cell-width="100%"></ui:cell-text>
			</ui:row>
			<ui:row>
				<ui:cell-text/>
			</ui:row>
		</xsl:if>		
	
	</xsl:template>
	
	<xsl:template name="vzenv:post-net-core-js">
		<input type="hidden" id="bridged_removed" name="bridged_removed"/>
		<input type="hidden" id="new_iface" name="new_iface"/>
			
		<script type="text/javascript">	
			function addBridgedIface(){
				document.getElementById('new_iface').value = '1';
				doSubmit();	
			}
			function removeBridgedIface(iface_id){
				document.getElementById('bridged_removed').value = iface_id;
				doSubmit();	
			}
		</script>
	</xsl:template>
	
	<func:function name="vzenv:new-iface-index">
		<xsl:param name="ifaces"/>
		<xsl:param name="index" select="0"/>
		
		<xsl:variable name="new-id" select="concat('eth',$index)"/>
		<xsl:choose>
			<xsl:when test="$ifaces[.=$new-id]">
				<!-- new ID already exists -->
				<func:result select="vzenv:new-iface-index($ifaces,$index+1)"/>
			</xsl:when>
			<xsl:otherwise>
				<!-- new ID is free -->
				<func:result select="$new-id"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

</xsl:stylesheet>