<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred func voc ips resourcem global"
  xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl			="http://exslt.org/common"
  xmlns:func			="http://exslt.org/functions"
  xmlns:sw				="http://www.swsoft.com/xsl/cp"
	xmlns:cred			="http://www.swsoft.com/xsl/cp/cred"
	xmlns:voc				="http://www.swsoft.com/xsl/cp/voc"	
	xmlns:vt				="http://www.swsoft.com/xsl/cp/vt"	
	xmlns:ips				="http://www.swsoft.com/xsl/cp/ips"
	xmlns:global		="http://www.swsoft.com/xsl/cp/global"
	xmlns:resourcem ="http://www.swsoft.com/xsl/cp/resourcem"
	xmlns:env       ="http://www.swsoft.com/xsl/cp/env"
>
	<!-- Imports -->
	<sw:include href="../vocabulary.xsl"/>
	<sw:include	href="../vza/global.xsl"/>  
	<sw:include	href="../vza/resourcem.xsl"/>  
	<sw:include	href="/lib/vt/env-core.xsl"/>  
	<!-- /Imports -->
	
	<!-- Check, if IP Pool enabled for IPs autoselection 	-->
	<func:function name="ips:pool-enabled">
		<xsl:variable name="ranges" select="ips:ranges()"/>
		<func:result select="count($ranges/range)!=0"/>
	</func:function>
	
	<!-- Prepare part of ve/set packet with IPS -->
	<func:function name="ips:set-packet">
		<xsl:param name="ips"/>
		<xsl:param name="hn-platform"/>
		<xsl:param name="is-bridged" select="false()"/>						
		
		<func:result>
			<xsl:for-each select="$ips/ip">
				<ip_address>
					<xsl:choose>
						<xsl:when test="address=$def-ip-auto-vzcp">
							<ip><xsl:value-of select="$def-ip-auto-vza"/></ip>
						</xsl:when>
						<xsl:otherwise>	
							<ip><xsl:value-of select="address"/></ip>
							<xsl:if test="$is-bridged or vt:is-platform-windows($hn-platform)">
								<netmask><xsl:value-of select="netmask"/></netmask>
							</xsl:if>
						</xsl:otherwise>
					</xsl:choose>
				</ip_address>
			</xsl:for-each>
		</func:result>
	
	</func:function>
	
	<!-- Transform IP addresses from VZA format to VZCP internal format -->
	<func:function name="ips:vza2vzcp">
		<xsl:param name="addresses"/>
		<xsl:param name="hn-platform"/>
		
		<func:result>
			<xsl:for-each select="$addresses">
				<ip>
					<address>
						<xsl:choose>
							<xsl:when test="ip=$def-ip-auto-vza">
								<xsl:value-of select="$def-ip-auto-vzcp"/>
							</xsl:when>
							<xsl:otherwise>	
								<xsl:value-of select="ip"/>
							</xsl:otherwise>
						</xsl:choose>
					</address>
					<xsl:copy-of select="netmask"/>
				</ip>
			</xsl:for-each>
		</func:result>
	
	</func:function>
	
	<!-- Lease specified count of IP addresses	-->
	<!--
		return 
			ip[]
				or 
			error
				code
				message
	-->
	<func:function name="ips:lease">
		<xsl:param name="ve"/>
		<xsl:param name="ips"/>
	
		<xsl:variable name="auto" select="$ips/ip[.=$def-ip-auto-vzcp]"/>
	
		<!-- Return IPS -->
		<xsl:choose>
			<!-- No request for autoallocation -->
			<xsl:when test="not($auto)">
				<func:result select="$ips"/>
			</xsl:when>
			<!-- Found request for autoallocation -->
			<xsl:otherwise>
				<!-- Ask VZA -->
				<xsl:variable name="query-rtf">
					<packet>
						<target>resourcer</target>
						<data>
							<resourcer>
								<allocate>
									<veid>
										<xsl:value-of select="$ve/id"/>
									</veid>
									<xsl:for-each select="$auto">
										<ip/>
									</xsl:for-each>
								</allocate>
							</resourcer>
						</data>
					</packet>
				</xsl:variable>
				<xsl:variable name="vza-result" select="sw:xchg($query-rtf)/packet/data"/>
				<!-- /Ask VZA -->
				
				<!-- Return allocated IPS -->
				<xsl:choose>
					<xsl:when test="$vza-result[error|resourcer/error]">
						<func:result select="$vza-result/error|$vza-result/resourcer/error"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:variable name="res-rtf">
							<ips>
								<xsl:copy-of select="$ips/ip[.=$def-ip-auto-vzcp]"/>
								<xsl:for-each select="$vza-result/resourcer/node/ve/ip_pool/ip">
									<ip>
										<address>
											<xsl:value-of select="."/>
										</address>
									</ip>
								</xsl:for-each>
							</ips>
						</xsl:variable>
						<func:result select="exsl:node-set($res-rtf)/ips"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Return allocated IPS -->
			</xsl:otherwise>
			<!-- /Found request for autoallocation -->
		</xsl:choose>
		
	</func:function>
	
	<!--  Load all used IPs
		Returns
			ips
				ip
					value
					value-num
					ve-id
					hw-id
					ve-hostname[in case of "get-hostnames" argument]
	-->
	<func:function name="ips:all-used">
		<xsl:param name="filter-ranges" select="/.."/>
		<xsl:param name="get-hostnames" select="false()"/>
	
		<xsl:variable name="ips-request">
			<packet>
				<target>pager</target>
				<data>
					<pager>
						<select>
							<field>pager.env.vconfig.ip</field>
							<field>pager.env.vconfig.veid</field>
							<field>pager.env.eid</field>
							<field>pager.env.title</field>
						</select>
					</pager>
				</data>
			</packet>
		</xsl:variable>
		<xsl:variable name="data" select="sw:xchg($ips-request)/packet/data/pager/row_set/row"/>
		
		<xsl:variable name="ips-rtf">
			<ips>
				<xsl:for-each select="$data">
					<xsl:variable name="row" select="."/>
					<xsl:variable name="ips" select="sw:if(param[1]/param,param[1]/param/value,param[1]/value)"/>
					<xsl:for-each select="$ips">
						<xsl:variable name="ip-str" select="sw:base64-decode(.)"/>
						<xsl:variable name="ip-num" select="sw:ip2number($ip-str)"/>
						<xsl:if test="not($filter-ranges) or 
							($filter-ranges/range[@start-num&lt;=$ip-num and @end-num&gt;=$ip-num])
							">
							<ip value="{$ip-str}" value-num="{$ip-num}" 
								ve-id="{sw:base64-decode($row/param[2]/value)}"
								ve-eid="{sw:base64-decode($row/param[3]/value)}"
								ve-title="{sw:base64-decode($row/param[4]/value)}"/>
						</xsl:if>						
					</xsl:for-each>
				</xsl:for-each>
			</ips>
		</xsl:variable>		
		
		<func:result select="exsl:node-set($ips-rtf)/ips"/>
		
	</func:function>
	<!--  /Load assigned IPs -->
	
	
	<!--  Load all used IPs
		Returns
			ips
				ip
					value
					value-num
					ve-id
					hw-id
					ve-hostname[in case of "get-hostnames" argument]
	-->
	<func:function name="ips:all-used2">
		<xsl:param name="filter-ranges" select="/.."/>
		<xsl:param name="get-hostnames" select="false()"/>
	
		<!-- Ask vza -->
		<xsl:variable name="sql-query">			
			<fields>
				<env.vconfig.veid/>
				<env.vconfig.ip/>
				<xsl:if test="$get-hostnames">
					<env.vconfig.hostname/>
				</xsl:if>
			</fields>
		</xsl:variable>
		<xsl:variable name="sql-answer" select="sw:xchg-sql($sql-query)"/>
		<!-- /Ask vza -->
		
		<xsl:variable name="ips-rtf">
			<ips>
				<xsl:for-each select="$sql-answer/sql/row_set/row/env">
					<xsl:sort select="ip"/>
					<xsl:variable name="ip" select="string(ip)"/>
					<xsl:if test="not($filter-ranges) or 
						($filter-ranges/range[@start-num&lt;=$ip and @end-num&gt;=$ip])
					">
						<ip value="{sw:number2ip(ip)}" value-num="{ip}" ve-id="{veid}" ve-hostname="{hostname}"/>
					</xsl:if>
				</xsl:for-each>
			</ips>
		</xsl:variable>		
		
		<func:result select="exsl:node-set($ips-rtf)/ips"/>
		
	</func:function>
	<!--  /Load assigned IPs -->	
	
	<!--  Load all IPs
		Returns
			ips
				range
					@start
					@end
					@start-num
					@end-num
					@total					
	-->
	<func:function name="ips:ranges">
	
		<xsl:variable name="pools" select="resourcem:get-pool('resource_ip')"/>
		
		<xsl:variable name="ips-rtf">
			<ips>
				<xsl:for-each select="$pools//ip_range">	        
					<range
						start="{start_ip}" start-num="{sw:ip2number(start_ip)}"
						end="{end_ip}" end-num="{sw:ip2number(end_ip)}"
						total="{sw:ip2number(end_ip) - sw:ip2number(start_ip) + 1}"
					/>				
	      </xsl:for-each> 
	      <xsl:for-each select="$pools//ip">
	      	<range
						start="{.}" start-num="{sw:ip2number(.)}"
						end="{.}" end-num="{sw:ip2number(.)}"
						total="1"
					/>
	      </xsl:for-each> 
	  	</ips>
	  </xsl:variable>
		
		<func:result select="exsl:node-set($ips-rtf)/ips"/>
		
	</func:function>
	<!--  /Load all IPs -->

</xsl:stylesheet>
