<!--
		 Copyright (c) SWsoft, 1999-2007
		 All rights reserved.
	-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl env func res"
	xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:sw			="http://www.swsoft.com/xsl/cp"
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"
	xmlns:voc  		="http://www.swsoft.com/xsl/cp/voc"
	xmlns:env  		="http://www.swsoft.com/xsl/cp/env"
  xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
	xmlns:vt  		="http://www.swsoft.com/xsl/cp/vt"
	xmlns:ve		="http://www.swsoft.com/xsl/cp/ve"	
	xmlns:vzenv  	="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:func		="http://exslt.org/functions"	
 	xmlns:res			="http://www.swsoft.com/xsl/cp/res"	
	xmlns:format	="http://www.swsoft.com/xsl/cp/format" 	
 	xmlns:check	="http://www.swsoft.com/xsl/cp/check"	
>
	<sw:include href="/lib/utils/format-number.xsl"/>
	<sw:include href="/lib/utils/format-resusage.xsl"/>	
	<sw:include href="/lib/vocabulary.xsl"/>
	
	<xsl:output method="xml"/>

	<!-- Check unit selection posibility -->	
	<func:function name="res:measure2factor">
		<xsl:param name="measure"/>
		<func:result>
			<xsl:choose>
				<xsl:when test="$measure='1K-blocks'">	
					<xsl:value-of select="'kb'"/>
				</xsl:when>
				<xsl:when test="$measure='bytes'">	
					<xsl:value-of select="'bytes'"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="''"/>
				</xsl:otherwise>
			</xsl:choose>
		</func:result>
	</func:function>
	
	<func:function name="res:find-factor">
		<xsl:param name="linux"/>	
		<xsl:param name="soft-value"/>
		<xsl:param name="hard-value"/>
		<func:result>
			<xsl:choose>
				<xsl:when test="($linux and check:nan($soft-value)) or check:nan($hard-value)">
					<xsl:value-of select="1"/>
				</xsl:when>
<!--	commented before support in local:factor-kb-label, fix for #88839
				<xsl:when test="
					($linux or not($soft-value mod 1073741824))
					and
					not($hard-value mod 1073741824)
				">
					<xsl:value-of select="1073741824"/>
				</xsl:when>
-->				
				<xsl:when test="
					($linux or not($soft-value mod 1048576))
					and
					not($hard-value mod 1048576)
				">
					<xsl:value-of select="1048576"/>
				</xsl:when>
				<xsl:when test="
					($linux or not($soft-value mod 1024))
					and
					not($hard-value mod 1024)
				">
					<xsl:value-of select="1024"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="1"/>
				</xsl:otherwise>
			</xsl:choose>
		</func:result>
	</func:function>
	
	
	
	<xsl:template name="res:extend-info">
		<xsl:param name="is-linux"/>
		<xsl:param name="id" select="1"/>
		<xsl:param name="voc-res"/>
		<xsl:param name="ve-res" select="/.."/>
		<xsl:param name="usage-res" select="''"/>	
		<xsl:param name="warns" select="/.."/>
		<xsl:param name="warn-restart" select="false()"/>
		<xsl:param name="only-changed" select="false()"/>

		<xsl:variable name="show-soft-limit" select="$is-linux"/>
		
		<xsl:for-each select="$voc-res">							
			<xsl:variable name="real_id" select="id"/>
	
			<xsl:variable name="unlimited">
				<xsl:choose>
					<xsl:when test="disabled">
						<xsl:value-of select="disabled"/>
					</xsl:when>
					<xsl:when test="unlimited">
						<xsl:value-of select="unlimited"/>
					</xsl:when>						
				</xsl:choose>
			</xsl:variable>
						
			<xsl:variable name="min" select="min"/>
			<xsl:variable name="min_soft" select="res:param2soft($min)"/>
			<xsl:variable name="min_hard" select="res:param2hard($min)"/>
			<xsl:variable name="max" select="max"/>
			<xsl:variable name="max_soft" select="res:param2soft($max)"/>
			<xsl:variable name="max_hard" select="res:param2hard($max)"/>				
			
			<xsl:variable name="unlim_soft" select="res:param2soft($unlimited)"/>
			<xsl:variable name="unlim_hard" select="res:param2hard($unlimited)"/>
			<xsl:variable name="def_soft" select="res:param2soft(basic)"/>
			<xsl:variable name="def_hard" select="res:param2hard(basic)"/>
						
			<!-- prepare current value -->
			<xsl:variable name="data_def">		
				<hard><xsl:value-of select="$def_hard"/></hard>
				<hard_src><xsl:value-of select="$def_hard"/></hard_src>		
				<xsl:if test="complex=2">
						<soft><xsl:value-of select="$def_soft"/></soft>
						<soft_src><xsl:value-of select="$def_soft"/></soft_src>
				</xsl:if>
			</xsl:variable>
			<xsl:variable name="data_exists" select="$ve-res"/>
			<xsl:variable name="data_res" select="sw:if($data_exists,$data_exists,exsl:node-set($data_def))"/>						
			<!-- /prepare current value -->				
						
			<xsl:variable name="is-unlimited" select="$unlim_hard!='' and $data_res/hard=$unlim_hard"/>
			<xsl:variable name="disabled" select="disabled and $data_res/hard=disabled"/>							
			
			<xsl:if test="not($only-changed) or (
				($data_res/soft!=$data_res/soft_src and not($is-unlimited)
				) or 
				$data_res/hard!=$data_res/hard_src)
			">
				
				<!-- prepare label for unlimited value -->
				<xsl:variable name="unlim_label">
					<xsl:choose>
						<xsl:when test="disabled">
							<sw:text>Disabled</sw:text>
						</xsl:when>
						<xsl:when test="unlimited">
							<sw:text>Unlimited</sw:text>
						</xsl:when>									
					</xsl:choose>
				</xsl:variable>
				<xsl:variable name="unlim_type_src">
					<xsl:choose>
						<xsl:when test="disabled">disabled</xsl:when>
						<xsl:when test="unlimited">unlimited</xsl:when>									
					</xsl:choose>
				</xsl:variable>
				<!-- /prepare label for unlimited value -->
				
				<!-- prepare value tips  -->
				<xsl:variable name="soft-tip">
					<xsl:choose>
						<xsl:when test="$is-linux">
							<sw:text>
								<xsl:with-param name="min" select="format:res2str($min_soft,measure)"/>
								<xsl:with-param name="max" select="format:res2str($max_soft,measure)"/>
								<xsl:with-param name="measure" select="measure"/>
								The resource soft limit. The range is %{min} - %{max} %{measure}.
							</sw:text>
						</xsl:when>
					</xsl:choose>
				</xsl:variable>
							
				<xsl:variable name="hard-tip">
					<xsl:choose>
						<xsl:when test="$is-linux">
							<sw:text>
								<xsl:with-param name="min" select="format:res2str($min_hard,measure)"/>
								<xsl:with-param name="max" select="format:res2str($max_hard,measure)"/>
								<xsl:with-param name="measure" select="measure"/>
								The resource hard limit. The range is %{min} - %{max} %{measure}.
							</sw:text>
						</xsl:when>
						<xsl:otherwise>
							<sw:text>
								<xsl:with-param name="min" select="format:res2str($min_hard,measure)"/>
								<xsl:with-param name="max" select="format:res2str($max_hard,measure)"/>
								<xsl:with-param name="measure" select="measure"/>											
								The resource value. The range is %{min} - %{max} %{measure}.
							</sw:text>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<!-- /prepare value tips  -->

				<!-- Prepare "def-unlimited" -->
				<xsl:variable name="def-unlimited">
					<xsl:choose>
						<xsl:when test="$data_res/def-unlimited"><xsl:value-of select="sw:if($data_res/def-unlimited=1,'true','false')"/></xsl:when>
						<xsl:otherwise><xsl:value-of select="sw:if($is-unlimited or $disabled,'true','false')"/></xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<!-- /Prepare "def-unlimited" -->
							
				<xsl:variable name="soft-now">
					<xsl:value-of select="sw:if($is-unlimited or $disabled,$data_res/soft_src,$data_res/soft)"/>
				</xsl:variable>
				<xsl:variable name="hard-now">
					<xsl:value-of select="sw:if($is-unlimited or $disabled,$data_res/hard_src,$data_res/hard)"/>
				</xsl:variable>	
				
				<!-- Check unit selection posibility -->
				<xsl:variable name="factor-type" select="res:measure2factor(measure)"/>					
				
				<!-- calc current factor -->
				<xsl:variable name="factor">
					<xsl:choose>
						<xsl:when test="not($is-unlimited) and not($disabled) and $factor-type!=''">
							<xsl:value-of select="
								res:find-factor($is-linux,$soft-now,$hard-now)
							"/>		
						</xsl:when>								
						<xsl:otherwise>
							<xsl:value-of select="number(1)"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
							
				<!-- calc default factor -->
				<xsl:variable name="def-factor">
					<xsl:choose>
						<xsl:when test="$def-unlimited!='true' and $factor-type!=''">
							<xsl:value-of select="
								res:find-factor($is-linux,$data_res/soft_src,$data_res/hard_src)
							"/>		
						</xsl:when>								
						<xsl:otherwise>
							<xsl:value-of select="number(1)"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<xsl:variable name="hard-def"><xsl:value-of select="sw:if($data_res/hard_src!='',format-number($data_res/hard_src div $def-factor,'#'),'')"/></xsl:variable>							
				<xsl:variable name="soft-def"><xsl:value-of select="sw:if($data_res/soft_src!='',format-number($data_res/soft_src div $def-factor,'#'),'')"/></xsl:variable>							
							
				<!-- Resource current usage -->
				<xsl:variable name="curr" select="$usage-res"/>	
				<xsl:variable name="curr-str" select="sw:if($factor-type!='',format:int2str($curr,true(),$factor,$factor!=1),format:res2str($curr,'',true()))"/>
											
				<!-- Post "param" definition -->
				<ui:qos-param 
					id="{$id}" 
					real-id="{$real_id}"
					unlimited-label="{$unlim_label}"
					unlimited-type-src="{$unlim_type_src}"
					unit="{measure}"
					short="{short}"
				>
							
					<!-- Post "Warning" flag -->
					<xsl:if test="$warns">
						<xsl:attribute name="has-warning">true</xsl:attribute>
					</xsl:if>
				
					<!-- Post "Default is unlimited" -->
					<xsl:attribute name="def-unlimited"><xsl:value-of select="$def-unlimited"/></xsl:attribute>
					
					<!-- Post "Unit" -->
					<xsl:choose>
						<xsl:when test="normalize-space(measure)">
							<xsl:attribute name="unit-label">
								<xsl:value-of select="res:factor2text(measure/text(),$factor,$factor-type)"/>
							</xsl:attribute>
						</xsl:when>
					</xsl:choose>
		
					<!-- Post KB/MB/GB unit -->
					<xsl:if test="$factor-type!=''">
						<xsl:attribute name="factor-type"><xsl:value-of select="$factor-type"/></xsl:attribute>
						<xsl:attribute name="factor"><xsl:value-of select="$factor"/></xsl:attribute>
						<xsl:attribute name="def-factor"><xsl:value-of select="$def-factor"/></xsl:attribute>
					</xsl:if>

					<!-- Post "Restart after" definition -->
					<xsl:if test="$warn-restart and restart and ve:context-state() = $env-state/running">
						<xsl:attribute name="alert-restart-label">
							<sw:text>
								<xsl:with-param name="id" select="$real_id"/>
								For the new resource value (%{id}) to come into effect, it is necessary to restart the Container. Should the Container be automatically restarted?
							</sw:text>
						</xsl:attribute>
						<xsl:attribute name="alert-restart-id">rve</xsl:attribute>
						<xsl:attribute name="restart-ve"><xsl:value-of select="$data_res/restart-ve"/></xsl:attribute>
					</xsl:if>
				
					<!-- Post "Unlimited" definition -->
					<xsl:attribute name="unlimited">
						<xsl:choose>
							<xsl:when test="$disabled">true</xsl:when>
							<xsl:when test="$is-unlimited">true</xsl:when>										
							<xsl:otherwise>false</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
		
					<!-- Post Current Usage  -->
					<xsl:if test="$usage-res!=''">
						<xsl:attribute name="current"><xsl:value-of select="$curr"/></xsl:attribute>
						<xsl:attribute name="current-str"><xsl:value-of select="$curr-str"/></xsl:attribute>
					</xsl:if>
								
					<!-- Post "Soft Limit" Definition -->
					<xsl:attribute name="soft">
						<xsl:choose>
							<xsl:when test="$soft-now=''"></xsl:when>
							<xsl:when test="$factor!=1 and not(check:nan($soft-now))">
								<xsl:value-of select="format-number($soft-now div $factor,'#')"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="$soft-now"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>	
					<xsl:attribute name="soft-def"><xsl:value-of select="$soft-def"/></xsl:attribute>
					<xsl:attribute name="soft-unlimited"><xsl:value-of select="$unlim_soft"/></xsl:attribute>																
					<xsl:choose>
						<xsl:when test="$show-soft-limit and complex=2 ">
							<xsl:attribute name="soft-tip"><xsl:value-of select="$soft-tip"/></xsl:attribute>
							<xsl:attribute name="soft-min"><xsl:value-of select="$min_soft"/></xsl:attribute>
							<xsl:attribute name="soft-max"><xsl:value-of select="$max_soft"/></xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="soft-off">true</xsl:attribute>									
						</xsl:otherwise>
					</xsl:choose>
								
					<!-- Post Hard Limit -->
					<xsl:attribute name="hard">
						<xsl:choose>
							<xsl:when test="$hard-now=''"></xsl:when>
							<xsl:when test="$factor!=1  and not(check:nan($hard-now))">
								<xsl:value-of select="format-number($hard-now div $factor,'#')"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="$hard-now"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>	
					<xsl:attribute name="hard-unlimited"><xsl:value-of select="$unlim_hard"/></xsl:attribute>								
					<xsl:attribute name="hard-def"><xsl:value-of select="$hard-def"/></xsl:attribute>
					<xsl:attribute name="hard-tip"><xsl:value-of select="$hard-tip"/></xsl:attribute>
					<xsl:attribute name="hard-min"><xsl:value-of select="$min_hard"/></xsl:attribute>
					<xsl:attribute name="hard-max"><xsl:value-of select="$max_hard"/></xsl:attribute>	
						
					<!-- Post "Limit/Unlimited" Control-->
					<xsl:choose>
						<xsl:when test="unlimited or disabled">
							<xsl:attribute name="unlimited-control-type">checkbox</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="unlimited-control-type">label</xsl:attribute>
							<xsl:attribute name="unlimited-control-label"><sw:text>yes</sw:text></xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
			
					<!-- Post "def-label" value -->
					<xsl:attribute name="def-label">
						<xsl:choose>
							<xsl:when test="$def-unlimited='true'">
								<sw:text>
									<xsl:with-param name="unlim" select="$unlim_label"/>
									Reset the resource limit to the default \"%{unlim}\" value.
								</sw:text>
							</xsl:when>
							<xsl:when test="$factor-type='kb'">
								<xsl:if test="$show-soft-limit">
									<sw:text>
										<xsl:with-param name="soft" select="format:kb2str($data_res/soft_src,true(),$def-factor)"/>
										<xsl:with-param name="hard" select="format:kb2str($data_res/hard_src,true(),$def-factor)"/>
											Reset the resource limits to the default %{soft}/%{hard} values.
									</sw:text>
								</xsl:if>
								<xsl:if test="not($show-soft-limit)">
									<sw:text>
										<xsl:with-param name="hard" select="format:kb2str($data_res/hard_src,true(),$def-factor)"/>
											Reset the resource limit to the default %{hard} value.
									</sw:text>
								</xsl:if>
							</xsl:when>
							<xsl:when test="$factor-type='bytes'">
								<xsl:if test="$show-soft-limit">
									<sw:text>
										<xsl:with-param name="soft" select="format:bytes2str($data_res/soft_src,true(),$def-factor)"/>
										<xsl:with-param name="hard" select="format:bytes2str($data_res/hard_src,true(),$def-factor)"/>
										Reset the resource limits to the default %{soft}/%{hard} values.
									</sw:text>
								</xsl:if>
								<xsl:if test="not($show-soft-limit)">
									<sw:text>
										<xsl:with-param name="hard" select="format:bytes2str($data_res/hard_src,true(),$def-factor)"/>
										Reset the resource limit to the default %{hard} value.
									</sw:text>
								</xsl:if>
							</xsl:when>
							<xsl:when test="complex=2">
								<sw:text>
									<xsl:with-param name="soft" select="format:res2str($data_res/soft_src,measure)"/>
									<xsl:with-param name="hard" select="format:res2str($data_res/hard_src,measure)"/>
									Reset the resource limits to the default %{soft}/%{hard} values.
								</sw:text>
							</xsl:when>
							<xsl:otherwise>
								<sw:text>
									<xsl:with-param name="hard" select="format:res2str($data_res/hard_src,measure)"/>
									Reset the resource limit to the default %{hard} value.
								</sw:text>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
							
				</ui:qos-param>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>

	<func:function name="res:param2soft">
		<xsl:param name="value"/>
		<func:result>
			<xsl:choose>
				<xsl:when test="contains($value,':')">
					<xsl:value-of select="substring-before($value,':')"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$value"/>
				</xsl:otherwise>
			</xsl:choose>
		</func:result>
	</func:function>
	
	<func:function name="res:param2hard">
		<xsl:param name="value"/>
		<func:result>
			<xsl:choose>
				<xsl:when test="contains($value,':')">
					<xsl:value-of select="substring-after($value,':')"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$value"/>
				</xsl:otherwise>
			</xsl:choose>
		</func:result>
	</func:function>

	<func:function name="res:factor2text">
		<xsl:param name="measure"/>
		<xsl:param name="factor"/>	
		<xsl:param name="factor-type"/>	

		<xsl:if test="$measure!=''">
			<func:result>
				<xsl:choose>
					<!-- Make title for KB -->
					<xsl:when test="$factor-type='kb'">
						<xsl:value-of select="local:factor-kb-label($factor)"/>
					</xsl:when>
					<!-- /Make title for KB -->
					<!-- Make title for BYTES -->
					<xsl:when test="$factor-type='bytes'">
						<xsl:value-of select="local:factor-bytes-label($factor)"/>
					</xsl:when>
					<!-- /Make title for BYTES -->
					<!-- Any other unit -->
					<xsl:when test="$measure!=''">
						<sw:text domain="vzagent-vocabulary" select="string($measure)"/>
					</xsl:when>
					<xsl:otherwise>&#160;</xsl:otherwise>
				</xsl:choose>		
			</func:result>
		</xsl:if>
	</func:function>	
	
	
	<func:function name="local:factor-kb-label">
		<xsl:param name="factor"/>
		<func:result>
			<xsl:choose>
				<xsl:when test="$factor='1'">
					<sw:text>KB</sw:text>
				</xsl:when>
				<xsl:when test="$factor='1024'">
					<sw:text>MB</sw:text>
				</xsl:when>
				<xsl:when test="$factor='1048576'">
					<sw:text>GB</sw:text>
				</xsl:when>
			</xsl:choose>
		</func:result>
	</func:function>
	
	<func:function name="local:factor-bytes-label">
		<xsl:param name="factor"/>
		<func:result>
			<xsl:choose>
				<xsl:when test="$factor='1'">
					<sw:text>Bytes</sw:text>
				</xsl:when>
				<xsl:when test="$factor='1024'">
					<sw:text>KB</sw:text>
				</xsl:when>
				<xsl:when test="$factor='1048576'">
					<sw:text>MB</sw:text>
				</xsl:when>
				<xsl:when test="$factor='1073741824'">
					<sw:text>GB</sw:text>
				</xsl:when>
			</xsl:choose>
		</func:result>
	</func:function>

	<func:function name="res:recalc-value-by-factor">
		<xsl:param name="value"/>
		<xsl:param name="factor"/>

		<func:result>
			<xsl:choose>
				<xsl:when test="$value=''"></xsl:when>
				<xsl:when test="$factor!=1 and not(check:nan($value))">
					<xsl:value-of select="format-number($value div $factor,'#')"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$value"/>
				</xsl:otherwise>
			</xsl:choose>
		</func:result>
		
	</func:function>

	<sw:include href="/lib/common.xsl"/>
	
</xsl:stylesheet>
