<!--
	Copyright (c) SWsoft, 1999-2007
	All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred hwm show local date updateui dynamic format html"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz" xmlns:hwm="http://www.swsoft.com/xsl/cp/hwm"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui" xmlns:show="http://www.swsoft.com/xsl/cp/show"
	xmlns:date="http://exslt.org/dates-and-times" xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:func="http://exslt.org/functions" xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:updateui="http://www.swsoft.com/xsl/cp/update-screen"
	xmlns:set="http://exslt.org/sets" 
	xmlns:dynamic="http://www.swsoft.com/xsl/cp/dynamic"
	xmlns:format="http://www.swsoft.com/xsl/cp/format"
	xmlns:update="http://www.swsoft.com/xsl/cp/update"
	xmlns:html="http://www.swsoft.com/xsl/cp/html"	
>
	
	<sw:include href="/lib/utils/format-datetime.xsl"/>
	<sw:include href="/layout/lib/html.xsl"/>
	<sw:include href="/lib/update.xsl"/>
	
	<func:function name="updateui:hours">
	
		<xsl:variable name="i" select="sw:split('0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23', ',')"/>
		
		<xsl:variable name="hours">
			<xsl:for-each select="$i">
				<hour id="{.}">
					<xsl:value-of select="updateui:format-hour(.)"/>
				</hour>
			</xsl:for-each>
		</xsl:variable>	

		<func:result select="exsl:node-set($hours)/hour" />
	</func:function> 
	
	<func:function name="updateui:days">
		<xsl:variable name="local:days">
			<day id="everyday">
				<sw:text>Every day</sw:text>
			</day>
			<day id="sunday">
				<sw:text>Every Sunday</sw:text>
			</day>
			<day id="monday">
				<sw:text>Every Monday</sw:text>
			</day>
			<day id="tuesday">
				<sw:text>Every Tuesday</sw:text>
			</day>
			<day id="wednesday">
				<sw:text>Every Wednesday</sw:text>
			</day>
			<day id="thursday">
				<sw:text>Every Thursday</sw:text>
			</day>
			<day id="friday">
				<sw:text>Every Friday</sw:text>
			</day>
			<day id="saturday">
				<sw:text>Every Saturday</sw:text>
			</day>
		</xsl:variable>

		<func:result select="exsl:node-set($local:days)/day" />
	</func:function>
	
	<func:function name="updateui:format-day">
		<xsl:param name="day" select="''"/>
		<xsl:variable name="days" select="updateui:days()"/>
		<func:result select="sw:if($days[@id=string($day)], 
									$days[@id=string($day)], 
									$days[@id='everyday'])"/>
	</func:function>
	
	<func:function name="updateui:format-hour">
		<xsl:param name="hour"/>
		
		<func:result select="concat(sw:if($hour &lt; 10, '0',''), $hour, ':00')"/>
	</func:function>
	
	<xsl:template name="updateui:add-advanced-controls">
		<xsl:param name="no_boot_loader" />
		<xsl:param name="no_reboot" />
		
		<ui:raw>
			<script>
			<![CDATA[
				function checkCritical(id) {
					var bootloader = document.getElementById('no_boot_loader');
					var reboot = document.getElementById('no_reboot');
					var msg="]]><sw:text>The Virtuozzo services will be stopped after the installation of the updates (Parallels Infrastructure Manager and Parallels Power Panel will be unavailable). You will have to manually reboot the Hardware Node.</sw:text><![CDATA["
					var msg2="]]><sw:text>The new Virtuozzo kernel will not be set as default in your bootloader configuration.</sw:text><![CDATA["
					if (id == 'no_boot_loader') {
						if(bootloader.checked) {
							if ((reboot.checked && confirm(msg2))|| confirm(msg2 + ' ' + msg)) {
								reboot.checked=bootloader.checked;
								reboot.disabled=true;
							} else {
								reboot.disabled=false;
								bootloader.checked = false;
							}
						} else {
							reboot.disabled=false;
							reboot.checked=false;
						}
					} else {
						if(reboot.checked && !confirm(msg)) {
								reboot.checked = false;
						} 
					}
				}
			]]>
			</script>
		</ui:raw>
		
		<ui:block width="max">
			<ui:rows title="{sw:text('Install Options')}" id="adv_settings"
				status-def="{sw:if($no_reboot or $no_boot_loader, '1', '0')}"
				closed-text="{sw:text('Click to configure install options.')}">
				<ui:row>
					<ui:cell />
					<ui:cell-check id="no_boot_loader" close="false" value="no_boot_loader"
						checked="{sw:if($no_boot_loader, '1', '0')}" align="left" 
						onclick="checkCritical('no_boot_loader')">
					</ui:cell-check>

					<ui:cell label-for="no_boot_loader" open="false" align="left">
						<nobr>
							<sw:text>Disable automatic bootloader configuration</sw:text>
						</nobr>
					</ui:cell>
				</ui:row>
				<ui:row>
					<ui:cell />
					<ui:cell-check id="no_reboot" close="false" value="no_reboot"
						checked="{sw:if($no_reboot, '1', '0')}" align="left" 
						onclick="checkCritical('no_reboot')"/>

					<ui:cell label-for="no_reboot" open="false" align="left">
						<nobr>
							<sw:text>Disable automatic reboot</sw:text>
						</nobr>
					</ui:cell>
				</ui:row>
			</ui:rows>
		</ui:block>
	</xsl:template>
	
	<xsl:template name="updateui:install-progress-body">
		<xsl:param name="status" />
		<xsl:param name="msgid" />
		
		<ui:hidden name="step" value="progress" />
		<ui:hidden name="status" id="status" value="2" />
		<ui:hidden name="msgid" value="{$msgid}" />
		
		<xsl:variable name="once" select="$status=4 or $status=3" />
		<xsl:variable name="form" select="sw:sesget($wiz_data)" />

		<ui:raw>
			<script>
				<![CDATA[
					var run = ]]>
				<xsl:value-of select="sw:if($once, 'false', 'true')" />
				
				<![CDATA[;
					var noreboot = ]]><xsl:value-of select="sw:if($form/summary/no_reboot, 'true', 'false')" /><![CDATA[;
				
					var noloader = ]]><xsl:value-of select="sw:if($form/summary/no_boot_loader, 'true', 'false')" /><![CDATA[;
				
					function onLoad() {
						getMessage();
					}
					
					]]>
					function getMessage() {
						requestContent("<xsl:value-of select="concat($baseurl, '/vzdir/maintman/updates/install-update-dynamic?id=', 
						$msgid)" />", updateMessage,'<xsl:value-of select="$ticket"/>' , "<xsl:value-of select="$ticketid"/>");
					}
					<![CDATA[
					
					var log = "";	
					var first = true;
					var count = 0;
					var errCount = 0;
				
					function updateMessage(res) {
						if (res.readyState==1) {
							if (errCount > 5) {
								reportLongWait();
							} else {
								errCount++;
							}
						} else if (res.readyState==4) {
							errCount=0;
							if (checkStatus(res)) {
								if (res.responseText != '' && res.responseText.indexOf(":STATUS:") != -1){
									count = 0;
									var str=res.responseText;

									var status = str.substring(str.indexOf(":STATUS:") + ":STATUS:".length, str.indexOf(":MESSAGE:"));
									var msg = str.substring(str.indexOf(":MESSAGE:") + ":MESSAGE:".length);
									
									document.getElementById("msg").innerHTML = describeStatus(status) + msg;
									
									first = false;
									
									if (status == "3" || status == "4") {
										var dfo=document.defaultForm;
										if (dfo) { if (dfo.status) dfo.status.value=status;}
										if (run) {
											document.defaultForm.submit();
										}
										run = false;
									}
									log = msg;
								} else if (res.responseText.indexOf('LoginUser') > -1) {
									count = 0;
									document.getElementById("msg").innerHTML= describeStatus(3) + log + '<br />]]><sw:text>
											<xsl:with-param name="aopen">&lt;a target="_top" href="<xsl:value-of select="$baseurl" />"&gt;</xsl:with-param>
											<xsl:with-param name="aclose">&lt;/a&gt;</xsl:with-param>
The installation is finished. You should %{aopen}click here%{aclose} to log in again.</sw:text><![CDATA[';
									run = false;
								}
							} else {
								reportLongWait();
							}
							//--- if 'run' and previous request end;
							if (run) setTimeout("getMessage()", 5000);
						}			
					}			
					
					function checkStatus(res) {
						
						try {
							if (res.status==200) {
								return true;
							}
						} catch (e) {
							return false;
						}	
						return false;							
					}
					
					function reportLongWait() {
						count++;
						var s = describeStatus(2) + log;
						if (count > 120 && noloader) {
							document.getElementById("msg").innerHTML= describeStatus(3) + log + "<br />]]><sw:text>The Virtuozzo services are stopped. Log in to the Hardware Node by other means (e.g. via SSH) to configure the bootloader manually. To finish the update installation, you should reboot the Hardware Node.</sw:text><![CDATA[";
							run = false;
						} else if (count > 120 && noreboot) {
							document.getElementById("msg").innerHTML= describeStatus(3) + log + "<br />]]><sw:text>The Virtuozzo services are stopped. Log in to the Hardware Node by other means (e.g. via SSH) to finish the update(s) installation by rebooting it manually.</sw:text><![CDATA[";
							run = false;
						} else if (count > 120) { 
							document.getElementById("msg").innerHTML= s + "<br />]]><sw:text>Restarting Virtuozzo and VZCC has timed out. Log in to the Node by other means (e.g. via SSH, or Terminal Server Client) to check its status.</sw:text><![CDATA[";
							run = false;
						} else if (noloader || noreboot) {
							document.getElementById("msg").innerHTML= s + "<br />]]><sw:text>The Virtuozzo services will be stopped until the system has been updated. Please wait a few minutes.</sw:text><![CDATA[";
						} else {
							document.getElementById("msg").innerHTML= s + "<br />]]><sw:text>Restarting the Virtuozzo services. Please wait a few minutes.</sw:text><![CDATA[";							
						}
					}	
					
					function describeStatus(status) {
						var str = '<b>'; 
						if (status == 3) {
							str += '<img id="img_size" width="16" border="0" height="16" src="/]]><xsl:value-of select="$theme" /><![CDATA[/icons/check_green.gif" />';
							str += '&#160;<span class="green">]]><sw:text>Completed</sw:text><![CDATA[</span>';
						} else if (status == 4) {
							str += '<img id="img_size" width="16" border="0" height="16" src="/]]><xsl:value-of select="$theme" /><![CDATA[/icons/del_red.gif" />';
							str += '&#160;<span class="red">]]><sw:text>Failed</sw:text><![CDATA[</span>';
						} else {
							str += '<img id="img_size" width="16" border="0" height="16" src="/]]><xsl:value-of select="$theme" /><![CDATA[/icons/indicator.gif" />';
							str += '&#160;]]><sw:text>In Progress</sw:text><![CDATA[</span>';
						}
						str += '</b><br /><br />';
						
						return str;
					}			
				]]>
			</script>
		</ui:raw>
		<ui:block width="max">
			<ui:rows title="{sw:text('Installation Progress')}">
				<ui:row>
					<ui:cell id="msg" name="msg">
						<img id="img_size" width="16" border="0" height="16" src="/{$theme}/icons/indicator.gif" />
						&#160;<sw:text>Waiting for progress information...</sw:text>
					</ui:cell>
				</ui:row>
			</ui:rows>
		</ui:block>
	</xsl:template>
	
	
	<xsl:template name="updateui:install-progress-transition">
		<ui:block width="max">
			<ui:rows title="{sw:text('Virtuozzo Updates Installation')}">
				<ui:row>
					<ui:cell-value>
						<ui:raw>
							<img onmouseover="callTip('vzupdate_transition_icon',event)" onmouseout="callTip()" src="/{$theme}/icons/env_updating" width="16" height="16" hspace="5" class="veState"/>
							<sw:text>Virtuozzo is installing the updates. It may take some time.</sw:text>
						</ui:raw>
					</ui:cell-value>
				</ui:row>
			</ui:rows>
		</ui:block>
	</xsl:template>
	
	<xsl:template name="updateui:install-templates-progress-ajax">
		<xsl:param name="msgid" />
		
		<ui:raw>
			<script>
				<![CDATA[
					var run = true;			

					function onLoad() {
						getMessage();
					}
					
					]]>
					function getMessage() {
						requestContent("<xsl:value-of select="concat($baseurl, '/vzdir/maintman/updates/install-update-dynamic?id=', $msgid)" />", updateMessage,"<xsl:value-of select='$ticket'/>","<xsl:value-of select="$ticketid"/>");
					}
					<![CDATA[
					
					var log = "";	
					var first = true;
					var count = 0;
					var errCount = 0;
				
					function updateMessage(res) {
						if (res.readyState==1) {
							if (errCount > 5) {
								reportLongWait();
							} else {
								errCount++;
							}
						} else if (res.readyState==4) {
							errCount=0;
							if (checkStatus(res)) {
								if (res.responseText != '' && res.responseText.indexOf(":STATUS:") != -1){
									count = 0;
									var str=res.responseText;

									var status = str.substring(str.indexOf(":STATUS:") + ":STATUS:".length, str.indexOf(":MESSAGE:"));
									var msg = str.substring(str.indexOf(":MESSAGE:") + ":MESSAGE:".length);
									
									document.getElementById("msg").innerHTML = describeStatus(status) + msg;
									
									first = false;
									
									if (status == "3" || status == "4") {
										var dfo=document.defaultForm;
										if (dfo) { if (dfo.status) dfo.status.value=status;}
										if (run) {
											document.defaultForm.submit();
										}
										run = false;
									}
									log = msg;
								} else if (res.responseText.indexOf('LoginUser') > -1) {
									count = 0;
									document.getElementById("msg").innerHTML= describeStatus(3) + log + '<br />]]><sw:text>
											<xsl:with-param name="aopen">&lt;a target="_top" href="<xsl:value-of select="$baseurl" />"&gt;</xsl:with-param>
											<xsl:with-param name="aclose">&lt;/a&gt;</xsl:with-param>
The installation is finished. You should %{aopen}click here%{aclose} to log in again.</sw:text><![CDATA[';
									run = false;
								}
							} else {
								reportLongWait();
							}
							//--- if 'run' and previous request end;
							if (run) setTimeout("getMessage()", 5000);
						}			
					}			
					
					function checkStatus(res) {
						
						try {
							if (res.status==200) {
								return true;
							}
						} catch (e) {
							return false;
						}	
						return false;							
					}
					
					function reportLongWait() {
						count++;
						var s = describeStatus(2) + log;
						if (count > 120) { 
							document.getElementById("msg").innerHTML= s + "<br />]]><sw:text>Restarting Virtuozzo and Parallels Infrastructure Manager has timed out. Log in to the Node by other means (e.g. via SSH) to check its status.</sw:text><![CDATA[";
							run = false;
						} 
					}	
					
					function describeStatus(status) {
						var str = '<b>'; 
						if (status == 3) {
							str += '<img id="img_size" width="16" border="0" height="16" src="/]]><xsl:value-of select="$theme" /><![CDATA[/icons/check_green.gif" />';
							str += '&#160;<span class="green">]]><sw:text>Completed</sw:text><![CDATA[</span>';
							doSubmit();
						} else if (status == 4) {
							str += '<img id="img_size" width="16" border="0" height="16" src="/]]><xsl:value-of select="$theme" /><![CDATA[/icons/del_red.gif" />';
							str += '&#160;<span class="red">]]><sw:text>Failed</sw:text><![CDATA[</span>';
						} else {
							str += '<img id="img_size" width="16" border="0" height="16" src="/]]><xsl:value-of select="$theme" /><![CDATA[/icons/indicator.gif" />';
							str += '&#160;]]><sw:text>In Progress</sw:text><![CDATA[</span>';
						}
						str += '</b><br /><br />';
						
						return str;
					}			
				]]>
			</script>
		</ui:raw>
		<ui:block width="max">
			<ui:rows title="{sw:text('Update Installation Progress')}">
				<ui:row>
					<ui:cell id="msg" name="msg">
						<img id="img_size" width="16" border="0" height="16" src="/{$theme}/icons/indicator.gif" />
						&#160;<sw:text>Waiting for progress information...</sw:text>
					</ui:cell>
				</ui:row>
			</ui:rows>
		</ui:block>
	</xsl:template>
	
	<xsl:template name="updateui:install-progress-generic">
		<xsl:param name="progress-msg" />
		<xsl:param name="status" />
		<xsl:param name="msgid" />
		<xsl:param name="options" />
		
		<ui:screen path-id="{$path-id}" id="{$step_data/@screen-id}" title="{$step_data/@screen-title}"
			icon="{$step_data/@screen-icon}">

			<xsl:variable name="once" select="$status=4 or $status=3" />
			
			<xsl:call-template name="local:show-properties">
				<xsl:with-param name="progress-msg" select="$progress-msg" />
				<xsl:with-param name="status" select="$status" />
			</xsl:call-template>
						
			<ui:content>
				<xsl:call-template name="local:show-warning" />
				
				<xsl:call-template name="updateui:install-progress-body">
					<xsl:with-param name="status" select="$status" />
					<xsl:with-param name="msgid" select="$msgid" />
				</xsl:call-template>
			</ui:content>
		</ui:screen>
	</xsl:template>
	
	<xsl:template name="updateui:install-progress">
		<xsl:param name="progress-msg" />

		<xsl:variable name="status" select="sw:sesget('vzaup2date_op_status')" />
		<xsl:variable name="msgid" select="sw:sesget('vzaup2date_op_id')" />
	
		<ui:screen path-id="{$path-id}" id="{$step_data/@screen-id}" title="{$step_data/@screen-title}"
			icon="{$step_data/@screen-icon}">

			<xsl:variable name="once" select="$status=4 or $status=3" />

			<xsl:call-template name="local:show-properties">
				<xsl:with-param name="progress-msg" select="$progress-msg" />
				<xsl:with-param name="status" select="$status" />
			</xsl:call-template>

			<ui:content>
				<xsl:call-template name="local:show-warning" />
				
				<xsl:call-template name="updateui:install-progress-body">
					<xsl:with-param name="status" select="$status" />
					<xsl:with-param name="msgid" select="$msgid" />
				</xsl:call-template>
		
				<ui:block width="max">
					<ui:buttons>
						<xsl:choose>
							<xsl:when test="$status=3">
								<ui:button type="ok" tip="{sw:text('Exit the installation wizard.')}" name="ok" id="ok"
									sandclock="false">
									<sw:text>Exit</sw:text>
								</ui:button>
							</xsl:when>
							<xsl:when test="$status=4">
								<ui:button type="simple" tip="{sw:text('Retry installation.')}" name="retry"
									id="retry" sandclock="false">
									<sw:text>Retry</sw:text>
								</ui:button>
								<ui:button type="cancel" tip="{sw:text('Exit the installation wizard.')}" name="cancel" id="cancel"
									sandclock="false">
									<sw:text>Exit</sw:text>
								</ui:button>
							</xsl:when>
							<xsl:otherwise>
								<ui:button type="cancel" tip="{sw:text('Exit the installation wizard.')}" name="cancel" id="cancel"
									sandclock="false" disabled="true">
									<sw:text>Exit</sw:text>
								</ui:button>
							</xsl:otherwise>
						</xsl:choose>

					</ui:buttons>
				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>
	
	<xsl:template name="local:show-properties">
		<xsl:param name="progress-msg" />
		<xsl:param name="status" />
		
		<xsl:variable name="once" select="$status=4 or $status=3" />

		<ui:properties>
			<ui:refresh-type>none</ui:refresh-type>
			<ui:description mandatory="yes">
				<xsl:choose>
					<xsl:when test="$once">
						<xsl:value-of select="$progress-msg[id=$status]/desc" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$progress-msg[id=2]/desc" />
					</xsl:otherwise>
				</xsl:choose>
			</ui:description>
		</ui:properties>
		
	</xsl:template>
	
	<xsl:template name="local:show-warning">
		<xsl:variable name="form" select="sw:sesget($wiz_data)" />
		
		<xsl:if test="$form/summary/*[name()='no_reboot' or name()='no_boot_loader']">
			<ui:block width="max">
				<ui:rows title="Warning!">
					<ui:row>
						<ui:cell cell-width="5%">
							<xsl:copy-of select="$img-error" />
						</ui:cell>
						<ui:cell-value cell-width="95%">
							<xsl:choose>
								<xsl:when test="$form/summary/no_boot_loader">
									<sw:text>
										You have chosen to configure the bootloader and reboot the Hardware Node manually. The Virtuozzo services will be stopped during the update procces.
									</sw:text>
								</xsl:when>
								<xsl:otherwise>
									<sw:text>
										You have chosen to reboot the Hardware Node manually. The Virtuozzo services will be stopped during the updating.
									</sw:text>
								</xsl:otherwise>
							</xsl:choose>
						</ui:cell-value>
					</ui:row>
				</ui:rows>
			</ui:block>
		</xsl:if>
	</xsl:template>
	
	<func:function name="updateui:filter-template-updates-by-uid">
		<xsl:param name="updates" />
		<xsl:param name="id" />
		
		<xsl:variable name="res">
			<xsl:for-each select="$updates[id=$id or app_template/id=$id]">
				<xsl:variable name="os" select="."/>
				<xsl:call-template name="update:generate-update">
					<xsl:with-param name="type" select="update:type(.)"/>
					<xsl:with-param name="id" select="id"/>
					<xsl:with-param name="content">
						<xsl:copy-of select="*[not(self::id or self::app_template)]"/>
						<xsl:copy-of select="app_template[id=$id]"/>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:for-each>
		</xsl:variable>
		
		<func:result select="exsl:node-set($res)/update"/>
	</func:function>
	
	<func:function name="local:oses">
		<xsl:param name="oses"/>

		<xsl:variable name="res">
			<xsl:for-each select="$oses">
				<xsl:choose>
					<xsl:when test="id">
						<xsl:copy-of select="."/>
					</xsl:when>
					<xsl:otherwise>
						<os>
							<id><xsl:value-of select="substring-before($os, '/')"/></id>
							<xsl:if test="contains($os,'/')">
								<version><xsl:value-of select="substring-after($os, '/')"/></version>
							</xsl:if>
						</os>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
		</xsl:variable>
		<func:result select="exsl:node-set($res)/os"/>
	</func:function>
	
	<xsl:template name="updateui:show-template-update-details">
		<xsl:param name="updates" />

		<xsl:variable name="ups" select="$updates[update:is-update(.)]|$updates/app_template[update:is-update(.)]"/>
		
		<xsl:variable name="msg">
			<xsl:choose>
				<xsl:when test="$ups">
					<sw:text>
						<xsl:with-param name="count" select="count($ups)"/>
						Template Updates (%count)
					</sw:text>
				</xsl:when>
				<xsl:otherwise>
					<sw:text>Template Updates</sw:text>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<ui:block width="max">
			<ui:rows separate-tables="true" title="{$msg}">
				<ui:tree>
					<ui:nodes collapsed="false">
						<xsl:call-template name="local:os-nodes">
							<xsl:with-param name="updates" select="$updates[update:is-update(.)]" />
							<xsl:with-param name="collapsed" select="false()" />
						</xsl:call-template>
						<xsl:call-template name="local:app-nodes">
							<xsl:with-param name="updates" select="$updates" />
							<xsl:with-param name="collapsed" select="false()" />
						</xsl:call-template>
					</ui:nodes>
				</ui:tree>
			</ui:rows>
		</ui:block>
	</xsl:template>
	
	<xsl:template name="updateui:show-template-update-list">
		<xsl:param name="updates" />

		<xsl:variable name="ups" select="$updates[update:is-update(.)]|$updates/app_template[update:is-update(.)]"/>
		
		<ui:block width="max">
			<xsl:variable name="msg">
				<xsl:choose>
					<xsl:when test="$ups">
						<sw:text>
							<xsl:with-param name="count" select="count($ups)" />
							Available Template Updates (%count)
						</sw:text>
					</xsl:when>
					<xsl:otherwise>
						<sw:text>Template Updates</sw:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
			
			<ui:rows separate-tables="true" title="{$msg}">
				<ui:tree>
					<ui:nodes>
						<xsl:call-template name="local:os-nodes">
							<xsl:with-param name="updates" select="$updates[update:is-update(.)]" />
						</xsl:call-template>
						<xsl:call-template name="local:app-nodes">
							<xsl:with-param name="updates" select="$updates" />
						</xsl:call-template>
					</ui:nodes>
				</ui:tree>
			</ui:rows>
		</ui:block>
	</xsl:template>
	
	<xsl:template name="local:os-nodes">
		<xsl:param name="updates" />
		<xsl:param name="collapsed" select="true()" />
		
		<xsl:variable name="oses" select="$updates[update:is-update(.)]"/>
		<xsl:variable name="new-oses" select="$oses[update:is-new(.)]"/>
		
		<xsl:if test="$oses/id">
			<ui:node>
				<xsl:if test="$collapsed=false()">
					<xsl:attribute name="collapsed">false</xsl:attribute>
				</xsl:if>
				<ui:title>
					<sw:text>
						<xsl:with-param name="count-new" select="count($new-oses)"/>
						<xsl:with-param name="count-upd" select="count($oses)-count($new-oses)"/>
						OS Templates (%{count-new} new, %{count-upd} updates).
					</sw:text>
				</ui:title>

				<xsl:for-each select="$oses">
					<xsl:call-template name="local:show-app-node">
						<xsl:with-param name="app" select="." />
						<xsl:with-param name="message">
							<sw:text>New OS template.</sw:text>
						</xsl:with-param>
						<xsl:with-param name="collapsed" select="$collapsed" />
					</xsl:call-template>
				</xsl:for-each>
			</ui:node>
		</xsl:if>
	</xsl:template>

	<xsl:template name="local:app-nodes">
		<xsl:param name="updates" />
		<xsl:param name="collapsed" select="true()" />
		
		<xsl:for-each select="$updates[app_template[update:is-update(.)]]">
			<xsl:sort select="id"/>
			<xsl:variable name="os" select="sw:if(update:type(.)=$update:types/os-templates, concat(id, '/', version), id)" />

			<ui:node>
				<xsl:if test="$collapsed=false()">
					<xsl:attribute name="collapsed">false</xsl:attribute>
				</xsl:if>
				<ui:title>
					<sw:text>
						<xsl:with-param name="ver" select="$os"/>
						<xsl:with-param name="count-new" select="count(app_template[update:is-new(.)])"/>
						<xsl:with-param name="count-upd" select="count(app_template[update:is-update(.) and not(update:is-new(.))])"/>
						Applications for the %{ver} OS template (%{count-new} new, %{count-upd} updates).
					</sw:text>
				</ui:title>

				<xsl:for-each select="app_template[update:is-update(.)]">
					<xsl:sort select="sw:lc(sw:base64-decode(name))" />
					<xsl:call-template name="local:show-app-node">
						<xsl:with-param name="app" select="." />
						<xsl:with-param name="message">
							<sw:text>New application template.</sw:text>
						</xsl:with-param>
						<xsl:with-param name="collapsed" select="$collapsed" />
					</xsl:call-template>
				</xsl:for-each>
			</ui:node>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="local:show-app-node">
		<xsl:param name="app" />
		<xsl:param name="message" />
		<xsl:param name="collapsed" select="true()" />
		
		<ui:node>
			<xsl:if test="$collapsed=false()">
				<xsl:attribute name="collapsed">false</xsl:attribute>
			</xsl:if>
			<ui:title>
				<ui:raw>
					<xsl:value-of select="$app/id"/><br/>
					<xsl:value-of select="sw:base64-decode($app/name)"/>
					<br />
					<span class="inactive">
						<xsl:choose>
							<xsl:when test="update:is-new($app)">
								<xsl:value-of select="$message"/>
							</xsl:when>
							<xsl:otherwise>
								<sw:text>
									<xsl:with-param name="ver" select="$app/version" />
									Update to version %ver.
								</sw:text>
							</xsl:otherwise>
						</xsl:choose>
					</span>
				</ui:raw>
			</ui:title>
			<ui:node>
				<ui:title nohref="yes">
					<xsl:value-of select="html:plain2html(sw:base64-decode($app/description))" disable-output-escaping="yes"/>
				</ui:title>
			</ui:node>
		</ui:node>
	</xsl:template>
	
	<xsl:template name="updateui:update-status">
		<xsl:param name="time" />
		<xsl:param name="url" />
		<xsl:param name="has-problem" select="false()"/>
		<xsl:param name="disable-buttons-ids" select="/.."/>
		
		<ui:raw>
			<div>
				<xsl:choose>
					<xsl:when test="$has-problem">
						<span id="refresh_img" style="display:none;float:left">
							<nobr>
							<img id="refresh_img" width="16" border="0" height="16"
								src="/{$theme}/icons/indicator.gif" />&#160;<span id="update_result">
								<sw:text>Checking for updates...</sw:text>
							</span>
							</nobr>
						</span>
					</xsl:when>
					<xsl:when test="not($time) or $time=0">
						<img id="refresh_img" width="16" border="0" height="16"
							src="/{$theme}/icons/indicator.gif" />&#160;<span id="update_result">
							<sw:text>Checking for updates...</sw:text>
						</span>
					</xsl:when>
					<xsl:otherwise>
						<span id="refresh_img" style="display:none;float:left"><img width="16" border="0" height="16"
							src="/{$theme}/icons/indicator.gif" />&#160;</span><span id="update_result"><sw:text>
								<xsl:with-param name="date" select="format:date-time($time)" />
								The last update check was performed on <b>%date</b>.
							</sw:text>
						</span>
					</xsl:otherwise>
				</xsl:choose>
			</div>
			<xsl:variable name="send-ui-name" select="'get_updates'" />
			<xsl:variable name="recv-ui-name" select="'list_updates'" />
			<xsl:variable name="div-name" select="'update_result'" />
			
			<xsl:call-template name="dynamic:error-reporter-script" />
			
			<xsl:variable name="progress-content">
				<img id="refresh_img" width="16" border="0" height="16"
							src="/{$theme}/icons/indicator.gif" />&#160;<sw:text>Checking for updates...</sw:text>
			</xsl:variable>

			<script>
				function pre_get() {
				<xsl:for-each select="$disable-buttons-ids">
					disableToolbarItem('<xsl:value-of select="."/>');
				</xsl:for-each>
					document.getElementById('refresh_img').style.display='block';
					document.getElementById('update_result').innerHTML = '<xsl:value-of select="sw:html-escape(sw:text('Checking for updates...'))"/>';
				}
				
				function recv(content) {
					<!-- replace progress with initial message -->
					var div_obj = document.getElementById('update_result');
					if (content.length &gt; 1) {
						if (content[0] == 'NA') {
							document.getElementById('refresh_img').style.display='none';
							document.getElementById('update_result').innerHTML = content[1];
						} else if(content[0] !='error') {
							document.getElementById('update_result').innerHTML = '<xsl:value-of select="sw:html-escape(sw:text('Getting list of updates...'))"/>';
						} 
						 
						doSubmit();
					} 
				}
			</script>
			
			<xsl:call-template name="dynamic:ajax-sender-func">
				<xsl:with-param name="sender-func" select="'get_updates'"/>
				<xsl:with-param name="reciever-func" select="'handle_updates'" />
				<xsl:with-param name="request-url" select="$url"/>
				<xsl:with-param name="ui-func" select="'pre_get'" />
			</xsl:call-template>
	
			<xsl:call-template name="dynamic:ajax-reciever-func">
				<xsl:with-param name="reciever-func" select="'handle_updates'"/>
				<xsl:with-param name="ui-func" select="'recv'" />
			</xsl:call-template>
		</ui:raw>
	</xsl:template>
	
	<func:function name="updateui:show-date">
		<xsl:param name="date"/>
		<xsl:variable name="time" select="sw:vzatime2utime($date)"/>
		<func:result>
			<xsl:choose>
				<xsl:when test="$time=-1">
					<sw:text>n/a</sw:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="format:date-date($time)"/>
				</xsl:otherwise>
			</xsl:choose>
		</func:result>
	</func:function>
	
	<sw:include href="/lib/screen.xsl" />
	<sw:include href="/lib/dynamic.xsl" />
	<sw:include href="/lib/update.xsl" />
	<sw:include href="/lib/vocabulary.xsl" />
</xsl:stylesheet>