
<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func cred vzenv env tem voc vzapackagem vz local trace"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl	="http://exslt.org/common"
  xmlns:set		="http://exslt.org/sets"
  xmlns:math="http://exslt.org/math"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
  xmlns:tem		="http://www.swsoft.com/xsl/cp/tem"
  xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
  xmlns:env		="http://www.swsoft.com/xsl/cp/env"
  xmlns:ve		="http://www.swsoft.com/xsl/cp/ve" 
  xmlns:vzenv ="http://www.swsoft.com/xsl/cp/vzenv"
  xmlns:func	="http://exslt.org/functions"
  xmlns:voc		="http://www.swsoft.com/xsl/cp/voc"
  xmlns:vzapackagem	="http://www.swsoft.com/xsl/cp/vzapackagem"
  xmlns:vz		="http://www.swsoft.com/xsl/cp/vz"
  xmlns:local	="http://www.swsoft.com/xsl/cp/local"
  xmlns:trace	="http://www.swsoft.com/xsl/cp/trace"
  xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
>
	<sw:include href="../vocabulary.xsl"/>
	<sw:include href="../trace.xsl"/>	
	<sw:include href="../vt/ve-core.xsl"/>	
	<sw:include href="/lib/vza/vzapackagem.xsl"/>	
	<sw:include href="/lib/vz/apps.xsl"/>	
	<sw:include href="/lib/vz/vzenv-core.xsl"/>	
	<sw:include href="/lib/vz/vzenv-os.xsl"/>	

	<xsl:template name="vzenv:show-os-apps">
		<xsl:param name="env"/>
		<xsl:param name="advanced" select="false()"/>
		
		<xsl:variable name="templates" select="vzapackagem:get-env-templates($env)"/>
		
		<xsl:variable name="os" select="$templates[vzapackagem:is-os(.)][1]"/>
		<xsl:variable name="apps" select="$templates[not(vzapackagem:is-os(.))]"/>
		
		<xsl:variable name="os-undefined" select="not($os)"/>
		
		<ui:row>
			<xsl:variable name="newpkgm" select="sw:is-ez-package($os/name)"/>
			<ui:cell-label><sw:text>OS Template</sw:text></ui:cell-label>
			<ui:cell-value>	
				<xsl:call-template name="vzenv:get-os-tmpl-label">
					<xsl:with-param name="os" select="$os"/>
					<xsl:with-param name="enabled" select="not($activeMode='vzcp') and cred:check('vzcp.template')"/>
					<xsl:with-param name="show-generation" select="$advanced and not($os-undefined)"/>
					<xsl:with-param name="hn-eid" select="$env/parent_eid"/>
				</xsl:call-template>
			</ui:cell-value>
		</ui:row>
		<xsl:if test="$advanced or $apps">
			<ui:row>
				<ui:cell-label><sw:text>Applications Installed</sw:text></ui:cell-label>
				<ui:cell-value>
					<xsl:choose>
						<xsl:when test="$apps">
							<xsl:call-template name="vzenv:view-apps-list">
								<xsl:with-param name="apps" select="$apps"/>
								<xsl:with-param name="enabled" select="not($activeMode='vzcp') and cred:check('vzcp.template')"/>
								<xsl:with-param name="hn-eid" select="$env/parent_eid"/>
							</xsl:call-template>
						</xsl:when>
						<xsl:otherwise>
							<span class="inactive"><sw:text>No applications installed</sw:text></span>
						</xsl:otherwise>
					</xsl:choose>
				</ui:cell-value>
			</ui:row>
		</xsl:if>
	</xsl:template>
	
	<!-- Show OS template label (link if possible) for VE or sample -->
	<xsl:template name="vzenv:get-os-tmpl-label">
		<xsl:param name="os"/>
		<xsl:param name="enabled" select="true()"/>
		<xsl:param name="empty-message" select="''"/>
		<xsl:param name="show-generation" select="true()"/>
		<xsl:param name="hn-eid" select="''"/>
		
		<xsl:variable name="package" select="vzapackagem:vztemplate-packages($os)[1]"/>
		<xsl:variable name="base" select="$package/name"/>
		<xsl:variable name="latest" select="not(sw:is-ez-package($base)) and string($package/version)=''"/>
		<xsl:variable name="version" select="sw:if($latest, sw:text('latest'), $package/version)"/>
		
		<xsl:variable name="found" select="vz:find-template($os, string($hn-eid))"/>		
		
		<xsl:choose>									
			<!-- Show undefined os or defined without link -->
			<xsl:when test="not($enabled) or (string($os)='') or not($found)">
				<xsl:copy-of select="sw:app-id2title($base,$version,$empty-message)"/>  												
			</xsl:when>
			<!-- Show defined new OS with link -->
			<xsl:otherwise>
				<a href="{$baseurl}/vzdir/infrman/templates/ez/group-app?path=reset&amp;app-id={sw:base64-encode(vzapackagem:generate-id($found/packages))}&amp;hn-eid={sw:base64-encode($found/env/eid)}">
					<xsl:copy-of select="sw:app-id2title($base, $version, $empty-message, $show-generation)"/>
				</a>
			</xsl:otherwise>									
		</xsl:choose>
	</xsl:template>
	
	<!--  Utility template used to display link to OS/App template information.
		app		- template information (name, os, version, etc. as in vzapackagem functions)
		label	- link text
		hn-eid	- eid of HN where template information is
		global	- flag to switch link to group specific info (true) or HN specific template info (false) 
	-->
	<xsl:template name="local:show-app-link">
		<xsl:param name="app"/>
		<xsl:param name="label"/>
		<xsl:param name="hn-eid"/>
		<xsl:param name="global" select="true()"/>
		
		<a 
			href="{$baseurl}/vzdir/infrman/templates/ez/{sw:if($global, 'group-app', 'app')}?path=reset&amp;app-id={
				sw:base64-encode(vzapackagem:generate-id($app))}&amp;hn-eid={sw:base64-encode($hn-eid)}&amp;type={
				sw:if(vzapackagem:is-os($app), 'os', 'app')}">
			<xsl:copy-of select="$label"/>
		</a>
	</xsl:template>
	
	<!-- Show App template label (link if possible) for VE or sample -->
	<xsl:template name="vzenv:get-app-tmpl-label">
		<xsl:param name="app"/>
		<xsl:param name="enabled" select="true()"/>
		<xsl:param name="show-generation" select="false()"/>
		<xsl:param name="hn-eid" select="''"/>
		<xsl:param name="global" select="true()"/>
		
		<xsl:variable name="package" select="vzapackagem:vztemplate-packages($app)[1]"/>
		<xsl:variable name="base" select="$package/name"/>
		<xsl:variable name="latest" select="not(sw:is-ez-package($base)) and string($package/version)=''"/>
		<xsl:variable name="version" select="sw:if($latest, sw:text('latest'), $package/version)"/>
		
		<xsl:variable name="found-rtf">
			<data>
				<xsl:choose>
					<xsl:when test="$global">
						<xsl:copy-of select="vz:find-template($app, string($hn-eid))/*"/>
					</xsl:when>
					<xsl:otherwise>
						<env>
							<eid><xsl:value-of select="$hn-eid"/></eid>
						</env>
						<xsl:copy-of select="$package"/>
					</xsl:otherwise>
				</xsl:choose>
			</data>
		</xsl:variable>
		<xsl:variable name="found" select="exsl:node-set($found-rtf)/data"/>

		<xsl:choose>									
			<!-- Show undefined app or defined without link -->
			<xsl:when test="not($enabled) or (string($app)='') or string($found/env/eid)=''">
				<xsl:copy-of select="sw:app-id2title($base,$version)"/>  												
			</xsl:when>
			<!-- Show defined EZ app with link -->
			<xsl:otherwise>
				<xsl:call-template name="local:show-app-link">
					<xsl:with-param name="app" select="$found/packages|$found/package"/>
					<xsl:with-param name="label" select="sw:app-id2title($base, $version, '', $show-generation)"/>
					<xsl:with-param name="hn-eid" select="$found/env/eid"/>
					<xsl:with-param name="global" select="$global"/>
				</xsl:call-template>
			</xsl:otherwise>									
		</xsl:choose>
	</xsl:template>
	
	<!-- Show app template list (as links wher possible) for VE or sample software summary -->
	<xsl:template name="vzenv:view-apps-list">
		<xsl:param name="apps"/> <!-- in vzapackagem format  -->
		<xsl:param name="enabled" select="true()"/>
		<xsl:param name="hn-eid" select="''"/>
		<xsl:param name="skip-check" select="false()"/>
		<xsl:param name="global" select="true()"/>
		
		<xsl:for-each select="$apps">
			<xsl:sort select="name"/>
			
			<xsl:if test="not(preceding-sibling::*[name = current()/name])">
				<xsl:if test="position() != 1">,<br/></xsl:if>
				<nobr>
					<xsl:choose>
						<xsl:when test="$enabled">
							<xsl:variable name="name" select="name"/>
							<xsl:for-each select=".|following-sibling::*[name = $name]">
								<xsl:sort select="version"/>
								<xsl:if test="position() != 1">&#160;/&#160;</xsl:if>
								
								<xsl:variable name="latest"
									select="not(sw:is-ez-package($name)) and string(version)=''"/>
								<xsl:variable name="version" select="sw:if($latest, sw:text('latest'), version)"/>
								
								<xsl:choose>
									<xsl:when test="$skip-check">
										<xsl:call-template name="local:show-app-link">
											<xsl:with-param name="app" select="."/>
											<xsl:with-param name="label" select="sw:if(position()=1, 
																					sw:app-id2title(name, $version),
																					$version)"/>
											<xsl:with-param name="hn-eid" select="$hn-eid"/>
											<xsl:with-param name="global" select="$global"/>
										</xsl:call-template>
									</xsl:when>
									<xsl:otherwise>
										<xsl:variable name="found" select="vz:find-template(., string($hn-eid))"/>
										<xsl:choose>
											<xsl:when test="$found[$global or $found/env/eid=$hn-eid]">
												<xsl:call-template name="local:show-app-link">
													<xsl:with-param name="app" select="$found/packages"/>
													<xsl:with-param name="label"
														select="sw:if(position()=1, 
																					sw:app-id2title(name, $version),
																					$version)"/>
													<xsl:with-param name="hn-eid" select="$found/env/eid"/>
													<xsl:with-param name="global" select="$global"/>
												</xsl:call-template>
											</xsl:when>
											<xsl:otherwise>
												<xsl:copy-of 
													select="sw:if(position() = 1, sw:app-id2title(name, $version), $version)"/>
											</xsl:otherwise>
										</xsl:choose>
									</xsl:otherwise>
								</xsl:choose>
								
							</xsl:for-each>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="sw:app-id2title(name)"/>
							<xsl:variable name="name" select="name"/>
							<xsl:for-each select=".|following-sibling::*[name = $name]">
								<xsl:sort select="version"/>
								
								<xsl:variable name="latest"
									select="not(sw:is-ez-package($name)) and string(version)=''"/>
								<xsl:variable name="version" select="sw:if($latest, sw:text('latest'), version)"/>
								
								<xsl:if test="$version!=''">
									<xsl:value-of select="concat(' / ',$version)"/>
								</xsl:if>
							</xsl:for-each>
						</xsl:otherwise>
					</xsl:choose>
				</nobr>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>

	<xsl:template name="vzenv:view-apps-simple"> 
		<xsl:param name="env"/>
		<xsl:param name="is-os" select="false()"/>
		<xsl:param name="hide-version" select="false()"/>
		
		<xsl:variable name="pkgs" select="vzapackagem:get-env-templates($env)"/>
		<xsl:variable name="os" select="$pkgs[vzapackagem:is-os(.)][1]"/>
		<xsl:variable name="apps" select="$pkgs[not(vzapackagem:is-os(.))]"/>
		<xsl:variable name="cred-manage-apps"
			select="cred:check-hw('vzcp.template',$env/parent_eid)"/>

		
		<xsl:choose>
			<xsl:when test="$pkgs and $is-os">
				<xsl:variable name="os-label" select="sw:app-id2title($os/name)"/>
				<xsl:choose>
					<xsl:when test="$cred-manage-apps">
						<xsl:call-template name="local:show-app-link">
							<xsl:with-param name="app" select="$os"/>
							<xsl:with-param name="label" select="$os-label"/>
							<xsl:with-param name="hn-eid" select="$env/parent_eid"/>
							<xsl:with-param name="global" select="false()"/>
						</xsl:call-template>						
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="$os-label"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="$apps and not($is-os)">
				<xsl:for-each select="set:distinct($apps/name)">
					<xsl:sort select="."/>
					<xsl:variable name="name" select="."/>
					<xsl:if test="position() &gt; 1">
						<br/>
					</xsl:if>
					<xsl:variable name="selected-apps" select="$apps[name=$name]"/>
					<xsl:variable name="app" select="$selected-apps[string(version)=''
														 or version=math:max($selected-apps/version)][1]"/>
					
					<xsl:variable name="app-title" select="sw:app-id2title($app/name)"/>
					<xsl:choose>
						<xsl:when test="$cred-manage-apps">
							<xsl:call-template name="local:show-app-link">
								<xsl:with-param name="app" select="$app"/>
								<xsl:with-param name="label" select="$app-title"/>
								<xsl:with-param name="hn-eid" select="$env/parent_eid"/>
								<xsl:with-param name="global" select="false()"/>
							</xsl:call-template>							
						</xsl:when>
						<xsl:otherwise>
							<xsl:copy-of select="$app-title"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:for-each>      
			</xsl:when>
			<xsl:otherwise>
				<span class="inactive"><sw:text>No applications installed</sw:text></span>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

 <func:function name="vzenv:restore-apps">
		<func:result>
			<xsl:for-each select="$request/http_request/*[self::post or self::get]/parameter[starts-with(name ,'app_') and value = '1' and not(starts-with(name ,'app_ver_'))]">
				<xsl:variable name="id" select="substring-after(name, 'app_')"/>
				<xsl:variable name="name" select="string(parent::node()/parameter[name = concat('base_',$id)]/value/text())"/>
				<app>
					<name><xsl:value-of select="$name"/></name>
					<version><xsl:value-of select="string(parent::node()/parameter[name = concat('app_ver_', $id)]/value)"/></version>
				</app>
			</xsl:for-each>
		</func:result>
 </func:function>  

	<func:function name="vzenv:check-apps"> 
		<xsl:param name="apps"/>
		<xsl:param name="hn-eid"/>
		
		<xsl:for-each select="$apps/app">
			<xsl:variable name="app" select="."/>
			<xsl:variable name="config" select="tem:get-config(base,version, $hn-eid)"/>			
			<!--<xsl:if test="sw:sesput('$config',$config)"/>-->
			<!-- check depend -->
			<xsl:variable name="conflicts-src">
				<!--<xsl:if test="sw:sesput('$config//required_sets/package',$config//required_sets/package)"/>-->
				<xsl:for-each select="$config//required_sets/package">										
					<xsl:variable name="req-name" select="name"/>
					<xsl:variable name="req-version" select="version"/>
					<xsl:choose>
						<xsl:when test="$req-version!=''">
							<xsl:if test="not($apps/app[name=$req-name and version=$req-version])">
								<xsl:copy-of select="."/>
							</xsl:if>
						</xsl:when>
						<xsl:otherwise>
							<xsl:if test="not($apps/app[name=$req-name])">
								<xsl:copy-of select="."/>
							</xsl:if>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:for-each>
			</xsl:variable>
			<!-- /check depend -->
			<xsl:variable name="conflicts" select="exsl:node-set($conflicts-src)"/>
			<xsl:if test="count($conflicts)">
				<xsl:for-each select="$conflicts">
					<xsl:variable name="error">						
					</xsl:variable>
				</xsl:for-each>
			</xsl:if>
		</xsl:for-each>
		<func:result/>
	</func:function>   
 	
 	<func:function name="local:load-hspc-configs"> 		
		<xsl:param name="os"/>
		<xsl:param name="comp-apps"/>
		<xsl:param name="hn-eid" select="''"/>
		<xsl:param name="auth" select="false()"/>
				
		<xsl:choose>
			<xsl:when test="sw:is-ez-package($os/name)">		
				<func:result select="/.."/>
			</xsl:when>
			<xsl:otherwise>
				<!-- Prepare to depend.resolving -->
				<xsl:variable name="versions">
					<xsl:for-each select="$comp-apps">
						<app>
							<name><xsl:value-of select="name"/></name>
							<version><xsl:value-of select="version"/></version>
						</app>
					</xsl:for-each>
				</xsl:variable>
				<func:result select="tem:get-hspc-configs(exsl:node-set($versions)/app, $hn-eid, $auth)"/>
			</xsl:otherwise>
		</xsl:choose>
 	</func:function>
 	
 	<func:function name="local:get-version-mark">
 		<xsl:param name="version"/>
 		
 		<func:result select="sw:if(string($version)='', '00000001', string($version))"/>
 	</func:function>
 	
  <!--
  	Requires:
  		<sw:include href="/lib/vz/apps.xsl"/>	
  		<sw:include href="/lib/vza/tem.xsl"/>	
  		<sw:include href="/lib/vza/vzapackagem.xsl"/>	
  -->
  	<func:function name="vzenv:prepare-new-ve-apps">
  		<xsl:param name="apps"/>
		<xsl:param name="os"/> <!-- base=,version= -->
		<xsl:param name="setup"/> <!-- look ui:vz-app-selector for details -->		
		<xsl:param name="hn-eid"/>
		<xsl:param name="os_in_sample" select="/.."/>
		
		<func:result select="vzenv:prepare-ve-apps($apps, $os, $setup, /.., $hn-eid, $os_in_sample, false())"/>
  	</func:function>
  	
	<func:function name="vzenv:prepare-ve-apps"> <!-- was sw:showVEApps -->		
		<xsl:param name="apps"/>
		<xsl:param name="os"/> <!-- base=,version= -->
		<xsl:param name="setup"/> <!-- look ui:vz-app-selector for details -->		
		<xsl:param name="eid"/>
		<xsl:param name="hn-eid"/>
		<xsl:param name="os_in_sample" select="/.."/>
		<xsl:param name="filter-old" select="true()"/>
		
		<xsl:variable name="cred">
			<xsl:choose>
				<xsl:when test="not(string($eid)='')">
					<xsl:value-of select="cred:check-env('vzcp.env.manage.properties.application',$eid)"/>
				</xsl:when>
				<xsl:otherwise>
					false
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
  		
  		<xsl:variable name="platform-ref" select="env:make-platform-ref($hn-eid, /..)"/>					
		<!-- application on HW node _NOT FILTERED_  by OS -->
		<xsl:variable name="apps-on-hw-node" select="vz:load-hw-apps($os, $platform-ref, 'all', string($cred)='true')"/>
		<xsl:variable name="hspc" select="local:load-hspc-configs($os, $apps-on-hw-node, $hn-eid, string($cred)='true')"/>
		<!-- filter out old versions of installed templates to prevent app downgrade -->
		<xsl:choose>
			<xsl:when test="$filter-old">
				<func:result select="vzenv:prepare-apps(local:filter-old-version($apps-on-hw-node, $apps/app), $hspc, $apps, $os, $setup, $hn-eid, $os_in_sample, $platform-ref)"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="vzenv:prepare-apps($apps-on-hw-node, $hspc, $apps, $os, $setup, $hn-eid, $os_in_sample, $platform-ref)"/>
			</xsl:otherwise>
		</xsl:choose>
  	</func:function>
  	
  	<func:function name="local:filter-old-version">
  		<xsl:param name="apps"/>
  		<xsl:param name="installed"/>
  		
  		<xsl:choose>
  			<xsl:when test="not($apps) or $apps[1][sw:is-ez-package(name)]">
  				<func:result select="$apps"/>
  			</xsl:when>
  			<xsl:otherwise>
  				<xsl:variable name="res">
	  				<xsl:for-each select="$apps">
	  					<xsl:variable name="versions" select="$installed[name=current()/name]"/>
	  					<xsl:if test="not($versions and string($versions/version)!='' and number(version) &lt; math:max($versions/version))">
	  						<xsl:copy-of select="."/>
	  					</xsl:if>
	  				</xsl:for-each>
  				</xsl:variable>
  				<func:result select="exsl:node-set($res)/*"/>
  			</xsl:otherwise>
  		</xsl:choose>
  	</func:function>
  	
  	<func:function name="vzenv:prepare-sample-apps"> <!-- was sw:showVEApps -->		
		<xsl:param name="apps"/>
		<xsl:param name="os"/> <!-- base=,version= -->
		<xsl:param name="setup"/> <!-- look ui:vz-app-selector for details -->		
		<xsl:param name="platform" select="''"/>
		
		<xsl:variable name="platform-ref" select="env:make-platform-ref(/.., $platform)"/>					
		<!-- application on HW node _NOT FILTERED_  by OS -->
		<xsl:variable name="apps-on-hw-node" select="vz:load-hw-apps($os, $platform-ref, 'all')"/>
  		<func:result select="vzenv:prepare-apps($apps-on-hw-node, /.., $apps, $os, $setup, '', /.., $platform-ref)"/>
  	</func:function>
  	
	<func:function name="vzenv:prepare-apps"> <!-- was sw:showVEApps -->
		<xsl:param name="apps-on-hw-node"/>
		<xsl:param name="hspc"/>
		<xsl:param name="apps"/>
		<xsl:param name="os"/> <!-- base=,version= -->
		<xsl:param name="setup"/> <!-- look ui:vz-app-selector for details -->		
		<xsl:param name="hn-eid" select="''"/>
		<xsl:param name="os_in_sample" select="/.."/>		
		<xsl:param name="platform-ref" select="''"/>
		
		<xsl:variable name="os-title" select="sw:app-id2title($os/name)"/>
		<xsl:variable name="newpkgm" select="sw:is-ez-package($os/name)"/>			
		<xsl:variable name="sys-apps" select="voc:get('vztemplates', $platform-ref)"/>
		
		<!-- application on HW node FILTERED by OS -->
		<xsl:variable name="apps-on-hw-node-filtered-by-os" select="$apps-on-hw-node[
				not(vzapackagem:is-os(.))
			][not(string(name)=$sys-apps[category='vztemplates']/id)]"/>

		<xsl:variable name="known-os" select="set:distinct($apps-on-hw-node[vzapackagem:is-os(.)]/name)"/>
		<xsl:variable name="known-apps" select="set:distinct($apps-on-hw-node-filtered-by-os/name)"/>

		<xsl:choose>
			<xsl:when test="$apps-on-hw-node-filtered-by-os">
				<func:result>
					<ui:vz-app-selector>
						<ui:setup>
							<xsl:copy-of select="$setup"/>
							<xsl:if test="$newpkgm">
								<ui:newpkgm/>
							</xsl:if>
							<xsl:if test="not($hspc)">
								<ui:no-resolve/>
							</xsl:if>
						</ui:setup>
						<ui:apps>
							<!-- work with next application:
								1) installed on node and compatible with OS and ve type (ez or standart)
							-->
							<xsl:for-each select="$known-apps">
								<xsl:sort select="sw:uc(.)"/>
								<xsl:variable name="name" select="sw:app-id2title(.)"/>
								<xsl:variable name="id" select="."/>
								<xsl:variable name="app" select="$apps/app[name=$id]"/>
								<xsl:variable name="versions" select="$apps-on-hw-node-filtered-by-os[name=$id]"/>
								<xsl:variable name="last" select="$versions[last()]"/>
								
								<ui:app>
									<ui:name><xsl:value-of select="$name"/></ui:name>
									<ui:id><xsl:value-of select="$id"/></ui:id>
									<ui:description><xsl:value-of 
										select="sw:if($last/summary, $last/summary, $last/description)"/></ui:description>
									
									<xsl:for-each select="$versions">
										<xsl:sort select="version"/>
										<xsl:variable name="mark" select="local:get-version-mark(version)"/>
										<ui:version>
											<ui:id>
												<xsl:if test="not($newpkgm)">										
													<xsl:value-of select="$mark"/>
												</xsl:if>
											</ui:id>
											<ui:name>		
												<xsl:choose>
													<xsl:when test="not($setup/ui:show-empty-ver) and position()=last()">
														<xsl:value-of select="$mark"/> (<sw:text>latest</sw:text>)
													</xsl:when>
													<xsl:otherwise>
														<xsl:value-of select="$mark"/>
													</xsl:otherwise>
												</xsl:choose>
											</ui:name>
											<xsl:if test="not($app/version!='') and position()=last()">
												<ui:default/>
											</xsl:if>
											<xsl:if test="$apps/app[name=$id and version=$mark]">
												<xsl:if test="$mark=math:max($apps/app[name=$id]/version)">
													<ui:default/>
													
												</xsl:if>
											</xsl:if>
											<!-- post requires -->
											<xsl:for-each select="$hspc[@Package=$id and @VersionID=$mark]/Requires/Template[not(@Package=$known-os)]">
												<ui:dependency>
													<ui:name><xsl:value-of select="@Package"/></ui:name>
													<ui:version><xsl:value-of select="@VersionID"/></ui:version>
												</ui:dependency>
											</xsl:for-each>
											<!-- /post requires -->
										</ui:version>			
									</xsl:for-each>
									<!-- Add Empty Latest version -->
									<xsl:if test="$setup/ui:show-empty-ver">
										<ui:version>
											<ui:id></ui:id>
											<ui:name><sw:text>latest</sw:text></ui:name>
											<xsl:if test="not($app/version!='')">
												<ui:default/>
											</xsl:if>
											<!-- post requires for prev.version -->
											<xsl:variable name="prev-mark">
													<xsl:for-each select="$versions">
														<xsl:sort select="version"/>
														<xsl:if test="position()=last()">
															<xsl:value-of select="local:get-version-mark(version)"/>
														</xsl:if>
													</xsl:for-each>
											</xsl:variable>
											<xsl:for-each select="$hspc[@Package=$id and @VersionID=$prev-mark]/Requires/Template[not(@Package=$known-os)]">
												<ui:dependency>
													<ui:name><xsl:value-of select="@Package"/></ui:name>
													<ui:version><xsl:value-of select="@VersionID"/></ui:version>
												</ui:dependency>
											</xsl:for-each>
											<!-- /post requires -->
										</ui:version>
									</xsl:if>
									<xsl:if test="$app != ''">
										<ui:selected/>
									</xsl:if>
								</ui:app>
							</xsl:for-each>
							<!--
									2) installed on node, but application not compatible with ve type (ez or standart)
									3) os is same type as template, but os name is different
							 -->
							<xsl:for-each select="$apps/app">
								<xsl:variable name="name" select="sw:app-id2title(name)"/>
								<xsl:variable name="id" select="sw:if(id!='',id,name)"/>
								<xsl:variable name="app-ez" select="sw:is-ez-package($id)"/>
								<xsl:variable name="app-already-present" select="$apps-on-hw-node-filtered-by-os[name = $id]"/>
								<xsl:if test="not($app-already-present != '')">
									<ui:app>
										<ui:name><xsl:value-of select="$name"/></ui:name>
										<ui:id><xsl:value-of select="$id"/></ui:id>										
										<ui:description></ui:description>
										<xsl:if test="version!=''">
											<ui:version>
												<ui:id><xsl:value-of select="version"/></ui:id>
												<ui:name><xsl:value-of select="version"/></ui:name>
												<ui:default/>
											</ui:version>
										</xsl:if>
										<!-- Add Empty Latest version -->
										<xsl:if test="$setup/ui:show-empty-ver">
											<ui:version>
												<ui:id></ui:id>
												<ui:name><sw:text>latest</sw:text></ui:name>
												<xsl:if test="not(version!='')">
													<ui:default/>
												</xsl:if>
											</ui:version>
										</xsl:if>
										<!-- Add Fake Version -->
										<xsl:if test="not($setup/ui:show-empty-ver) and not(version!='')">
											<ui:version>
												<ui:id></ui:id>
												<ui:name><sw:text>N/A</sw:text></ui:name>
												<ui:default/>
											</ui:version>
										</xsl:if>
										<ui:selected/>
										<xsl:choose>										
											<xsl:when test="$newpkgm and not($app-ez)">
												<ui:app-gen-wrong>standard</ui:app-gen-wrong>
											</xsl:when>
											<xsl:when test="not($newpkgm) and $app-ez">
												<ui:app-gen-wrong>ez</ui:app-gen-wrong>
											</xsl:when>
											<xsl:when test="$os_in_sample/name != '' and  $os_in_sample/name != $os/name">
												<!-- selected os different from os, set os_in_sample -->
												<ui:app-os-wrong/>
											</xsl:when>
											<xsl:when test="not($apps-on-hw-node[ name=$id ])">
												<ui:app-not-installed/>
											</xsl:when>
											<xsl:otherwise>
												<!-- selected os different from os, by default -->
												<ui:app-os-wrong/>
											</xsl:otherwise>											
										</xsl:choose>
									</ui:app>
								</xsl:if>
							</xsl:for-each>		
							<!-- /Scan noninstalled apps -->					
						</ui:apps>
					</ui:vz-app-selector>
					<!-- Layout will implement this function -->
					<ui:event type="on-press-ok">
						if(!checkApps()){return false;};
					</ui:event>
				</func:result>
			</xsl:when>
			<xsl:otherwise>
				<func:result>
					<ui:rows>
						<ui:row>
							<ui:cell>
								<sw:text>
									<xsl:with-param name="os" select="$os-title"/>
									No applications compatible with the selected operating system "%os".
								</sw:text>
							</ui:cell>
						</ui:row>
					</ui:rows>
				</func:result>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	
	<func:function name="vzenv:is-ve-updating">
		<xsl:param name="eid"/>
		<xsl:variable name="env" select="env:get-env($eid)/env"/>
		<xsl:variable name="trans" select="$env/status/transition"/>
		
		<func:result select="sw:if(sw:is-ez-package($env/virtual_config/os_template/name), 
								$trans=$env-trans/updating or $trans=$env-trans/unknown,
								$trans=$env-trans/updating)"/>
	</func:function>
	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
