<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
 -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred func voc vzenv env vzve"
  xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl			="http://exslt.org/common"
  xmlns:func			="http://exslt.org/functions"
  xmlns:sw				="http://www.swsoft.com/xsl/cp"
	xmlns:cred			="http://www.swsoft.com/xsl/cp/cred"
	xmlns:voc				="http://www.swsoft.com/xsl/cp/voc"	
	xmlns:trace			="http://www.swsoft.com/xsl/cp/trace"
	xmlns:vzenv			="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:vzhn			="http://www.swsoft.com/xsl/cp/vzhn"
	xmlns:request		="http://www.swsoft.com/xsl/cp/request"
	xmlns:env				="http://www.swsoft.com/xsl/cp/env"
	xmlns:ve				="http://www.swsoft.com/xsl/cp/ve"
	xmlns:vt				="http://www.swsoft.com/xsl/cp/vt"	
	xmlns:vzve			="http://www.swsoft.com/xsl/cp/vzve"
	xmlns:envm			="http://www.swsoft.com/xsl/cp/envm"
	xmlns:ui				="http://www.swsoft.com/xsl/cp/ui"
	xmlns:tem				="http://www.swsoft.com/xsl/cp/tem"
	xmlns:vz				="http://www.swsoft.com/xsl/cp/vz"
>
	
	<sw:include href="/lib/vocabulary.xsl"/>	
	<sw:include href="/lib/vt/ve-core.xsl"/>	
	<sw:include href="/lib/swa/envm.xsl"/>	
	<sw:include href="/lib/vza/tem.xsl"/>		
	<sw:include href="/lib/vz/vzhn-core.xsl"/>			
	<sw:include href="/lib/trace.xsl"/>
	
		<!-- 
		Change current VE
		Arguments:
			envid
		Result
			env or empty nodeset
	-->
	<func:function name="vzenv:set-current">	
		<xsl:param name="new-eid"/>
		<xsl:param name="check-existsing" select="true()"/>
		<xsl:param name="default-context" select="''"/>
		
		<xsl:variable name="env" select="ve:set-current($new-eid,$check-existsing)"/>
		<xsl:if test="$env">
			
			<!-- Check context -->
			<xsl:variable name="new-context" select="sw:if(sw:param('context')!='',string(sw:param('context')),$default-context)"/>
			<xsl:choose>
				<!-- HN already setuped context -->
				<xsl:when test="$new-context='current'">
				</xsl:when>						
				<!-- Setup default Context (also handle empty context )-->
				<xsl:when test="$new-context='default' or $new-context=''">
					<xsl:if test="trace:set-branch('env-home','hn')"/>
					<xsl:if test="vzhn:set-current($env/parent_eid,'default')"/>					
				</xsl:when>	
				<!-- VE is in Infrastucture or Logical unit -->
				<xsl:when test="$new-context='unit'">
					<xsl:if test="trace:set-branch('env-home','unit')"/>
					<xsl:if test="vzhn:set-current($env/parent_eid,'unit')"/>
				</xsl:when>
				<!-- VE is in HN -->
				<xsl:when test="$new-context='hn'">
					<xsl:if test="trace:set-branch('env-home','hn')"/>
					<xsl:if test="vzhn:set-current($env/parent_eid,'unit')"/>
				</xsl:when>
			</xsl:choose>
			<!-- /Check context -->

			<!-- fill env 'templates' -->			
			<xsl:if test="vzenv:update-ve-info($env)"/>
		</xsl:if>
		<func:result select="$env"/>
	</func:function>
	
  <func:function name="vzenv:update-ve-info">
    <xsl:param name="env"/>
    
    <xsl:if test="sw:sesputstr('vzenv-title',env:env2title($env))"/>
    <!-- update VE config parameters -->
    <xsl:for-each select="$env">
    	<xsl:if test="sw:sesputstr('env-veid', virtual_config/veid)"/>
      	<xsl:if test="sw:sesputstr('hostname', virtual_config/hostname)"/>
      	<xsl:if test="sw:sesput('templates', ve:get-env-templates(.))"/>
				<xsl:if test="sw:sesputstr('env-name', virtual_config/name)"/>
			
      	<xsl:if test="sw:sesput('base_set', virtual_config/os_template/*)"/>
	
      	<xsl:if test="sw:sesput('ip',virtual_config/address)"/>
      	<xsl:variable name="ips">
        	<xsl:for-each select="virtual_config/address">
          		<xsl:value-of select="ip"/>
          		<xsl:if test="position() != last()"><xsl:text>, </xsl:text></xsl:if>
        	</xsl:for-each>
      	</xsl:variable>
      	<xsl:if test="sw:sesput('iplist',string($ips))"/>
    </xsl:for-each>

    <func:result select="$env"/>

  </func:function> 
	
	<!-- Transform ENVs NODESET to RTF with ui:list-item data -->
	<func:function name="vzenv:envs2ui-items">
		<xsl:param name="envs"/>
		<func:result>					
			<xsl:for-each select="$envs">				
				<xsl:sort select="env:env2title(.)"/>
				<ui:list-item id="{eid}" title="{env:env2title(.)}"/>
			</xsl:for-each>
		</func:result>
	</func:function>
	
	<func:function name="vzenv:env-is-sve">
		<xsl:param name="eid" />
		
		<func:result select="$eid=vzenv:sve-eid()" />
	</func:function>
	
	<!--
		Return the EID of SVE.
		Arguments
			hn-eid
		Result
			sve eid
	-->
	<func:function name="vzenv:sve-eid">
		<xsl:param name="hn-eid" select="'any-hw'"/>
		<!-- Impersonate. Always allow to get SVE EID -->
		<xsl:variable name="result-eid" select="vzenv:get-vt-info($hn-eid,true())/sve_eid"/>
		<sw:die test="$result-eid=''">
			Can not find SVE EID
		</sw:die>
		<!-- Return result -->
		<func:result select="$result-eid"/>
	</func:function>

	<!--
		Return the full vzaenvm/get_vt_info 
		Arguments
			hn-eid
		Result
			vzaenvm/vt_info			
	-->
	<func:function name="vzenv:get-vt-info">
		<xsl:param name="hn-eid" select="'any-hw'"/>
		<xsl:param name="impersonate" select="false()"/>
		<xsl:variable name="req">
			<packet log="on">
				<target>vzaenvm</target>
				<xsl:if test="$hn-eid!='any-hw'">
					<xsl:copy-of select="sw:env-dst($hn-eid)"/>
				</xsl:if>
				<data>
					<vzaenvm>
						<get_vt_info/>
					</vzaenvm>
				</data>
				<xsl:if test="$impersonate">
					<vzcpauth/>
				</xsl:if>
			</packet>	
		</xsl:variable>
		<func:result select="sw:xchg($req)/packet/data/vzaenvm/vt_info"/>
	</func:function>

	
	<func:function name="vzenv:veid-to-eid">
		<xsl:param name="ve-id"/>
		<xsl:param name="hn-eid" select="'any-hw'"/>
		
		<xsl:choose>
			<xsl:when test="$ve-id='1'">
				<func:result select="vzenv:sve-eid($hn-eid)"/>
			</xsl:when>
			<xsl:otherwise>
				<!-- Ask vza -->
				<xsl:variable name="sql-query">			
					<fields>
						<env.eid/>
						<env.parent_eid/>
						<env.vconfig.veid/>
					</fields>
					<where>
						{env.vconfig.veid}='<xsl:value-of select="$ve-id"/>'
						<xsl:if test="$hn-eid!='any-hw'">
							AND {env.parent_eid}='<xsl:value-of select="$hn-eid"/>'
						</xsl:if>
					</where>			
				</xsl:variable>
				<xsl:variable name="sql-answer" select="sw:xchg-sql($sql-query)"/>
				<!-- Return result -->
				<func:result select="$sql-answer/pager/row_set/row/env/eid"/>
			</xsl:otherwise>
		</xsl:choose>
		
	</func:function>
	
	<func:function name="vzenv:name-to-eid">
		<xsl:param name="ve-name"/>
		<xsl:param name="hn-eid" select="''"/>
		
		<!-- Ask vza -->
		<xsl:variable name="sql-query">			
			<fields>
				<env.eid/>
				<env.parent_eid/>
				<env.vconfig.name/>
			</fields>
			<where>
				UPPER({env.vconfig.name})='<xsl:value-of select="sw:uc($ve-name)"/>'
				<xsl:if test="$hn-eid!=''">
					AND {env.parent_eid}='<xsl:value-of select="$hn-eid"/>'
				</xsl:if>
			</where>			
		</xsl:variable>
		<xsl:variable name="sql-answer" select="sw:xchg-sql($sql-query)"/>

		<!-- Return result -->
		<func:result select="$sql-answer/pager/row_set/row/env/eid"/>
		
	</func:function>
	
	
	<!-- Returns regexp for VE ID checking -->
	<func:function name="vzenv:id-regexp">
		<func:result select="'^[0-9]{1,10}$'"/>
	</func:function>
	
	<!-- 
		requires the folloing libs :
			lib/vem.xsl
	-->	
	<func:function name="vzenv:get-newid">
		<xsl:param name="first_ve_id"/>
		<xsl:param name="hw-eid"/>
		  	
		<func:result select="'0'"/><!-- 0=special ID for autoallocation in VZA -->
	</func:function>

	<xsl:template name="vzenv:view-template-full">
		<xsl:param name="template-info"/>
		<!--|-->
		<ui:rows title="{sw:text('Original Container Sample')}">
			<ui:row>
				<ui:cell-label>
					<sw:text>Name</sw:text>
				</ui:cell-label>
				<ui:cell-value>
					<xsl:choose>
						<xsl:when test="$template-info/id!=''">
							<xsl:value-of select="$template-info/id"/>
						</xsl:when>
						<xsl:otherwise>
							<span class="inactive"><sw:text>n/a</sw:text></span>
						</xsl:otherwise>
					</xsl:choose>
				</ui:cell-value>
			</ui:row>
			<xsl:if test="$template-info/id!=''">
				<ui:row>
					<ui:cell-label>
						<sw:text>Description</sw:text>
					</ui:cell-label>
					<ui:cell-value>
						<xsl:choose>
							<xsl:when test="$template-info/descr!=''">
								<xsl:value-of select="$template-info/descr"/>
							</xsl:when>
							<xsl:otherwise>
								<span class="inactive"><sw:text>n/a</sw:text></span>
							</xsl:otherwise>
						</xsl:choose>
					</ui:cell-value>
				</ui:row>
			</xsl:if>
			<xsl:if test="$template-info/customized='1'">
				<ui:row>
					<ui:cell-label>
						<sw:text>Additional Information</sw:text>
					</ui:cell-label>
					<ui:cell-value>
						<sw:text>The Container configuration has been customized</sw:text>
					</ui:cell-value>
				</ui:row>
			</xsl:if>
		</ui:rows>
		<!--|-->
	</xsl:template>			

	<func:function name="vzenv:get-veid-range-filter">
		<xsl:param name="hn-id" select="''" />	
		<func:result>
			<xsl:copy-of select="ve:get-veid-range-filter($hn-eid)"/>
		</func:result>
	</func:function>
	
	<func:function name="vzenv:filter-veid-nodes">
		<xsl:param name="veids" />
		<xsl:param name="vzprivrange" select="vzenv:get-vzprivate-range()" />

		<xsl:variable name="res">
			<xsl:for-each select="number($veids)">
				<xsl:if test=". &gt; 0 and (. &lt; $vzprivrange/min or . &gt;= $vzprivrange/max)">
					<veid>
						<xsl:value-of select="." />
					</veid>
				</xsl:if>
			</xsl:for-each>
		</xsl:variable>
		<func:result select="exsl:node-set($res)/veid" />
	</func:function>
	
	<func:function name="vzve:voc-qos"> 		
 		<xsl:param name="platform-ref"/>
 	
 		<xsl:variable name="args">
			<category>cpu</category>
			<category>quota</category>
			<xsl:choose>
				<xsl:when test="vt:is-platform-windows($platform-ref/platform)">
					<category>ubc</category>			
				</xsl:when>
				<xsl:otherwise>
					<category>ubc_primary</category>
					<category>ubc_secondary</category>
					<category>ubc_auxilary</category>            
					<category>slm</category>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<func:result select="voc:get($args, $platform-ref)"/>
 </func:function>    


</xsl:stylesheet>
