<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred filem func voc error file"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:func="http://exslt.org/functions"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:vt="http://www.swsoft.com/xsl/cp/vt"	
	xmlns:vzenv-files="http://www.swsoft.com/xsl/cp/vzenv-files"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:hwm="http://www.swsoft.com/xsl/cp/hwm"
	xmlns:filem="http://www.swsoft.com/xsl/cp/filem"
	xmlns:voc="http://www.swsoft.com/xsl/cp/voc"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:file="http://www.swsoft.com/xsl/cp/file"
>

  <sw:include href="/lib/core/browse-filter-raw.xsl"/>  
	<sw:include href="/lib/vt/core.xsl"/>
	<sw:include href="/lib/utils/file.xsl"/>
	
	<func:function name="vzenv-files:path">
		<xsl:param name="path-session-key"/>
		<xsl:param name="browse-session-key"/>
		<xsl:variable name="fm-path">
			<xsl:variable name="ses-fm-path" select="sw:sesget($path-session-key)"/>
			<xsl:choose>
				<xsl:when test="sw:param('path_abs')">
					<xsl:value-of select="sw:param('path_abs')"/>
				</xsl:when>
				<xsl:when test="sw:param('path')">
					<xsl:value-of
						select="sw:base64-decode(sw:param('path'))"/>
				</xsl:when>
				<xsl:when test="not(sw:param('mod')='start') and $ses-fm-path">
					<xsl:value-of select="$ses-fm-path"/>
				</xsl:when>
				<xsl:otherwise>/</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:if test="sw:param('mod')='start'">
			<xsl:if test="sw:sesput(concat('browse_',$browse-session-key),'')"/>
		</xsl:if>
		<xsl:if test="sw:sesput($path-session-key,$fm-path)"/>
		<func:result select="$fm-path"/>
	</func:function>

	<func:function name="vzenv-files:check-win-root">
		<xsl:param name="path"/>
		<xsl:param name="env-platform"/>
		<func:result select="vt:is-platform-windows($env-platform) and $path='/'"/>
	</func:function>

	<!--	
	Need the following includes:
  <sw:include href="../lib/vza/filem.xsl"/>  		
	-->

	<xsl:template name="vzenv-files:browse">
		<xsl:param name="env-platform"/>
		<xsl:param name="dst-eid"/><!-- VE or HN EID -->
		<xsl:param name="browse-session-key"/>
		<xsl:param name="browse-url"/>
		<xsl:param name="height" select="false()"/>
		<xsl:param name="select-type" select="'checkbox'"/>
		<xsl:param name="select-id" select="'file-name'"/>
		<xsl:param name="path"/>
		<xsl:param name="cwd" select="/.."/>
		<xsl:param name="show-actions" select="/.."/>
		<!-- Link to downloader  -->
		<xsl:param name="url-to-download" select="'/vzdir/infrman/envs/files/download'"/>
		<!-- Is it a browse backup? -->
		<xsl:param name="backup-browser" select="false()"/>
		<!-- Does user can select forders? -->
		<xsl:param name="select-folders" select="true()"/>
		<xsl:param name="select-files" select="true()"/>
		<xsl:param name="root-title-pre" select="''"/>
		<xsl:param name="browse-controls" select="false()"/>
		<xsl:param name="screen-buttons" select="false()"/>
		<!-- Screen buttons -->

		<xsl:variable name="platform-windows" select="vt:is-platform-windows($env-platform)"/>
		<xsl:variable name="platform-linux" select="vt:is-platform-linux($env-platform)"/>
		
		<xsl:variable name="root-title-default"
			select="sw:if($platform-windows,sw:text('My Computer'),'/')"/>
		<xsl:variable name="root-title"
			select="sw:if($root-title-pre != '',$root-title-pre,$root-title-default)"/>

		<xsl:variable name="allow-edit" select="$backup-browser or cred:check-env('vzcp.env.manage.services_and_files',$dst-eid)"/>
		<xsl:variable name="allow-props" select="$backup-browser or $allow-edit"/>
		<xsl:variable name="allow-download"
			select="$backup-browser or cred:check-env('vzcp.env.manage.services_and_files',$dst-eid) or $allow-edit"/>

		<xsl:variable name="fm-path" select="$path"/>
		<xsl:variable name="fm-path-conv" select="sw:if($fm-path='/','',$fm-path)"/>
		<xsl:variable name="list-path-src" select="file:path4vza($fm-path)"/>
		<xsl:variable name="list-path" select="sw:if($platform-windows and $list-path-src='/','',$list-path-src)"/>	

		<xsl:variable name="user-mimetypes" select="sw:document('mimetypes.xml')/types/type"/>
		<xsl:variable name="text-mimetypes" select="$user-mimetypes[editor='text/plain']"/>

		<xsl:variable name="levels" select="sw:split($fm-path,'/')"/>
		<xsl:variable name="level-up">
			<xsl:for-each select="$levels">
				<xsl:if test="position()!=last()">
					<xsl:value-of select="."/>
					<xsl:if test="position()!=(last()-1)">
						<xsl:value-of select="'/'"/>
					</xsl:if>
				</xsl:if>
			</xsl:for-each>
			<xsl:if test="count($levels)=2">
				<xsl:value-of select="'/'"/>
			</xsl:if>
		</xsl:variable>

		<xsl:variable name="fm-list-input">
			<info>
				<name/>
				<type/>
				<xsl:if test="not($backup-browser)">
					<user/>
					<group/>
				</xsl:if>
				<size/>
				<date/>
				<mode/>
				<content_type/>
			</info>
			<follow_links/>
		</xsl:variable>
		<xsl:variable name="fm-res"
			select="filem:list($list-path,$dst-eid,$fm-list-input,$cwd)"/>

		<xsl:variable name="filter_init_">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="{$browse-session-key}" url="{$browse-url}"
						select-type="{$select-type}">
						<xsl:if test="$height">
							<xsl:attribute name="div-rows-id">scrollArea</xsl:attribute>
							<xsl:attribute name="div-rows-height">
								<xsl:value-of select="$height"/>
							</xsl:attribute>
						</xsl:if>
					</ui:browse-setup>
					<ui:cols sorting-col="file-name">
						<ui:column id="file-icon" sorting="no" title="&#160;" filter-title="{sw:text('Type')}" apply-templates="yes"/>
						<ui:column id="file-type" hidden="yes" for-url="yes"/>
						<ui:column id="file-name" data-type="file-name" width="50%" title="{sw:text('Name')}"
							apply-templates="yes"/>
						<ui:column id="file-path" select-id="{$select-id}" hidden="yes" apply-templates="yes"
							for-select="yes">
							<xsl:choose>
								<xsl:when test="$select-folders and $select-files">
									<xsl:attribute name="for-select-condition"
										>not((file-type &gt; 15 and file-type &lt; 22))</xsl:attribute>
								</xsl:when>
								<xsl:when test="not($select-folders) and $select-files">
									<xsl:attribute name="for-select-condition"
										>not((file-type &gt; 15 and file-type &lt; 22) or (file-type=4))</xsl:attribute>
								</xsl:when>
								<xsl:when test="$select-folders and not($select-files)">
									<xsl:attribute name="for-select-condition"
										>not((file-type &gt; 15 and file-type &lt; 22) or (file-type=8))</xsl:attribute>
								</xsl:when>
								<xsl:otherwise>
									<!-- nothing select -->
									<xsl:attribute name="for-select-condition"
										>not((file-type &gt; 15 and file-type &lt; 22) or (file-type=4) or (file-type=8))</xsl:attribute>
								</xsl:otherwise>
							</xsl:choose>
						</ui:column>
						<ui:column id="file-size" title="{sw:text('Size')}" data-type="int"
							apply-templates="yes"/>
						<ui:column id="file-modified" title="{sw:text('Modified')}" data-type="datetime"/>
						<xsl:if test="$platform-linux">
							<ui:column id="file-perms" title="{sw:text('Permissions')}"/>
							<xsl:if test="not($backup-browser)">
								<ui:column id="file-user" title="{sw:text('User')}"/>
								<ui:column id="file-group" title="{sw:text('Group')}"/>
							</xsl:if>
						</xsl:if>
						<xsl:if
							test="($allow-props and $show-actions/actions/props) or 
															($allow-download and $show-actions/actions/download) or
															($allow-edit and $show-actions/actions/edit)">
							<ui:column id="file-actions" title="{sw:text('Actions')}" apply-templates="yes"
								sorting="no"/>
						</xsl:if>
					</ui:cols>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="browse-result" select="$fm-res/file"/>

		<xsl:variable name="filter">
			<xsl:call-template name="browse:fill-filter">
				<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
				<xsl:with-param name="rows">
					<ui:browse-rows>
						<xsl:if test="substring-after($fm-path,'/')">

							<ui:row position="top" disable-checkbox="yes" disable-selector="yes">
								<file-name>..</file-name>
								<file-path>..</file-path>
								<file-icon/>
								<level-up>
									<xsl:value-of select="$level-up"/>
								</level-up>
								<file-actions/>
								<file-type/>
							</ui:row>

						</xsl:if>
						<xsl:for-each
							select="$browse-result[sw:base64-decode(name)!='.' and sw:base64-decode(name)!='..']">
							<xsl:variable name="name-src" select="sw:base64-decode(name)"/>
							<xsl:variable name="name"
								select="sw:if(contains($name-src,'\'),substring-before($name-src,'\'),$name-src)"/>
							<!-- remove '\' from 'c:\' -->
							<xsl:variable name="ext" select="sw:lc(sw:re-match($name,'\.([^.]+)$',i)[2])"/>
							<xsl:variable name="content-type" select="substring-before(content_type,';')"/>
							<xsl:variable name="editable"
								select="$text-mimetypes[extension=$ext] or ($content-type!='' and $content-type=$text-mimetypes/mime)"/>
							<ui:row>
								<!--
		            	<xsl:if test="type='4'">
		            		<xsl:if test="not($select-folders)">
		            			<xsl:attribute name="disable-checkbox">yes</xsl:attribute>
		            			<xsl:attribute name="disable-selector">yes</xsl:attribute>
		            		</xsl:if>
		            	</xsl:if>
		            	-->
								<file-ext>
									<xsl:choose>
										<xsl:when test="$editable and not($user-mimetypes[extension=$ext])">
											<xsl:value-of select="'txt'"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="$ext"/>
										</xsl:otherwise>
									</xsl:choose>
								</file-ext>
								<xsl:if test="$editable">
									<file-editable/>
								</xsl:if>
								<file-all>
									<xsl:copy-of select="."/>
								</file-all>
								<file-type>
									<xsl:value-of select="type"/>
								</file-type>
								<file-icon>
									<xsl:value-of select="$name"/>
								</file-icon>
								<file-name>
									<xsl:copy-of select="$name"/>
								</file-name>
								<file-path>
									<xsl:choose>
										<xsl:when
											test="not($browse-controls) and (type='4' or (type &gt; 15 and type &lt; 22))">
											<!-- Folder -->
											<xsl:copy-of select="concat($name,'/')"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:copy-of select="$name"/>
										</xsl:otherwise>
									</xsl:choose>
								</file-path>
								<file-modified>
									<xsl:choose>
										<!-- volume -->
										<xsl:when test="type &gt; 15 and type &lt; 22"/>
										<xsl:otherwise>
											<xsl:value-of select="date"/>
										</xsl:otherwise>
									</xsl:choose>
								</file-modified>
								<file-size>
									<xsl:choose>
										<xsl:when test="type='8' or type='10'">
											<xsl:value-of select="size"/>
										</xsl:when>
										<!-- dir -->
										<xsl:when test="type='4'">0</xsl:when>
										<!-- volume -->
										<xsl:when test="type &gt; 15 and type &lt; 22">0</xsl:when>
										<xsl:otherwise>0</xsl:otherwise>
									</xsl:choose>
								</file-size>
								<xsl:if test="$platform-linux">
									<file-perms>
										<xsl:value-of select="sw:permissions-str(mode)"/>
									</file-perms>
								</xsl:if>
								<xsl:if test="not($backup-browser)">
									<file-user>
										<xsl:value-of select="user"/>
									</file-user>
									<xsl:if test="$platform-linux">
										<file-group>
											<xsl:value-of select="group"/>
										</file-group>
									</xsl:if>
								</xsl:if>
								<xsl:if test="$platform-windows"> </xsl:if>
								<path>
									<xsl:value-of select="$fm-path-conv"/>
								</path>
								<file-actions>
									<xsl:if test="$allow-props and $show-actions/actions/props">
										<props/>
									</xsl:if>
									<xsl:if test="$allow-edit and $show-actions/actions/edit">
										<edit/>
									</xsl:if>
									<xsl:if test="$allow-download and $show-actions/actions/download">
										<download/>
									</xsl:if>
								</file-actions>
							</ui:row>
						</xsl:for-each>
					</ui:browse-rows>
				</xsl:with-param>
				<xsl:with-param name="cookies">
					<url-to-download>
						<xsl:value-of select="$url-to-download"/>
					</url-to-download>
					<xsl:if test="not($allow-download and $show-actions/actions/download)">
						<disable-download/>
					</xsl:if>
					<xsl:if test="$backup-browser">
						<backup-browser/>
					</xsl:if>
					<mimetypes>
						<user>
							<xsl:copy-of select="$user-mimetypes[not(default)]"/>
						</user>
						<default>
							<xsl:copy-of select="$user-mimetypes[default]"/>
						</default>
					</mimetypes>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>


		<xsl:choose>
			<xsl:when test="$fm-res/error">

				<ui:operation-problem>
					<ui:type>vza-error</ui:type>
					<ui:descr>
						<sw:text>The file manager is unavailable now.</sw:text>
					</ui:descr>
					<ui:reason>
						<sw:text>You have no access to this function.</sw:text>
					</ui:reason>
					<ui:vza-error>
						<xsl:copy-of select="$fm-res/error/*"/>
					</ui:vza-error>
					<xsl:if test="$level-up!=''">
						<ui:solution>
							<ui:link href="?path={sw:base64-encode($level-up)}"
								>
										Return to upper folder.
									</ui:link>
						</ui:solution>
					</xsl:if>
				</ui:operation-problem>

			</xsl:when>
			<xsl:otherwise>
				<ui:rows separate-tables="true">

					<ui:rows-title>
						<span>
							<sw:text>
								<xsl:with-param name="path">
									<xsl:variable name="delim" select="sw:if($platform-windows,'\','/')"/>
									<xsl:for-each select="sw:split(concat($fm-path,'/'),'/')">
										<xsl:if test="not(.='' and position()!=1)">
											<xsl:variable name="node" select="."/>
											<xsl:variable name="node-title"
												select="sw:if(.='',$root-title,concat(.,$delim) )"/>
											<xsl:variable name="node-path"><xsl:for-each select="preceding::token[.!='']"
														>/<xsl:value-of select="."/></xsl:for-each>/<xsl:value-of select="$node"
												/>
											</xsl:variable>
														&lt;a href="?path=<xsl:value-of
												select="sw:base64-encode(string($node-path)) "
												/>" onmouseover="callTip('click2change_dir',event)" onmouseout="callTip"&gt;<xsl:value-of
												select="$node-title"/>&lt;/a&gt;&#160;
													</xsl:if>
									</xsl:for-each>
								</xsl:with-param>
											Current path: %{path}
										</sw:text>&#160;
						</span>
					</ui:rows-title>
					<ui:browse title="{sw:text('Files')}">

						<ui:browse-js-many>
							<ui:warn>
								<sw:text>Select at least one item!</sw:text>
							</ui:warn>
						</ui:browse-js-many>

						<ui:browse-js-one>
							<ui:warn>
								<sw:text>Select only one item!</sw:text>
							</ui:warn>
						</ui:browse-js-one>


						<ui:filter>
							<xsl:copy-of select="$filter"/>
						</ui:filter>

						<ui:browse-empty-msg>
							<sw:text>No files could be found. </sw:text>
						</ui:browse-empty-msg>

						<xsl:if test="$browse-controls">
							<xsl:copy-of select="$browse-controls"/>
						</xsl:if>

					</ui:browse>
				</ui:rows>

				<xsl:copy-of select="$screen-buttons"/>

			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

</xsl:stylesheet>
