<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw func vzenv exsl xsi ips"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl	="http://exslt.org/common"
	xmlns:func	="http://exslt.org/functions"
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:xsi		="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:vzat	="http://www.swsoft.com/webservices/vza/4.0.0/vzatypes"
	xmlns:local	="http://www.swsoft.com/xsl/cp/local"
	xmlns:vt		="http://www.swsoft.com/xsl/cp/vt"
	xmlns:vzenv	="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:ips		="http://www.swsoft.com/xsl/cp/ips"
>

	<sw:include href="/lib/vt/core.xsl"/>
	<sw:include href="/lib/vz/ips.xsl"/>

	<!--===================================================== Init UI data ============================================-->
	<xsl:template name="vzenv:init-net-ifaces">
		<xsl:param name="platform"/>
		<xsl:param name="only-routed" selec="false()"/>
		<xsl:param name="only-bridged" selec="false()"/>
		<xsl:param name="routed-enabled" selec="false()"/>				
		<xsl:param name="bridged-enabled" selec="false()"/>		
		
		<xsl:if test="not($only-bridged)">
			<routed>
				<inited/>
				<id>venet0</id>
				<enabled><xsl:value-of select="boolean($routed-enabled)"/></enabled>
				<ips>
				</ips>
			</routed>
		</xsl:if>
		<xsl:if test="not($only-routed)">
			<bridged>
				<inited/>
				<enabled><xsl:value-of select="boolean($bridged-enabled)"/></enabled>
				<iface>
					<id>eth0</id>
					<dhcp>true</dhcp>
					<mac-type>auto</mac-type>
					<mac-address></mac-address>							
				</iface>
			</bridged>
		</xsl:if>
	</xsl:template>

	<xsl:template name="vzenv:new-interface">
		<xsl:param name="bridged-ifaces"/>
		<iface>
			<id><xsl:value-of select="vzenv:new-iface-index($bridged-ifaces/id)"/></id>
			<dhcp>true</dhcp>
			<mac-type>auto</mac-type>
			<mac-address></mac-address>							
		</iface>
	</xsl:template>
	
	<!--===================================================== Data transformation=========================================-->
		
	<!-- Transform VE network config from VZA env/config nodes to internal format -->
	<xsl:template name="vzenv:env2net">
		<xsl:param name="env"/>
		<xsl:param name="hn-platform"/>
		<xsl:param name="reset-mac-addresses" select="false()"/>
		<!--|-->
		<xsl:variable name="config" select="sw:if($env/virtual_config,$env/virtual_config,$env/config)"/>		
		<xsl:variable name="win" select="vt:is-platform-windows($hn-platform)"/>
		<xsl:variable name="linux" select="vt:is-platform-linux($hn-platform)"/>		
		<!--|-->
		<!-- GLOBAL -->
		<xsl:if test="true()">
			<xsl:variable name="device" select="$config"/>		
			<hostname>
				<xsl:value-of select="$device/hostname"/>
			</hostname>
			<xsl:copy-of select="local:search-config2net($device)"/>				
			<xsl:if test="$linux">
				<xsl:copy-of select="local:dns-config2net($device)"/>
			</xsl:if>
		</xsl:if>
		<!-- ROUTED -->
		<xsl:if test="true()">
			<xsl:variable name="device" select="$config/net_device[contains(@xsi:type,':net_vethType') and host_routed]"/>
			<xsl:choose>
				<!-- interface without IP is disabled interface too -->
				<xsl:when test="$device and $device/ip_address">
					<routed>
						<id><xsl:value-of select="$device/id"/></id>
						<enabled>true</enabled>
						<ips>
							<xsl:copy-of select="ips:vza2vzcp($device/ip_address,$hn-platform)"/>
						</ips>
						<xsl:if test="$win">
							<xsl:copy-of select="local:dns-config2net($device)"/>
							<xsl:copy-of select="local:wins-config2net($device)"/>
							<!--<xsl:copy-of select="local:gateway-config2net($device)"/>-->
						</xsl:if>
					</routed>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="vzenv:init-net-ifaces">
						<xsl:with-param name="only-routed" select="true()"/>
						<xsl:with-param name="platform" select="$hn-platform"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		<!-- BRIDGED -->
		<xsl:variable name="bridged-devices" select="$config/net_device[contains(@xsi:type,':net_vethType') and not(host_routed)]"/>
		<xsl:choose>
			<xsl:when test="$bridged-devices">
				<bridged>
					<enabled>true</enabled>
					<xsl:for-each select="$bridged-devices">
						<xsl:sort select="id"/>
						<xsl:variable name="device" select="."/>
						<iface>
							<id><xsl:value-of select="id"/></id>
							<net-id><xsl:value-of select="sw:base64-decode(network_id)"/></net-id>
							<xsl:choose>
								<xsl:when test="mac_address">
									<!-- We can't differ auto from manual -->
									<mac-type>auto</mac-type>
									<xsl:if test="not($reset-mac-addresses)">
										<mac-address><xsl:value-of select="mac_address"/></mac-address>
										<mac-address-current><xsl:value-of select="mac_address"/></mac-address-current>									
									</xsl:if>
								</xsl:when>
								<xsl:otherwise>
									<mac-type>auto</mac-type>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:choose>
								<xsl:when test="dhcp">
									<dhcp>true</dhcp>
									<dhcp-ips>
										<xsl:copy-of select="ips:vza2vzcp($device/ip_address,$hn-platform)"/>
									</dhcp-ips>
								</xsl:when>
								<xsl:otherwise>
									<ips>
										<xsl:copy-of select="ips:vza2vzcp($device/ip_address,$hn-platform)"/>
									</ips>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:if test="$win">
								<xsl:copy-of select="local:dns-config2net($device)"/>
								<xsl:copy-of select="local:wins-config2net($device)"/>
							</xsl:if>
							<xsl:copy-of select="local:gateway-config2net($device)"/>
						</iface>
					</xsl:for-each>
				</bridged>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="vzenv:init-net-ifaces">
					<xsl:with-param name="only-bridged" select="true()"/>
					<xsl:with-param name="platform" select="$hn-platform"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<func:function name="local:dns-config2net">
		<xsl:param name="device"/>
		<func:result>
			<dns_ips>
				<xsl:for-each select="$device/nameserver[.!='']">
					<ip><xsl:value-of select="."/></ip>
				</xsl:for-each>
			</dns_ips>
		</func:result>
	</func:function>
	
	<func:function name="local:search-config2net">
		<xsl:param name="device"/>
		<func:result>
			<search_domains>
				<xsl:for-each select="$device/search_domain[.!='']">
					<dom><xsl:value-of select="."/></dom>
				</xsl:for-each>
			</search_domains>
		</func:result>
	</func:function>	

	<func:function name="local:wins-config2net">
		<xsl:param name="device"/>
		<func:result>
			<wins_servers>
				<xsl:for-each select="$device/wins_server[.!='']">
					<ip><xsl:value-of select="."/></ip>
				</xsl:for-each>
			</wins_servers>
		</func:result>
	</func:function>	
	
	<func:function name="local:gateway-config2net">
		<xsl:param name="device"/>
		<func:result>
			<default_gateway>
				<xsl:value-of select="$device/default_gateway"/>
			</default_gateway>
		</func:result>
	</func:function>		
	
	<!-- Tranform VE net config from internal format to VZA env/config/ nodes -->
	<func:function name="vzenv:net2config">
		<xsl:param name="net"/>
		<xsl:param name="hn-platform"/>
		<xsl:param name="edit-mode" select="false()"/>
		<!-- Check arguments -->
		
		<sw:die test="not($hn-platform!='')">
			Problem is in vzenv:net2config() - hn-platform should be specified.
		</sw:die>
		<!--|-->
		<xsl:variable name="win" select="vt:is-platform-windows($hn-platform)"/>
		<xsl:variable name="linux" select="vt:is-platform-linux($hn-platform)"/>
	
		<xsl:variable name="res-rtf">
			<!-- GLOBAL -->
			<xsl:if test="true()">			
				<xsl:variable name="iface" select="$net"/>
				<xsl:if test="$edit-mode or $iface/hostname!=''">
					<hostname>
						<xsl:value-of select="$iface/hostname"/>
					</hostname>
				</xsl:if>
				<xsl:copy-of select="local:post-search($iface/search_domains)"/>
				<xsl:if test="$linux">
					<xsl:copy-of select="local:post-dns($iface/dns_ips)"/>					
				</xsl:if>
			</xsl:if>
			<!-- ROUTED -->
			<xsl:if test="true()">
				<xsl:variable name="iface" select="$net/routed"/>
				<xsl:choose>
					<xsl:when test="$iface/enabled='true'">	
						<vzat:net_device xsi:type="vzat:net_vethType">
							<id><xsl:value-of select="$iface/id"/></id>
							<xsl:copy-of select="ips:set-packet($iface/ips,$hn-platform)"/>
							<xsl:if test="$win">
								<xsl:copy-of select="local:post-dns($iface/dns_ips)"/>
								<xsl:copy-of select="local:post-wins($iface/wins_servers)"/>
								<!--<xsl:copy-of select="local:post-gateway($iface/default_gateway)"/>-->
								<xsl:copy-of select="local:post-search($iface/search_domains)"/>								
							</xsl:if>
							<host_routed/>
						</vzat:net_device>
					</xsl:when>
					<xsl:when test="$linux">
						<vzat:net_device xsi:type="vzat:net_vethType">
							<id><xsl:value-of select="$iface/id"/></id>
							<host_routed/>
						</vzat:net_device>
					</xsl:when>
				</xsl:choose>
			</xsl:if>
			<!-- BRIDGED -->
			<xsl:variable name="bridged" select="$net/bridged"/>
			<xsl:if test="$bridged/enabled='true'">
				<xsl:for-each select="$bridged/iface">
					<xsl:sort select="id"/>
					<xsl:variable name="iface" select="."/>
					<vzat:net_device xsi:type="vzat:net_vethType">
						<id><xsl:value-of select="$iface/id"/></id>
						<network_id><xsl:value-of select="sw:base64-encode($iface/net-id)"/></network_id>
						<xsl:choose>
							<xsl:when test="mac-type='set'">
								<mac_address><xsl:value-of select="mac-address"/></mac_address>
							</xsl:when>
						</xsl:choose>						
						<xsl:choose>
							<xsl:when test="$iface/dhcp='true'">
								<dhcp/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:copy-of select="ips:set-packet($iface/ips,$hn-platform,true())"/>
								<xsl:copy-of select="local:post-gateway($iface/default_gateway)"/>															
							</xsl:otherwise>
						</xsl:choose>
						<xsl:if test="$win">
							<xsl:copy-of select="local:post-dns($iface/dns_ips)"/>
							<xsl:copy-of select="local:post-wins($iface/wins_servers)"/>
						</xsl:if>
						<xsl:if test="$win">
							<xsl:copy-of select="local:post-search($iface/search_domains)"/>
    				</xsl:if>
					</vzat:net_device>
				</xsl:for-each>
			</xsl:if>	
		</xsl:variable>
		<!--|-->
		<func:result select="$res-rtf"/>
	</func:function>
	
	<!-- Tranform VE net config from internal Sample format to internal ENV format -->
	<xsl:template name="vzenv:sample2net">
		<xsl:param name="config"/>
		<xsl:param name="hn-platform"/>
		<!-- Special params for VE multiply creation -->
		<xsl:param name="routed-ip-rule" select="''"/>	
		<xsl:param name="bridged-ip-rule" select="''"/>	
		<xsl:param name="ves-count" select="''"/>			
		<!--|-->
		<!--|-->
		<xsl:variable name="default-ifaces-rtf">
			<xsl:call-template name="vzenv:init-net-ifaces">
				<xsl:with-param name="platform" select="$hn-platform"/>	
				<xsl:with-param name="bridged-enabled" select="$bridged-ip-rule='pool' 
					or $bridged-ip-rule='range' or $bridged-ip-rule='set'
				"/>			
				<xsl:with-param name="routed-enabled" select="$routed-ip-rule='pool' 
					or $routed-ip-rule='range' or $routed-ip-rule='set'
				"/>			
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="default-ifaces" select="exsl:node-set($default-ifaces-rtf)"/>		
		<xsl:variable name="win" select="vt:is-platform-windows($hn-platform)"/>
		<xsl:variable name="linux" select="vt:is-platform-linux($hn-platform)"/>		
		<!--|-->
		<!-- GLOBAL -->
		<xsl:if test="$ves-count!=1">
			<xsl:call-template name="local:iterate-ve">
				<xsl:with-param name="count" select="$ves-count"/>
				<xsl:with-param name="index" select="1"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:copy-of select="local:search-config2net($config/env_config)"/>
		<xsl:if test="$linux">
			<xsl:copy-of select="local:dns-config2net($config/env_config)"/>			
		</xsl:if>
		<!-- ROUTED -->
		<xsl:if test="true()">
			<xsl:variable name="device" select="$config/env_config/net_device[contains(@xsi:type,':net_vethType') and host_routed]"/>
			<!-- Prepare IP rule, set it to pool if user selected 'Use Sample' -->
			<xsl:variable name="ip-rule" select="sw:if($routed-ip-rule='','',sw:if($routed-ip-rule='sample','pool',$routed-ip-rule))"/>
			<routed>
				<xsl:if test="$ip-rule!=''">
					<ip-rule><xsl:value-of select="$ip-rule"/></ip-rule>
				</xsl:if>
				<!-- Init base settings -->
				<xsl:choose>
					<!-- Copy device settings from VE Sample -->
					<xsl:when test="$device">
						<id><xsl:value-of select="$device/id"/></id>
						<enabled>true</enabled>
						<xsl:if test="$win">
							<xsl:copy-of select="local:dns-config2net($device)"/>
							<xsl:copy-of select="local:wins-config2net($device)"/>	
							<!--<xsl:copy-of select="local:gateway-config2net($device)"/>-->
							<xsl:copy-of select="local:search-config2net($device)"/>		
						</xsl:if>
					</xsl:when>
					<!-- Set device settings to default -->
					<xsl:otherwise>
						<xsl:copy-of select="$default-ifaces/routed/*"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Init base settings -->
				<!-- Init IP settings -->
				<!-- Assign one IP address from Pool -->					
				<xsl:if test="$ip-rule=''">
					<ips>
						<ip>
							<address>
								<xsl:value-of select="$def-ip-auto-vzcp"/>
							</address>
						</ip>
					</ips>
				</xsl:if>
				<!-- /Init IP settings -->				
			</routed>			
		</xsl:if>
		<!-- BRIDGED -->
		<xsl:if test="true()">
			<!-- Prepare IP rule, set it to pool if user selected 'Use Sample' -->
			<xsl:variable name="ip-rule" select="sw:if($bridged-ip-rule='','',sw:if($bridged-ip-rule='sample','pool',$bridged-ip-rule))"/>

			<xsl:variable name="sample-bridged-devices" select="$config/env_config/net_device[contains(@xsi:type,':net_vethType') and not(host_routed)]"/>
			<xsl:variable name="default-bridged-devices" select="$default-ifaces/routed/*"/>
			
			<bridged>
				<xsl:if test="$ip-rule!=''">
					<ip-rule><xsl:value-of select="$ip-rule"/></ip-rule>
				</xsl:if>
				<xsl:choose>
					<xsl:when test="$sample-bridged-devices">
						<enabled>true</enabled>
						<xsl:for-each select="$sample-bridged-devices">
							<xsl:sort select="id"/>
							<xsl:variable name="device" select="."/>
							<iface>
								<id><xsl:value-of select="id"/></id>
								<net-id><xsl:value-of select="sw:base64-decode(network_id)"/></net-id>
								<mac-type>auto</mac-type>
								<!-- Init IP settings for Single VE Creation -->
								<xsl:if test="$ip-rule=''">	
									<xsl:choose>
										<xsl:when test="dhcp">
											<dhcp>true</dhcp>
										</xsl:when>
										<xsl:otherwise>
											<!-- assign one IP address from Pool -->
											<ips>
												<ip>
													<address>
														<xsl:value-of select="$def-ip-auto-vzcp"/>
													</address>
												</ip>
											</ips>
											<!-- /assign one IP address from Pool -->
										</xsl:otherwise>
									</xsl:choose>
								</xsl:if>
								<!-- /Init IP settings for Single VE Creation -->								
								<xsl:if test="$win">
									<xsl:copy-of select="local:dns-config2net($device)"/>
									<xsl:copy-of select="local:wins-config2net($device)"/>
								</xsl:if>
								<xsl:copy-of select="local:gateway-config2net($device)"/>	
								<xsl:if test="$win">							
									<xsl:copy-of select="local:search-config2net($device)"/>									
								</xsl:if>
							</iface>
						</xsl:for-each>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="$default-ifaces/bridged/*"/>
					</xsl:otherwise>
				</xsl:choose>
			</bridged>
		</xsl:if>
	</xsl:template>
	
	<!--======================================== Local Functions ========================================-->
	
	<xsl:template name="local:iterate-ve">
		<xsl:param name="count"/>
		<xsl:param name="index"/>
		<ve index="{$index}"/>
		<xsl:if test="$index &lt; $count">
			<xsl:call-template name="local:iterate-ve">
				<xsl:with-param name="count" select="$count"/>
				<xsl:with-param name="index" select="$index+1"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>	
	
	<!-- Prepare part of ve/set packet with DNS Server IPs -->
	<func:function name="local:post-dns">
		<xsl:param name="dns"/>
		<func:result>
			<xsl:for-each select="$dns/ip">
				<nameserver><xsl:value-of select="."/></nameserver>
			</xsl:for-each>
			<xsl:if test="not($dns/ip)">
				<nameserver/>
			</xsl:if>
		</func:result>
	</func:function>
	
	<!-- Prepare part of ve/set packet with Search Domains -->
	<func:function name="local:post-search">
		<xsl:param name="domains"/>
		<func:result>
			<xsl:for-each select="$domains/dom">
				<search_domain><xsl:value-of select="."/></search_domain>
			</xsl:for-each>
			<xsl:if test="not($domains/dom)">
				<search_domain/>
			</xsl:if>
		</func:result>
	</func:function>

	<!-- Prepare part of ve/set packet with WINS Servers -->
	<func:function name="local:post-wins">
		<xsl:param name="servers"/>
		<func:result>
			<xsl:for-each select="$servers/ip">
				<wins_server><xsl:value-of select="."/></wins_server>
			</xsl:for-each>
		</func:result>
	</func:function>
		
	<!-- Prepare part of ve/set packet with default_gateway -->
	<func:function name="local:post-gateway">
		<xsl:param name="value"/>
		<func:result>
			<default_gateway><xsl:value-of select="$value"/></default_gateway>
		</func:result>
	</func:function>		
		
</xsl:stylesheet>

