<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw func form check vzenv voc env vznet exsl xsi request server_group"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl	="http://exslt.org/common"
	xmlns:func	="http://exslt.org/functions"
	xmlns:xsi		="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:error	="http://www.swsoft.com/xsl/cp/error"
	xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
	xmlns:request		="http://www.swsoft.com/xsl/cp/request"
	xmlns:env		="http://www.swsoft.com/xsl/cp/env"
	xmlns:vzenv		="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:form	="http://www.swsoft.com/xsl/cp/form"
	xmlns:check	="http://www.swsoft.com/xsl/cp/check"
	xmlns:local	="http://www.swsoft.com/xsl/cp/local"
	xmlns:voc		="http://www.swsoft.com/xsl/cp/voc"
	xmlns:vznet	="http://www.swsoft.com/xsl/cp/vznet" 
	xmlns:server_group="http://www.swsoft.com/xsl/cp/server_group"
	xmlns:vt		="http://www.swsoft.com/xsl/cp/vt"		
> 	
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/core/check-funcs.xsl"/>
 	<sw:include href="../vocabulary.xsl"/>
 	<sw:include href="../vt/env-core.xsl"/>
 	<sw:include href="../vz/vzenv-core.xsl"/>
 	<sw:include href="../../layout/forms-list.xsl"/>
 	
 	<sw:include href="/lib/swa/server-group.xsl"/>

	<sw:include href="/lib/vz/env-net-core-ui.xsl"/>

	<sw:include href="/lib/vz/vzenv-net.xsl"/>
	<sw:include href="/lib/vz/vznet-adaptor.xsl"/>
	<sw:include href="/lib/vz/vznet-switch.xsl"/>

	
	<!--===================================================== Check UI data ============================================-->
	
	<!-- Check Data for VE Net Inferfaces UI -->
	<xsl:template name="vzenv:check-net-ifaces">
		<xsl:param name="env-form"/>
		<xsl:param name="ve-net" select="/.."/>
		<!--|-->
		<xsl:variable name="net" select="sw:if($ve-net,$ve-net,$env-form/net)"/>		
		<xsl:variable name="platform-ref" select="env:make-platform-ref($env-form/hn/eid,$env-form/hn/platform)"/>		
		<!-- check hostname presence -->
		<!-- Do not show in multy-ve creation wizard -->
		<xsl:if test="not($net/ve)">
			<xsl:if test="vzenv:check-ve-hostname(
				$net/hostname,$env-form/hn/eid
			)"/>
		</xsl:if>
	
		<!-- ROUTED -->
		<xsl:for-each select="$net/routed[enabled='true']">
			<xsl:variable name="ip-rule" select="ip-rule"/>
			<!-- Check IP Addresses -->
			<xsl:choose>
				<!-- Get IP from Global Pool -->
				<xsl:when test="$ip-rule='pool'">
				</xsl:when>
				<!-- Get IP from custom range -->
				<xsl:when test="$ip-rule='range'">
					<xsl:call-template name="vzenv:check-ip">
						<xsl:with-param name="code" select="'routed_first_ip'"/>
						<xsl:with-param name="ip" select="first-ip"/>				
						<xsl:with-param name="pool-enabled" select="$env-form/def/ips-pool-enabled"/>					
						<xsl:with-param name="hn-platform" select="$env-form/hn/platform"/>
					</xsl:call-template>
				</xsl:when>
				<!-- Set IP per VE manually -->
				<xsl:when test="$ip-rule='set'">
					<xsl:call-template name="local:check-ves-ips">
						<xsl:with-param name="env-form" select="$env-form"/>
						<xsl:with-param name="iface" select="."/>	
						<xsl:with-param name="iface-code" select="'routed'"/>									
					</xsl:call-template>
				</xsl:when>
				<!-- Single VE mode -->
				<xsl:otherwise>
					<xsl:choose>
						<xsl:when test="not(ips/ip)">
							<xsl:if test="error:put(sw:text('Please assign at least one IP address to the host-routed interface or disable the latter.'),'','routed_ips')"/>
						</xsl:when>
						<xsl:when test="not(sw:checkVEIPs(ips/ip,$env-form/hn/platform,'routed_ips',$env-form/def/ips-pool-enabled))"/>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
			<!-- /Check IP Addresses -->				
			<xsl:if test="not($env-form/hn/linux)">
				<xsl:if test="vzenv:check-net-dns(dns_ips/ip,'routed_dns_ips')"/>
				<xsl:if test="vzenv:check-net-wins(wins_servers/ip,'routed_wins_servers')"/>
				<!--<xsl:if test="vzenv:check-net-gateway(default_gateway,'routed_default_gateway')"/>-->
				<xsl:if test="vzenv:check-net-search($platform-ref,search_domains/dom,'routed_search_domains')"/>
			</xsl:if>
		</xsl:for-each>
		<!-- BRIDGED -->
		<xsl:variable name="bridged" select="$net/bridged"/>
		<xsl:if test="$bridged/enabled='true'">
			<xsl:variable name="ip-rule" select="$bridged/ip-rule"/>
			<xsl:for-each select="$bridged/iface">
				<xsl:variable name="index" select="position()-1"/>
				<!-- Check IP Addresses -->
				<xsl:choose>
					<!-- Get IP from DHCP -->
					<xsl:when test="$ip-rule='dhcp'">
					</xsl:when>
					<!-- Get IP from Global Pool -->
					<xsl:when test="$ip-rule='pool'">
					</xsl:when>
					<!-- Get IP from custom range -->
					<xsl:when test="$ip-rule='range'">
						<xsl:call-template name="vzenv:check-ip">
							<xsl:with-param name="code" select="concat('bridged_first_ip_',$index)"/>
							<xsl:with-param name="ip" select="first-ip"/>				
							<xsl:with-param name="pool-enabled" select="$env-form/def/ips-pool-enabled"/>					
							<xsl:with-param name="hn-platform" select="$env-form/hn/platform"/>
						</xsl:call-template>
					</xsl:when>
					<!-- Set IP per VE manually -->
					<xsl:when test="$ip-rule='set'">
						<xsl:call-template name="local:check-ves-ips">
							<xsl:with-param name="env-form" select="$env-form"/>
							<xsl:with-param name="iface" select="."/>	
							<xsl:with-param name="iface-code" select="concat('bridged_',$index)"/>
						</xsl:call-template>
					</xsl:when>
					<!-- Single VE mode -->
					<xsl:otherwise>
						<xsl:if test="not(dhcp='true')">
							<xsl:if test="sw:checkVEIPs(ips/ip,$env-form/hn/platform,concat('bridged_ips',$index),$env-form/def/ips-pool-enabled)"/>
						</xsl:if>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Check IP Addresses -->				
				<xsl:if test="not($ip-rule!='')">				
					<xsl:if test="mac-type='set'">
						<xsl:if test="sw:checkVEMACAddress(mac-address,$env-form/hn/platform,concat('bridged_mac_address',$index))"/>
					</xsl:if>
				</xsl:if>
			 	<xsl:if test="not($env-form/hn/linux) and net-id=''">
					<xsl:if test="error:put(sw:text('Please select a virtual network.'),'',concat('bridged_net_id',$index))"/>
			 	</xsl:if>
			 	<xsl:if test="not($env-form/hn/linux)">
					<xsl:if test="vzenv:check-net-dns(dns_ips/ip,concat('bridged_dns_ips',$index))"/>
					<xsl:if test="vzenv:check-net-wins(wins_servers/ip,concat('bridged_wins_servers',$index))"/>		
				</xsl:if>
				<xsl:if test="not(dhcp='true')">				
					<xsl:if test="vzenv:check-net-gateway(default_gateway,concat('bridged_default_gateway',$index))"/>
				</xsl:if>
			 	<xsl:if test="not($env-form/hn/linux)">				
					<xsl:if test="vzenv:check-net-search($platform-ref,search_domains/dom,concat('bridged_search_domains',$index))"/>					
				</xsl:if>
			 </xsl:for-each>
		</xsl:if>
		<!--|-->
		<!-- Common -->
		<xsl:if test="$env-form/hn/windows and not($net/routed[enabled='true']) and not($bridged/enabled='true')">
			<xsl:if test="error:put(sw:text('The Windows Container should have at least one network interface enabled.'),'')"/>
		</xsl:if>
		<xsl:if test="$env-form/hn/linux">
			<xsl:if test="vzenv:check-net-dns($net/dns_ips/ip)"/>
		</xsl:if>
		<xsl:if test="vzenv:check-net-search($platform-ref,$net/search_domains/dom)"/>		
		<!--|-->
	</xsl:template>
	
	<!--===================================================== Restore UI data ============================================-->
	
	<xsl:template name="vzenv:restore-net-ifaces">
		<xsl:param name="env-form"/>
		<xsl:param name="ve-net" select="/.."/>
		<xsl:param name="options-rtf" select="''"/>		
		<!--|-->
		<xsl:variable name="options" select="exsl:node-set($options-rtf)"/>				
		<xsl:variable name="net" select="sw:if($ve-net,$ve-net,$env-form/net)"/>
		
		<!-- Restore hostname in single-VE mode -->	
		<xsl:if test="not($options/exclude-hostname) and not($net/ve)">
			<hostname>
				<xsl:value-of
					select="normalize-space(sw:param('hostname'))"
				/>
			</hostname>
		</xsl:if>
		<!-- INTERNAL DATA -->
		<xsl:copy-of select="$net/ve"/>		
		<!-- GLOBAL -->
		<xsl:if test="$env-form/hn/linux">
			<dns_ips>
				<xsl:copy-of select="vzenv:restore-net-dns()"/>
			</dns_ips>
		</xsl:if>
		<search_domains>
			<xsl:copy-of select="vzenv:restore-net-search()"/>
		</search_domains>
		<!--|-->
		<routed>
			<xsl:choose>
				<xsl:when test="sw:param('routed_enabled')='1'">
					<xsl:for-each select="$net/routed">
						<!-- enabled -->
						<enabled>true</enabled>
						<xsl:copy-of select="*[self::id or self::ip-rule]"/>
						<!-- Restore IP Addresses -->
						<xsl:choose>
							<!-- Get IP from Global Pool -->
							<xsl:when test="ip-rule='pool'">
							</xsl:when>
							<!-- Get IP from custom range -->
							<xsl:when test="ip-rule='range'">
								<first-ip>
									<xsl:copy-of select="vzenv:restore-ip('routed_first_ip')"/>
								</first-ip>
							</xsl:when>
							<!-- Set IP per VE manually -->
							<xsl:when test="ip-rule='set'">
								<xsl:call-template name="local:restore-ves-ips">
									<xsl:with-param name="net" select="$net"/>
									<xsl:with-param name="iface" select="."/>	
									<xsl:with-param name="iface-code" select="'routed'"/>									
								</xsl:call-template>
							</xsl:when>
							<!-- Single VE mode -->
							<xsl:otherwise>
								<ips>
									<xsl:copy-of select="sw:restoreVEIPs('routed_ips')"/>
								</ips>
							</xsl:otherwise>
						</xsl:choose>
						<!-- /Restore IP Addresses -->					
						<xsl:if test="not($env-form/hn/linux)">
							<dns_ips>
								<xsl:copy-of select="vzenv:restore-net-dns('routed_dns_ips')"/>
							</dns_ips>
							<wins_servers>
								<xsl:copy-of select="vzenv:restore-net-wins('routed_wins_servers')"/>
							</wins_servers>						
							<!--<default_gateway>
								<xsl:copy-of select="sw:param('routed_default_gateway')"/>
							</default_gateway>-->
							<search_domains>
								<xsl:copy-of select="vzenv:restore-net-search('routed_search_domains')"/>
							</search_domains>
						</xsl:if>
					</xsl:for-each>
				</xsl:when>
				<xsl:otherwise>
					<!-- disabled -->
					<enabled>false</enabled>
					<xsl:copy-of select="$net/routed/*[not(self::enabled)]"/>
				</xsl:otherwise>
			</xsl:choose>
		</routed>
		<bridged>
			<xsl:copy-of select="$net/bridged/ip-rule"/>
			<xsl:variable name="remove-id" select="string(sw:param('bridged_removed'))"/>
			<xsl:variable name="ip-rule" select="$net/bridged/ip-rule"/>
			<xsl:choose>
				<!-- Remove last interface, reset bridged interface -->
				<xsl:when test="$remove-id!='' and count($net/bridged/iface)=1">
					<xsl:variable name="default-ifaces-rtf">
						<xsl:call-template name="vzenv:init-net-ifaces">
							<xsl:with-param name="platform" select="$hn-platform"/>							
						</xsl:call-template>
					</xsl:variable>
					<xsl:variable name="default-ifaces" select="exsl:node-set($default-ifaces-rtf)"/>		
					<xsl:copy-of select="$default-ifaces/bridged/*"/>					
				</xsl:when>
				<xsl:when test="sw:param('bridged_enabled')='1'">
					<!-- enabled -->
					<enabled>true</enabled>
					<xsl:for-each select="$net/bridged/iface">
						<xsl:variable name="index" select="position()-1"/>
						<xsl:if test="id!=$remove-id">
							<iface>
								<xsl:copy-of select="*[self::id]"/>
								<net-id><xsl:value-of select="sw:param(concat('bridged_net_id',$index))"/></net-id>
								<xsl:if test="not($ip-rule!='')">
									<mac-type><xsl:value-of select="sw:param(concat('bridged_mac_type',$index))"/></mac-type>
									<mac-address><xsl:value-of select="sw:param(concat('bridged_mac_address',$index))"/></mac-address>
									<xsl:copy-of select="mac-address-current"/>									
								</xsl:if>
								
								<!-- Restore IP Addresses -->
								<xsl:choose>
									<!-- Get IP from Global Pool -->
									<xsl:when test="$ip-rule='pool'">
									</xsl:when>
									<!-- Get IP from DHCP -->
									<xsl:when test="$ip-rule='dhcp'">
									</xsl:when>
									<!-- Get IP from custom range -->
									<xsl:when test="$ip-rule='range'">
										<first-ip>
											<xsl:copy-of select="vzenv:restore-ip(concat('bridged_first_ip_',$index))"/>
										</first-ip>
									</xsl:when>
									<!-- Set IP per VE manually -->
									<xsl:when test="$ip-rule='set'">
										<xsl:call-template name="local:restore-ves-ips">
											<xsl:with-param name="net" select="$net"/>
											<xsl:with-param name="iface" select="."/>	
											<xsl:with-param name="iface-code" select="concat('bridged_',$index)"/>	
										</xsl:call-template>
									</xsl:when>
									<!-- Single VE mode -->
									<xsl:otherwise>
										<dhcp><xsl:value-of select="sw:if(sw:param(concat('bridged_dhcp',$index))='1','true','false')"/></dhcp>
										<ips>
											<xsl:copy-of select="sw:restoreVEIPs(concat('bridged_ips',$index))"/>
										</ips>
									</xsl:otherwise>
								</xsl:choose>
								<!-- /Restore IP Addresses -->			
								
								<xsl:copy-of select="dhcp-ips"/>									
								<xsl:if test="not($env-form/hn/linux)">
									<dns_ips>
										<xsl:copy-of select="vzenv:restore-net-dns(concat('bridged_dns_ips',$index))"/>
									</dns_ips>
									<wins_servers>
										<xsl:copy-of select="vzenv:restore-net-wins(concat('bridged_wins_servers',$index))"/>
									</wins_servers>					
								</xsl:if>
								<default_gateway>
									<xsl:copy-of select="sw:param(concat('bridged_default_gateway',$index))"/>
								</default_gateway>
								<xsl:if test="not($env-form/hn/linux)">								
									<search_domains>
										<xsl:copy-of select="vzenv:restore-net-search(concat('bridged_search_domains',$index))"/>
									</search_domains>
								</xsl:if>
							</iface>
						</xsl:if>
					</xsl:for-each>
					<!-- Add new interface -->
					<xsl:if test="sw:param('new_iface')!=''">
						<xsl:call-template name="vzenv:new-interface">
							<xsl:with-param name="bridged-ifaces" select="$net/bridged/iface"/>
						</xsl:call-template>
					</xsl:if>
				</xsl:when>
				<xsl:otherwise>
					<!-- disabled -->
					<enabled>false</enabled>
					<xsl:copy-of select="$net/bridged/*[not(self::enabled)]"/>
				</xsl:otherwise>
			</xsl:choose>
		</bridged>			
	</xsl:template>
	<!-- /Restore VE Net Inferfaces UI -->
	
	<!--===================================================== Show UI ============================================-->


	<!-- Show VE Net Inferfaces UI 
		form
			net
			hn
				eid
				platofrm
				linux|windows
			def
				ips-pool-enabled
		ve-net - empty nodeset or ref to form/net
		options
			<exclude-hostname/>
	-->
	<xsl:template name="vzenv:edit-net">
		<xsl:param name="env-form"/>
		<xsl:param name="ve-net" select="/.."/>
		<xsl:param name="options-rtf" select="''"/>

		<!--|-->
		<xsl:variable name="options" select="exsl:node-set($options-rtf)"/>				
		<xsl:variable name="net" select="sw:if($ve-net,$ve-net,$env-form/net)"/>		
		
		<!-- Preload some data -->
		<xsl:variable name="net-config" select="local:load-net-config($env-form/hn/eid)"/>
		<!-- /Preload some data -->
		
		<xsl:call-template name="local:show-global">
			<xsl:with-param name="net-config" select="$net-config"/>
			<xsl:with-param name="env-form" select="$env-form"/>
			<xsl:with-param name="net" select="$net"/>			
			<xsl:with-param name="options" select="$options"/>				
		</xsl:call-template>
		
		<ui:rows separate-tables="true">
		
			<xsl:choose>
				<xsl:when test="($net/routed/ip-rule='pool' and not($env-form/def/ips-pool-enabled))">
					<xsl:call-template name="local:show-routed-disabled">
						<xsl:with-param name="env-form" select="$env-form"/>
						<xsl:with-param name="net-config" select="$net-config"/>
						<xsl:with-param name="net" select="$net"/>						
					</xsl:call-template>				
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="local:show-routed">
						<xsl:with-param name="env-form" select="$env-form"/>
						<xsl:with-param name="net-config" select="$net-config"/>
						<xsl:with-param name="net" select="$net"/>							
					</xsl:call-template>					
				</xsl:otherwise>
			</xsl:choose>				
		</ui:rows>
		
		<ui:rows separate-tables="true">
			<xsl:choose>
				<xsl:when test="not(($net-config/net or $env-form/hn/linux or $net/bridged/enabled='true'))
					or ($net/bridged/ip-rule='pool' and not($env-form/def/ips-pool-enabled))
				">
					<xsl:call-template name="local:show-bridged-disabled">
						<xsl:with-param name="env-form" select="$env-form"/>
						<xsl:with-param name="net-config" select="$net-config"/>
						<xsl:with-param name="net" select="$net"/>													
					</xsl:call-template>				
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="local:show-bridged">
						<xsl:with-param name="env-form" select="$env-form"/>
						<xsl:with-param name="net-config" select="$net-config"/>
						<xsl:with-param name="net" select="$net"/>																			
					</xsl:call-template>					
				</xsl:otherwise>
			</xsl:choose>
		</ui:rows>
		
		<xsl:call-template name="local:post-js-code">
			<xsl:with-param name="net-config" select="$net-config"/>
			<xsl:with-param name="env-form" select="$env-form"/>
		</xsl:call-template>
		
	</xsl:template>
	<!-- /Show VE Net Inferfaces UI -->

	<!-- Show routed iface -->
	<xsl:template name="local:show-routed">
		<xsl:param name="net-config"/>
		<xsl:param name="env-form"/>
		<xsl:param name="net"/>
		<!--|-->		
		<xsl:variable name="iface" select="$net/routed"/>
		
		<ui:rows-title>
			<ui:text><sw:text>Routed Network</sw:text>&#160;</ui:text>
			<input type="checkbox" id="routed_enabled" name="routed_enabled" onclick="routedEnabledChanged(this.checked)" value="1">
				<xsl:if test="$net/routed/enabled='true'">
					<xsl:attribute name="checked">1</xsl:attribute>
				</xsl:if>
			</input>
		</ui:rows-title>
	
		<ui:row>
			<ui:cell-text offset="">
				<img src="/{$theme}/icons/networkadapter_16.gif" width="16" height="16"/>&#160;
				<sw:text>
					<xsl:with-param name="id" select="$iface/id"/>
					Virtual Network Interface %{id}
				</sw:text>
			</ui:cell-text>
		</ui:row>
		
		<xsl:choose>
			<!-- Get IP from Global Pool -->
			<xsl:when test="$iface/ip-rule='pool'">
				<ui:row>
					<ui:cell-text offset="3" colspan="2">  
						<sw:text>Every Container will receive an IP address from the global IP addresses pool.</sw:text>
					</ui:cell-text>
				</ui:row>			
			</xsl:when>
			<!-- Get IP from custom range -->
			<xsl:when test="$iface/ip-rule='range'">
				<ui:row>
					<ui:cell-text offset="3" colspan="2">
						<sw:text>Every Container will receive an IP address from the range of IP addresses starting with the following one:</sw:text>
					</ui:cell-text>
				</ui:row>
				<xsl:call-template name="vzenv:edit-ip">
					<xsl:with-param name="code" select="'routed_first_ip'"/>
					<xsl:with-param name="ip" select="$iface/first-ip"/>				
					<xsl:with-param name="label" select="sw:text('IP Address')"/>					
					<xsl:with-param name="offset" select="3"/>
					<xsl:with-param name="pool-enabled" select="$env-form/def/ips-pool-enabled"/>					
					<xsl:with-param name="hn-platform" select="$env-form/hn/platform"/>
					<xsl:with-param name="offset" select="3"/>					
					<xsl:with-param name="label-as-text" select="vt:is-platform-windows($env-form/hn/platform)"/>					
				</xsl:call-template>
			</xsl:when>
			<!-- Specify IP for every VE -->
			<xsl:when test="$iface/ip-rule='set'">
				<xsl:call-template name="local:edit-ves-ips">
					<xsl:with-param name="env-form" select="$env-form"/>
					<xsl:with-param name="net" select="$net"/>
					<xsl:with-param name="iface" select="$iface"/>	
					<xsl:with-param name="iface-code" select="'routed'"/>									
					<xsl:with-param name="is-bridged" select="false()"/>														
				</xsl:call-template>
			</xsl:when>
			<!-- Single VE mode -->
			<xsl:otherwise>
				<xsl:copy-of select="sw:showVEIPs($iface/ips,$env-form/hn/platform,'routed_ips',$env-form/def/ips-pool-enabled,'3',true())"/>
			</xsl:otherwise>
		</xsl:choose>
		
		<xsl:if test="not($env-form/hn/linux)">
			<xsl:copy-of select="vzenv:show-net-dns($iface/dns_ips,$env-form/hn/platform,'routed_dns_ips',3)"/> 
			<xsl:copy-of select="vzenv:show-net-wins($iface/wins_servers,'routed_wins_servers',3)"/> 		
			<!--<xsl:copy-of select="vzenv:show-net-gateway($iface/default_gateway,'routed_default_gateway',3)"/> -->
		</xsl:if>
		
	</xsl:template>
	<!-- /Show routed iface -->
	
	<!-- Show routed network in disabled state -->
	<xsl:template name="local:show-routed-disabled">
		<xsl:param name="net-config"/>
		<xsl:param name="env-form"/>
		<xsl:param name="net"/>		
		<!--|-->				
		<ui:rows-title>
			<ui:text><sw:text>Routed Network</sw:text>&#160;</ui:text>
			<input type="checkbox" disabled="1"/>
		</ui:rows-title>
		<ui:row>
			<ui:cell-text>
				<img src="/{$theme}/icons/alert_yellow.gif" width="16" height="16"/>
			</ui:cell-text>
			<ui:cell-text>
				<xsl:choose>
					<xsl:when test="$net/routed/ip-rule='pool'">
						<sw:text>
							The host-routed network mode is not available because the global IP address pool is disabled.
						</sw:text>
					</xsl:when>
					<xsl:otherwise>
					</xsl:otherwise>
				</xsl:choose>
			</ui:cell-text>
		</ui:row>
		<!--|-->
	</xsl:template>
	<!-- /Show bridged network in disabled state -->	
	
	<!-- Show routed iface -->
	<xsl:template name="local:show-bridged">
		<xsl:param name="net-config"/>
		<xsl:param name="net"/>	
		<xsl:param name="env-form"/>
		<!--|-->
		<ui:rows-title>
			<ui:text><sw:text>Bridged Network</sw:text>&#160;</ui:text>
			<input type="checkbox" id="bridged_enabled" name="bridged_enabled"  onclick="bridgedEnabledChanged(this.checked)" value="1">
				<xsl:if test="$net/bridged/enabled='true'">
					<xsl:attribute name="checked">1</xsl:attribute>
				</xsl:if>
			</input>
		</ui:rows-title>
		
		<xsl:variable name="ip-rule" select="$net/bridged/ip-rule"/>
		
		<xsl:for-each select="$net/bridged/iface">
			<xsl:variable name="index" select="position()-1"/>
			<xsl:variable name="iface" select="."/>
			
			<ui:div id="div_bridged_iface{$index}">
				
				<xsl:call-template name="vzenv:show-bridged-iface-header">
					<xsl:with-param name="index" select="$index"/>
					<xsl:with-param name="iface" select="$iface"/>
					<xsl:with-param name="networks" select="$net-config/net"/>
					<xsl:with-param name="env-platform" select="$env-form/hn/platform"/>
				</xsl:call-template>
				
				<!-- MAC -->
				<xsl:if test="not($ip-rule!='')">
					<ui:row>
						<ui:cell-label offset="3"><sw:text>MAC Address</sw:text></ui:cell-label>
						<ui:cell-list id="bridged_mac_type{$index}" value="{$iface/mac-type}"
							onchange="bridgedMACTypeChanged({$index})"
						>
							<ui:list-item id="auto">
								<xsl:attribute name="title">
									<xsl:choose>
										<xsl:when test="mac-address-current">
											<xsl:value-of select="mac-address-current"/>
										</xsl:when>
										<xsl:otherwise>
											<sw:text>Obtain Automatically</sw:text>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:attribute>
							</ui:list-item>
							<ui:list-item id="set" title="{sw:text('Set Manually to')}"/>						
						</ui:cell-list>
						<ui:cell-input id="bridged_mac_address{$index}" value="{$iface/mac-address}" maxlength="17">
							<xsl:if test="not($iface/mac-type='set')">
								<xsl:attribute name="style">display:none;</xsl:attribute>
							</xsl:if>
						</ui:cell-input>
					</ui:row>
				</xsl:if>
				<!-- /MAC -->	
				
				<!-- Show IP Settings -->
				<xsl:choose>
					<!-- Multiply VE Creation -->
					<xsl:when test="$ip-rule!=''">
						<xsl:choose>
							<!-- Get IP from DHCP -->
							<xsl:when test="$ip-rule='dhcp'">
								<ui:row>
									<ui:cell-text offset="3" colspan="2">
										<sw:text>Every Container will receive an IP address from the DHCP server.</sw:text>
									</ui:cell-text>
								</ui:row>			
							</xsl:when>						
							<!-- Get IP from Global Pool -->
							<xsl:when test="$ip-rule='pool'">
								<ui:row>
									<ui:cell-text offset="3" colspan="2">
										<sw:text>Every Container will receive an IP address from the global IP addresses pool.</sw:text>
									</ui:cell-text>
								</ui:row>			
							</xsl:when>
							<!-- Get IP from custom range -->
							<xsl:when test="$ip-rule='range'">
								<ui:row>
									<ui:cell-text offset="3" colspan="2">
										<sw:text>Every Container will receive an IP address from the range of IP addresses starting with the following one:</sw:text>
									</ui:cell-text>
								</ui:row>
								<xsl:call-template name="vzenv:edit-ip">
									<xsl:with-param name="code" select="concat('bridged_first_ip_',$index)"/>
									<xsl:with-param name="ip" select="$iface/first-ip"/>				
									<xsl:with-param name="label" select="sw:text('IP Address')"/>					
									<xsl:with-param name="offset" select="3"/>
									<xsl:with-param name="pool-enabled" select="$env-form/def/ips-pool-enabled"/>					
									<xsl:with-param name="hn-platform" select="$env-form/hn/platform"/>
									<xsl:with-param name="label-as-text" select="vt:is-platform-windows($env-form/hn/platform)"/>														
									<xsl:with-param name="offset" select="3"/>					
								</xsl:call-template>
							</xsl:when>
							<!-- Specify IP for every VE -->
							<xsl:when test="$ip-rule='set'">
								<ui:row>
									<ui:cell-text offset="3" colspan="2">
										<sw:text>Specify the IP addresses for each Container individually:</sw:text>
									</ui:cell-text>
								</ui:row>
								<xsl:call-template name="local:edit-ves-ips">
									<xsl:with-param name="env-form" select="$env-form"/>
									<xsl:with-param name="net" select="$net"/>									
									<xsl:with-param name="iface" select="$iface"/>	
									<xsl:with-param name="iface-code" select="concat('bridged_',$index)"/>			
									<xsl:with-param name="is-bridged" select="true()"/>																							
								</xsl:call-template>
							</xsl:when>
						</xsl:choose>
						
					</xsl:when>
					<!-- Single VE creation -->
					<xsl:otherwise>
						<!-- DHCP -->
						<ui:row>
							<ui:cell-label offset="3"><sw:text>Get IP Address by DHCP</sw:text></ui:cell-label>
							<ui:cell-check id="bridged_dhcp{$index}" checked="{$iface/dhcp='true'}"
								onclick="bridgedDHCPChanged({$index},this)"
							/>
						</ui:row>
						<!-- /DHCP -->	
						
						<!-- IP Addresses -->
						<ui:div id="div_bridged_ips{$index}" hidden="{$iface/dhcp}">
							<xsl:copy-of select="sw:showVEIPs(
								$iface/ips,$env-form/hn/platform,concat('bridged_ips',$index),$env-form/def/ips-pool-enabled,
								3,
								false(),
								true()
							)"/>
						</ui:div>
					</xsl:otherwise>
				</xsl:choose>
				
				<xsl:call-template name="vzenv:show-bridged-iface-footer">
					<xsl:with-param name="index" select="$index"/>
					<xsl:with-param name="iface" select="$iface"/>
					<xsl:with-param name="env-platform" select="$env-form/hn/platform"/>
					<xsl:with-param name="is-last" select="position()=last()"/>
					<xsl:with-param name="bridged-ip-rule" select="$ip-rule"/>
				</xsl:call-template>	
										
			</ui:div>
		</xsl:for-each>
		
		
	</xsl:template>
	<!-- /Show routed iface -->

	
	<!-- Show bridged network in disabled state -->
	<xsl:template name="local:show-bridged-disabled">
		<xsl:param name="net-config"/>
		<xsl:param name="env-form"/>
		<xsl:param name="net"/>
		<!--|-->				
		<ui:rows-title>
			<ui:text><sw:text>Bridged Network</sw:text>&#160;</ui:text>
			<input type="checkbox" id="bridged_enabled" name="bridged_enabled" disabled="1" value=""/>			
		</ui:rows-title>
		<ui:row>
			<ui:cell-text>
				<img src="/{$theme}/icons/alert_yellow.gif" width="16" height="16"/>
			</ui:cell-text>
			<ui:cell-text>
				<xsl:choose>
					<xsl:when test="not($net-config/net)">
						<sw:text>
							The bridged network mode is not available because the selected Hardware Node has neither virtual networks nor virtual switches configured on it.
						</sw:text>
					</xsl:when>
					<xsl:when test="$net/bridged/ip-rule='pool'">
						<sw:text>
							The bridged network mode is not available because the global IP address pool is disabled.
						</sw:text>
					</xsl:when>
					<xsl:otherwise>
						<sw:text>
							Uknown error was occured.
						</sw:text>
					</xsl:otherwise>
				</xsl:choose>
			</ui:cell-text>
		</ui:row>
		<!--|-->
	</xsl:template>
	<!-- /Show bridged network in disabled state -->
	
	<!-- Show VE Global network settings -->
	<xsl:template name="local:show-global">
		<xsl:param name="net-config"/>
		<xsl:param name="env-form"/>
		<xsl:param name="net"/>		
		<xsl:param name="options"/>		
		
		<ui:rows title="{sw:text('Global Network')}" separate-tables="true">
			<ui:row>
				<ui:cell-text>
					<img src="/{$theme}/icons/network_16.gif" width="16" height="16"/>&#160;
					<sw:text>All Interfaces</sw:text>
				</ui:cell-text>
			</ui:row>
			<!-- Do not show in multy-ve creation wizard -->
			<xsl:if test="not($net/ve) and not($options/exclude-hostname)">
				<ui:row>
					<ui:cell-label offset="3">
						<sw:text>Hostname</sw:text>
					</ui:cell-label>
					<ui:cell-input id="hostname" maxlength="256">
						<xsl:if test="$env-form/hn/windows">
							<xsl:attribute name="required">true</xsl:attribute>
						</xsl:if>
						<xsl:attribute name="value"><xsl:value-of select="$net/hostname"/></xsl:attribute>
					</ui:cell-input>
				</ui:row>
			</xsl:if>
			<xsl:if test="$env-form/hn/linux">
				<xsl:copy-of select="vzenv:show-net-dns($net/dns_ips,$env-form/hn/platform,'dns_ips',3)"/> 
			</xsl:if>
			<xsl:copy-of select="vzenv:show-net-search($net/search_domains,'search_domains',3)"/> 	
		</ui:rows>
		
	</xsl:template>
	<!-- /Show VE Global network settings -->

	<!-- Post JS-code for iface selection -->
	<xsl:template name="local:post-js-code">
		<xsl:param name="net-config"/>
		<xsl:param name="env-form"/>
		<!--|-->
		<ui:raw>
			<xsl:call-template name="vzenv:post-net-core-js"/>
			
		<script type="text/javascript">	
			function routedEnabledChanged(enabled){
				<xsl:choose>
					<xsl:when test="$env-form/net/routed/ip-rule='range'">
						document.getElementById('routed_first_ip_address').disabled = !enabled;
					</xsl:when>
					<xsl:when test="$env-form/net/routed/ip-rule='set'">
						<xsl:for-each select="$env-form/net/ve">
							document.getElementById('routed_<xsl:value-of select="position()"/>_ip_address').disabled = !enabled;
							<xsl:if test="not($env-form/hn/linux)">
								document.getElementById('routed_<xsl:value-of select="position()"/>_ip_netmask').disabled = !enabled;
							</xsl:if>
						</xsl:for-each>
					</xsl:when>
					<xsl:when test="not($env-form/net/routed/ip-rule!='')">
						disable_routed_ips(!enabled);
					</xsl:when>
				</xsl:choose>
				<xsl:if test="not($env-form/hn/linux)">
					disable_routed_dns_ips(!enabled);
					disable_routed_wins_servers(!enabled);				
					// document.getElementById('routed_default_gateway').disabled = !enabled;
				</xsl:if>
			}
			function bridgedEnabledChanged(enabled){
				var disabled = !enabled;
				<xsl:for-each select="$env-form/net/bridged/iface">
					<xsl:variable name="index" select="position()-1"/>
					
					<xsl:choose>
						<xsl:when test="$env-form/net/bridged/ip-rule='range'">
							document.getElementById('bridged_first_ip_<xsl:value-of select="$index"/>_address').disabled = !enabled;
						</xsl:when>
						<xsl:when test="$env-form/net/bridged/ip-rule='set'">
							<xsl:for-each select="$env-form/net/ve">
								document.getElementById('bridged_<xsl:value-of select="$index"/>_<xsl:value-of select="position()"/>_ip_address').disabled = !enabled;
								<xsl:if test="not($env-form/hn/linux)">
									document.getElementById('bridged_<xsl:value-of select="$index"/>_<xsl:value-of select="position()"/>_ip_netmask').disabled = !enabled;
								</xsl:if>
							</xsl:for-each>
						</xsl:when>
						<xsl:when test="not($env-form/net/bridged/ip-rule!='')">
							disable_bridged_ips<xsl:value-of select="$index"/>(disabled);
							document.getElementById('bridged_dhcp<xsl:value-of select="$index"/>').disabled = disabled;							
						</xsl:when>
					</xsl:choose>
					
					<xsl:if test="not($env-form/hn/linux)">
						disable_bridged_dns_ips<xsl:value-of select="$index"/>(disabled);
						disable_bridged_wins_servers<xsl:value-of select="$index"/>(disabled);
					</xsl:if>
					<xsl:if test="not($env-form/net/bridged/ip-rule='dhcp')">
						document.getElementById('bridged_default_gateway<xsl:value-of select="$index"/>').disabled = !enabled;										
					</xsl:if>
					<xsl:if test="not($env-form/net/bridged/ip-rule!='')">
						document.getElementById('bridged_mac_type<xsl:value-of select="$index"/>').disabled = disabled;	
						document.getElementById('bridged_mac_address<xsl:value-of select="$index"/>').disabled = disabled;						
					</xsl:if>
					document.getElementById('bridged_net_id<xsl:value-of select="$index"/>').disabled = disabled;
					showObjExt('div_bridged_iface_remove<xsl:value-of select="$index"/>',enabled);
				</xsl:for-each>
			}
			function bridgedDHCPChanged(iface_index,check_obj){
				var use_dhcp = check_obj.checked;
				showObjExt('div_bridged_ips'+iface_index,!use_dhcp);
				showObjExt('div_bridged_gateway'+iface_index,!use_dhcp);				
			}
			function bridgedMACTypeChanged(iface_index){
				var type_obj = document.getElementById('bridged_mac_type'+iface_index);
				var type_auto = type_obj.options[type_obj.selectedIndex].value=='auto';
				showObjExt('bridged_mac_address'+iface_index,!type_auto);	
			}
			v = document.getElementById('routed_enabled');
			if(v){
				routedEnabledChanged(v.checked);
			}
			v = document.getElementById('bridged_enabled');
			if(v &amp;&amp; v.value!=''){
				bridgedEnabledChanged(v.checked);
			}
		</script>
		</ui:raw>
	</xsl:template>
	<!-- /Post JS-code for iface selection -->
	
	<!--===================================================== Load funcs ============================================-->
	
	
	<!-- Load all nets available for new VE  -->
	<func:function name="local:list-nets">
		<xsl:param name="hn-eid"/>
		<xsl:variable name="nets-src" select="server_group:get-config(sw:master-eid(),true())"/>
		<xsl:variable name="nets-rtf">
			<xsl:for-each select="$nets-src/networks/network">
				<xsl:sort select="id"/>
				<net>
					<id><xsl:value-of select="sw:base64-decode(id)"/></id>
					<title><xsl:value-of select="sw:base64-decode(id)"/></title>
				</net>
			</xsl:for-each>
			<xsl:if test="$nets-src/errors">
				<xsl:if test="error:put(concat('VZA error #',$nets-src/error/code,' occured during virtual networks listing'),$nets-src/error/message)"/>
				<net>
					<error/>
					<id/>
					<title><sw:text>Cannot list virtual networks.</sw:text></title>
				</net>
			</xsl:if>
		</xsl:variable>
		<func:result select="exsl:node-set($nets-rtf)/net"/>
	</func:function>
	<!-- /Load all nets available for new VE  -->

	<func:function name="local:load-net-config">
		<xsl:param name="hn-eid"/>
		<xsl:variable name="res-rtf">
			<xsl:copy-of select="local:list-nets($hn-eid)"/>
		</xsl:variable>
		<func:result select="exsl:node-set($res-rtf)"/>
	</func:function>
	
	<!--===================================================== Review UI data ============================================-->
	

	
	<xsl:template name="local:check-ves-ips">
		<xsl:param name="env-form"/>
		<xsl:param name="iface"/>		
		<xsl:param name="iface-code"/>	
		
		<xsl:for-each select="$iface/ve-ip">
			<xsl:variable name="ve-index" select="position()"/>
			
			<xsl:call-template name="vzenv:check-ip">
				<xsl:with-param name="code" select="concat($iface-code,'_',$ve-index,'_ip')"/>
				<xsl:with-param name="ip" select="."/>				
				<xsl:with-param name="pool-enabled" select="$env-form/def/ips-pool-enabled"/>					
				<xsl:with-param name="hn-platform" select="$env-form/hn/platform"/>
			</xsl:call-template>
			
		</xsl:for-each>
		
	</xsl:template>
		
	<xsl:template name="local:restore-ves-ips">
		<xsl:param name="net"/>
		<xsl:param name="iface"/>		
		<xsl:param name="iface-code"/>	
		
		<xsl:for-each select="$net/ve">
			<xsl:variable name="ve-index" select="@index"/>
			<ve-ip>
				<xsl:copy-of select="vzenv:restore-ip(concat($iface-code,'_',$ve-index,'_ip'))"/>
			</ve-ip>
		</xsl:for-each>
		
	</xsl:template>
	
	<xsl:template name="local:edit-ves-ips">
		<xsl:param name="env-form"/>
		<xsl:param name="net"/>		
		<xsl:param name="iface"/>		
		<xsl:param name="iface-code"/>
		<xsl:param name="is-bridged"/>			
		
		<xsl:for-each select="$net/ve">
			<xsl:variable name="ve-index" select="@index"/>
			<ui:row>
				<ui:cell-text offset="3">
					<sw:text>
						<xsl:with-param name="index" select="$ve-index"/>
						Settings for Container #%{index} 
					</sw:text>
				</ui:cell-text>
			</ui:row>
			<xsl:call-template name="vzenv:edit-ip">
				<xsl:with-param name="code" select="concat($iface-code,'_',$ve-index,'_ip')"/>
				<xsl:with-param name="ip" select="$iface/ve-ip[position()=$ve-index]"/>				
				<xsl:with-param name="label">
					<sw:text>
						IP Address
					</sw:text>
				</xsl:with-param>
				<xsl:with-param name="offset" select="5"/>		
				<xsl:with-param name="label-as-text" select="vt:is-platform-windows($env-form/hn/platform) or $is-bridged"/>
				<xsl:with-param name="pool-enabled" select="$env-form/def/ips-pool-enabled"/>					
				<xsl:with-param name="hn-platform" select="$env-form/hn/platform"/>
				<xsl:with-param name="is-bridged" select="$is-bridged"/>	
			</xsl:call-template>
		</xsl:for-each>
	</xsl:template>
	
</xsl:stylesheet>
