<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw func form check vzenv voc env"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
  xmlns:error		="http://www.swsoft.com/xsl/cp/error"
  xmlns:ui	="http://www.swsoft.com/xsl/cp/ui"
  xmlns:env		="http://www.swsoft.com/xsl/cp/env"
  xmlns:vzenv		="http://www.swsoft.com/xsl/cp/vzenv"
  xmlns:form	="http://www.swsoft.com/xsl/cp/form"
  xmlns:func	="http://exslt.org/functions"
  xmlns:check	="http://www.swsoft.com/xsl/cp/check"
  xmlns:voc		="http://www.swsoft.com/xsl/cp/voc"
 	xmlns:vt		="http://www.swsoft.com/xsl/cp/vt" 
 	xmlns:global		="http://www.swsoft.com/xsl/cp/global"  	
>
	<sw:include href="/lib/core/check-funcs.xsl"/>
 	<sw:include href="../vocabulary.xsl"/>
 	<sw:include href="../vt/env-core.xsl"/>
 	<sw:include href="../vz/vzenv-core.xsl"/>
 	<sw:include href="../../layout/forms-list.xsl"/>

  <xsl:variable name="veIPEmpty" select="''"/><!-- todo: convert danger symbols to HTML entities -->

	<!-- Check VE hostname on MultiVE setup screen -->
	<func:function name="vzenv:check-ves-hostname">
		<xsl:param name="platform-ref"/> 
		<xsl:param name="env"/> <!-- /hostname -->
		<xsl:param name="title"/>
		<xsl:param name="index"/>

		<xsl:choose>
			<xsl:when test="$env/hostname=''">
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="error-info" select="check:hostname-ext($platform-ref,$env/hostname)"/>
				<!-- Show error -->
				<xsl:choose>
					<xsl:when test="not($error-info)">
						<!-- all is ok -->
					</xsl:when>
					<xsl:when test="$error-info[self::long]">
						<xsl:variable name="error-text">
							<sw:text>
								<xsl:with-param name="title" select="$title"/>
								<xsl:with-param name="limit" select="$error-info[self::info]/max"/>
								The hostname of Container %{title} cannot be longer than %{limit} characters.
							</sw:text>
						</xsl:variable>
						<xsl:if test="error:put($error-text,'',concat('hostname_',$index))"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:variable name="error-text">
							<sw:text>
								<xsl:with-param name="title" select="$title"/>
								The hostname of Container %{title} is invalid.
							</sw:text>
						</xsl:variable>
						<xsl:if test="error:put($error-text,$error-info[self::info]/short,concat('hostname_',$index))"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Show error -->	
			</xsl:otherwise>			
		</xsl:choose>
	</func:function>
	<!-- /Check VE hostname on MultiVE setup screen -->

	<!-- Check VE IPS on MultiVE setup screen -->
	<func:function name="vzenv:check-ves-ips">
		<xsl:param name="ve"/>
		<xsl:param name="index"/>
		<xsl:param name="id"/>
		<xsl:param name="pool-enabled" select="false()"/>

		<xsl:variable name="error-ip-empty">
			<sw:text>
				<xsl:with-param name="id" select="$id"/>
				Please specify at least one IP address for Container %{id}.
			</sw:text>
		</xsl:variable>
		<xsl:variable name="error-ip-wrong">
			<sw:text>
				<xsl:with-param name="id" select="$id"/>
				Please correct the IP address of Container %{id}.
			</sw:text>
		</xsl:variable>
		<xsl:variable name="error-netmask-wrong">
			<sw:text>
				<xsl:with-param name="id" select="$id"/>
				Please correct the subnet mask for Container %{id}.
			</sw:text>
		</xsl:variable>
		<xsl:if test="sw:checkVEIPs($ve/ips/ip, $ve/hn/platform, concat('ips_',$index),$pool-enabled
			,$error-ip-empty,$error-ip-wrong,$error-netmask-wrong
		)"/>
	</func:function>
	<!-- /Check VE IPS on MultiVE setup screen -->

	<func:function name="vzenv:check-ve-id">
		<xsl:param name="ve-id"/>
		<xsl:param name="hw-eid"/>
		<xsl:param name="last-ve-id"/>
		<xsl:param name="control-id" select="'ve_id'"/>

		<xsl:choose>
			<xsl:when test="string($ve-id)=''">
	    	<xsl:if test="error:put(sw:text('You should specify a Container ID.'),'',$control-id)"/>
	    </xsl:when>
	    <xsl:when test="not(sw:re-test(string($ve-id),vzenv:id-regexp()))">
	    	<xsl:if test="error:put(sw:text('Please correct the Container ID.'),'',$control-id)"/>
	    </xsl:when>
	    <xsl:when test="number($ve-id)&lt;2">
	    	<xsl:if test="error:put(sw:text('Please correct the Container ID. The ID should be greater than 1.'),'',$control-id)"/>
	    </xsl:when>
	    <xsl:when test="number($ve-id)&gt;$last-ve-id">
	    	<xsl:variable name="error">
	    		<sw:text>
		    		<xsl:with-param name="limit" select="$last-ve-id"/>
		    		Please correct the Container ID. The ID should not be greater than %{limit}.
		    	</sw:text>
	    	</xsl:variable>
	    	<xsl:if test="error:put($error,'',$control-id)"/>
	    </xsl:when>
	    <xsl:otherwise>
	    	<!-- Check,  if VE ID is already used for another VE -->
				<xsl:if test="vzenv:veid-to-eid($ve-id,$hw-eid)!=''">
	    		<xsl:if test="error:put(sw:text('The requested Container ID is already in use.'),'',$control-id)"/>
	    	</xsl:if>
	    </xsl:otherwise>
	  </xsl:choose>
	  <func:result/>
	</func:function>

	<!-- Check VE  name on MultiVE setup screen -->
	<func:function name="vzenv:check-ves-name">
		<xsl:param name="hn-eid"/>	
		<xsl:param name="env"/> <!-- /hostname -->
		<xsl:param name="title"/>
		<xsl:param name="index"/>

		<xsl:variable name="platform-ref" select="env:make-platform-ref($hn-eid)"/>

		<xsl:choose>
			<xsl:when test="not(check:env-name($platform-ref,$env/name))">
				<xsl:variable name="error-text">
					<sw:text>
						<xsl:with-param name="title" select="$title"/>
						The name of Container %{title} contains invalid characters.
					</sw:text>
				</xsl:variable>
				<xsl:if test="error:put($error-text,'',concat('name_',$index))"/>
			</xsl:when>
			<xsl:otherwise>
	    	<xsl:variable name="found-eid" select="string(vzenv:name-to-eid($env/name,$hn-eid))"/>
	    	<xsl:if test="not($found-eid='')">
	    		<xsl:variable name="error-text">
						<sw:text>
							<xsl:with-param name="title" select="$title"/>
							The requested Container name - %{title} - is already in use.
						</sw:text>
					</xsl:variable>
					<xsl:if test="error:put($error-text,'',concat('name_',$index))"/>	    		
	    	</xsl:if>
	    </xsl:otherwise>
		</xsl:choose>
	</func:function>
	<!-- /Check VE hostname on MultiVE setup screen -->
	
	<func:function name="vzenv:check-ve-hostname">
		<xsl:param name="hostname"/>
		<xsl:param name="hn-eid"/>
		<xsl:param name="control-id" select="'hostname'"/>

		<xsl:variable name="platform-ref" select="env:make-platform-ref($hn-eid)"/>

		<xsl:choose>
			<xsl:when test="string($hostname)=''">
	    </xsl:when>
	    <xsl:otherwise>
				<xsl:variable name="error-info" select="check:hostname-ext($platform-ref,$hostname)"/>
				<!-- Show error -->
				<xsl:choose>
					<xsl:when test="not($error-info)">
					</xsl:when>
					<xsl:when test="$error-info[self::long]">
						<xsl:variable name="error-text">
							<sw:text>
								<xsl:with-param name="limit" select="$error-info[self::pattern]/max"/>
								The hostname cannot be longer than %{limit} characters.
							</sw:text>
						</xsl:variable>
						<xsl:if test="error:put($error-text,'',$control-id)"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:variable name="error-text">
							<sw:text>
								The hostname is invalid.
							</sw:text>
						</xsl:variable>
						<xsl:if test="error:put($error-text,$error-info[self::pattern]/short,$control-id)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Show error -->	
			</xsl:otherwise>	
	  </xsl:choose>
	  
	  <func:result/>
	</func:function>

	<func:function name="vzenv:check-ve-name">
		<xsl:param name="ve-name"/>
		<xsl:param name="hn-eid"/>
		<xsl:param name="ve-eid" select="''"/>		
		<xsl:param name="control-id" select="'name'"/>
		<xsl:param name="mandatory-name" select="true()"/>

		<xsl:variable name="platform-ref" select="env:make-platform-ref($hn-eid)"/>

		<xsl:choose>
			<xsl:when test="string($ve-name)=''">
				<xsl:if test="$mandatory-name">
	    	<xsl:if test="error:put(sw:text('You should specify a Container name.'),'',$control-id)"/>
				</xsl:if>
	    </xsl:when>
	    <xsl:when test="not(check:env-name($platform-ref,$ve-name))">
	    	<xsl:if test="error:put(sw:text('The name contains invalid characters.'),'',$control-id)"/>
	    </xsl:when>
	    <xsl:otherwise>
	    	<xsl:variable name="found-eid" select="string(vzenv:name-to-eid($ve-name,$hn-eid))"/>
	    	<xsl:if test="not($found-eid='' or $found-eid=$ve-eid)">
	    		<xsl:if test="error:put(sw:text('The requested Container name is already in use.'),'',$control-id)"/>
	    	</xsl:if>
	    </xsl:otherwise>
	  </xsl:choose>
	  
	  <func:result/>
	</func:function>
	
	<func:function name="vzenv:restore-net-capabilities">
		<xsl:param name="data"/>
		<func:result>
			<xsl:for-each select="$data/parameter">
				<xsl:variable name="pos" select="position()"/>
				<capability>
					<id><xsl:value-of select="id"/></id>
					<value><xsl:value-of select="sw:if(
						sw:param(concat('cap_',$pos)),'1','0'
					)"/></value>
				</capability>
			</xsl:for-each>
		</func:result>
	</func:function>


	<func:function name="vzenv:restore-ip">
		<xsl:param name="code"/>
		
		<xsl:variable name="address" select="sw:param(concat($code,'_address'))"/>
		<xsl:variable name="netmask" select="sw:param(concat($code,'_netmask'))"/>

		<xsl:variable name="data-rtf">
			<address><xsl:value-of select="$address"/></address>
			<netmask>
				<xsl:value-of select="sw:if($netmask=$def-ip-auto-vzcp and $address!=$def-ip-auto-vzcp,$global:ip-default-netmask,$netmask)"/>
			</netmask>
		</xsl:variable>
		<func:result select="$data-rtf"/>
	</func:function>

	<func:function name="sw:restoreVEIPs">
		<xsl:param name="code" select="'ips'"/>
		<xsl:variable name="data-src-rtf">
			<xsl:call-template name="form:restore-list">
				<xsl:with-param name="code" select="$code"/>
				<xsl:with-param name="row-node-name" select="'ip'"/>
				<xsl:with-param name="def-values">
					<netmask><xsl:value-of select="$global:ip-default-netmask"/></netmask>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="data-rtf">
			<xsl:for-each select="exsl:node-set($data-src-rtf)/ip">
				<ip>
					<xsl:copy-of select="address"/>
					<netmask>
						<xsl:value-of select="sw:if(netmask=$def-ip-auto-vzcp and address!=$def-ip-auto-vzcp,$global:ip-default-netmask,netmask)"/>
					</netmask>
				</ip>
			</xsl:for-each>
		</xsl:variable>
		<func:result select="$data-rtf"/>
	</func:function>

	<func:function name="vzenv:restore-net-dns">
		<xsl:param name="code" select="'dns_ips'"/>
		<func:result>
			<xsl:call-template name="form:restore-list">
				<xsl:with-param name="code" select="$code"/>
				<xsl:with-param name="row-node-name" select="''"/>
			</xsl:call-template>
		</func:result>
	</func:function>

	<func:function name="vzenv:restore-net-search">
		<xsl:param name="code" select="'search_domains'"/>
		<func:result>
			<xsl:call-template name="form:restore-list">
				<xsl:with-param name="code" select="$code"/>
				<xsl:with-param name="row-node-name" select="''"/>
			</xsl:call-template>
		</func:result>
	</func:function>

	<func:function name="vzenv:restore-net-wins">
		<xsl:param name="code" select="'wins_servers'"/>
		<func:result>
			<xsl:call-template name="form:restore-list">
				<xsl:with-param name="code" select="$code"/>
				<xsl:with-param name="row-node-name" select="''"/>
			</xsl:call-template>
		</func:result>
	</func:function>
	
	<func:function name="sw:checkVEMACAddress">
		<xsl:param name="address"/>
		<xsl:param name="hn-platform"/>
		<xsl:param name="code"/>

		<xsl:choose>
			<xsl:when test="$address=''">
				<xsl:if test="error:put(sw:text('Please specify a MAC address .'),'',$code)"/>
			</xsl:when>
		</xsl:choose>
		<func:result/>
	</func:function>	
	
	<xsl:template name="vzenv:check-ip">
		<xsl:param name="ip"/>
		<xsl:param name="hn-platform"/>
		<xsl:param name="code"/>
		<xsl:param name="pool-enabled"/>
		<xsl:param name="error-ip-empty">
			<sw:text>
				Please specify an IP address.
			</sw:text>
		</xsl:param>
		<xsl:param name="error-ip-wrong">
			<sw:text>
				The IP address is invalid.
			</sw:text>
		</xsl:param>
		<xsl:param name="error-ip-no-pool">
			<sw:text>
				The IP addresses pool is not enabled, so please specify an IP address.
			</sw:text>
		</xsl:param>
		<xsl:param name="error-netmask-wrong">
			<sw:text>
				Please correct the subnet mask.
			</sw:text>
		</xsl:param>

		<xsl:variable name="address-code" select="concat($code,'_address')"/>
		
		<xsl:choose>
			<xsl:when test="$ip/address=''">
				<xsl:if test="$error-ip-empty!=''">
					<xsl:if test="error:put($error-ip-empty,'',$address-code)"/>
				</xsl:if>
			</xsl:when>
			<xsl:when test="$ip/address!=$def-ip-auto-vzcp">
				<xsl:if test="not(check:ip($ip/address))">
					<xsl:if test="error:put( $error-ip-wrong,'', $address-code )"/>
				</xsl:if>
			</xsl:when>
			<xsl:when test="not($pool-enabled)">
				<xsl:if test="error:put( $error-ip-no-pool,'', $address-code )"/>						
			</xsl:when>
		</xsl:choose>
		
		<xsl:if test="vt:is-platform-windows($hn-platform)">
			<xsl:if test="$ip/netmask!='' and not(check:ip($ip/netmask) or ($ip/netmask=$def-ip-auto-vzcp and $pool-enabled))">
				<xsl:if test="error:put( $error-netmask-wrong ,'',concat($code,'_netmask') )"/>
			</xsl:if>
		</xsl:if>
	
	</xsl:template>

	<func:function name="sw:checkVEIPs">
		<xsl:param name="data"/>
		<xsl:param name="hn-platform"/>
		<xsl:param name="code" select="'ips'"/>
		<xsl:param name="pool-enabled" select="false()"/>
		<xsl:param name="error-ip-empty">
			<sw:text>
				Please specify at least one IP address.
			</sw:text>
		</xsl:param>
		<xsl:param name="error-ip-wrong">
			<sw:text>
				The IP address is invalid.
			</sw:text>
		</xsl:param>
		<xsl:param name="error-ip-no-pool">
			<sw:text>
				The IP addresses pool is not enabled, so please specify an IP address.
			</sw:text>
		</xsl:param>
		<xsl:param name="error-netmask-wrong">
			<sw:text>
				Please correct the subnet mask.
			</sw:text>
		</xsl:param>

		<xsl:if test="vt:is-platform-windows($hn-platform)">
			<xsl:if test="count($data)=0">
				<xsl:if test="error:put($error-ip-empty,'',concat('address_',$code,'_1'))"/>
			</xsl:if>
		</xsl:if>
		<xsl:if test="count($data)">
			<xsl:for-each select="$data">
				<xsl:choose>
					<xsl:when test="address!=$def-ip-auto-vzcp">
						<xsl:if test="not(check:ip(address))">
							<xsl:if test="error:put( $error-ip-wrong,'', concat('address_',$code,'_',position()) )"/>
						</xsl:if>
					</xsl:when>
					<xsl:when test="not($pool-enabled)">
							<xsl:if test="error:put( $error-ip-no-pool,'', concat('address_',$code,'_',position()) )"/>						
					</xsl:when>
				</xsl:choose>
				<xsl:if test="netmask and netmask!='' and not(check:ip(netmask) or (netmask=$def-ip-auto-vzcp and $pool-enabled))">
					<xsl:if test="error:put( $error-netmask-wrong ,'',concat('netmask_',$code,'_',position()) )"/>
				</xsl:if>
			</xsl:for-each>
		</xsl:if>
		<func:result/>
	</func:function>

	<func:function name="vzenv:check-net-dns">
		<xsl:param name="data"/>
		<xsl:param name="code" select="'dns_ips'"/>
		
		<xsl:if test="false()">
			<xsl:if test="count($data)=0">
				<xsl:if test="error:put(sw:text('Please specify at least one DNS server IP address.'),'',concat('ip_',$code,'_1'))"/>
			</xsl:if>
		</xsl:if>
		<xsl:if test="count($data)">
			<xsl:for-each select="$data">
				<xsl:choose>
		      <xsl:when test="not(check:ip(.))">
						<xsl:if test="error:put(sw:text('Please correct the DNS server IP address.'),'',concat('ip_',$code,'_',position()))"/>
		      </xsl:when>
	      </xsl:choose>
			</xsl:for-each>
		</xsl:if>
		<func:result/>
	</func:function>

	<func:function name="vzenv:check-net-search">
		<xsl:param name="platform-ref"/>	
		<xsl:param name="data"/>
		<xsl:param name="code" select="'search_domains'"/>
		
		<xsl:if test="false()">
			<xsl:if test="count($data)=0">
				<xsl:if test="error:put(sw:text('Please specify at least one search domain.'),'',concat('dom_',$code,'_1'))"/>
			</xsl:if>
		</xsl:if>
		<xsl:if test="count($data)">
			<xsl:for-each select="$data">
				<xsl:choose>
		      <xsl:when test="not(check:search-domain($platform-ref,.))">
						<xsl:if test="error:put(sw:text('Please correct the search domain.'),'',concat('dom_',$code,'_',position())  )"/>
		      </xsl:when>
	      </xsl:choose>
			</xsl:for-each>
		</xsl:if>
		<func:result/>
	</func:function>
	
	<func:function name="vzenv:check-net-gateway">
		<xsl:param name="value"/>
		<xsl:param name="code" select="'gateway'"/>
			
		<xsl:choose>
			<xsl:when test="$value=''"/>		
			<xsl:when test="not(check:ip($value))">
				<xsl:if test="error:put(sw:text('Please correct the default gateway IP address.'),'',$code  )"/>
			</xsl:when>
		</xsl:choose>

		<func:result/>
	</func:function>	

	<func:function name="vzenv:check-net-wins">
		<xsl:param name="data"/>
		<xsl:param name="code" select="'wins_ips'"/>
		
		<xsl:if test="false()">
			<xsl:if test="count($data)=0">
				<xsl:if test="error:put(sw:text('Please specify at least one WINS server IP address.'),'',concat('ip_',$code,'_1'))"/>
			</xsl:if>
		</xsl:if>
		<xsl:if test="count($data)">
			<xsl:for-each select="$data">
				<xsl:choose>
		      <xsl:when test="not(check:ip(.))">
						<xsl:if test="error:put(sw:text('Please correct the WINS server IP address.'),'',concat('ip_',$code,'_',position())  )"/>
		      </xsl:when>
	      </xsl:choose>
			</xsl:for-each>
		</xsl:if>
		<func:result/>
	</func:function>

 <xsl:template name="vzenv:edit-ip">
		<xsl:param name="code"/>
		<xsl:param name="id"/>		
		<xsl:param name="hn-platform"/>
		<xsl:param name="label"/>		
		<xsl:param name="pool-enabled"/>
		<xsl:param name="is-bridged" select="false()"/>
		<xsl:param name="offset" select="''"/>
		<xsl:param name="label-as-text" select="false()"/>		
		<xsl:param name="required" select="true()"/>		
		<!--|-->
		<xsl:variable name="is-windows" select="vt:is-platform-windows($hn-platform)"/>
		<xsl:variable name="ve-net-use-netmask" select="$is-windows or $is-bridged"/>
		
		<xsl:variable name="label-rtf">
			<nobr>
				<xsl:value-of select="$label"/><xsl:if test="$ve-net-use-netmask">&#160;/&#160;<sw:text>Subnet Mask</sw:text></xsl:if>
			</nobr>
		</xsl:variable>
		
		<ui:row>
			<xsl:choose>
				<xsl:when test="$label-as-text">
					<ui:cell-text offset="{$offset}">
						<xsl:copy-of select="$label-rtf"/>
					</ui:cell-text>				
				</xsl:when>
				<xsl:otherwise>
					<ui:cell-label offset="{$offset}">
						<xsl:copy-of select="$label-rtf"/>
					</ui:cell-label>
				</xsl:otherwise>
			</xsl:choose>
			<ui:cell-input maxlength="15" id="{$code}_address" value="{$ip/address}" tip="ip_address" required="{boolean($required)}">
				<xsl:if test="$pool-enabled">
					<xsl:attribute name="tip">ip_address_auto</xsl:attribute>
				</xsl:if>
				<xsl:if test="$ve-net-use-netmask">
					<xsl:attribute name="width">15</xsl:attribute>
					<xsl:attribute name="close">false</xsl:attribute>
				</xsl:if>
				<xsl:if test="$ve-net-use-netmask">&#160;&#160;/&#160;&#160;</xsl:if>
			</ui:cell-input>
			<xsl:if test="$ve-net-use-netmask">
				<ui:cell-input open="false" tip="ip_netmask"  maxlength="15" width="15" id="{$code}_netmask" value="{$ip/netmask}"/>
			</xsl:if>
		</ui:row>

 </xsl:template>


 <func:function name="sw:showVEIPs">
		<xsl:param name="ips"/>
		<xsl:param name="hn-platform"/>
		<xsl:param name="code" select="'ips'"/>
		<xsl:param name="pool-enabled" select="false()"/>
		<xsl:param name="offset" select="''"/>
		<xsl:param name="force-required" select="false()"/>		
		<xsl:param name="is-bridged" select="false()"/>				
		<!--|-->
		<xsl:variable name="is-windows" select="vt:is-platform-windows($hn-platform)"/>
		<xsl:variable name="ve-net-use-netmask" select="$is-windows or $is-bridged"/>
		<xsl:variable name="required" select="$force-required or $is-windows"/>
		<func:result>
			<xsl:call-template name="form:show-list">
 				<xsl:with-param name="config">
					<code><xsl:value-of select="$code"/></code>
					<xsl:if test="$pool-enabled">
						<add-script>
							{
								if(total_<xsl:value-of select="$code"/>==1 ){
									first = document.getElementById(
										names_<xsl:value-of select="$code"/>[0]
										+ '_<xsl:value-of select="$code"/>_'
										+ last_<xsl:value-of select="$code"/>
									);
									if(first &amp;&amp; first.value==''){
										first.value = '<xsl:value-of select="$def-ip-auto-vzcp"/>';
										updateDel<xsl:value-of select="$code"/>(counter_<xsl:value-of select="$code"/>,first.value,true);
										return false;
									}
								}
							}
						</add-script>
					</xsl:if>
					<xsl:if test="$required">
						<required>true</required>
					</xsl:if>
					<add_label><sw:text>Add a new IP address.</sw:text></add_label>
					<remove_label><sw:text>Remove the IP address.</sw:text></remove_label>
					<xsl:for-each select="$ips/ip">
						<ui:row>
							<ui:cell-label offset="{$offset}">
		  					<nobr>
			  					<sw:text>IP Address</sw:text><xsl:if test="$ve-net-use-netmask">&#160;/&#160;<sw:text>Subnet Mask</sw:text></xsl:if>
			  				</nobr>
		  				</ui:cell-label>
		  				<ui:cell-input maxlength="15" id="address" value="{address}" tip="ip_address">
		  					<xsl:if test="$pool-enabled">
		  						<xsl:attribute name="tip">ip_address_auto</xsl:attribute>
		  					</xsl:if>
		  					<xsl:if test="$ve-net-use-netmask">
		  						<xsl:attribute name="width">15</xsl:attribute>
		  						<xsl:attribute name="close">false</xsl:attribute>
		  					</xsl:if>
		  					<xsl:if test="$ve-net-use-netmask">&#160;&#160;/&#160;&#160;</xsl:if>
		  				</ui:cell-input>
		  				<xsl:if test="$ve-net-use-netmask">
		  					<ui:cell-input open="false" tip="ip_netmask"  maxlength="15" width="15" id="netmask" value="{netmask}"/>
		  				</xsl:if>
						</ui:row>
					</xsl:for-each>
					<ui:new-row>
						<ui:cell-label offset="{$offset}">
	  					<nobr>
		  					<sw:text>IP Address</sw:text><xsl:if test="$ve-net-use-netmask">&#160;/&#160;<sw:text>Subnet Mask</sw:text></xsl:if>
		  				</nobr>
	  				</ui:cell-label>
	  				<ui:cell-input nowrap="1" maxlength="15" id="address" tip="ip_address">
	  					<xsl:if test="$pool-enabled">
	  						<xsl:attribute name="value"><xsl:value-of select="$def-ip-auto-vzcp"/></xsl:attribute>
	  					</xsl:if>
	  					<xsl:if test="$ve-net-use-netmask">
	  						<xsl:attribute name="width">15</xsl:attribute>
	  						<xsl:attribute name="close">false</xsl:attribute>
	  					</xsl:if>
	  					<xsl:if test="$ve-net-use-netmask">&#160;&#160;/&#160;&#160;</xsl:if>
	  				</ui:cell-input>
	  				<xsl:if test="$ve-net-use-netmask">
	  					<ui:cell-input open="false" maxlength="15" width="15" id="netmask" tip="ip_netmask">
	  						<xsl:if test="$pool-enabled">
	  							<xsl:attribute name="value"><xsl:value-of select="$def-ip-auto-vzcp"/></xsl:attribute>
	  						</xsl:if>
	  					</ui:cell-input>
	  				</xsl:if>
					</ui:new-row>
				</xsl:with-param>
			</xsl:call-template>
			<xsl:if test="$required or $pool-enabled">
				<ui:row offset="{$offset}">
					<ui:cell-label/>				
					<ui:cell>
						<ui:text-disabled>
							<xsl:variable name="note">
								<xsl:choose>
									<xsl:when test="$required and $pool-enabled">
										<sw:text>
											<xsl:with-param name="auto"><![CDATA[&lt;auto&gt;]]></xsl:with-param>
											Please enter at least one IP address, or leave  %{auto} for auto-allocation.
										</sw:text>
									</xsl:when>
									<xsl:when test="not($required) and $pool-enabled">
										<sw:text>
											<xsl:with-param name="auto"><![CDATA[&lt;auto&gt;]]></xsl:with-param>
											Leave  %{auto} for auto-allocation.
										</sw:text>
									</xsl:when>
									<xsl:when test="$required and not($pool-enabled)">
										<sw:text>
											Please enter at least one IP address.
										</sw:text>
									</xsl:when>
								</xsl:choose>
							</xsl:variable>
							<xsl:value-of select="$note" disable-output-escaping="yes"/>
						</ui:text-disabled>
					</ui:cell>
				</ui:row>
			</xsl:if>			
		</func:result>

 </func:function>

 <func:function name="vzenv:show-net-dns">
		<xsl:param name="ips"/>
		<xsl:param name="hn-platform"/>
		<xsl:param name="code" select="'dns_ips'"/>
		<xsl:param name="offset" select="''"/>
		<!--|-->
		<xsl:variable name="ve-net-use-netmask" select="vt:is-platform-windows($hn-platform)"/>
		<xsl:variable name="required" select="false()"/>
		<func:result>
			<xsl:if test="$required">
				<ui:row required="true">
					<ui:cell offset="{$offset}">
						<sw:text>DNS Server IP Addresses (please type at least one address)</sw:text>
					</ui:cell>
				</ui:row>
			</xsl:if>
			<xsl:call-template name="form:show-list">
 				<xsl:with-param name="config">
					<code><xsl:value-of select="$code"/></code>
					<xsl:if test="$required">
						<required>true</required>
					</xsl:if>
					<add_label><sw:text>Add a new DNS IP address.</sw:text></add_label>
					<remove_label><sw:text>Remove the DNS IP address.</sw:text></remove_label>
					<xsl:for-each select="$ips/ip">
						<ui:row>
							<ui:cell-label offset="{$offset}">
		  					<nobr><sw:text>DNS Server IP Address</sw:text></nobr>
		  				</ui:cell-label>
		  				<ui:cell-input id="ip" value="{.}">
		
		  				</ui:cell-input>
						</ui:row>
					</xsl:for-each>
					<ui:new-row>
						<ui:cell-label offset="{$offset}">
		  					<nobr><sw:text>DNS Server IP Address</sw:text></nobr>
		  			</ui:cell-label>
		  			<ui:cell-input  id="ip">
		  				
		  			</ui:cell-input>
					</ui:new-row>
				</xsl:with-param>
			</xsl:call-template>
		</func:result>

	</func:function>
	
	<func:function name="vzenv:custom-net-interfaces-selected">
		<func:result select="sw:param('iface_mode')='custom'" />
	</func:function>

	<func:function name="vzenv:restore-net-interfaces">
		<xsl:param name="hw-interfaces"/>
		<func:result>
			<xsl:if test="sw:param('iface_mode') = 'custom'">
				<xsl:for-each select="$hw-interfaces/interface">
					<xsl:sort select="name"/>
					<xsl:variable name="pos" select="position()"/>
					<xsl:choose>
						<xsl:when test="sw:param(concat('iface_',$pos)) = '1'">
						<interface>
							<name><xsl:value-of select="id"/></name>
						</interface>
						</xsl:when>
					<xsl:otherwise>
						<interface />
					</xsl:otherwise>
					</xsl:choose>
				</xsl:for-each>
			</xsl:if>
		</func:result>
	</func:function>

	<func:function name="vzenv:show-net-intefaces">
		<xsl:param name="hw-interfaces"/>
		<xsl:param name="vznet-interfaces"/>
		<xsl:param name="ve-interfaces"/>
		<!--|-->
		<func:result>
			<xsl:choose>
				<xsl:when test="$hw-interfaces/interface">
					<ui:row>
						<ui:cell-text colspan="2">
							<span class="inactive">
								<sw:text>Here you can replace the Container default network interface with a particular Hardware Node network interface.</sw:text>
							</span>
						</ui:cell-text>
					</ui:row>
					<!-- Default -->
					<ui:row>
						<ui:cell-radio id="iface_mode_default" name="iface_mode" value="default">
							<xsl:if test="not($ve-interfaces/interface)">
								<xsl:attribute name="checked">true</xsl:attribute>
							</xsl:if>
							<xsl:for-each select="$hw-interfaces/interface">
								<xsl:sort select="name"/>
								<ui:control-slave inverse="true">
									<xsl:value-of select="concat('iface_',position())"/>
								</ui:control-slave>
							</xsl:for-each>
		    	  </ui:cell-radio>
		    	  <ui:cell cell-width="100%">
		    	  	Use VE default network interfaces
		    	  </ui:cell>
					</ui:row>
					<xsl:if test="$vznet-interfaces/interface">
						<ui:row offset="2">
				    	<ui:cell cell-width="100%" colspan="2">
				    		<ul>
									<xsl:for-each select="$vznet-interfaces/interface">
										<xsl:sort select="name"/>
										<xsl:variable name="name" select="name"/>
							    	<li><xsl:value-of select="$name"/></li>
									</xsl:for-each>
								</ul>
							</ui:cell>
						</ui:row>
					</xsl:if>
					<!-- /Default -->
					<ui:row>
						<ui:cell-radio id="iface_mode_custom" name="iface_mode" value="custom">
							<xsl:if test="$ve-interfaces/interface">
								<xsl:attribute name="checked">true</xsl:attribute>
							</xsl:if>
							<xsl:for-each select="$hw-interfaces/interface">
								<xsl:sort select="name"/>
								<ui:control-slave>
									<xsl:value-of select="concat('iface_',position())"/>
								</ui:control-slave>
							</xsl:for-each>
		    	  </ui:cell-radio>
		    	  <ui:cell cell-width="100%">
		    	  	Use some of HW network interfaces
		    	  </ui:cell>
					</ui:row>
					<xsl:for-each select="$hw-interfaces/interface">
						<xsl:sort select="name"/>
						<xsl:variable name="name" select="name"/>
						<xsl:variable name="id" select="id"/>
						<ui:row offset="2">
							<ui:cell-check id="iface_{position()}">
								<xsl:if test="$ve-interfaces/interface[name=$id]">
									<xsl:attribute name="checked">true</xsl:attribute>
								</xsl:if>
			    	  </ui:cell-check>
			    	  <ui:cell cell-width="100%">
			    	  	<xsl:value-of select="$name"/>
			    	  </ui:cell>
						</ui:row>
					</xsl:for-each>
				</xsl:when>
				<xsl:otherwise>
					<ui:row>
						<ui:cell-text colspan="2">
							<sw:text>No network interfaces available on the HN.</sw:text>
						</ui:cell-text>
					</ui:row>
				</xsl:otherwise>
			</xsl:choose>
		</func:result>
	</func:function>

	<func:function name="vzenv:show-net-capabilites">
		<xsl:param name="voc-params" select="/"/>
		<xsl:param name="sel-params" select="/"/>
		<!--|-->
		<func:result>
			<xsl:for-each select="$voc-params/parameter">
				<xsl:variable name="param" select="."/>
				<ui:row>
					<ui:cell-check id="cap_{position()}">
						<xsl:if test="$sel-params/capability[id=$param/id and value='1']">
							<xsl:attribute name="checked">true</xsl:attribute>
						</xsl:if>
	    	  </ui:cell-check>
	    	  <ui:cell cell-width="100%">
	    	  	<xsl:value-of select="$param/short"/>
	    	  </ui:cell>
				</ui:row>
			</xsl:for-each>
		</func:result>
	</func:function>

	<func:function name="vzenv:review-net-capabilites">
		<xsl:param name="voc-params" select="/"/>
		<xsl:param name="sel-params" select="/"/>
		<!--|-->
		<func:result>
			<xsl:for-each select="$voc-params/parameter">
				<xsl:variable name="param" select="."/>
				<xsl:if test="$sel-params/capability[id=$param/id and value='1']">
					<ui:row>
		    	  <ui:cell-label>
		    	  	<xsl:value-of select="$param/short"/>
		    	  </ui:cell-label>
		    	  <ui:cell-value>
		    	  	<sw:text>Yes</sw:text>
		    	  </ui:cell-value>
					</ui:row>
				</xsl:if>
			</xsl:for-each>
		</func:result>
	</func:function>

 <func:function name="vzenv:show-net-search">
		<xsl:param name="doms"/>
		<xsl:param name="code" select="'search_domains'"/>
		<xsl:param name="offset" select="''"/>
		<!--|-->
		<xsl:variable name="required" select="false()"/>
		<func:result>
			<xsl:if test="$required">
				<ui:row required="true">
					<ui:cell offset="{$offset}">
						<sw:text>Search Domains (please type at least one domain)</sw:text>
					</ui:cell>
				</ui:row>
			</xsl:if>
			<xsl:call-template name="form:show-list">
 				<xsl:with-param name="config">
					<code><xsl:value-of select="$code"/></code>
					<xsl:if test="$required">
						<required>true</required>
					</xsl:if>
					<add_label><sw:text>Add a new search domain.</sw:text></add_label>
					<remove_label><sw:text>Remove the search domain.</sw:text></remove_label>
					<xsl:for-each select="$doms/dom">
						<ui:row>
							<ui:cell-label offset="{$offset}">
		  					<nobr><sw:text>Search Domain</sw:text></nobr>
		  				</ui:cell-label>
		  				<ui:cell-input maxlength="255" id="dom" value="{.}"/>
						</ui:row>
					</xsl:for-each>
					<ui:new-row>
						<ui:cell-label offset="{$offset}">
		  					<nobr><sw:text>Search Domain</sw:text></nobr>
		  			</ui:cell-label>
		  			<ui:cell-input maxlength="255" id="dom"/>
					</ui:new-row>
				</xsl:with-param>
			</xsl:call-template>
		</func:result>
	</func:function>
	
	<func:function name="vzenv:show-net-gateway">
		<xsl:param name="value"/>
		<xsl:param name="code" select="'gateway'"/>
		<xsl:param name="offset" select="''"/>
		<!--|-->
		<func:result>
			<ui:row>
				<ui:cell-label offset="{$offset}">
					<nobr><sw:text>Default Gateway	</sw:text></nobr>
				</ui:cell-label>
				<ui:cell-input maxlength="255" id="{$code}" value="{$value}"/>
			</ui:row>
		</func:result>
	</func:function>	

 <func:function name="vzenv:show-net-wins">
		<xsl:param name="ips"/>
		<xsl:param name="code" select="'wins_servers'"/>
		<xsl:param name="offset" select="''"/>
		<!--|-->
		<xsl:variable name="required" select="false()"/>
		<func:result>
			<xsl:if test="$required">
				<ui:row required="true">
					<ui:cell offset="{$offset}">
						<sw:text>WINS Server IP Address (please type at least one address)</sw:text>
					</ui:cell>
				</ui:row>
			</xsl:if>
			<xsl:call-template name="form:show-list">
 				<xsl:with-param name="config">
					<code><xsl:value-of select="$code"/></code>
					<xsl:if test="$required">
						<required>true</required>
					</xsl:if>
					<add_label><sw:text>Add a new WINS server.</sw:text></add_label>
					<remove_label><sw:text>Remove the WINS server IP address.</sw:text></remove_label>
					<xsl:for-each select="$ips/ip">
						<ui:row>
							<ui:cell-label offset="{$offset}">
		  					<nobr><sw:text>WINS Server IP Address</sw:text></nobr>
		  				</ui:cell-label>
		  				<ui:cell-input maxlength="255" id="ip" value="{.}"/>
						</ui:row>
					</xsl:for-each>
					<ui:new-row>
						<ui:cell-label offset="{$offset}">
		  					<nobr><sw:text>WINS Server IP Address</sw:text></nobr>
		  			</ui:cell-label>
		  			<ui:cell-input maxlength="255" id="ip"/>
					</ui:new-row>
				</xsl:with-param>
			</xsl:call-template>
			<ui:row>
				<ui:cell-text>
					<br/><img src="/{$theme}/icons/alert_yellow.gif" width="16" height="16"/><br/>
				</ui:cell-text>
				<ui:cell-text>
					<sw:text>
					<br/>Please note that it is important to specify the data in this section correctly, <br/>as specifying wrong IP addresses may severely affect the operation of the Container.
					<br/>Before making changes, please ensure that the IP addresses are valid and reachable.<br/>
					</sw:text>
				</ui:cell-text>
			</ui:row>
		</func:result>
	</func:function>

	
 	<func:function name="vzenv:get-hostname-lenght">
 		<xsl:param name="platform-ref"/>
 		<func:result select="voc:get-pattern($platform-ref, 'pattern.hostname')/max"/>
 	</func:function>

	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>