<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw func env vzenv"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
  xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
  xmlns:func	="http://exslt.org/functions"
  xmlns:vzenv   ="http://www.swsoft.com/xsl/cp/vzenv"
  xmlns:env   ="http://www.swsoft.com/xsl/cp/env"
  xmlns:redirect	="http://www.swsoft.com/xsl/cp/redirect"
  xmlns:vt    ="http://www.swsoft.com/xsl/cp/vt"
>
  <sw:include href="/lib/vt/env-core.xsl"/>	
  <sw:include href="/lib/vt/core.xsl"/>
  <sw:include href="/lib/vz/vzhn-redirects.xsl"/>	

	<!-- return ui control for show offline management selector 
				mode=predefined , render control for case predefined offline services
				any other: , render control for case offline service get from hnode
	-->
	<func:function name="vzenv:show-offline-selector">
		<xsl:param name="form" select="/.."/>
		<xsl:param name="mode" select="''"/>
		<xsl:param name="row-offset" select="0"/>
		<xsl:param name="warning-row" select="''"/>
		
		<xsl:variable name="all-offline-service-rtf">
			<xsl:choose>
				<xsl:when test="$mode='predefined'">
					<xsl:copy-of select="$form/def/all_offline_service/service[vt:compare-platforms($form/platform,@platform) or not(@platform)]"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="$form/def/all_offline_service/service"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="all-offline-service" select="exsl:node-set($all-offline-service-rtf)"/>
		<!--|-->
		<func:result>
			<!-- Offline management -->
			<ui:rows  title="{sw:text('Offline Management')}" id="show_offline" status-def="1"
				status="{sw:if($warning-row!='','1',$form/gen/show_offline)}"
				closed-text="{sw:text('Click to show the offline management settings')}" separate-tables="true"
			>
				<xsl:if test="$warning-row!=''">
					<xsl:copy-of select="$warning-row"/>
				</xsl:if>
			
				<xsl:variable name="disable-checkbox-rtf">
					<xsl:for-each select="$all-offline-service/service">
						<ui:control-slave inverse="true">
							<xsl:value-of select="concat('offline_service_',string(id))"/>
						</ui:control-slave>
					</xsl:for-each>
				</xsl:variable>
				<xsl:variable name="disable-checkbox"  select="exsl:node-set($disable-checkbox-rtf)"/>

				<xsl:variable name="enable-checkbox-rtf">
					<xsl:for-each select="$all-offline-service/service">
						<ui:control-slave>
							<xsl:value-of select="concat('offline_service_',string(id))"/>
						</ui:control-slave>
					</xsl:for-each>
				</xsl:variable>
				<xsl:variable name="enable-checkbox"  select="exsl:node-set($enable-checkbox-rtf)"/>

				<!-- disable service -->
				<ui:row offset="1">
					<ui:cell-radio name="offline_type" id="offline_type_disable" value="disable"
						 close="false" colspan="2" 
					>
					<xsl:if test="$form/gen/offline_type = 'disable'">
						<xsl:attribute name="checked">true</xsl:attribute>
					</xsl:if>
					<xsl:copy-of select="$disable-checkbox"/>
					</ui:cell-radio>
    			<ui:cell open="false">
						<sw:text>Disable Container offline management</sw:text>
					</ui:cell>
				</ui:row>
				<!-- /disable service -->

				<!-- default service -->
				<ui:row offset="1">
					<ui:cell-radio name="offline_type"  id="offline_type_default" value="default"  close="false" colspan="2">
		    		<xsl:if test="$form/gen/offline_type = 'default'">
    		  		<xsl:attribute name="checked">true</xsl:attribute>
	        	</xsl:if>
  	      	<xsl:copy-of select="$disable-checkbox"/>
					</ui:cell-radio>
    			<ui:cell open="false">
    				<xsl:choose>
    					<xsl:when test="$mode = 'predefined'">
								<sw:text>Use the predefined settings for the selected platform</sw:text>
							</xsl:when>
    					<xsl:otherwise>
								<sw:text>Use the actual settings of the Hardware Node</sw:text>
							</xsl:otherwise>
						</xsl:choose>
					</ui:cell>
				</ui:row>
				<ui:row>
					<xsl:variable name="def-services" select="$all-offline-service/service[default = 1 or $mode = 'predefined']"/>
					<ui:cell offset="0">
						<ul style="padding:0;margin-top:0;margin-bottom:0;margin-left:30px">
							<span class="inactive">
                <xsl:choose>
                  <xsl:when test="$mode = 'predefined'">
                    <sw:text>
                      The Container offline management will work according to the predefined configuration.<br/> Currently the predefined configuration is the following:<br/>
                    </sw:text>
                  </xsl:when>
                  <xsl:otherwise>
                    <sw:text>
                      The Container offline management will work according to the HN configuration.<br/> Currently the HN has the following offine management configuration:<br/>
                    </sw:text>
                  </xsl:otherwise>
                </xsl:choose>								
							</span>
							<xsl:choose>			
								<xsl:when test="$def-services">				
									<xsl:for-each select="$def-services">
										<li style="padding:3px"><span class="inactive"><xsl:value-of select="string(id)"/>&#160;
											<sw:text>
										    <xsl:with-param name="port" select="port"/>
										    (port %{port})
						          </sw:text>
						         </span>
										</li>
									</xsl:for-each>
								</xsl:when>
								<xsl:otherwise>
									<span><sw:text>No default offline services have been specified yet.</sw:text></span>
								</xsl:otherwise>
							</xsl:choose>
						</ul>
					</ui:cell>
				</ui:row>
				<!-- /default service -->

				<!-- custom service -->
				<ui:row offset="1">
					<ui:cell-radio name="offline_type"  id="offline_type_custom" value="custom"  close="false" colspan="2">
						<xsl:if test="$form/gen/offline_type = 'custom'">
							<xsl:attribute name="checked">true</xsl:attribute>
						</xsl:if>
						<xsl:copy-of select="$enable-checkbox"/>
					</ui:cell-radio>
					<ui:cell open="false">
						<sw:text>Configure the Container offline management manually</sw:text>
					</ui:cell>
				</ui:row>
				<ui:row>
					<ui:cell colspan="2" offset="2">
						<span class="inactive">
							<sw:text>
								Select the services you want to be available for this Container offline management. 
							</sw:text>
						</span>
					</ui:cell>
				</ui:row>
				<xsl:for-each select="$all-offline-service/service">
					<ui:row>
						<ui:cell-check close="false" offset="2" name="selected_offline_service" id="offline_service_{string(id)}" value="{string(id)}">
							<xsl:if test="$form/gen/selected_offline_service/value = string(id)">
								<xsl:attribute name="checked">true</xsl:attribute>
							</xsl:if>
						</ui:cell-check>
						<ui:cell open="false" cell-width="100%">
							<xsl:value-of select="string(id)"/>&#160;
									<sw:text>
								    <xsl:with-param name="port" select="port"/>
								    (port %{port})
				          </sw:text>
						</ui:cell>
					</ui:row>
				</xsl:for-each>
				<!-- /custom service -->                
			</ui:rows>
		</func:result>
	</func:function>

	<func:function name="vzenv:ve-offline-status">
    <xsl:param name="service" select="''"/>
    <xsl:param name="eid"/>  
    <!-- assumed that ALL services redirect to VPS1 -->
 		<xsl:variable name="ve-config"							select="env:get-env($eid,true())/env"/> 
		<xsl:variable name="service-global-present" select="redirect:load($ve-config/parent_eid,$service)/service"/>
		<xsl:variable name="offline-management" 		select="number($ve-config/virtual_config/offline_management)"/>
		<xsl:variable name="offline-service" 				select="$ve-config/virtual_config/offline_service"/>
		<xsl:variable name="offline-service-not-present"	select="not($ve-config/virtual_config/offline_service)"/>		
		<xsl:variable name="service-local-present"	select="sw:if($offline-service = $service,1,0)"/>

		<!-- service must be present on virtuozzo AND 
					offline managemnt must be on for VE AND
				 (ve must hav "service" in list of offline_service)
				 		or
				 (ve has NO  offline_service list AND default "service")
		-->
		<xsl:variable name="env-info" select="env:eid2info($eid)"/>
		<xsl:variable name="service-present" select="
				$service-global-present 
					and 
				$offline-management
					and
				(($offline-service != '') and ($service-local-present = 1)
					or 
				($offline-service-not-present and ($service-global-present/default = '1')))
		"/>
		<func:result>
				<service-present>
					<xsl:value-of	select="sw:if($service-present = 'true',1,0)"/>
				</service-present>
				<offline-management>
					<xsl:value-of select="$offline-management"/>
				</offline-management>
				<service-global-present>
					<xsl:value-of select="sw:if(not(string($service-global-present)=''),1,0)"/> 
				</service-global-present>
				<ip-address>
					<xsl:choose>
						<xsl:when test="not($env-info/windows)">
							<!-- 
								Virtuozzo 4.0 Linux does not provide offline services for bridged IPs.
								Get IPs only from host-routed network devices
							-->
							<xsl:variable name="hostrouted-ips"
								select="$ve-config/virtual_config/net_device[host_routed]/ip_address/ip"/>
							<xsl:value-of select="$hostrouted-ips[1]"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$ve-config/virtual_config/address/ip[1]"/>
						</xsl:otherwise>
					</xsl:choose>
				</ip-address>
				<config-present>
					<xsl:value-of select="sw:if($ve-config/status/state = $env-state/unexist or $ve-config/status/state = $env-state/unknown,0,1)"/>
				</config-present>
		</func:result>
	</func:function>


	<!-- return type of offline management 
		input: offline-management 1 or 0 for VE or for sample
		offline-service: list of services defined  in object config
	-->
	<func:function name="vzenv:get-offline-type">
    <xsl:param name="offline-management" select="''"/>
    <xsl:param name="offline-service" select="''"/>  
    <func:result>
			<xsl:choose>
				<xsl:when test="$offline-management != 1">
					<xsl:value-of select="'disable'"/>
				</xsl:when>
				<xsl:when test="($offline-management = 1) and not($offline-service)">
					<xsl:value-of select="'default'"/>
				</xsl:when>
				<xsl:when test="($offline-management = 1) and $offline-service">
					<xsl:value-of select="'custom'"/>
				</xsl:when>							
				<xsl:otherwise>
					<!-- fallback -->
					<xsl:value-of select="'disable'"/>
				</xsl:otherwise>
			</xsl:choose>
		</func:result>
	</func:function>


	<!-- return type of predefined offline servfice	-->
	<func:function name="vzenv:get-predefined-redirect">
		<func:result select="$config/vzcpcon/offline-service/service"/>
	</func:function>


	<func:function name="vzenv:vzpp-service-allowed">
		<xsl:param name="eid"/>
		<!-- Check offline service configuration -->
		<xsl:variable name="env-info" select="env:eid2info($eid)"/>
		<xsl:variable name="service" select="'vzpp'"/>
		<xsl:variable name="service-status" select="exsl:node-set(vzenv:ve-offline-status($service,$eid))"/>
		<xsl:variable name="my-ip" select="sw:if($env-info/windows, $request/http_request/env/parameter[name = 'LOCAL_ADDR']/value, $request/http_request/env/parameter[name = 'SERVER_ADDR']/value)"/>
		<xsl:variable name="service-login-result-rtf">
			<xsl:choose>
				<xsl:when test="$service-status/service-global-present = 0">
					<!-- no offline service on HW node -->
					<xsl:value-of select="1"/>
				</xsl:when>
				<xsl:when test="$service-status/service-present = 0">
					<!-- offline service disable for VE -->
					<xsl:value-of select="2"/>
				</xsl:when>
				<xsl:when test="not($service-status/ip-address != '')">
					<!-- VE no has IP address -->
					<xsl:value-of select="3"/>  
				</xsl:when>
				<xsl:when test="$service-status/ip-address = $my-ip">
					<!-- special case - login into service  by current VE address -->
					<xsl:value-of select="4"/>
				</xsl:when>
				<xsl:otherwise>
					<!-- login allowed -->
					<xsl:value-of select="0"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<func:result select="not(boolean(number($service-login-result-rtf)))"/>
	</func:function>

 
</xsl:stylesheet>
