<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func vzenv math vzapackagem tem vz"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:math="http://exslt.org/math"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:error="http://www.swsoft.com/xsl/cp/error"
  xmlns:vt		="http://www.swsoft.com/xsl/cp/vt"
  xmlns:vzenv="http://www.swsoft.com/xsl/cp/vzenv"
  xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
  xmlns:func="http://exslt.org/functions"
  xmlns:tem="http://www.swsoft.com/xsl/cp/tem"
  xmlns:vzapackagem="http://www.swsoft.com/xsl/cp/vzapackagem"
  xmlns:vz="http://www.swsoft.com/xsl/cp/vz"
  xmlns:set="http://exslt.org/sets" 
  xmlns:env="http://www.swsoft.com/xsl/cp/env"
  xmlns:voc="http://www.swsoft.com/xsl/cp/voc"
	xmlns:xsi		="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:vzat	="http://www.swsoft.com/webservices/vza/4.0.0/vzatypes"  
>
  
  <sw:include href="core.xsl"/>
  <sw:include href="/lib/vt/core.xsl"/>
  <sw:include href="/lib/vt/env-core.xsl"/>
  <sw:include href="/lib/vz/apps.xsl"/>
  
  <!--
  	Requires:
  		<sw:include href="/lib/vza/tem.xsl"/>
  		<sw:include href="/lib/vza/vzapackagem.xsl"/>
  -->
	<func:function name="vzenv:list-oses">
		<xsl:param name="hn-platform"/>
		<xsl:param name="hw-id" select="''"/>
		
		
		<xsl:variable name="platform-ref" select="env:make-platform-ref($hw-id, $hn-platform)"/>
		
		<xsl:variable name="oses" select="vz:list-templates-for-select($hw-id, $platform-ref, 'os')"/>

				
		<xsl:variable name="old-oses" select="$oses[not(sw:is-ez-package(name))]"/>		
		<xsl:variable name="new-oses" select="$oses[sw:is-ez-package(name)]"/>
				
		<xsl:variable name="res">
			<xsl:choose>
				<xsl:when test="$oses[self::error]">			
					<package>
						<name><sw:text>Cannot list templates.</sw:text></name>
						<version>
							<mark><sw:text>n/a</sw:text></mark>
						</version>
						<disabled/>
					</package>
				</xsl:when>
				<xsl:otherwise>
					
					<!-- List standard templates -->
					<xsl:if test="$old-oses">
						<package>
							<name><sw:text>-- Standard --</sw:text></name>
							<version>
								<mark></mark>
								<cached>1</cached>
							</version>
							<disabled/>
						</package>	
					</xsl:if>
					
					<xsl:for-each select="set:distinct($old-oses/name)">
						<xsl:sort select="."/>
						
						<xsl:variable name="name" select="string(.)"/>
						<xsl:variable name="versions" select="$old-oses[string(name)=$name]"/>
						<package>
							<xsl:choose>
								<xsl:when test="$versions/cached='1'">
									<name><xsl:copy-of select="$name"/></name>		
								</xsl:when>
								<xsl:otherwise>									
									<name><xsl:value-of select="$name"/>(<sw:text>uncached</sw:text>)</name>
									<disabled/>
								</xsl:otherwise>
							</xsl:choose>
							
							<xsl:for-each select="$versions">
								<version>
									<mark><xsl:value-of select="version"/></mark>
									<xsl:copy-of select="cached"/>
								</version>
							</xsl:for-each>
						</package>
					</xsl:for-each>
					
					<!-- List EZ templates -->
					<xsl:if test="$new-oses">
						<package>
							<name><sw:text>-- EZ --</sw:text></name>
							<version>
								<mark></mark>
								<cached>1</cached>
							</version>
							<disabled/>
						</package>	
					</xsl:if>
					<xsl:for-each select="$new-oses">
						<xsl:sort select="name"/>
						<package>
							<xsl:choose>
								<xsl:when test="cached='1'">
									<xsl:copy-of select="name"/>
								</xsl:when>
								<xsl:otherwise>
									<name><xsl:value-of select="name"/>(<sw:text>uncached</sw:text>)</name>
									<disabled/>
								</xsl:otherwise>
							</xsl:choose>
							<version>
								<mark>00000001</mark>
								<xsl:copy-of select="cached"/>
							</version>
						</package>	
					</xsl:for-each>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<func:result select="exsl:node-set($res)/package"/>
	</func:function>
  
 <func:function name="vzenv:restore-os">
		<func:result>
			<os_template>
				<name><xsl:value-of select="sw:param('os_template_name')"/></name>
				<version><xsl:value-of select="sw:param('os_template_ver')"/></version>
			</os_template>
		</func:result>
 </func:function>  
 
 <func:function name="vzenv:check-os">
		<xsl:param name="os"/>
    <xsl:if test="not($os/name!='')">
			<xsl:if test="error:put(sw:text('Please select an operating system.'),'','os_template_name')"/>
    </xsl:if>
    <xsl:if test="not(sw:is-ez-package($os/name)) and not($os/version!='')">
			<xsl:if test="error:put(sw:text('Please select an OS version.'),'','os_template_ver')"/>
    </xsl:if>
		<func:result/>
	</func:function>
 
	<func:function name="vzenv:show-os">
	 	<xsl:param name="config"/><!--|
	 		platform
	 		os_template
	 		os_templates
	 		show_empty_var
	 		init_on_start
	 		empty_os_text
	 		empty_ver_text
	 		change-os-js 
	 		required
	 	|-->
	 	
		<xsl:variable name="os" select="$config/os_template"/>
		<xsl:variable name="os_templates"  select="$config/os_templates/package"/>
		<xsl:variable name="show_empty_ver" select="$config/show_empty_ver"/>
		<xsl:variable name="init_on_start" select="$config/init_on_start"/>
		<xsl:variable name="empty_os_text" select="$config/empty_os_text"/>
		<xsl:variable name="change-os-js" select="$config/change-os-js"/>
		<xsl:variable name="platform-linux" select="vt:is-platform-linux($config/platform)"/>

		<func:result>
			<ui:cell-label><xsl:value-of select="sw:text('OS Template/Version')"/></ui:cell-label>
			<ui:cell-list id="os_template_name" close="false" value="{$os/name}">
				<xsl:attribute name="onchange">
					updateOS('');var wr_os=document.getElementById('os_template_ver');
					if (wr_os) {if (wr_os.selectedIndex &lt; 0) {wr_os.selectedIndex=0;}}
					<xsl:value-of select="$change-os-js"/>
				</xsl:attribute>
				<xsl:if test="$config/required">
					<xsl:attribute name="required">true</xsl:attribute>
				</xsl:if>
				<xsl:if test="$empty_os_text">
					<ui:list-item id="" title="{$empty_os_text}"/>
				</xsl:if>
				<xsl:for-each select="$os_templates">
					<xsl:variable name="mark" select="math:max(version/mark)"/>
					<ui:list-item title="{sw:app-id2title(name)}">
						<xsl:choose>
							<xsl:when test="disabled">
								<xsl:attribute name="disabled">true</xsl:attribute>
								<xsl:attribute name="id"></xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="id"><xsl:value-of select="name"/></xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>					
					</ui:list-item>
				</xsl:for-each>				
			</ui:cell-list>		
			<ui:cell open="false" close="false">&#160;/&#160;</ui:cell>
			<!--|-->
			<ui:cell-list id="os_template_ver" open="false">
				<xsl:copy-of select="sw:getOSJS(
					$os_templates,
					$show_empty_ver,
					$init_on_start,
					$os/version,
					sw:if($config/empty_os_ver,$config/empty_os_ver,sw:text('Any'))
				)"/>
			</ui:cell-list>
			<!--|-->
		</func:result>
	</func:function>
	
	<func:function name="sw:getOSJS">
		<xsl:param name="os_templates"/>
		<xsl:param name="show_empty_ver"/>
		<xsl:param name="init_on_start" select="true()"/>
		<xsl:param name="init_version" select="''"/>
		<xsl:param name="empty_os_ver"/>
		
		<func:result>
			<script type="text/javascript">	
				<![CDATA[
				function updateOS(req_version){
					os_view=document.getElementById('os_template_name');
					os_version=document.getElementById('os_template_ver');
				]]>
					os_version.options.length=0;
					os_version.options.selectedIndex=-1;
					//
					if(os_view.options[ os_view.selectedIndex ].value==''){
						o = new Option('<xsl:value-of select="sw:html-escape($empty_os_ver,'escape-quote')"/>','');
						os_version.options[0]=o;
						os_version.options[0].selected = true;
					}
					<xsl:for-each select="$os_templates">
						if(os_view.value=='<xsl:value-of select="name"/>'){
							<xsl:for-each select="version[cached=1]">
								<xsl:sort select="mark" data-type="number"/>
								<xsl:choose>
									<xsl:when test="$show_empty_ver">
										o = new Option('<xsl:value-of select="mark"/>','<xsl:value-of select="mark"/>');
									</xsl:when>
									<xsl:when test="not($show_empty_ver) and (position()=last())">
										o = new Option('<xsl:value-of select="mark"/>&#160;<xsl:value-of select="sw:html-escape(sw:text('(latest)'),'escape-quote')"/>','<xsl:value-of select="mark"/>');
										if(req_version.length==0){
											o.selected=true;
										}
									</xsl:when>
									<xsl:otherwise>
										o = new Option('<xsl:value-of select="mark"/>','<xsl:value-of select="mark"/>');
									</xsl:otherwise>
								</xsl:choose>								
								os_version.options[<xsl:value-of select="position()-1"/>]=o;								
								<![CDATA[			
									if(req_version!='' && req_version==o.value){
										os_version.selectedIndex = os_version.options.length-1;
									}																							
								]]>					
							</xsl:for-each>
						}
					</xsl:for-each>
					<xsl:if test="$show_empty_ver">
						if(os_view.value!=''){
							a = new Option('<xsl:value-of select="sw:html-escape(sw:text('latest'), 'escape-quote')"/>','');							
							os_version.options[os_version.options.length]=a;
							if(req_version.length==0){
								os_version.selectedIndex = os_version.options.length-1;
							}
						}
					</xsl:if>
					if(os_view.options[ os_view.selectedIndex ].value.charAt(0)=='.'){
						os_version.disabled = true;	
					}else{	
						os_version.disabled = false;	
					}
				<![CDATA[				
				}
				]]>
				<xsl:if test="$init_on_start">
					updateOS('<xsl:value-of select="$init_version"/>');
				</xsl:if>
				var wr_os=document.getElementById('os_template_ver');
				if (wr_os) {
					if (wr_os.selectedIndex &lt; 0) {wr_os.selectedIndex=0;}
				}
			</script> 
		</func:result>
		
	</func:function>
	
	
	<func:function name="vzenv:getConfigJS">
		<xsl:param name="data"/>
		<xsl:param name="configs"/>
		<xsl:param name="os_templates"/>
		<xsl:param name="skip_os_preselect"/>
		<xsl:param name="config_can_empty"/>
		<xsl:param name="os-can-empty"/>
		<xsl:param name="ip-autoallocation-on" select="false()"/>
		
		<xsl:variable name="show-warn" select="$data/hn/windows"/>
		<xsl:variable name="inc-conf" select="sw:if($config_can_empty,1,0)"/>
		<xsl:variable name="slm-modes" select="vz:get-slm-modes()"/>
		<func:result>
			<script type="text/javascript">	
				var platform_is_linux = "<xsl:value-of select="vt:is-platform-linux($data/hn/platform)"/>";
				var configs=new Array();
				// <xsl:value-of select="$config_can_empty"/>
				<xsl:if test="$config_can_empty">
					// Empty Config
					configs[0]=new Array(
						'true',       // 0 on boot yes/no
						'true',       // 1 offline management yes/no
						0,            // 2 os name index
						0,            // 3 os version 
						0,            // 4 show os alert  yes/no
						'',           // 5 sample name
						new Array(),  // 6 offline services array
						'',           // 7 platform
						0,            	// 8 slm mode position: 0 ubc, 1 slm , 2 all
						'true'        // 9 sample and IP manager provides  IP auto allocation.
					);
				</xsl:if>
				<xsl:for-each select="$configs">					
					<xsl:sort select="name"/>
					<xsl:variable name="config" select="env_config"/>
					<xsl:variable name="os1" select="env_config/os_template"/>
					<xsl:variable name="os2">
						<xsl:choose>
							<!-- get os-template from Sample Config -->
							<xsl:when test="$os1/name!=''">								
								<xsl:copy-of select="$os1/*"/>
							</xsl:when>
							<!-- get os-template from VZ Config -->
							<xsl:otherwise>
								<name>
									<xsl:copy-of select="$data/def/os_template"/>
								</name>							
							</xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
					<xsl:variable name="os" select="exsl:node-set($os2)"/>
					<xsl:variable name="vers_index">
						<xsl:choose>
							<xsl:when test="$os/version!=''">
								<xsl:for-each select="$os_templates[name=$os/name]/version">
									<xsl:sort select="mark" data-type="number"/>
									<xsl:if test="mark=$os/version">
										<xsl:value-of select="string(mark)"/>
									</xsl:if>
								</xsl:for-each>
							</xsl:when>
							<!-- OS version contains "Latest" last item -->
							<xsl:when test="$os-can-empty">
								<xsl:value-of select="''"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:for-each select="$os_templates[name=$os/name]/version">
									<xsl:sort select="mark" data-type="number"/>
									<xsl:if test="position()=last()">
										<xsl:value-of select="string(mark)"/>
									</xsl:if>
								</xsl:for-each>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
					<xsl:variable name="os_index">
						<xsl:choose>
							<xsl:when test="vz:is-old-win-os-name($os/name, env:make-platform-ref($data/hn/eid, $data/hn/platform))">
								<xsl:for-each select="$os_templates">
									<xsl:if test="starts-with(name, 'win') and not(preceding-sibling::*[starts-with(name, 'win')])">
										<xsl:value-of select="position()"/>
									</xsl:if>
								</xsl:for-each>
							</xsl:when>
							<xsl:otherwise>
								<xsl:for-each select="$os_templates">
									<xsl:if test="name=$os/name">
										<xsl:value-of select="position()"/>
									</xsl:if>
								</xsl:for-each>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
					<xsl:variable name="ips-ok" select="
						env_config/net_device[
							(contains(@xsi:type,':net_vethType') and host_routed and $ip-autoallocation-on)
							or
							(contains(@xsi:type,':net_vethType') and not(host_routed) and (dhcp or $ip-autoallocation-on))
						]
					"/>
					
					// <xsl:value-of select="name"/>
					configs[<xsl:value-of select="position() - 1 + $inc-conf"/>]=new Array(
						<xsl:value-of select="sw:if(env_config/on_boot='1','true','false')"/>,
						<xsl:value-of select="sw:if(env_config/offline_management='1','true','false')"/>,
						<xsl:value-of select="sw:if($os_index!='',$os_index - sw:if($os-can-empty,0,1),sw:if($os/name!='','-1','0'))"/>,
						'<xsl:value-of select="sw:if($vers_index!='',$vers_index,'')"/>',
						<xsl:choose>
							<xsl:when test="$os_index='' and $os/name!='' and $os/name!='w2k3'">
									'<sw:text>
										<xsl:with-param name="os_name" select="sw:app-id2title($os/name,false(),false(),true())"/>
										Warning! The selected Container sample specifies an OS template, %{os_name}, which is not installed on the Hardware Node. Please select another OS template.
									</sw:text>',
							</xsl:when>
							<xsl:otherwise>
								0,
							</xsl:otherwise>
						</xsl:choose>
						'<xsl:value-of select="name"/>',
						'',
						'',
						<xsl:choose>
							<xsl:when test="vt:is-platform-linux($data/hn/platform)">
								<xsl:variable name="slm-selected" select="sw:if($slm-modes/id = $config/slm_mode,$config/slm_mode,'ubc')"/>
								<xsl:value-of select="$slm-modes[id = $slm-selected]/pos"/>
							</xsl:when>
							<xsl:otherwise>
							-1
							</xsl:otherwise>
						</xsl:choose>,
						'<xsl:value-of select="boolean($ips-ok)"/>'
					);
					<xsl:if test="not(env_config/offline_service = '')">
						configs[<xsl:value-of select="position() - 1 + $inc-conf"/>][6] = new Array (
							<xsl:for-each select="env_config/offline_service">'<xsl:value-of select="."/>'<xsl:if test="position()!=last()">,</xsl:if></xsl:for-each>
						);
					</xsl:if>
					configs[<xsl:value-of select="position() - 1 + $inc-conf"/>][7] = platform_is_linux;
				</xsl:for-each>				
				<![CDATA[
				function changedConfig(check_os_warn){
					cv = document.getElementById('config');
					ca =  configs[cv.selectedIndex];
					if(!ca || !ca[5]){
						return;
					}
					if ( document.getElementById('sample_ip_alert') ) {showObjExt('sample_ip_alert',ca[9]!='true');}
					document.getElementById('start_after_boot').checked = ca[0];
					if (ca[7]) {
						if (ca[6].length > 0 && ca[1] && document.defaultForm.selected_offline_service) {
							// custom offline services
							document.getElementById('offline_type_custom').checked = 1;
							for(i=0; i<document.defaultForm.selected_offline_service.length; i++) {
								document.defaultForm.selected_offline_service[i].disabled=0;
								document.defaultForm.selected_offline_service[i].checked=0;
							}
							for(i=0; i<ca[6].length; i++) {
								document.getElementById('offline_service_' + ca[6][i]).checked = 1;
							}
						} else {
							if (document.defaultForm.selected_offline_service) {
								for(i=0; i<document.defaultForm.selected_offline_service.length; i++) {
									document.defaultForm.selected_offline_service[i].disabled=1;
									document.defaultForm.selected_offline_service[i].checked=0;
								}					
							}
							if (ca[1]) {
								// default offline service 
								document.getElementById('offline_type_default').checked = 1;
							} else {
								// disable offline management
								document.getElementById('offline_type_disable').checked = 1;
							}
						}
						// set SLM mode
						if(ca[8] >= 0){
							//document.getElementById('slm').selectedIndex = ca[8];
						}
						} else {
							if (ca[1]) {
								// default offline service 
								 document.getElementById('offline_type_default').checked = 1;	
							} else {
								// disable offline management
								document.getElementById('offline_type_default').checked = 0;
							}
					}
					ost = document.getElementById('os_template_name');
					if(ca[2]<0){
						if(check_os_warn){
							alert(ca[4]);
						}
						ost.selectedIndex=0;		
					}else{
						if(ost.options.length > 1){
							ost.selectedIndex=ca[2];
						}
					}
					updateOS(ca[3]);
				}
				]]>
				<xsl:if test="not($skip_os_preselect)">
					changedConfig(false);
				</xsl:if>
			</script> 
		</func:result>
	</func:function>
	
</xsl:stylesheet>
