<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func check vzenv here vem voc local vz computerm format"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl	="http://exslt.org/common"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
  xmlns:error		="http://www.swsoft.com/xsl/cp/error"
  xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
  xmlns:here	="http://www.swsoft.com/xsl/cp/here"
  xmlns:local	="http://www.swsoft.com/xsl/cp/local"
  xmlns:func	="http://exslt.org/functions"
 	xmlns:request  ="http://www.swsoft.com/xsl/cp/request"  
	xmlns:proc		="http://www.swsoft.com/xsl/cp/proc"
 	xmlns:check	="http://www.swsoft.com/xsl/cp/check"
 	xmlns:vem		="http://www.swsoft.com/xsl/cp/vem" 	
 	xmlns:computerm		="http://www.swsoft.com/xsl/cp/computerm"
 	xmlns:env		="http://www.swsoft.com/xsl/cp/env"	
 	xmlns:vzenv	="http://www.swsoft.com/xsl/cp/vzenv"
 	xmlns:voc		="http://www.swsoft.com/xsl/cp/voc"
 	xmlns:vt		="http://www.swsoft.com/xsl/cp/vt"
 	xmlns:vz		="http://www.swsoft.com/xsl/cp/vz"
 	xmlns:vzve	="http://www.swsoft.com/xsl/cp/vzve"	
	xmlns:ve		="http://www.swsoft.com/xsl/cp/ve"
	xmlns:res		="http://www.swsoft.com/xsl/cp/res"	
	xmlns:format="http://www.swsoft.com/xsl/cp/format"
	xmlns:math	="http://exslt.org/math" 
	xmlns:envm	="http://www.swsoft.com/xsl/cp/envm"
	xmlns:ubcs  ="http://www.swsoft.com/xsl/cp/ubcs"
>

	<sw:include href="core.xsl"/>
	<sw:include href="../vocabulary.xsl"/>
	<sw:include href="/lib/proc.xsl"/>
	<sw:include href="../swa/computerm.xsl"/>
	<sw:include href="/lib/utils/format-number.xsl"/>
	<sw:include href="/lib/utils/format-resusage.xsl"/>
	<sw:include href="/lib/vt/core.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>	
	<sw:include href="/lib/vz/core.xsl"/>	
	<sw:include href="/lib/vz/res-funcs.xsl"/>	
	<sw:include href="/lib/vz/vzenv-core.xsl"/>
	<sw:include href="/lib/vz/ubcs.xsl"/>
	<sw:include	href="/lib/swa/envm.xsl"/>


	<func:function name="vzenv:get-all-alerts">
		<xsl:param name="sysinfo"/>
		<xsl:variable name="ubcsalerts-rtf">
			<xsl:call-template name="ubcs:get-alerts"/>
		</xsl:variable>
		<xsl:variable name="total-alerts-rtf">
			<xsl:copy-of select="exsl:node-set($ubcsalerts-rtf)"/>
			<!-- now vzagent not support CPU alert, because trick it -->
			<xsl:call-template name="proc:cpualerts">
				<xsl:with-param name="sysinfo" select="$sysinfo"/>
			</xsl:call-template>
		</xsl:variable>
		<func:result select="exsl:node-set($total-alerts-rtf)"/>
	</func:function>

		
	<func:function name="vzenv:edit-slm-mode">
		<xsl:param name="hn-platform"/>
		<xsl:param name="slm-mode"/>
		<xsl:param name="slm-supported"/> <!-- any boolean -->
		<xsl:param name="can-empty" select="false()"/>
		<xsl:param name="empty-title" select="''"/>
		<xsl:param name="submit-on-change" select="false()"/>
		
		<func:result>
			<xsl:if test="vt:is-platform-linux($hn-platform)">
				<ui:row>
					<ui:cell-label><xsl:value-of select="sw:text('Memory Management Mode')"/></ui:cell-label>
					<ui:cell-list id="slm" style="width:300px" value="{$slm-mode}">
						<xsl:if test="$submit-on-change">
							<xsl:attribute name="onchange">showSandclock();doSubmit()</xsl:attribute>
						</xsl:if>
						<!--<xsl:if test="not($can-empty)">
							<xsl:attribute name="required">true</xsl:attribute>
						</xsl:if>-->
						<xsl:if test="$empty-title!=''">
							<ui:list-item id="" title="{$empty-title}"/>
						</xsl:if>
						<xsl:for-each select="vz:get-slm-modes()">
							<ui:list-item id="{id}" title="{title}"/>
						</xsl:for-each>
					</ui:cell-list>
				</ui:row>
				<xsl:if test="not($slm-supported)">
					<ui:row>
						<ui:cell-label/>
						<ui:cell-text>
							<ui:text-disabled>
								<sw:text>
									Warning - SLM is disabled on this Hardware Node.
								</sw:text>
							</ui:text-disabled>
						</ui:cell-text>
					</ui:row>
				</xsl:if>
			</xsl:if>
		</func:result>
		
	</func:function>
	
	<func:function name="vzenv:view-slm-mode">
		<xsl:param name="hn-platform"/>
		<xsl:param name="value"/>
		<xsl:variable name="slm" select="sw:if($value!='',$value,'ubc')"/>
		
		<func:result>
			<xsl:if test="vt:is-platform-linux($hn-platform)">
				<ui:row>
					<ui:cell-label><xsl:value-of select="sw:text('Memory Management Mode')"/></ui:cell-label>
					<ui:cell-value>
						<xsl:value-of select="vz:get-slm-modes()[id=$slm]/title"/>
					</ui:cell-value>						
				</ui:row>
			</xsl:if>
		</func:result>
		
	</func:function>
	
	<func:function name="sw:checkQoS">
		<xsl:param name="platform-ref"/>
		<xsl:param name="data"/>
		<xsl:param name="mode" select="'all'"/>
		
		<xsl:variable name="is-linux" select="vt:is-platform-linux($platform-ref/platform)"/>				

		<xsl:variable name="ubc_groups" select="vzenv:get-ubc-groups($platform-ref/platform, $data/slm-mode, true(), $mode)"/>		
		<xsl:variable name="voc-parameter" select="vzve:voc-qos($platform-ref)[category=$ubc_groups/group/@id]"/>

		<xsl:for-each select="$data/res[not(skip-check='1') and id=$voc-parameter/id]">
			<xsl:variable name="id" select="id"/>
			<xsl:variable name="voc_res" select="$voc-parameter[id=$id]"/>
			
			<!-- Check unit selection posibility -->
			<xsl:variable name="factor-type" select="res:measure2factor($voc_res/measure)"/>								
			
			<!-- Check factor -->
			<!--<xsl:variable name="factor">
				<xsl:choose>
					<xsl:when test="factor!=''">	
						<xsl:value-of select="factor"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="1"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>		-->
			
			<!-- calc current factor -->
			<xsl:variable name="factor">
				<xsl:choose>
					<xsl:when test="$factor-type!=''">
						<xsl:value-of select="
							res:find-factor($is-linux,soft,hard)
						"/>		
					</xsl:when>								
					<xsl:otherwise>
						<xsl:value-of select="number(1)"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
			
			
			<!-- Check SOFT -->
			<xsl:if test="$voc_res/complex=2">
				<xsl:choose>
					<xsl:when test="$voc_res/unlimited and soft=res:param2soft($voc_res/unlimited)">
						<!-- ok, resource unlimited -->
					</xsl:when>				
					<xsl:when test="soft &gt; hard">
						<xsl:variable name="error">
							<sw:text>
								<xsl:with-param name="name" select="$voc_res/id"/>
								The soft limit value of "%{name}" should be equal to or less than the hard limit value.
							</sw:text>
						</xsl:variable>
						<xsl:if test="error:put($error,'',concat('s_',form_id))"/>
		      </xsl:when>
					<xsl:when test="string(soft)=''">
						<xsl:variable name="error">
							<sw:text>
								<xsl:with-param name="name" select="$voc_res/id"/>
								The soft limit value of "%{name}" should be specified.
							</sw:text>
						</xsl:variable>
						<xsl:if test="error:put($error,'',concat('s_',form_id))"/>
		      </xsl:when>
		      <xsl:when test="not(check:num(soft))">
		      	<xsl:variable name="error">
							<sw:text>
								<xsl:with-param name="name" select="$voc_res/id"/>
								The soft limit value of "%{name}" contains invalid characters. Please correct it.
							</sw:text>
						</xsl:variable>
						<xsl:if test="error:put($error,'',concat('s_',form_id))"/>
		      </xsl:when>
		      <xsl:when test="check-only-number"/>
		      <xsl:when test="number(res:param2soft($voc_res/min)) = number(res:param2soft($voc_res/max))">
		      	<!-- not need check -  recource noteditable by vzcp, pass throw asis -->
	  	    </xsl:when>
		      <xsl:when test="number(soft) > number(res:param2soft($voc_res/max))">
						<xsl:variable name="error">
	    				<sw:text>
	    					<xsl:with-param name="name" select="$voc_res/id"/>
	    					<xsl:with-param name="limit" select="res:recalc-value-by-factor(res:param2soft($voc_res/max),$factor)"/>
								<xsl:with-param name="measure" select="res:factor2text($voc_res/measure,$factor,$factor-type)"/>	    					
								The soft limit value of "%{name}" should be equal to or less than %limit %{measure}.
	    				</sw:text>
	    			</xsl:variable>
						<xsl:if test="error:put($error,'',concat('h_',form_id))"/>
					</xsl:when>
					<xsl:when test="number(soft) &lt; number(res:param2soft($voc_res/min))">
						<xsl:variable name="error">
	    				<sw:text>
	    					<xsl:with-param name="name" select="$voc_res/id"/>
	    					<xsl:with-param name="min" select="res:recalc-value-by-factor(res:param2soft($voc_res/min),$factor)"/>
								<xsl:with-param name="measure" select="res:factor2text($voc_res/measure,$factor,$factor-type)"/>	    					
	    					The soft limit value of "%{name}" should be equal to or greater than %min %{measure}.
	    				</sw:text>
	    			</xsl:variable>
						<xsl:if test="error:put($error,'',concat('h_',form_id))"/>
					</xsl:when>
	      </xsl:choose>
			</xsl:if>					
			<!-- Check HARD -->
			<xsl:choose>
				<xsl:when test="$voc_res/disabled and hard=$voc_res/disabled">
	      	<!-- ok, resource disabled -->
	      </xsl:when>
				<xsl:when test="$voc_res/unlimited and hard=res:param2hard($voc_res/unlimited)">
	      	<!-- ok, resource unlimited -->
	      </xsl:when>
	      <xsl:when test="number(res:param2hard($voc_res/min)) = number(res:param2hard($voc_res/max))">
	      	<!-- not need check -  recource noteditable by vzcp, pass throw asis -->
	      </xsl:when>
				<xsl:when test="string(hard)=''">
					<xsl:variable name="error">
						<sw:text>
							<xsl:with-param name="name" select="$voc_res/id"/>
							The hard limit value of "%{name}" should be specified.
						</sw:text>
					</xsl:variable>
					<xsl:if test="error:put($error,'',concat('h_',form_id))"/>
				</xsl:when>
				<xsl:when test="not(check:num(hard))">
					<xsl:variable name="error">
						<sw:text>
							<xsl:with-param name="name" select="$voc_res/id"/>
							The hard limit value of "%{name}" contains invalid characters. Please correct it.
						</sw:text>
					</xsl:variable>
					<xsl:if test="error:put($error,'',concat('h_',form_id))"/>
	      </xsl:when>				
	      <xsl:when test="check-only-number"/> 
				<xsl:when test="number(hard) > number(res:param2hard($voc_res/max))">
					<xsl:variable name="refactored-max" select="res:recalc-value-by-factor(res:param2hard($voc_res/max),$factor)"/>				
					<xsl:variable name="error">
  	  			<sw:text>
    					<xsl:with-param name="name" select="$voc_res/id"/>
    					<xsl:with-param name="current" select="hard"/>
    					<xsl:with-param name="limit" select="$refactored-max"/>
							<xsl:with-param name="measure" select="res:factor2text($voc_res/measure,$factor,$factor-type)"/>    					
   						The hard limit value of "%{name}" should be equal to or less than %{limit} %{measure}.
    				</sw:text>
	    		</xsl:variable>
					<xsl:if test="error:put($error,'',concat('h_',form_id))"/>
				</xsl:when>
				<xsl:when test="number(hard) &lt; number(res:param2hard($voc_res/min))">
					<xsl:variable name="refactored-min" select="res:recalc-value-by-factor(res:param2hard($voc_res/min),$factor)"/>
					<xsl:variable name="error">
						<xsl:choose>
							<xsl:when test="$refactored-min!='0'">
								<sw:text>
									<xsl:with-param name="name" select="$voc_res/id"/>
									<xsl:with-param name="min" select="$refactored-min"/>
									<xsl:with-param name="measure" select="res:factor2text($voc_res/measure,$factor,$factor-type)"/>
									The hard limit value of "%{name}" should be equal to or greater than %min %{measure}.
								</sw:text>
							</xsl:when>
							<xsl:otherwise>
								<sw:text>
									<xsl:with-param name="name" select="$voc_res/id"/>
									<xsl:with-param name="min" select="$refactored-min"/>
									<xsl:with-param name="measure" select="res:factor2text($voc_res/measure,$factor,$factor-type)"/>
									The hard limit value of "%{name}" should be greater than %min %{measure}.
								</sw:text>
							</xsl:otherwise>
						</xsl:choose>
    			</xsl:variable>
					<xsl:if test="error:put($error,'',concat('h_',form_id))"/>
				</xsl:when>
			</xsl:choose>
		</xsl:for-each>
		<func:result/>
	</func:function>
	
	<xsl:template name="sw:getQoSCurrentValues">
		<xsl:param name="eid"/>
		<xsl:param name="qos-limit"/>
		<xsl:param name="ubcs"/>
		<xsl:param name="sysinfo"/>
		<xsl:param name="vequota"/>
		<!-- Return UBC -->
		<xsl:for-each select="$ubcs/ubc">
			<res>
				<id><xsl:value-of select="id"/></id>
				<curr><xsl:value-of select="cur"/></curr>
			</res>
		</xsl:for-each>
		<!-- Return DiskSpace -->		
		<res>
			<id>diskspace</id>
			<curr><xsl:value-of select="$vequota//diskspace/cur"/></curr>
		</res>
		<res>
			<id>diskinodes</id>
			<curr><xsl:value-of select="$vequota//diskinodes/cur"/></curr>
		</res>
		<res>
			<id>quotaugidlimit</id>
			<curr><xsl:value-of select="$vequota//quotaugidlimit/cur"/></curr>
		</res>
		<!--|-->
	</xsl:template>
  
  <xsl:template name="sw:getQoSValidateResults">  	
  	<xsl:param name="qos"/>
  	<xsl:param name="qos-warns"/>
		<!--|-->
		<xsl:choose>			
			<xsl:when test="$qos-warns/packet/data/vzaenvm/validation">
				<ui:stop-sign>
					<xsl:if test="not($qos-warns/packet/data/vzaenvm/validation[type=0])">
						<xsl:attribute name="icon">exclamation</xsl:attribute>
					</xsl:if>
					<b><sw:text>The resources validation has been completed. Please look at the validation comments on the following resources.</sw:text></b>
					<xsl:call-template name="vzenv:get-validate-results">
						<xsl:with-param name="qos" select="$qos"/>
						<xsl:with-param name="qos-warns" select="$qos-warns"/>
					</xsl:call-template>
				</ui:stop-sign>
			</xsl:when>
			<xsl:when test="sw:param('validate') and not(error:get())">
				<xsl:if test="sw:sesput('msg',sw:text('The resources configuration is valid.'))"/>
			</xsl:when>
		</xsl:choose>
  </xsl:template>
  
	<xsl:template name="vzenv:get-validate-results">  	
  	<xsl:param name="qos"/>
  	<xsl:param name="qos-warns"/>
		<!--|-->
		<xsl:choose>			
			<xsl:when test="$qos-warns/packet/data/vzaenvm/validation">				
					<table cellpadding="5" cellspacing="0" border="0">
						<xsl:for-each select="$qos-warns/packet/data/vzaenvm/validation">				
							<tr>
								<td>
									<xsl:choose>
										<xsl:when test="type=0">
											<img src="/{$theme}/icons/alert_red.gif" width="16" height="16" border="0" onmouseover="callTip('qos_validate_error',event)" onmouseout="callTip()"/>
										</xsl:when>
										<xsl:otherwise>
											<img src="/{$theme}/icons/alert_yellow.gif" width="16" height="16" border="0" onmouseover="callTip('qos_validate_warn',event)" onmouseout="callTip()"/>
										</xsl:otherwise>
									</xsl:choose>
								</td>
								<td>
									<b>
										<xsl:for-each select="qos_id">
											<xsl:variable name="id" select="."/>
											<xsl:if test="position()>1"><br/></xsl:if>
											<sw:text domain="vzagent-vocabulary" select="."/>
										</xsl:for-each>
									</b>
								</td>
								<td>
									<xsl:value-of select="warning"/>
								</td>
							</tr>
						</xsl:for-each>
					</table>
			</xsl:when>
		</xsl:choose>
  </xsl:template>
  
  <xsl:template name="sw:validateQoS">
  	<xsl:param name="hn-eid"/>
		<xsl:param name="data"/>
		<!-- Prepare packet to VZA -->
		<xsl:variable name="packet">
			<packet>
				<target>vzaenvm</target>
        <xsl:copy-of select="sw:env-dst($hn-eid)"/>
				<data>
					<vzaenvm>
						<validate>
							<config>
								<slm_mode><xsl:value-of select="$data/slm-mode"/></slm_mode>
								<xsl:for-each select="$data/res">
									<xsl:if test="soft!='' or hard!=''">
										<qos>
											<xsl:copy-of select="id"/>
											<xsl:if test="soft!=''">
												<xsl:copy-of select="soft"/>
											</xsl:if>
											<xsl:if test="hard!=''">
												<xsl:copy-of select="hard"/>
											</xsl:if>
										</qos>
									</xsl:if>
								</xsl:for-each>
							</config>
						</validate>
					</vzaenvm>
				</data>
				<vzcpauth/>
			</packet>
		</xsl:variable>
		<!-- /Prepare packet to VZA -->
		<!-- Send packet to VZA and return result-->
		<xsl:copy-of select="sw:xchg($packet)"/>
	</xsl:template>
  
	<func:function name="sw:restoreQoS">
		<xsl:param name="platform-ref"/>
		<xsl:param name="old-data"/>

		<xsl:variable name="old-slm-mode" select="$old-data/slm-mode"/>
		<xsl:variable name="slm-mode" select="sw:param('slm')"/>
		<xsl:variable name="ubc_groups" select="vzenv:get-ubc-groups($platform-ref/platform,$old-slm-mode)"/>		
		<xsl:variable name="voc-parameter" select="vzve:voc-qos($platform-ref)[category=$ubc_groups/group/@id]"/>
				
		<func:result>
			<slm-mode><xsl:value-of select="$slm-mode"/></slm-mode>
			<xsl:for-each select="$voc-parameter[min=max]">			
				<xsl:variable name="def" select="basic"/>
				<res>
					<xsl:copy-of select="id"/>
					<soft>
						<xsl:value-of select="res:param2soft($def)"/>
					</soft>
					<hard>
						<xsl:value-of select="res:param2hard($def)"/>
					</hard>
					<skip-check>1</skip-check>
				</res>
			</xsl:for-each>
			<xsl:for-each select="$voc-parameter[min!=max]">
				<xsl:variable name="real_id" select="id"/>
				
				<xsl:variable name="min" select="min"/>
				<xsl:variable name="min_soft" select="res:param2soft($min)"/>
				<xsl:variable name="min_hard" select="res:param2hard($min)"/>
				<xsl:variable name="max" select="max"/>
				<xsl:variable name="max_soft" select="res:param2soft($max)"/>
				<xsl:variable name="max_hard" select="res:param2hard($max)"/>
				
				<xsl:variable name="unlimited">
					<xsl:choose>
						<xsl:when test="disabled">
							<xsl:value-of select="disabled"/>
						</xsl:when>
						<xsl:when test="unlimited">
							<xsl:value-of select="unlimited"/>
						</xsl:when>						
					</xsl:choose>
				</xsl:variable>
				<xsl:variable name="unlim_soft" select="res:param2soft($unlimited)"/>
				<xsl:variable name="unlim_hard" select="res:param2hard($unlimited)"/>
				
				<xsl:variable name="id_">
					<xsl:for-each select="$request/http_request/*[self::post or self::get]/parameter[starts-with(name, 'qos_') and value = $real_id]">
						<xsl:value-of select="substring-after(name, 'qos_')"/>
					</xsl:for-each>
				</xsl:variable>				
				<xsl:variable name="id" select="string($id_)"/>
				
				<xsl:variable name="factor" select="sw:param(concat('m_',$id))"/>				
				<xsl:variable name="def-factor" select="sw:param(concat('df_',$id))"/>				
				<res>
					<xsl:copy-of select="$real_id"/>
					<def-unlimited><xsl:value-of select="sw:param(concat('du_',$id))"/></def-unlimited>
					<form_id><xsl:value-of select="$id"/></form_id>
					<xsl:copy-of select="complex"/>
					<soft_src><xsl:value-of select="format:str2int(sw:param(name = concat('ss_',$id)),$def-factor)"/></soft_src>
  				<hard_src><xsl:value-of select="format:str2int(sw:param(concat('hs_',$id)),$def-factor)"/></hard_src>
					<xsl:choose>
						<xsl:when test="not(sw:param(concat('u_',$id)))">
							<!-- Unlimited -->
							<xsl:choose>
								<xsl:when test="complex=2 and $unlim_soft!=''">
									<soft><xsl:value-of select="$unlim_soft"/></soft>
								</xsl:when>								
								<xsl:when test="complex=2">
									<soft><xsl:value-of select="$unlim_hard"/></soft>
								</xsl:when>								
							</xsl:choose>
							<hard><xsl:value-of select="$unlim_hard"/></hard>
						</xsl:when>
						<xsl:otherwise>
							<!-- Limited -->
							<xsl:if test="$factor!=''">
								<factor><xsl:value-of select="$factor"/></factor>
							</xsl:if>
							<soft>
								<xsl:value-of select="format:str2int(sw:param(concat('s_',$id)), $factor)"/>
							</soft>
							<hard>
								<xsl:value-of select="format:str2int(sw:param(concat('h_',$id)), $factor)"/>
							</hard>
						</xsl:otherwise>
					</xsl:choose>					
					<xsl:if test="restart">
						<restart-ve><xsl:value-of select="sw:param(concat('rve_',$id))"/></restart-ve>
					</xsl:if>
				</res>	
			</xsl:for-each>
			<xsl:for-each select="$ubc_groups/group">
				<xsl:variable name="cat-id" select="concat('cat_',@id)"/>
				<group-status id="{$cat-id}" status="{sw:param($cat-id)}"/>
			</xsl:for-each>
		</func:result>
 </func:function>   
 
 
 <xsl:template name="vzve:restore-qos-selector">
		<xsl:param name="platform-ref"/>
		<xsl:param name="slm-mode"/>

		<xsl:variable name="ubc_groups" select="vzenv:get-ubc-groups($platform-ref/platform,$slm-mode)"/>		
		<xsl:variable name="voc-parameter" select="vzve:voc-qos($platform-ref)[category=$ubc_groups/group/@id]"/>
		
		<xsl:for-each select="$voc-parameter">			
			<xsl:variable name="id" select="id"/>
			<xsl:if test="sw:param(concat('res_sel_',$id))!=''">
				<res>
					<xsl:copy-of select="id"/>
				</res>
			</xsl:if>
		</xsl:for-each>
 </xsl:template>
 
 <xsl:template name="vzenv:show-qos-header"> 
 	<xsl:param name="qos"/>
 	<!--|-->
 	<xsl:variable name="show-current" select="$qos/@show-current='true'"/>
 	<!--|-->
	<ui:row type="head">
		<ui:cell><sw:text>Parameter</sw:text>
			<br/><img src="/{$theme}/images/1x1.gif" width="130" height="1"/>
		</ui:cell>		
		<ui:cell cell-width="50" align="center"><sw:text>Limited</sw:text></ui:cell>				
		<xsl:if test="$show-current">
			<ui:cell cell-width="90" align="right">
				<sw:text>Current Usage</sw:text>
			</ui:cell>						
		</xsl:if>
		<xsl:if test="$qos/platform-linux">
			<ui:cell cell-width="90" align="center"><sw:text>Soft Limit</sw:text></ui:cell>
			<ui:cell cell-width="90" align="center"><sw:text>Hard Limit</sw:text></ui:cell>
		</xsl:if>
		<xsl:if test="$qos/platform-windows">
			<ui:cell cell-width="90" align="center"><sw:text>Limit</sw:text></ui:cell>
		</xsl:if>
		<ui:cell cell-width="50" align="center"><sw:text>Units</sw:text></ui:cell>
		<ui:cell cell-width="100%"><sw:text>Description</sw:text></ui:cell>
		<ui:cell cell-width="20" align="center"> </ui:cell>
	</ui:row>
 </xsl:template>

 <func:function name="vzenv:get-ubc-groups">
 	<xsl:param name="hn-platform"/>
	<xsl:param name="slm-mode" select="'ubc'"/>
	<xsl:param name="show-advanced" select="true()"/>
	<xsl:param name="mode" select="'all'"/>

	<xsl:variable name="linux" select="vt:is-platform-linux($hn-platform)"/>

	<xsl:variable name="ubc-groups-rtf">
		<group id="cpu" name="{sw:text('CPU Parameters')}" click-title="{sw:text('Click to view the CPU parameters.')}" status="1" help-topic="resources"/>
		<group id="quota" name="{sw:text('Disk Quota')}" click-title="{sw:text('Click to set up the disk quota parameters.')}" status="1" help-topic="resources"/>
		<xsl:if test="$slm-mode='slm' or $slm-mode='all'">
			<group id="slm" name="{sw:text('Memory Parameters')}" click-title="{sw:text('Click to view the memory parameters.')}" status="1" help-topic="resources"/>
		</xsl:if>
		
		<xsl:choose>
			<xsl:when test="not($linux)">
				<group id="ubc" status="1" name="{sw:text('System Parameters')}" click-title="{sw:text('Click to view the system parameters.')}" help-topic="resources">
				</group>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="not($slm-mode) or $slm-mode='' or $slm-mode='ubc' or $slm-mode='all'">
					<xsl:if test="$show-advanced">
						<group id="ubc_primary" name="{sw:text('Primary System Parameters')}" click-title="{sw:text('Click to view the primary system parameters.')}" help-topic="resources">
							<xsl:if test="not($linux) or $mode='memory'">
								<xsl:attribute name="status">1</xsl:attribute>
							</xsl:if>
						</group>
						<xsl:if test="$linux">
							<group id="ubc_secondary" name="{sw:text('Secondary System Parameters')}" click-title="{sw:text('Click to view the secondary system parameters.')}" help-topic="resources"/>
							<group id="ubc_auxilary" name="{sw:text('Auxiliary System Parameters')}" click-title="{sw:text('Click to view the auxiliary system parameters.')}" help-topic="resources"/>
						</xsl:if>
					</xsl:if>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	
	<xsl:variable name="ubc-groups" select="exsl:node-set($ubc-groups-rtf)" />
	
	<xsl:variable name="res">
		<xsl:choose>
			<xsl:when test="$mode='cpu'">
				<xsl:copy-of select="$ubc-groups/group[@id='cpu']" />
			</xsl:when>
			<xsl:when test="$mode='disk'">
				<xsl:copy-of select="$ubc-groups/group[@id='quota']" />
			</xsl:when>
			<xsl:when test="$mode='memory'">
				<xsl:copy-of select="$ubc-groups/group[@id='slm' or starts-with(@id, 'ubc')]" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="$ubc-groups/group" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	
	<func:result select="exsl:node-set($res)" />
 </func:function>
 
 <!--
 	Look at func-qos.xsl for details
 -->
	<xsl:template name="vzenv:conv-qos-data">
		<!-- Input arguments -->
		<xsl:param name="platform-ref"/>
		<xsl:param name="data"/>
		<xsl:param name="mode" select="'all'"/>
		<xsl:param name="res-curr" select="/.."/> <!-- res/id|curr -->
		<xsl:param name="qos-warns" select="/.."/>		
		<xsl:param name="only-changed" select="false()"/>
		<xsl:param name="show-advanced" select="true()"/>
		<xsl:param name="warn-restart" select="true()"/>
		<xsl:param name="default-show-cats" select="false()"/>	
		<!-- /Input arguments -->
				
		<xsl:variable name="slm-mode" select="$data/slm-mode"/>	
		<xsl:variable name="linux" select="vt:is-platform-linux($platform-ref/platform)"/>				
		<xsl:variable name="voc-parameter" select="vzve:voc-qos($platform-ref)"/>
		<xsl:variable name="show-soft-limit" select="$linux"/>
  
		<xsl:variable name="ubc_groups" select="vzenv:get-ubc-groups($platform-ref/platform,$slm-mode,$show-advanced, $mode)"/>
		
		<xsl:variable name="unlim_labels_">
			<unlim unlimited="1" text="{sw:text('Unlimited')}"/>
			<!-- quotaugidlimit -->
			<unlim unlimited="2" text="{sw:text('Disabled')}"/>
			<!-- quotatime -->
			<unlim unlimited="3" text="{sw:text('Disabled')}"/>
		</xsl:variable>
		<xsl:variable name="unlim_labels" select="exsl:node-set($unlim_labels_)"/>				
		
		<ui:qos-data show-current="{sw:if($res-curr,'true','false')}" show-soft-limit="{sw:if($show-soft-limit,'true','false')}">
		
			<!-- Copy platform data -->
			<platform><xsl:value-of select="$platform-ref/platform"/></platform>
			<xsl:if test="$linux">
				<platform-linux/>
			</xsl:if>
			<xsl:if test="vt:is-platform-windows($platform-ref/platform)">
				<platform-windows/>
			</xsl:if>
			<!-- /Copy platform data -->
			
		  <xsl:for-each select="$ubc_groups/group">
		  	<xsl:variable name="category" select="@id"/>
		  	<xsl:variable name="cat-id" select="concat('cat_',@id)"/>
				<xsl:variable name="cat_position" select="position()"/>
				<xsl:variable name="group-status" select="$data/group-status[@id=$cat-id]/@status"/>
				
				<ui:qos-category title="{@name}" id="cat_{$category}" closed-text="{@click-title}" 
			  	status="{sw:if(count($group-status),$group-status,@status)}"
			  	status-def="{sw:if($default-show-cats,1,@status)}"
			  	help-topic="{@help-topic}"
			  >
					  		  			  
					<!-- comment: (2) we should skip resources with min=max -->
					<xsl:for-each select="$voc-parameter[category=$category and min!=max]">				
					
						<xsl:variable name="real_id" select="id"/>

						<xsl:call-template name="res:extend-info">
							<xsl:with-param name="warn-restart" select="$warn-restart"/>
							<xsl:with-param name="is-linux" select="$linux"/>						
							<xsl:with-param name="id" select="concat($cat_position,'_',position())"/>
							<xsl:with-param name="voc-res" select="."/>
							<xsl:with-param name="ve-res" select="$data/res[id=$real_id]"/>
							<xsl:with-param name="usage-res" select="$res-curr/res[id=$real_id]/curr"/>	
							<xsl:with-param name="qos-warns" select="$qos-warns[qos_id=$real_id]"/>
							<xsl:with-param name="only-changed" select="$only-changed"/>
						</xsl:call-template>
					
					</xsl:for-each>
					
				</ui:qos-category>
		  </xsl:for-each>

		</ui:qos-data>
	</xsl:template>  		
	
	<xsl:template name="vzenv:edit-qos">
		<xsl:param name="platform-ref"/><!-- use env:make-platform-ref() for ref generate -->
		<xsl:param name="data"/>
		<xsl:param name="mode" select="'all'"/>
		<xsl:param name="res-curr" select="/.."/> <!-- res/id|curr -->
		<xsl:param name="qos-warns" select="/.."/>		
		<xsl:param name="disk-quota-enabled" select="true()"/>
		<xsl:param name="warn-restart" select="true()"/>
		<xsl:param name="slm-supported" select="true()"/>		
				
		<xsl:variable name="slm-mode" select="$data/slm-mode"/>			
				
		<!-- Translate data into internal format -->
		<xsl:variable name="qos-src">
			<xsl:call-template name="vzenv:conv-qos-data">
				<xsl:with-param name="platform-ref" select="$platform-ref"/>
				<xsl:with-param name="data" select="$data"/>
				<xsl:with-param name="mode" select="$mode"/>
				<xsl:with-param name="qos-warns" select="$qos-warns"/>
				<xsl:with-param name="res-curr" select="$res-curr"/>
				<xsl:with-param name="warn-restart" select="$warn-restart"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="qos" select="exsl:node-set($qos-src)/ui:qos-data"/>
		<!-- /Translate data into internal format -->

		<!-- Process category -->
		<xsl:for-each select="$qos/ui:qos-category">
			<ui:rows title="{@title}" closed-text="{@closed-text}" 
				status="{@status}"
				status-def="{@status-def}"
			>
				<xsl:if test="@status-def!='1' or $qos/platform-linux">
					<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
				</xsl:if>
			
				<xsl:variable name="cat-disabled" select="$qos/platform-linux and not($disk-quota-enabled) and @id='cat_quota'"/>
				<xsl:if test="$cat-disabled">
					<xsl:attribute name="alert-icon">alert_red</xsl:attribute>
					<xsl:attribute name="alert-label"><sw:text>(&#160;Disk quota management is disabled in the Virtuozzo configuration&#160;)</sw:text></xsl:attribute>
				</xsl:if>
				<!-- Process category resources -->
				<xsl:for-each select="ui:qos-param">

					<xsl:variable name="res" select="."/>
					<xsl:variable name="id" select="@id"/>
					<xsl:variable name="real-id" select="@real-id"/>
					
					<xsl:variable name="on-change-restart-alert">
						<xsl:if test="@alert-restart-id!=''">
							<xsl:variable name="restart-id" select="concat(@alert-restart-id,'_',$id)"/>
							if(document.getElementById('<xsl:value-of select="$restart-id"/>').value=='')
							document.getElementById('<xsl:value-of select="$restart-id"/>').value = window.confirm('<xsl:value-of select="@alert-restart-label"/>')?1:0;
						</xsl:if>
					</xsl:variable>

					
					<!-- Show Category Header -->
			  	<xsl:if test="position()=1">
						<xsl:call-template name="vzenv:show-qos-header">	
							<xsl:with-param name="qos" select="$qos"/>
						</xsl:call-template>
					</xsl:if>
					<!-- /Show Category Header -->
					<!-- Show Resource -->
					<ui:row>						
						<xsl:if test="@has-warning='true'">
							<xsl:attribute name="contains-error">1</xsl:attribute>
						</xsl:if>						
						<!-- Show Resource ID  -->
						<ui:cell>
							<xsl:value-of select="@real-id"/>
						</ui:cell>
						<!-- Show Limit/Unlimited Checkbox -->
						<xsl:choose>
							<xsl:when test="@unlimited-control-type='label'">
								<ui:cell align="center">
									<xsl:value-of select="@unlimited-control-label"/>
									<input type="hidden" name="u_{$id}" value="1"/>										
								</ui:cell>
							</xsl:when>		      
							<xsl:otherwise>												
								<ui:cell-check id="u_{$id}" align="center">
									<xsl:attribute name="onclick">
										setUnlimited('<xsl:value-of select="$id"/>',-1,'<xsl:value-of select="@unlimited-label"/>','<xsl:value-of select="@factor"/>');		
										<xsl:copy-of select="$on-change-restart-alert"/>
									</xsl:attribute>
									<xsl:if test="@unlimited='false'">
										<xsl:attribute name="checked">true</xsl:attribute>
									</xsl:if >
								</ui:cell-check>
							</xsl:otherwise>
						</xsl:choose>									
						<!-- Show Current Usage  -->
						<xsl:if test="$qos/@show-current='true'">
							<ui:cell align="right" div_id='cuv_{$id}'>
								<xsl:choose>
									<xsl:when test="@current!=''">
										<xsl:value-of select="@current-str"/>
									</xsl:when>
									<xsl:otherwise>
										<sw:text>n/a</sw:text>
									</xsl:otherwise>
								</xsl:choose>
								&#160;
							</ui:cell>
						</xsl:if>			
						<!-- Show Soft Limit -->
						<xsl:if test="$qos/@show-soft-limit='true'">
							<xsl:choose>
								<xsl:when test="@soft-off='true'">
									<ui:cell align="center">
										<sw:text>n/a</sw:text>
										<input type="hidden" name="s_{$id}" value="{@soft}"/>	
									</ui:cell>	
								</xsl:when>
								<xsl:when test="@soft-min=@soft-max">
									<ui:cell-input width="12" maxlength="20"
										tip="{@soft-tip}" onchange="qos_m_{$id}=false"
									>
										<xsl:attribute name="disabled">true</xsl:attribute>
									 	<xsl:attribute name="value"><xsl:value-of select="@soft"/></xsl:attribute>
									 	<input type="hidden" name="s_{$id}" value="{@soft}"/>	
									</ui:cell-input>
								</xsl:when>
								<xsl:otherwise>
									<ui:cell-input width="12" maxlength="20" id="s_{$id}" 
										tip="{@soft-tip}"
									>
									  <xsl:choose>
									  	<xsl:when test="@unlimited='true' and @unlimited-control-type='checkbox'">
									  		<xsl:attribute name="disabled">true</xsl:attribute>
									  		<xsl:attribute name="value"><xsl:value-of select="@unlimited-label"/></xsl:attribute>
									  	</xsl:when>
									  	<xsl:otherwise>
									  		<xsl:attribute name="value"><xsl:value-of select="@soft"/></xsl:attribute>
									  	</xsl:otherwise>
									  </xsl:choose>
									  <xsl:attribute name="onchange"> 
											qos_m_<xsl:value-of select="$id"/>=false;
											<xsl:if test="@alert-restart-id!=''">
												<xsl:copy-of select="$on-change-restart-alert"/>
											</xsl:if>
										</xsl:attribute>		
									 </ui:cell-input>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:if>
						<!-- Show Hard Limit -->
						<xsl:choose>
							<xsl:when test="@hard-off = 'true'">
								<ui:cell align="center">
									<sw:text>n/a</sw:text>
									<input type="hidden" name="h_{$id}" value="{@hard}"/>	
								</ui:cell>								
							</xsl:when>
							<xsl:when test="@hard-min = @hard-max">
								<ui:cell-text tip="{@hard-tip}" align="center"
									 onchange="qos_m_{$id}=false"
								>
								 	<sw:text>maximum</sw:text>
								 	<input type="hidden" name="h_{$id}" value="{@hard}"/>	
								</ui:cell-text>
							</xsl:when>
							<xsl:otherwise>
								<ui:cell-input width="12" maxlength="20" id="h_{$id}" 
									tip="{@hard-tip}"
								>
								  <xsl:choose>
								  	<xsl:when test="@unlimited='true' and @unlimited-control-type='checkbox'">
								  		<xsl:attribute name="disabled">true</xsl:attribute>
								  		<xsl:attribute name="value"><xsl:value-of select="@unlimited-label"/></xsl:attribute>
								  	</xsl:when>
								  	<xsl:otherwise>
								  		<xsl:attribute name="value"><xsl:value-of select="@hard"/></xsl:attribute>
								  	</xsl:otherwise>
								  </xsl:choose>
								  
							  	<xsl:attribute name="onchange"> 
							  		qos_m_<xsl:value-of select="$id"/>=false;
									  <xsl:if test="@alert-restart-id!=''">
											<xsl:copy-of select="$on-change-restart-alert"/>
										</xsl:if>
									</xsl:attribute>										
								  
								</ui:cell-input>
							</xsl:otherwise>
						</xsl:choose>
						<!-- /Show Hard Limit -->						
						<!-- Units -->
						<xsl:call-template name="vzenv:show-res-unit">
							<xsl:with-param name="id" select="$id"/>
						</xsl:call-template>						
						<!-- Description -->
						<ui:cell>
							<sw:text select="@short" domain="vzagent-vocabulary"/>
							<input type="hidden" id="qos_{$id}" name="qos_{$id}" value="{$real-id}"/>
	            <!-- Default Unlimited -->
	            <input type="hidden" id="du_{$id}" name="du_{$id}" value="{sw:if(@def-unlimited='true','1','0')}"/>	            
	            <!-- Default Factor -->
	            <input type="hidden" id="df_{$id}" name="df_{$id}" value="{@def-factor}"/>	            
	            <!-- Soft Cache -->
	            <input type="hidden" id="sc_{$id}" name="sc_{$id}" value="{@soft}"/>
	            <!-- Hard Cache -->
	            <input type="hidden" id="hc_{$id}" name="hc_{$id}" value="{@hard}"/>
	            <!-- Soft Default -->
	            <input type="hidden" id="ss_{$id}" name="ss_{$id}" value="{@soft-def}"/>
	            <!-- Hard Default -->
	            <input type="hidden" id="hs_{$id}" name="hs_{$id}" value="{@hard-def}"/>
	            <!-- Restart VE -->
	            <xsl:if test="@alert-restart-id!=''">
	            	<input type="hidden" id="{@alert-restart-id}_{$id}" name="{@alert-restart-id}_{$id}" value="{@restart-ve}"/>
	            </xsl:if>
	            <!-- post current factor and current usage -->	           
	            <xsl:if test="@factor-type!=''"> 
		            <script type="text/javascript">
		            	var cf_<xsl:value-of select="$id"/>=<xsl:value-of select="@factor"/>;
		            	var cu_<xsl:value-of select="$id"/>='<xsl:value-of select="@current"/>';
		            </script>
		          </xsl:if>
						</ui:cell>
						<!-- Tools -->
						<ui:cell>
							<nobr>
								<!--
								<img onClick="setResValue('{$id}','{$min_soft}','{$min_hard}')" alt="{$min_title}" title="{$min_title}" width="16" height="16" src="/{$theme}/icons/check_green.gif"/>
								<xsl:text> </xsl:text>
								<img onClick="setResValue('{$id}','{$max_soft}','{$max_hard}')" alt="{$max_title}" title="{$max_title}" width="16" height="16" src="/{$theme}/icons/check_grey.gif"/>
								<xsl:text> </xsl:text>
								<img onClick="setUnlimited('{$id}',-1)" alt="{$unlim_title}" title="{$unlim_title}" width="16" height="16" src="/{$theme}/icons/check_red.gif"/>
								<xsl:text> </xsl:text>
								-->
								<a style="cursor:hand; cursor:pointer">
									<xsl:attribute name="onClick">
										<xsl:choose>
											<xsl:when test="@def-unlimited='true'">
												setUnlimited('<xsl:value-of select="$id"/>',1,'<xsl:value-of select="@unlimited-label"/>','<xsl:value-of select="@def-factor"/>')												
											</xsl:when>
											<xsl:otherwise>
												setResValue('<xsl:value-of select="$id"/>','<xsl:value-of select="format:res2str(@soft-def,@factor)"/>','<xsl:value-of select="format:res2str(@hard-def,@unit)"/>','<xsl:value-of select="@def-factor"/>');
											</xsl:otherwise>												
										</xsl:choose>
										return false;
									</xsl:attribute>
									<img width="16" height="16" src="/{$theme}/icons/undo.gif"
										onmouseover="callTip('{@def-label}',event)" onmouseout="callTip('')"
									>									
								</img>
								</a>
								&#160;								
								<a style="cursor:hand; cursor:pointer">
									<xsl:attribute name="onClick">showLong('<xsl:value-of select="@real-id"/>')</xsl:attribute>
									<img width="16" height="16" border="0"
										onmouseover="callTip('ve_qos_details',event)" onmouseout="callTip('')"
										src="/{$theme}/icons/help_16.gif"/>									
								</a>	
							</nobr>
						</ui:cell>
					</ui:row>
					<!-- /Show Resource -->
				</xsl:for-each>
				<!-- /Process category resources -->
			</ui:rows>
		</xsl:for-each>
		<!-- /Process category -->
		
		 <ui:rows>
	  	<xsl:copy-of select="sw:getQoSJS()"/>
	  </ui:rows>
	  
	  <xsl:if test="$qos/platform-linux">
			<ui:rows title="{sw:text('Memory Configuration')}">
				<xsl:copy-of
					select="vzenv:edit-slm-mode(
						$platform-ref/platform,
						$slm-mode,
						$slm-supported,
						false(),
						'',
						true()
					)"
				/>
			</ui:rows>
		</xsl:if>
		
	</xsl:template>
	
	<xsl:template name="vzenv:show-res-unit">
		<xsl:param name="id"/>
		<xsl:param name="post-div" select="false()"/>
		<xsl:param name="cell-attrs" select="/.."/>		
		
		<xsl:choose>
			<xsl:when test="@factor-type='bytes'">
				<ui:cell-list id="m_{$id}" style="width:55px" value="{@factor}" disabled="{@unlimited}"
					onchange="changedFactor('{$id}',typeof(qos_m_{$id})!='undefined'?qos_m_{$id}:true)"
				>
					<xsl:if test="$post-div">
						<xsl:attribute name="div_id">ud_<xsl:value-of select="$id"/></xsl:attribute>
					</xsl:if>
					<xsl:copy-of select="$cell-attrs/@*"/>														
					<ui:list-item id="1" title="{sw:text('Bytes')}"/>
					<ui:list-item id="1024" title="{sw:text('KB')}"/>
					<ui:list-item id="1048576" title="{sw:text('MB')}"/>
					<ui:list-item id="1073741824" title="{sw:text('GB')}"/>
				</ui:cell-list>
			</xsl:when>
			<xsl:when test="@factor-type='kb'">
				<ui:cell-list id="m_{$id}" style="width:55px" value="{@factor}" disabled="{@unlimited}"
					onchange="changedFactor('{$id}',typeof(qos_m_{$id})!='undefined'?qos_m_{$id}:true)"
				>
					<xsl:if test="$post-div">
						<xsl:attribute name="div_id">ud_<xsl:value-of select="$id"/></xsl:attribute>
					</xsl:if>				
					<xsl:copy-of select="$cell-attrs/@*"/>																			
					<ui:list-item id="1" title="{sw:text('KB')}"/>
					<ui:list-item id="1024" title="{sw:text('MB')}"/>
					<ui:list-item id="1048576" title="{sw:text('GB')}"/>										
				</ui:cell-list>
			</xsl:when>
			<xsl:otherwise>
				<ui:cell align="center">
					<xsl:if test="$post-div">
						<xsl:attribute name="div_id">ud_<xsl:value-of select="$id"/></xsl:attribute>
					</xsl:if>				
					<xsl:copy-of select="$cell-attrs/@*"/>
					<nobr><xsl:value-of select="@unit-label"/></nobr>
				</ui:cell>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<func:function name="sw:getQoSJS">
		<func:result>
			<script type="text/javascript">					
				var long_title = '<sw:text>Resource Description</sw:text>';
				<![CDATA[
				function saveScale(){
					hideControls();
				}
				function cancelScale(){
					hideControls();
				}
				function hideControls(){
					div = document.getElementById('scale_controls');
					// Hide controls
					div.style.display = 'none';
				}
				function showScaleControls(){
					div = document.getElementById('scale_controls');
					// Show controls
					div.style.display = 'block';
				}
				function showLong(id){
					open_help('/vz/cp/help?topic=resources&a='+id);
					//
					//alert(text);
					//return false;				
					//win = window.open("","longDescr","scrollbars=yes,width=400,height=300,resizable=yes");
					//win.document.write('<HTML><HEAD><TITLE>'+long_title+'</TITLE></HEAD><BODY>');
					//win.document.write(text);
					//win.document.write('</BODY></HTML>');
				}				
				function changedFactor(id,recalc_limits)
				{						
					var softError = false;
					var hardError = false;
					var u=document.getElementById('m_'+id);															
					
					// get old and new factor;
					var fold;
					eval('fold=cf_'+id);
					var fnew = u.options[u.selectedIndex].value;
										
					if(recalc_limits){
						// recalc soft limit
						var s=document.getElementById('s_'+id);
						if(s){
							var soft_old = parseInt(s.value);
							if(!isNaN(soft_old)){
								var snew  = Math.floor(s.value * fold / fnew);
								softError = parseInt(snew)!=snew;
								if(!softError) s.value = snew;
							}
						}
						
						// recalc hard limit
						var h=document.getElementById('h_'+id);
						if(h){
							var hard_old = parseInt(h.value);
							if(!isNaN(hard_old)){
								var hnew  = Math.floor(h.value * fold / fnew);
								hardError = parseInt(hnew)!=hnew;
								if(!hardError) h.value = hnew;
							}
						}
					}
					
					// recal current usage
					var current_view = document.getElementById('cuv_'+id);
					if(current_view){											
						var current_value;
						eval('current_value=parseInt(cu_'+id+')');
						if( !isNaN(current_value) ){
							var new_value = Math.round(100 * current_value / fnew)/100;
							current_view.innerHTML = intAddCommas(new_value) + '&#160&#160';
						}
					}
					
					// store new factor
					eval('cf_'+id+'='+fnew);
					
					]]>
					if(hardError &amp;&amp; softError){
						alert('<sw:text>The soft and hard limits values are too large for recalculation and will be left unchanged.</sw:text>');
					}else
					if(softError){
						alert('<sw:text>The soft limit value is too large for recalculation and will be left unchanged.</sw:text>');
					}else
					if(hardError){
						alert('<sw:text>The hard limit value is too large for recalculation and will be left unchanged.</sw:text>');
					}					
					<![CDATA[
				}
				
				function setResValue(id,soft_value,hard_value,factor){
					// show div
					setUnlimited(id,0,'',factor);
					// enable views -->
					s=document.getElementById('s_'+id);// soft
					if(s){
						s.value=soft_value;							
					}
					s=document.getElementById('h_'+id);//hard
					if(s){
						s.value=hard_value;							
					}
				}
				function setUnlimited1(id,unlimited,code,unlim_text){
					d=document.getElementById(code+'_'+id);
					if(d){
						// get cached value
						cache=document.getElementById(code+'c_'+id);
						old = d.value;
						d.value=unlimited?unlim_text:cache.value;
						d.disabled=unlimited;
						cache.value=old;
					}
				}
				
				function setUnlimited(id,value,unlim_text,factor){
					s=document.getElementById('u_'+id);
					if(s){
						unlimited = value<0?(!s.checked):(value==1);
						// change value
						if( value<0 || (value!=(s.checked?0:1)) ){
							if(value>=0){
								s.checked = !unlimited;
							}
							////////////////
							// soft
							setUnlimited1(id,unlimited,'s',unlim_text); 
							// hard
							setUnlimited1(id,unlimited,'h',unlim_text); 
							///////////////						
						}
					}
					
					// refresh unit
					if(factor!=''){
						var u=document.getElementById('m_'+id);
						if(s)	u.disabled=unlimited;
						if(!s || unlimited){
							u.selectedIndex = 0;
						}else{
							var o;
							for(var i=0;i<u.options.length;i++){
								o = u.options[i];
								if(o.value==factor){
									u.selectedIndex = i;
								}
							}
						}
						changedFactor(id,false);
						///
					}
				}
				]]>
			</script> 
		</func:result>
	</func:function>
	
	<!-- 
		Show VE/Sample QoS in view form 
		Arguments:
			qos : nodeset from vzenv:conv-qos-data()
			alerts: nodeset with QoS alerts [optional]
		Result
			ui:* content
	-->
	<xsl:template name="vzenv:view-qos">
		<xsl:param name="qos"/>	
		<xsl:param name="show-usage" select="true()"/>		
		<xsl:param name="show-selector" select="false()"/>	
		<xsl:param name="selected-res" select="/.."/>		
		<xsl:param name="total-alerts" select="/.."/>	
		
		<xsl:variable name="descr-width" select="sw:if($show-usage,'50','60')"/>
		
		<xsl:for-each select="$qos/ui:qos-category[ui:qos-param]">
			<xsl:variable name="cat" select="."/>
			<xsl:variable name="cat-pos" select="position()"/>
			<!-- Show one category -->
			<ui:rows title="{$cat/@title}"
				status-def="{sw:if($total-alerts/alerts/alert[id = $cat/ui:qos-param/@real-id],1,$cat/@status-def)}"
				closed-text="{$cat/@closed-text}" tip="{$cat/@tip}"
			>
				<xsl:if test="$cat/@status-def!='1'">
					<xsl:attribute name="id">
						<xsl:value-of select="$cat/@id"/>
					</xsl:attribute>
				</xsl:if>
				<!-- Show Headers -->
				<ui:row type="head">
					<!-- Show category selector -->
					<xsl:if test="$show-selector">
						<ui:cell-check id="cat_sel_{$cat-pos}" 
							cell-width="20"
							onchange="clickCat{$cat-pos}(checked)"
							checked="{boolean(not($selected-res) or 
								count(ui:qos-param)=count(ui:qos-param[@real-id=$selected-res/res/id])
							)}"
						>
						</ui:cell-check>
						<ui:java-script>
							function clickCat<xsl:value-of select="$cat-pos"/>(checked){
								<xsl:for-each select="$cat/ui:qos-param">
									<xsl:variable name="real-id" select="@real-id"/>
									document.getElementById('res_sel_<xsl:value-of select="$real-id"/>').checked=checked;
								</xsl:for-each>
							}
							function checkCat<xsl:value-of select="$cat-pos"/>(){
							  var count_checked=0;
								<xsl:for-each select="$cat/ui:qos-param">
									<xsl:variable name="real-id" select="@real-id"/>
									if(document.getElementById('res_sel_<xsl:value-of select="$real-id"/>').checked) count_checked++;
								</xsl:for-each>
								document.getElementById('cat_sel_<xsl:value-of select="$cat-pos"/>').checked=count_checked==<xsl:value-of select="count($cat/ui:qos-param)"/>;
							}
						</ui:java-script>
					</xsl:if>
					<!-- /Show category selector -->
					<xsl:choose>
						<xsl:when test="$qos/@show-soft-limit='true'">
							<ui:cell cell-width="10%" align="left">
								<nobr>
									<sw:text>Parameter</sw:text>
								</nobr>
							</ui:cell>
							<xsl:if test="$show-usage">
								<ui:cell cell-width="10%" align="right">
									<nobr>
										<sw:text>Current Use</sw:text>
									</nobr>
								</ui:cell>
							</xsl:if>
							<ui:cell cell-width="10%" align="right">
								<nobr>
									<sw:text>Soft Limit</sw:text>
								</nobr>
							</ui:cell>
							<ui:cell cell-width="10%" align="right">
								<nobr>
									<sw:text>Hard Limit</sw:text>
								</nobr>
							</ui:cell>
							<ui:cell cell-width="10%" align="center">
								<nobr>
									<sw:text>Units</sw:text>
								</nobr>
							</ui:cell>
							<ui:cell cell-width="{$descr-width}%" align="center">
								<nobr>
									<sw:text>Description</sw:text>
								</nobr>
							</ui:cell>
							<ui:cell cell-width="16" align="center">&#160;</ui:cell>
						</xsl:when>
						<xsl:otherwise>
							<ui:cell cell-width="20%" align="left">
								<nobr>
									<sw:text>Parameter</sw:text>
								</nobr>
							</ui:cell>
							<xsl:if test="$show-usage">
								<ui:cell cell-width="10%" align="right">
									<nobr>
										<sw:text>Current Use</sw:text>
									</nobr>
								</ui:cell>
							</xsl:if>
							<ui:cell cell-width="10%" align="right">
								<sw:text>Limit</sw:text>
							</ui:cell>
							<ui:cell cell-width="10%" align="center">
								<sw:text>Units</sw:text>
							</ui:cell>
							<ui:cell cell-width="{$descr-width}%" align="center">
								<sw:text>Description</sw:text>
							</ui:cell>
							<ui:cell cell-width="16" align="center">&#160;</ui:cell>
						</xsl:otherwise>
					</xsl:choose>
				</ui:row>
				<!-- Show Resources -->
				<xsl:for-each select="$cat/ui:qos-param">
					<xsl:variable name="real-id" select="@real-id"/>
					<xsl:variable name="alert" select="$total-alerts/alerts/alert[id = $real-id]/type"/>
					<ui:row>
						<xsl:attribute name="class">
							<xsl:choose>
								<xsl:when test="$alert &gt;= 2">rowRed</xsl:when>
								<xsl:when test="$alert &gt;= 1">rowYellow</xsl:when>
								<xsl:otherwise>
									<xsl:choose>
										<xsl:when test="position() mod 2">EvenRow</xsl:when>
										<xsl:otherwise>OddRow</xsl:otherwise>
									</xsl:choose>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:attribute>
				
						<xsl:if test="$show-selector">
							<ui:cell-check id="res_sel_{$real-id}" 
								cell-width="20"
								checked="{boolean(not($selected-res) or $selected-res/res[id=$real-id])}"
								onchange="checkCat{$cat-pos}()"
							>
							</ui:cell-check>
						</xsl:if>
						
						<ui:cell align="left">
							<xsl:value-of select="@real-id"/>
						</ui:cell>
	
						<!-- Show current -->
						<xsl:if test="$show-usage">
							<ui:cell align="right">
								<xsl:choose>
									<xsl:when test="@current &gt;= 0">
										<xsl:value-of select="@current-str"/>
									</xsl:when>
									<xsl:otherwise>
										<sw:text>n/a</sw:text>
									</xsl:otherwise>
								</xsl:choose>
							</ui:cell>
						</xsl:if>
	
						<!-- Show soft -->
						<xsl:if test="$qos/@show-soft-limit='true'">
							<ui:cell align="right">
								<xsl:choose>
									<xsl:when test="@soft-off='true'">
										<sw:text>n/a</sw:text>
									</xsl:when>
									<xsl:when test="@unlimited='true' and @unlimited-control-type='checkbox'">
										<xsl:value-of select="@unlimited-label"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="format:res2str(@soft,@unit,true())"/>
									</xsl:otherwise>
								</xsl:choose>
							</ui:cell>
						</xsl:if>
	
						<!-- Show Hard -->
						<ui:cell align="right">
							<xsl:choose>
								<xsl:when test="@hard-off='true'">
									<sw:text>n/a</sw:text>
								</xsl:when>
								<xsl:when test="@hard-min = @hard-max">
									<sw:text>maximum</sw:text>
								</xsl:when>
								<xsl:when test="@unlimited='true' and @unlimited-control-type='checkbox'">
									<xsl:value-of select="@unlimited-label"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="format:res2str(@hard,@unit,true())"/>
								</xsl:otherwise>
							</xsl:choose>
						</ui:cell>
	
						<!-- Show Unit -->
						<ui:cell align="center">
							<nobr>
								<xsl:value-of select="@unit-label"/>
							</nobr>
						</ui:cell>
	
						<!-- Show Short -->
						<ui:cell align="left">
							<sw:text select="@short"  domain="vzagent-vocabulary" />
						</ui:cell>
	
						<!-- Show Unit -->
						<ui:cell align="center">
							<a onmouseover="callTip('get_help_resource',event)" onmouseout="callTip()"
								href="javascript:open_help('{$baseurl}/help?topic={$cat/@help-topic}&amp;a={@real-id}')">
								<img width="16" height="16" border="0" src="/{$theme}/icons/help_16.gif"/>
							</a>
						</ui:cell>
					</ui:row>
				</xsl:for-each>
				<!-- /Show Resources -->
			</ui:rows>
			<!-- /Show one category -->			
		</xsl:for-each>
		
	</xsl:template>
	
	
	<xsl:template name="vzenv:review-qos">
		<xsl:param name="hn-eid"/>	
		<xsl:param name="platform-ref"/>
		<xsl:param name="all-qos"/>
		<xsl:param name="only-changed" select="true()"/>
		<xsl:param name="validate" select="true()"/>
		<xsl:param name="rows-title" select="sw:text('Customized Resources')"/>
		<!--|-->
		<xsl:variable name="slm-mode" select="$all-qos/slm-mode"/>
		<xsl:variable name="qos-warns-src">
			<xsl:if test="$slm-mode!='slm' and vt:is-platform-linux($platform-ref/platform) and $validate">
				<xsl:call-template name="sw:validateQoS">
					<xsl:with-param name="hn-eid" select="$hn-eid"/>											
					<xsl:with-param name="data" select="$all-qos"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:variable>
		<xsl:variable name="qos-warns" select="exsl:node-set($qos-warns-src)"/>
    	<xsl:if test="$qos-warns//error/code">
  		<xsl:if test="error:put(sw:text('The resources validation has failed.'),$qos-warns/packet//error/message)"/>
  	</xsl:if>	 
		<!--|-->
		<!-- Translate data into internal format -->
		<xsl:variable name="qos-src">
			<xsl:call-template name="vzenv:conv-qos-data">
				<xsl:with-param name="platform-ref" select="$platform-ref"/>
				<xsl:with-param name="data" select="$all-qos"/>
				<xsl:with-param name="qos-warns" select="$qos-warns"/>
				<xsl:with-param name="only-changed" select="$only-changed"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="qos" select="exsl:node-set($qos-src)/ui:qos-data"/>
		<!-- /Translate data into internal format -->
		
		<xsl:if test="count($qos//ui:qos-param)">
			<ui:rows title="{$rows-title}">
			
				<xsl:for-each select="$qos/ui:qos-category[ui:qos-param]">
					<xsl:variable name="cat" select="."/>
				
					<ui:row>
						<ui:cell cell-width="50%"><b><xsl:value-of select="$cat/@title"/></b></ui:cell>
						<xsl:if test="$qos/platform-linux">
							<ui:cell cell-width="16%" align="right"><b><nobr><sw:text>Soft Limit</sw:text></nobr></b></ui:cell>
							<ui:cell cell-width="16%" align="right"><b><nobr><sw:text>Hard Limit</sw:text></nobr></b></ui:cell>
							<ui:cell cell-width="16%" align="center"><b><nobr><sw:text>Units</sw:text></nobr></b></ui:cell>
						</xsl:if>
						<xsl:if test="$qos/platform-windows">
							<ui:cell cell-width="16%" align="right"><b><nobr><sw:text>Limit</sw:text></nobr></b></ui:cell>
							<ui:cell cell-width="16%" align="center"><b><nobr><sw:text>Units</sw:text></nobr></b></ui:cell>
							<ui:cell cell-width="16%" align="center"><b> </b></ui:cell>
						</xsl:if>					
					</ui:row>
					<xsl:for-each select="ui:qos-param">
						<xsl:variable name="id" select="@real-id"/>
						<ui:row>
							<ui:cell><xsl:value-of select="$id"/></ui:cell>
							<xsl:if test="$qos/@show-soft-limit='true'">
								<ui:cell align="right">
									<xsl:choose>
										<xsl:when test="@soft-off='true'"><sw:text>n/a</sw:text></xsl:when>
										<xsl:when test="@unlimited='true' and @unlimited-control-type='checkbox'"><xsl:value-of select="@unlimited-label"/></xsl:when>
										<xsl:otherwise><xsl:value-of select="format:res2str(@soft,@unit,true())"/></xsl:otherwise>
									</xsl:choose>  
								</ui:cell>
							</xsl:if>
							<ui:cell align="right">
								<xsl:choose>
									<xsl:when test="@hard-off='true'"><sw:text>n/a</sw:text></xsl:when>
									<xsl:when test="@hard-min = @hard-max"><sw:text>maximum</sw:text></xsl:when>
									<xsl:when test="@unlimited='true' and @unlimited-control-type='checkbox'"><xsl:value-of select="@unlimited-label"/></xsl:when>
									<xsl:otherwise><xsl:value-of select="format:res2str(@hard,@unit,true())"/></xsl:otherwise>
								</xsl:choose>  
							</ui:cell>
							<ui:cell align="center">
								<nobr><xsl:value-of select="@unit-label"/></nobr>
							</ui:cell>
							<xsl:if test="not($qos/@show-soft-limit='true')">
								<ui:cell> </ui:cell>
							</xsl:if>
						</ui:row>
					</xsl:for-each>
				</xsl:for-each>
				<xsl:if test="$qos-warns/packet/data/vzaenvm/validation">
					<ui:row>
						<ui:cell colspan="4">
							<b><sw:text>Resource Validation</sw:text></b>
						</ui:cell>
					</ui:row>
					<ui:row>
						<ui:cell colspan="4">
							<xsl:call-template name="vzenv:get-validate-results">
								<xsl:with-param name="qos" select="$all-qos/res"/>
								<xsl:with-param name="qos-warns" select="$qos-warns"/>
							</xsl:call-template>
						</ui:cell>
					</ui:row>
				</xsl:if>
			</ui:rows>
		</xsl:if>
	</xsl:template>
 	
	<func:function name="vzenv:get-memory-alert">
    <xsl:param name="ve-eid" select="sw:ve-eid()"/>
    <xsl:param name="total-alerts" select="/.."/>
		
		<xsl:variable name="env" select="env:get-env($ve-eid)/env"/>
		<xsl:variable name="slm-mode" select="$env/virtual_config/slm_mode"/>
		<xsl:variable name="parent-vt-settings" select="envm:get-vt-settings($env/parent_eid)"/>
		<xsl:variable name="hn-slm-loaded"		select="$parent-vt-settings/parameter[id='slm']/value"/>
		<xsl:variable name="hn-slm-mode"			select="$parent-vt-settings/parameter[id='slmmode']/value"/>

		<xsl:variable name="platform-is-windows" select="vt:is-platform-windows(ve:ve2platform($env))"/>
		
		<xsl:variable name="real-slm-mode">
			<xsl:choose>
				<xsl:when test="$slm-mode = 'ubc'">
					<!-- default behavior, not need check hnode slm -->
					<xsl:value-of select="'ubc'"/>
				</xsl:when>
				<xsl:when test="($slm-mode = 'slm' or $slm-mode = 'all') and ($hn-slm-loaded = 'yes')">
					<!-- ve in slm related mode even if node hav slm support -->
					<xsl:value-of select="$slm-mode"/>
				</xsl:when>
				<xsl:when test="not($slm-mode != '') and ($hn-slm-loaded = 'yes') and ($hn-slm-mode != '')">
					<!-- ve not have direct specify slm mode, use slm from hnode -->
					<xsl:value-of select="$hn-slm-mode"/>
				</xsl:when>
				<xsl:otherwise>
					<!-- fallback to ubc -->
					<xsl:value-of select="'ubc'"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

    <func:result>
	    <xsl:choose>
	    	<xsl:when test="$env/status/state != $env-state/running">
	    		<xsl:value-of select="'-1'"/>
	    	</xsl:when>
	    	<xsl:when test="$platform-is-windows">
			    <xsl:value-of select="$total-alerts/alerts/alert[id = 'vprvmem']/type"/>
	    	</xsl:when>
  	  	<xsl:when test="$real-slm-mode = 'slm'">
			    <xsl:value-of select="$total-alerts/alerts/alert[id = 'slmmemorylimit']/type"/>
		  	</xsl:when>		  
  	  	<xsl:when test="$real-slm-mode = 'all'">
			  	<!-- calc alert himself, mf -->
			  	<xsl:variable name="filtered-alerts-type-rtf">
				  	<xsl:copy-of select="$total-alerts/alerts/alert[id = 'kmemsize']/type"/>
			  		<xsl:copy-of select="$total-alerts/alerts/alert[id = 'tcprcvbuf']/type"/>
				  	<xsl:copy-of select="$total-alerts/alerts/alert[id = 'tcpsndbuf']/type"/>
				  	<xsl:copy-of select="$total-alerts/alerts/alert[id = 'dgramrcvbuf']/type"/>
				  	<xsl:copy-of select="$total-alerts/alerts/alert[id = 'othersockbuf']/type"/>
				  	<xsl:copy-of select="$total-alerts/alerts/alert[id = 'oomguarpages']/type"/>
				    <xsl:copy-of select="$total-alerts/alerts/alert[id = 'slmmemorylimit']/type"/>
		  		</xsl:variable>
					<xsl:value-of select="math:max(exsl:node-set($filtered-alerts-type-rtf)/type)"/>
		  	</xsl:when>
			  <xsl:otherwise>
			  	<!-- calc alert himself, mf -->
			  	<xsl:variable name="filtered-alerts-type-rtf">
				  	<xsl:copy-of select="$total-alerts/alerts/alert[id = 'kmemsize']/type"/>
			  		<xsl:copy-of select="$total-alerts/alerts/alert[id = 'tcprcvbuf']/type"/>
				  	<xsl:copy-of select="$total-alerts/alerts/alert[id = 'tcpsndbuf']/type"/>
				  	<xsl:copy-of select="$total-alerts/alerts/alert[id = 'dgramrcvbuf']/type"/>
				  	<xsl:copy-of select="$total-alerts/alerts/alert[id = 'othersockbuf']/type"/>
				  	<xsl:copy-of select="$total-alerts/alerts/alert[id = 'oomguarpages']/type"/>
		  		</xsl:variable>
					<xsl:value-of select="math:max(exsl:node-set($filtered-alerts-type-rtf)/type)"/>
			  </xsl:otherwise>
			</xsl:choose>		 
		</func:result>
	</func:function>		


</xsl:stylesheet>
