<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="exsl sw  func vzenv format"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl	="http://exslt.org/common"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
  xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
  xmlns:func	="http://exslt.org/functions"
  xmlns:vzenv ="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:format="http://www.swsoft.com/xsl/cp/format"
>

	<sw:include href="/lib/utils/format-resusage.xsl"/>
	
	<!-- return ui control for show rate management selector 	-->
	<func:function name="vzenv:show-rate-selector">
		<xsl:param name="form" select="/.."/> 		
		<func:result>
      <xsl:variable name="rate-base-offset" select="sw:if($form/ve/linux,1,0)"/>
      <xsl:variable name="enable-disable-class-rtf">
        <xsl:if test="$form/ve/linux">
          <!-- linux only -->
          <xsl:variable name="disable-class-rtf">
            <xsl:for-each select="$form/hn/class[id != 0]">
              <ui:control-slave inverse="true">
                <xsl:value-of select="concat('rate_',string(id))"/>
              </ui:control-slave>
              <ui:control-slave inverse="true">
                <xsl:value-of select="concat('factor_rate_',string(id))"/>
              </ui:control-slave>
              <ui:control-slave inverse="true">
                <xsl:value-of select="concat('class_',string(id))"/>
              </ui:control-slave>
            </xsl:for-each>
          </xsl:variable>
          <disable>
            <xsl:copy-of select="exsl:node-set($disable-class-rtf)"/>
          </disable>

          <xsl:variable name="enable-class-rtf">
            <xsl:for-each select="$form/hn/class[id != 0]">
              <ui:control-slave>
                <xsl:value-of select="concat('rate_',string(id))"/>
              </ui:control-slave>
              <ui:control-slave>
                <xsl:value-of select="concat('factor_rate_',string(id))"/>
              </ui:control-slave>
              <ui:control-slave>
                <xsl:value-of select="concat('class_',string(id))"/>
              </ui:control-slave>						
            </xsl:for-each>
          </xsl:variable>
          <enable>
            <xsl:copy-of select="exsl:node-set($enable-class-rtf)"/>
          </enable>
        </xsl:if>
      </xsl:variable>    
      <xsl:variable name="enable-disable-class" select="exsl:node-set($enable-disable-class-rtf)"/>

      <ui:rows separate-tables="true" title="{sw:text('Rate Guarantees Setup')}">
				<xsl:if test="$form/ve/linux">
          <!-- default rate -->
          <ui:row offset="{$rate-base-offset}">
            <ui:cell-radio name="rate_type"	id="rate_type_default" value="default"  close="false" colspan="2">
              <xsl:if test="$form/rate-type = 'default'">
                <xsl:attribute name="checked">true</xsl:attribute>
              </xsl:if>
              <xsl:copy-of select="$enable-disable-class/disable/*"/>
            </ui:cell-radio>
            <ui:cell open="false">
              <sw:text>Use the default settings of the Hardware Node</sw:text>
            </ui:cell>
          </ui:row>
          <ui:row>
            <ui:cell>
              <ul style="padding:0;margin-top:0;margin-bottom:0;margin-left:30px">
                <span class="inactive">
                  <sw:text>
                    The Container rate guarantees will be taken from the HN configuration.<br/> The current HN configuration is the following:<br/>
                  </sw:text>
                </span>
                <xsl:variable name="def-rate" select="$form/hn/class"/>
                <xsl:choose>			
                  <xsl:when test="$def-rate">				
                    <xsl:for-each select="$def-rate">
                      <xsl:variable name="class-id"  select="id"/>
                      <li style="padding:3px">
                        <sw:text>
                          <xsl:with-param name="class-id" select="$class-id"/>
                          <xsl:with-param name="totalrate" select="format:kbps2bps(totalrate,'','yes','#,##0.00')/value"/>
                          <xsl:with-param name="rate"			select="format:kbps2bps(rate,'','yes','#,##0.00')/value"/>
                          Class %{class-id}:  Total Rate %{totalrate}, Rate Guarantee %{rate}
                        </sw:text>
                      </li>
                    </xsl:for-each>
                  </xsl:when>
                  <xsl:otherwise>
                    <span><sw:text>No default rate guarantees have yet been specified.</sw:text></span>
                  </xsl:otherwise>
                </xsl:choose>
              </ul>
            </ui:cell>
          </ui:row>
          <!-- /default rate -->
          <!-- /linux only -->
				</xsl:if>
        <!-- custom rate -->
        <xsl:choose>
					<xsl:when	test="$form/ve/linux">
            <ui:row offset="{$rate-base-offset}">
              <ui:cell-radio name="rate_type"  id="rate_type_custom" value="custom"  close="false" colspan="2">
                <xsl:if test="$form/rate-type = 'custom'">
                  <xsl:attribute name="checked">true</xsl:attribute>
                </xsl:if>
                <xsl:copy-of select="$enable-disable-class/enable/*"/>
              </ui:cell-radio>
              <ui:cell open="false">
                <sw:text>Configure the Container rate guarantees manually</sw:text>
              </ui:cell>
            </ui:row>
          </xsl:when>
					<xsl:otherwise>
						<ui:hidden name="rate_type" id="rate_type_custom" value="custom"/>
					</xsl:otherwise> 
        </xsl:choose>
        
        <ui:row>
          <ui:cell colspan="2" offset="{$rate-base-offset + 2}">
            <span class="inactive">
              <sw:text>
                Select the classes for which you want the Container traffic shaping to be enabled. 
              </sw:text>
            </span>
          </ui:cell>
        </ui:row>
        
        <xsl:for-each select="$form/hn/range[class_id != 0]">
	        <xsl:sort select="class_id" data-type="number"/>
          <xsl:variable name="class-id" select="class_id"/>
          <xsl:variable name="rate-name"	select="concat('rate_', $class-id)"/>
          <xsl:variable name="class" select="$form/hn/class[id = $class-id]"/>
          <xsl:if test="$class/totalrate or not($form/ve/linux)">
            <ui:row offset="{$rate-base-offset +2}">
              <ui:cell-text>
                <b><xsl:value-of select="concat(sw:text('Class'), ' ', $class-id)"/></b>
              </ui:cell-text>
            </ui:row>							
            <ui:row offset="{$rate-base-offset + 2}">
              <ui:cell-check name="class" id="class_{$class-id}" close="false" cell-width="100%" colspan="9"
                value="{$class-id}" checked="{$form/ve/interface_rate/class_id = $class-id}" align="left">
                <ui:control-slave>
                  <xsl:value-of select="$rate-name"/>
                </ui:control-slave>
                <ui:control-slave>
                  <xsl:value-of select="concat('factor_rate_',$class-id)"/>
                </ui:control-slave> 
              </ui:cell-check>
              <ui:cell label-for="{$class-id}" open="false" align="left">
                <nobr>
                  <sw:text>Enable shaping for this class</sw:text>
                </nobr>
              </ui:cell>
            </ui:row>
            <xsl:if test="$form/ve/linux">
              <ui:row offset="{$rate-base-offset + 2}">
                <ui:cell cell-width="10%" align="left">
                  <nobr>
                    <sw:text>Total Rate</sw:text>
                  </nobr>
                </ui:cell>
                <ui:cell cell-width="15%" width="20" align="left">
                  <xsl:choose>
                    <xsl:when test="not($class/totalrate)">
                      <sw:text>Not Configured</sw:text>
                    </xsl:when>
                    <xsl:otherwise>
                      <xsl:value-of select="format:kbps2bps($class/totalrate,'','yes','#,##0.00')/value"/>
                    </xsl:otherwise>
                  </xsl:choose>
                </ui:cell>
              </ui:row>
            </xsl:if>
            <!-- prepare to show -->

            <xsl:variable name="rate-detail-rtf">
              <xsl:choose>
                <xsl:when test="error:has-errors()">
                  <factor>
                    <xsl:value-of select="$form/ve/interface_rate[class_id = $class-id]/factor_rate"/>
                  </factor>
                  <value>
                    <xsl:value-of select="$form/ve/interface_rate[class_id = $class-id]/rate"/>
                  </value>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:copy-of select="format:kbps2bps($form/ve/interface_rate[class_id = $class-id]/rate,'','no','#0.00')"/>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:variable>
            <xsl:variable name="rate-detail" select="exsl:node-set($rate-detail-rtf)"/>

            <ui:row offset="{$rate-base-offset + 2}">
              <ui:cell cell-width="10%" align="left">
                <nobr>
                  <sw:text>Rate Guarantee</sw:text>
                </nobr>
              </ui:cell>
              <ui:cell-input nowrap="1" maxlength="9" id="{$rate-name}"
                value="{$rate-detail/value}" tip="rate"
                cell-width="10%" width="10"/>
              <!-- Units -->
              <ui:cell-list id="factor_{$rate-name}" style="width:55px" value="{$rate-detail/factor}">
                <ui:list-item id="1000" title="{sw:text('Kbps')}"/>
                <ui:list-item id="1000000" title="{sw:text('Mbps')}"/>
                <ui:list-item id="1000000000" title="{sw:text('Gbps')}"/>
              </ui:cell-list>
            </ui:row>
          </xsl:if>
        </xsl:for-each>				
        <!-- /custom rate -->
      </ui:rows>
      <xsl:choose>
        <xsl:when test="$form/ve/linux">
          <ui:rows separate-tables="true" title="{sw:text('Rate Limits Setup')}">
            <ui:row offset="{$rate-base-offset}">
              <ui:cell-check name="rate_bound" id="rate_bound" close="false" cell-width="100%" colspan="9"
                value="1" checked="{$form/ve/rate_bound = 1}" align="left">
              </ui:cell-check>
              <ui:cell label-for="rate_bound" open="false" align="left">
                <sw:text>Do not allow to exceed the rate guarantees</sw:text>
                <ul style="padding:0;margin-top:0;margin-bottom:0;margin-left:30px">
                  <span class="inactive">
                    <sw:text>
                    Select this checkbox if you want to disallow the Container to get more bandwidth than is defined in its rate guarantees.
                    </sw:text>
                  </span>
                </ul>
              </ui:cell>
            </ui:row>
          </ui:rows>
        </xsl:when>
        <xsl:otherwise>
          <ui:hidden name="rate_bound" id="rate_bound" value="1"/>
        </xsl:otherwise>
      </xsl:choose>
		</func:result>
	</func:function>
 
</xsl:stylesheet>
