<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred func voc vzhn env vz"
  xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl			="http://exslt.org/common"
  xmlns:func			="http://exslt.org/functions"
  xmlns:sw				="http://www.swsoft.com/xsl/cp"
	xmlns:cred			="http://www.swsoft.com/xsl/cp/cred"
	xmlns:voc				="http://www.swsoft.com/xsl/cp/voc"	
	xmlns:vzhn				="http://www.swsoft.com/xsl/cp/vzhn"
	xmlns:env				="http://www.swsoft.com/xsl/cp/env"
	xmlns:ui				="http://www.swsoft.com/xsl/cp/ui"
	xmlns:vt				="http://www.swsoft.com/xsl/cp/vt"	
	xmlns:vz				="http://www.swsoft.com/xsl/cp/vz"
	xmlns:hn				="http://www.swsoft.com/xsl/cp/hn"
	xmlns:trace			="http://www.swsoft.com/xsl/cp/trace"	
	xmlns:units			="http://www.swsoft.com/xsl/cp/units"	
>
	<sw:include	href="/lib/core/units-core.xsl"/>
	<sw:include href="/lib/vz/core.xsl"/>	
	<sw:include href="/lib/vt/hn-core.xsl"/>	
	<sw:include	href="/lib/vt/core.xsl"/>
	<sw:include href="../vt/env-core.xsl"/>	
	<sw:include href="../vocabulary.xsl"/>
	<sw:include href="/lib/trace.xsl"/>	

	<!-- Transform ENVs NODESET to RTF with ui:list-item data -->
	<func:function name="vzhn:envs2ui-items">
		<xsl:param name="envs"/>
		<func:result>					
			<xsl:for-each select="$envs">				
				<xsl:sort select="env:env2title(.)"/>
				<ui:list-item id="{eid}" title="{env:env2title(.)}"/>
			</xsl:for-each>
		</func:result>
	</func:function>
	
	<func:function name="vzhn:set-hn-from-req">
		<xsl:param name="method" select="'get'"/>
		<xsl:param name="name" select="'id'"/>
		<xsl:param name="ignore-unset" select="false()"/>
		<func:result>
			<xsl:variable name="get-hn-eid-base64" select="$request/http_request/*[name()=$method]/parameter[name = $name]/value"/>
			<xsl:variable name="curr-hn-eid"	select="sw:hn-eid()"/>
			<xsl:if test="not($ignore-unset) and $get-hn-eid-base64='' and $curr-hn-eid=''">
				<!-- no current hn, no hn from get/post, Only die here -->
				<sw:die>HN should be specified.</sw:die>
			</xsl:if>
			<xsl:variable name="get-hn-eid"	select="sw:base64-decode($get-hn-eid-base64)"/>
			
			<!-- change current hn -->
			<xsl:choose>
				<xsl:when test="$get-hn-eid!=''">
					<xsl:variable name="hn" select="vzhn:set-current($get-hn-eid)"/>
					<xsl:choose>
						<xsl:when test="$hn">
							<xsl:value-of select="$hn/eid"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="''"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:otherwise>
					<!-- can't detect hnode from request, use current -->
					<xsl:value-of select="$curr-hn-eid"/>					
				</xsl:otherwise>
			</xsl:choose>
			<!-- /change current hn -->
		</func:result>
	</func:function>
	
	<!--
		Result:
			Return ref to	HN env or empty nodeset
	-->
	<func:function name="vzhn:set-current">
		<xsl:param name="new-eid"/>
		<xsl:param name="new-context" select="string(sw:param('context'))"/>
	
		<!-- set hn from request -->
		<xsl:variable name="hn" select="hn:set-current($new-eid)"/>
		<xsl:if test="$hn">
		
			<xsl:variable name="parent-dn-get" select="$request/http_request/get/parameter[ name='parent-dn' ]/value"/>		
			<xsl:if test="$parent-dn-get!=''">
				<xsl:if test="units:set-current-dn(sw:base64-decode($parent-dn-get))"/>
			</xsl:if>
							
			<!-- set new context -->
			<xsl:choose>
				<!-- Setup default context -->
				<xsl:when test="$new-context='default' or $new-context=''">
					<xsl:if test="trace:set-branch('hn-home','unit')"/>
					<xsl:if test="units:set-current-dn(units:infra-top-dn())"/>					
				</xsl:when>
				<!-- In Unit -->
				<xsl:when test="$new-context='unit'">
					<xsl:if test="trace:set-branch('hn-home','unit')"/>				
				</xsl:when>													
				<!-- Unit already setuped context -->
				<xsl:when test="$new-context='current'">
				</xsl:when>									
			</xsl:choose>
			<!-- /check context -->

		</xsl:if>
		
		<!-- Return HN env -->
		<func:result select="$hn"/>
		
	</func:function>

</xsl:stylesheet>
