<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func redirect local"
  xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl		="http://exslt.org/common"
	xmlns:func		="http://exslt.org/functions"
  xmlns:sw			="http://www.swsoft.com/xsl/cp"
	xmlns:local 	="http://www.swsoft.com/xsl/cp/local"
	xmlns:envm		="http://www.swsoft.com/xsl/cp/envm"
	xmlns:env			="http://www.swsoft.com/xsl/cp/env"
	xmlns:redirect="http://www.swsoft.com/xsl/cp/redirect"	
	xmlns:vzenv   ="http://www.swsoft.com/xsl/cp/vzenv"
>

	<sw:include href="/lib/swa/envm.xsl"/>
	<sw:include href="/lib/vz/vzenv-core.xsl"/>	
	<sw:include href="/lib/vt/env-core.xsl"/>		
	
	<!-- load one or many redirect service .
    work as wrapper to envm:get-vt-settings, but convert dst EID to VEID, and <default/> to 1,0
		input: hn-eid
		       redirect-id - if present, then load only one redirect servce
		output: node 
								<service>
									<id>				offline service name
									<dst>				destination VEID
									<port>			redirected port
									<default>		1 = is service default
								</service>
	-->
	<func:function name="redirect:load">
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>
		<xsl:param name="redirect-id" select="''"/>		
		<xsl:variable name="redirect-rtf">
			<xsl:for-each select="envm:get-vt-settings($hn-eid)/offline_service[(id = $redirect-id) or ($redirect-id='')]">
				<service>
					<xsl:copy-of select="id|port"/>
					<dst>
            <xsl:value-of select="env:get-env(dst)/env/virtual_config/veid"/>
          </dst>
					<default>
						<xsl:value-of select="sw:if(default,1,0)"/>
					</default>
				</service>
			</xsl:for-each>
		</xsl:variable>
		<func:result select="exsl:node-set($redirect-rtf)"/>
	</func:function>


	<!-- save redirect service .
    work as wrapper envm:set-vt-settings, but convert dst VEID to EID and defalt 1,0 to <default/>
    input: hn-eid
		       redirect-service - node with offline services to save
		       	<service>
		       		<id>       service name
		       		<dst>      destination VEID
		       		<port>		 redirected port
		       		<default>  1 - service used as default, 0 - not used
		output: 
					result from vzaenvm/set_vt_settings packet:
					packet/data/vzaenvm/ok or error
	-->
	<func:function name="redirect:save">
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>
		<xsl:param name="redirect-service" select="/.."/>		
		<xsl:variable name="old-vt-settings" select="envm:get-vt-settings($hn-eid)/vt_settings/*[name() != 'offline_service']"/>
		<xsl:variable name="new-vt-settings-rtf">
			<vt_settings>
        <xsl:copy-of select="$old-vt-settings"/>
       <xsl:for-each select="$redirect-service/service">
          <offline_service>
            <xsl:copy-of select="id|port"/>
            <dst>
            	<xsl:value-of select="vzenv:veid-to-eid(dst,$hn-eid)"/>
						</dst>  
            <xsl:if test="default = 1">
              <default/>
            </xsl:if>
          </offline_service>
        </xsl:for-each>
			</vt_settings>
		</xsl:variable>
		<!-- Impersonated call -->
		<func:result select="envm:set-vt-settings($hn-eid,exsl:node-set($new-vt-settings-rtf),true())"/>
	</func:function>

	
	<!-- add one redirect service:
		input: hn-eid
		       new-redirect - node with new data:
		       								 <service>
		       								   <id>
		       								   <dst>
		       								   <port>
		       								   <default>
													 </service> 
		output: node 
								<packet>
									<cookie>
										<msg>
											<set-ok> or <set-error>
	-->	
	<func:function name="redirect:add">
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>
		<xsl:param name="new-redirect" select="/.."/>		
		<xsl:variable name="new-offline-services-rtf">
			<xsl:copy-of select="redirect:load($hn-eid)/service"/>
			<xsl:copy-of select="$new-redirect"/>
		</xsl:variable>
		<xsl:variable name="offline-services-rc"	select="redirect:save($hn-eid,exsl:node-set($new-offline-services-rtf))"/>
		<xsl:variable name="cookie-rtf">
			<msg>
				<ok>
					<xsl:value-of select="sw:text('The offline service has been successfully added.')"/>
				</ok>
				<error>
					<xsl:value-of select="sw:text('Cannot add the offline service.')"/>
				</error>
			</msg>
			<operation>redirect_add</operation>
			<redirect-prev/>
		</xsl:variable>
		<func:result select="local:format-answer($offline-services-rc,exsl:node-set($cookie-rtf))"/>
	</func:function>


	<!-- change one redirect service:
		input: hn-eid
		       edit-redirect - node with modifyed data:
		       								 <service>
		       								   <id>
		       								   <dst>
		       								   <port>
		       								   <default>
													 </service>
		output: node 
								<packet>
									<cookie>
										<msg>
											<set-ok> or <set-error>													 
	-->
	<func:function name="redirect:edit">
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>
		<xsl:param name="edit-redirect" select="/.."/>		
		<xsl:variable name="new-offline-services-rtf">
			<xsl:copy-of select="redirect:load($hn-eid)/service[not(id = $edit-redirect/service/id)]"/>
			<xsl:copy-of select="$edit-redirect"/>
		</xsl:variable>
		<xsl:variable name="offline-services-rc"	select="redirect:save($hn-eid,exsl:node-set($new-offline-services-rtf))"/>
		<xsl:variable name="cookie-rtf">
			<msg>
				<ok>
					<xsl:value-of select="sw:text('The offline service has been successfully changed.')"/>
				</ok>
				<error>
					<xsl:value-of select="sw:text('Cannot change the offline service.')"/>
				</error>
			</msg>
			<operation>redirect_edit</operation>
			<redirect-prev/>
		</xsl:variable>
		<func:result select="local:format-answer($offline-services-rc,exsl:node-set($cookie-rtf))"/>
	</func:function>


	<!-- delete redirected service(s):
		input: hn-eid
		       deleted-redirect-ids - node with id of deleted services:
		       								 <_>
		       								   <id>1
		       								   <id>2
													 </_>
		output: node 
								<packet>
									<cookie>
										<msg>
											<set-ok> or <set-error>													 
	-->	
	<func:function name="redirect:delete">
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>
		<xsl:param name="deleted-redirect-ids" select="/.."/>
		<xsl:variable name="new-offline-services-rtf">
			<xsl:for-each select="redirect:load($hn-eid)/service[not(id = $deleted-redirect-ids)]">
				<xsl:copy-of select="."/>
			</xsl:for-each>			
		</xsl:variable>
		<xsl:variable name="offline-services-rc"	select="redirect:save($hn-eid,exsl:node-set($new-offline-services-rtf))"/>
		<xsl:variable name="cookie-rtf">
			<msg>
				<ok>
					<xsl:value-of select="sw:text('The selected offline services have been successfully deleted.')"/>
				</ok>
				<error>
					<xsl:value-of select="sw:text('Cannot delete the selected offline services.')"/>
				</error>
			</msg>
			<operation>redirect_delete</operation>
			<redirect-last/>			
		</xsl:variable>
		<func:result select="local:format-answer($offline-services-rc,exsl:node-set($cookie-rtf))"/>
	</func:function>


	<!-- set redirected service(s) as default:
		input: hn-eid
		       selected-redirect-ids - node with id of selected services:
		       								 <_>
		       								   <id>1
		       								   <id>2
													 </_>
		output: node 
								<packet>
									<cookie>
										<msg>
											<set-ok> or <set-error>													 
	-->	
	<func:function name="redirect:set-default">
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>
		<xsl:param name="selected-redirect-ids" select="/.."/>		
		<xsl:variable name="new-offline-services-rtf">
			<xsl:for-each select="redirect:load($hn-eid)/service">
				<service>
					<xsl:copy-of select="id|port|dst"/>
					<xsl:choose>
						<xsl:when test="(default = 1) or (id = $selected-redirect-ids)">
							<default>1</default>
						</xsl:when>
						<xsl:otherwise>
							<default>0</default>
						</xsl:otherwise>
					</xsl:choose>
				</service>
			</xsl:for-each>
		</xsl:variable>
		<xsl:variable name="offline-services-rc"	select="redirect:save($hn-eid,exsl:node-set($new-offline-services-rtf))"/>
		<xsl:variable name="cookie-rtf">
			<msg>
				<ok>
					<xsl:value-of select="sw:text('The selected offline services have been successfully changed.')"/>
				</ok>
				<error>
					<xsl:value-of select="sw:text('Cannot change the selected offline services.')"/>
				</error>
			</msg>
			<operation>redirect_mark_as_default</operation>
			<redirect-last/>			
		</xsl:variable>
		<func:result	select="local:format-answer($offline-services-rc,exsl:node-set($cookie-rtf))"/>
	</func:function>


	<!-- set redirected service(s) as not default:
		input: hn-eid
		       selected-redirect-ids - node with id of selected services:
		       								 <_>
		       								   <id>1
		       								   <id>2
													 </_>
		output: node 
								<packet>
									<cookie>
										<msg>
											<set-ok> or <set-error>													 
	-->
	<func:function name="redirect:unset-default">
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>
		<xsl:param name="selected-redirect-ids" select="/.."/>
		<xsl:variable name="new-offline-services-rtf">
			<xsl:for-each select="redirect:load($hn-eid)/service">
				<service>
					<xsl:copy-of select="id|port|dst"/>
					<xsl:choose>
						<xsl:when test="(default = 0) or (id = $selected-redirect-ids)">
							<default>0</default>
						</xsl:when>
						<xsl:otherwise>
							<default>1</default>
						</xsl:otherwise>
					</xsl:choose>
				</service>
			</xsl:for-each>
		</xsl:variable>
		<xsl:variable name="offline-services-rc"	select="redirect:save($hn-eid,exsl:node-set($new-offline-services-rtf))"/>
		<xsl:variable name="cookie-rtf">
			<msg>
				<ok>
					<xsl:value-of select="sw:text('The selected offline services have been successfully changed.')"/>
				</ok>
				<error>
					<xsl:value-of select="sw:text('Cannot change the selected offline services.')"/>
				</error>
			</msg>
			<operation>redirect_mark_as_nodefault</operation>
			<redirect-last/>			
		</xsl:variable>
		<func:result	select="local:format-answer($offline-services-rc,exsl:node-set($cookie-rtf))"/>
	</func:function>


	<!-- function for format ok or error messages according results of operation.
		input: vzagent-answer - answer from agent like
															packet/data/vzaenvm/ok
																		or
															packet/data/vzaenvm/error
						cookie -  node with text diagnostic
												<msg>
													<ok>
													<error>
	-->	
	<func:function name="local:format-answer">
    <xsl:param name="vzagent-answer"/>
    <xsl:param name="cookie"/>
		<func:result>
			<packet>
  	  	<cookie>
					<msg>
	  	    	<xsl:choose>
  		      	<xsl:when test="$vzagent-answer/packet/data/vzaenvm/ok">
  		      		<set-ok>
									<xsl:value-of select="$cookie/msg/ok"/>
  	    	  		</set-ok>
  	      		</xsl:when>
  		      	<xsl:when test="$vzagent-answer/packet/data/vzaenvm/error">
  	      			<set-error>
									<short-desc>
										<xsl:value-of select="$cookie/msg/error"/>
									</short-desc>
									<detail>
										<xsl:value-of select="$vzagent-answer/packet/data/vzaenvm/error/message"/>
									</detail>
	  	      		</set-error>
  	      		</xsl:when>
  		      </xsl:choose>
					</msg>
					<xsl:copy-of select="$cookie/operation"/>
					<xsl:copy-of select="$cookie/redirect-prev"/>
					<xsl:copy-of select="$cookie/redirect-last"/>
    		</cookie>
			</packet>
		</func:result>
  </func:function>


</xsl:stylesheet>
