<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
	extension-element-prefixes="exsl func networkm vznet local action sw xsi"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:exsl="http://exslt.org/common"
	xmlns:func="http://exslt.org/functions" xmlns:networkm="http://www.swsoft.com/xsl/cp/networkm"
	xmlns:vznet="http://www.swsoft.com/xsl/cp/vznet" xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:action="http://www.swsoft.com/xsl/cp/action" xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:vza_networkm="http://www.swsoft.com/webservices/vzl/4.0.0/networkm"
	xmlns:vzlt="http://www.swsoft.com/webservices/vzl/4.0.0/types">

	<sw:include href="../vza/networkm.xsl"/>
	<sw:include href="vznet-core.xsl"/>

	<func:function name="vznet:list-adaptors">
		<xsl:param name="hw_id"/>
		<xsl:variable name="req">
			<vza_networkm:net_device vzlt:ns="" xsi:type="vzlt:net_nicType"/>
		</xsl:variable>
		<func:result select="networkm:list($hw_id,exsl:node-set($req))"/>
	</func:function>

	<func:function name="vznet:get-adaptor">
		<xsl:param name="hw_id"/>
		<xsl:param name="adaptor_id"/>
		<xsl:variable name="req">
			<vza_networkm:net_device vzlt:ns="" xsi:type="vzlt:net_nicType">
				<id>
					<xsl:value-of select="$adaptor_id"/>
				</id>
			</vza_networkm:net_device>
		</xsl:variable>
		<xsl:variable name="list-result" select="networkm:list($hw_id,exsl:node-set($req))"/>
		<xsl:variable name="result">
			<xsl:choose>
				<xsl:when test="$list-result/*">
					<xsl:copy-of select="$list-result/*[position() = 1]"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="vznet:vznet-error('Network adaptor not found.')"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<func:result select="exsl:node-set($result)/*"/>
	</func:function>

	<func:function name="vznet:save-adaptor">
		<xsl:param name="hw_id"/>
		<xsl:param name="adaptor"/>
		<xsl:variable name="req">
			<vza_networkm:net_device vzlt:ns="" xsi:type="vzlt:net_nicType">
				<xsl:copy-of select="$adaptor/*"/>
			</vza_networkm:net_device>
		</xsl:variable>
		<xsl:variable name="cmd-result" select="networkm:set($hw_id,exsl:node-set($req))"/>
		<xsl:variable name="result">
			<xsl:choose>
				<xsl:when test="not($cmd-result/error)">
					<xsl:copy-of select="$cmd-result/*"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="vznet:vznet-error(string($cmd-result/error/message))"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<func:result select="exsl:node-set($result)"/>
	</func:function>

	<func:function name="vznet:get-adaptor-vlans">
		<xsl:param name="hw_id"/>
		<xsl:param name="adaptor_id"/>
		<xsl:variable name="req">
			<vza_networkm:net_device xsi:type="vza_networkm:net_vlanType">
				<base_device_id>
					<xsl:value-of select="$adaptor_id"/>
				</base_device_id>
			</vza_networkm:net_device>
		</xsl:variable>
		<func:result
			select="networkm:list($hw_id,exsl:node-set($req))/net_device[sw:split(@xsi:type,':')[last()] = 'net_vlanType']"
		/>
	</func:function>

	<sw:include href="/lib/common.xsl"/>
</xsl:stylesheet>
