<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
	extension-element-prefixes="exsl func networkm vznet action sw server_group"
	xmlns:exsl="http://exslt.org/common" xmlns:func="http://exslt.org/functions"
	xmlns:vza_networkm="http://www.swsoft.com/webservices/vzl/4.0.0/networkm"
	xmlns:vzlt="http://www.swsoft.com/webservices/vzl/4.0.0/types"
	xmlns:networkm="http://www.swsoft.com/xsl/cp/networkm"
	xmlns:vznet="http://www.swsoft.com/xsl/cp/vznet"
	xmlns:server_group="http://www.swsoft.com/xsl/cp/server_group"
	xmlns:action="http://www.swsoft.com/xsl/cp/action" xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:voc ="http://www.swsoft.com/xsl/cp/voc"
  xmlns:env ="http://www.swsoft.com/xsl/cp/env" 
	xmlns:xsi	="http://www.w3.org/2001/XMLSchema-instance"
>

	<sw:include href="../vza/networkm.xsl"/>
	<sw:include href="/lib/swa/server-group.xsl"/>
	<sw:include href="/lib//vocabulary.xsl"/>
	<sw:include href="/lib/utils/action.xsl"/>

	<xsl:variable name="vznet:not-connected" 		select="'not_connected'"/>
	<xsl:variable name="vznet:connected-iface" 	select="'connected_iface'"/>	
	<xsl:variable name="vznet:connected-switch" select="'connected_switch'"/>	

	<func:function name="vznet:list-devices">
		<xsl:param name="hw_id"/>
		<xsl:param name="req"/>
		<func:result select="networkm:list($hw_id,exsl:node-set($req))/net_device"/>
	</func:function>

	<func:function name="vznet:get-device">
		<xsl:param name="hw_id"/>
		<xsl:param name="device_id"/>
		<xsl:variable name="req">
			<vza_networkm:net_device>
				<id><xsl:value-of select="$device_id"/></id>
			</vza_networkm:net_device>
		</xsl:variable>
		<xsl:variable name="list-result" select="vznet:list-devices($hw_id,$req)"/>
		<func:result select="$list-result[position() = 1]"/>
	</func:function>

	<!-- input: hn-eid
			 output: node with loopback device name and description
			       <data>lo</data>
			       <short>Loopback interface name</short>
	-->
	<func:function name="vznet:get-loopback-device">
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>
		<func:result	select="exsl:node-set(voc:get('net', env:make-platform-ref($hn-eid)))[id = 'loopback_interface']"/>
	</func:function>

	<func:function name="vznet:action-delete">
		<xsl:param name="hw_id"/>
		<xsl:param name="bids"/>
		<func:result>
			<xsl:call-template name="action:make-packet">
				<xsl:with-param name="path" select="'actions/vzdir/infrman/hns/vznet/delete.xsl'"/>
				<xsl:with-param name="cookie">
					<msg>
						<sched>
							<sw:text>The network devices have been scheduled for deletion.</sw:text>
						</sched>
						<error>
							<sw:text>Failed to delete the network devices.</sw:text>
						</error>
					</msg>
					<operation>net_device.delete</operation>
					<redirect-last/>
				</xsl:with-param>
				<xsl:with-param name="input">
					<data>
						<xsl:for-each select="$bids">
							<net_device>
								<hw_id>
									<xsl:copy-of select="$hw_id"/>
								</hw_id>
								<id>
									<xsl:copy-of select="."/>
								</id>
							</net_device>
						</xsl:for-each>
					</data>
				</xsl:with-param>
			</xsl:call-template>
		</func:result>
	</func:function>

	<func:function name="vznet:action-set">
		<xsl:param name="hw_id"/>
		<xsl:param name="devices"/>

		<func:result>
			<xsl:call-template name="action:make-packet">
				<xsl:with-param name="path" select="'actions/vzdir/infrman/hns/vznet/set.xsl'"/>
				<xsl:with-param name="cookie">
					<msg>
						<sched>
							<sw:text>The updating of the network interfaces has been scheduled.</sw:text>
						</sched>
						<error>
							<sw:text>Failed to update the network interfaces.</sw:text>
						</error>
					</msg>
					<operation>net_device.set</operation>
					<redirect-last/>
				</xsl:with-param>
				<xsl:with-param name="input">
					<data>
						<hw_id>
							<xsl:value-of select="$hw_id"/>
						</hw_id>
						<net_devices>
							<xsl:copy-of select="$devices"/>
						</net_devices>
					</data>
				</xsl:with-param>
			</xsl:call-template>
		</func:result>
	</func:function>

	<func:function name="vznet:vznet-error">
		<xsl:param name="error_msg"/>
		<xsl:variable name="error">
			<xsl:element name="error">
				<xsl:value-of select="$error_msg"/>
			</xsl:element>
		</xsl:variable>
		<func:result select="exsl:node-set($error)"/>
	</func:function>

	<func:function name="vznet:merge-global-and-local-network">
		<xsl:param name="global-network"/>
		<xsl:param name="all-interfaces"/>
		<xsl:param name="switches"/>
		<xsl:param name="interfaces"/>
		<xsl:param name="hn-info"/>
		<!-- place in one node global network from server_group and local hn network -->
		<xsl:variable name="global-and-local-network-rtf">		
			<!-- copy only global networks, which has not connected already.
					 to avoid double records.
			-->
			<xsl:copy-of select="$global-network/network[not(id = $all-interfaces/network_id)]"/>
			<xsl:choose>
				<xsl:when test="$hn-info/linux">
					<xsl:for-each select="$switches/network_id">
						<xsl:variable name="cur-network-id" select="."/>
						<xsl:variable name="connected-iface-id"  select="$interfaces[network_id = $cur-network-id]/id"/>
						<xsl:variable name="parent-global-network" select="$global-network/network[id = $cur-network-id]"/>
						<network>
							<connected-iface-id>
									<xsl:value-of select="$connected-iface-id"/>
							</connected-iface-id>
							<id><xsl:value-of select="$cur-network-id"/></id>
							<xsl:choose>
								<xsl:when test="count($parent-global-network) &gt; 0">
									<!-- current network on hnode has global nwtwork with same name 
											 Get description of network from cluster
									-->
									<global/>
									<description><xsl:value-of select="$parent-global-network/description"/></description>
								</xsl:when>
								<xsl:otherwise>
									<!-- network and bridge added from command line, vzcp show such net, but such net
											 not defined in cluster configuration. No desciptions.
											 market as localy defined 
									-->
									<local/>
									<description>
										<xsl:value-of select="sw:base64-encode(sw:text('Locally defined'))"/>
									</description>
								</xsl:otherwise>
							</xsl:choose>
						</network>
					</xsl:for-each>
				</xsl:when>
				<xsl:otherwise>
					<xsl:for-each select="$interfaces/network_id">
						<xsl:variable name="cur-network-id" select="."/>
						<xsl:variable name="connected-iface-id"  select="$interfaces[network_id = $cur-network-id]/id"/>
						<network>
							<connected-iface-id>
              	<xsl:value-of select="$connected-iface-id"/>
							</connected-iface-id>
							<id><xsl:value-of select="$cur-network-id"/></id>
							<description><xsl:value-of select="$global-network/network[id = $cur-network-id]/description"/></description>
						</network>
					</xsl:for-each>				
				</xsl:otherwise>				
			</xsl:choose>
		</xsl:variable>
		<func:result select="exsl:node-set($global-and-local-network-rtf)"/> 
	</func:function>

	<!-- it's more fast filter switches only from all interfaces, then ask agent -->
	<func:function name="vznet:filter-switches-from-all">
		<xsl:param name="all-interfaces"/>
		<func:result select="$all-interfaces[sw:split(@xsi:type,':')[last()] = 'net_bridgeType']"/>
	</func:function>

	<!-- it's more fast filter interfaces only from all interfaces, then ask agent -->
	<func:function name="vznet:filter-interfaces-from-all">
		<xsl:param name="all-interfaces"/>
		<func:result select="$all-interfaces[sw:split(@xsi:type,':')[last()] = 'net_nicType' or sw:split(@xsi:type,':')[last()] = 'net_vlanType']"/>
	</func:function>

	<!-- return true in case network is only localy defined
		global-network 		-  list network from clutserm
		base64-network-id -  network id in base64
	-->
	<func:function name="vznet:is-network-local">
		<xsl:param name="global-network"/>
		<xsl:param name="base64-network-id"/>
		<func:result select="not($global-network/network[id = $base64-network-id]) and ($base64-network-id != '')"/>
	</func:function>


	<!-- return <status>
							<interface>
							<scope>
				 for virtual network $nid
				status can be :
					for linux:		Connected
										 		Local
										 		Not Configured
				  for windows:	Connected
				  							Not Configured
				status can have modifier (Local) in case network defined only on hnode, but not in global network 
	-->				            
	
	<func:function name="vznet:get-network-connection-info">
		<xsl:param name="nid"/>
		<xsl:param name="global-and-local-network"/>
    <xsl:param name="interfaces"/>
    <xsl:param name="switches"/>
    <xsl:param name="hn-info"/> 

		<xsl:variable name="iconnected" select="$interfaces[network_id = $nid]"/>
		<xsl:variable name="network-details-rtf">
			<status>
				<xsl:choose>
					<xsl:when test="$hn-info/linux and (count($switches[network_id = $nid]) &gt; 0)">
						<xsl:attribute name="status"><xsl:value-of select="sw:if(count($iconnected) > 0,'connected','local')"/></xsl:attribute>
						<xsl:value-of
							select="sw:if(count($iconnected) > 0,sw:text('Connected'),sw:text('Local'))"
						/>
					</xsl:when>
					<xsl:when test="$hn-info/windows and (count($interfaces[network_id = $nid]) &gt; 0)">
						<xsl:attribute name="status">connected</xsl:attribute>
						<xsl:value-of select="sw:text('Connected')"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:attribute name="status">not configured</xsl:attribute>
						<sw:text>Not Configured</sw:text>
					</xsl:otherwise>
				</xsl:choose>
			</status>
			<interface>
				<xsl:value-of select="sw:if($iconnected,$iconnected/id,sw:text('Not Assigned'))"/>
			</interface>
		</xsl:variable>
		<func:result select="exsl:node-set($network-details-rtf)"/>
	</func:function>

	<!-- removed from interface list loopback device and down device -->
	<func:function name="vznet:remove-loopback-and-down-iface">
		<xsl:param name="hn-eid"/>
		<xsl:param name="interfaces"/>
		<xsl:variable name="iface-up"	select="vznet:list-devices($hn-eid,/..)[status/up]"/>
		<xsl:variable name="loopback-device"	select="vznet:get-loopback-device($hn-eid)"/>
		<func:result select="$interfaces/interface[(name != $loopback-device/data) and (name = $iface-up/id)]"/>
	</func:function>

	

	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
