<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
	extension-element-prefixes="exsl func networkm vznet action sw"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:exsl="http://exslt.org/common"
	xmlns:func="http://exslt.org/functions" xmlns:networkm="http://www.swsoft.com/xsl/cp/networkm"
	xmlns:vza_networkm="http://www.swsoft.com/webservices/vzl/4.0.0/networkm"
	xmlns:vzlt="http://www.swsoft.com/webservices/vzl/4.0.0/types"
	xmlns:vznet="http://www.swsoft.com/xsl/cp/vznet"
	xmlns:action="http://www.swsoft.com/xsl/cp/action" xmlns:sw="http://www.swsoft.com/xsl/cp">

	<sw:include href="../vza/networkm.xsl"/>
	<sw:include href="vznet-core.xsl"/>
	<sw:include href="/lib/utils/action.xsl"/>

	<func:function name="vznet:list-switches">
		<xsl:param name="hw_id"/>
		<xsl:variable name="req">
			<vza_networkm:net_device xsi:type="vza_networkm:net_bridgeType"/>
		</xsl:variable>
		<func:result select="networkm:list($hw_id,exsl:node-set($req))"/>
	</func:function>

	<func:function name="vznet:get-switch">
		<xsl:param name="hw_id"/>
		<xsl:param name="bridge_id"/>
		<xsl:variable name="req">
			<vza_networkm:net_device xsi:type="vza_networkm:net_bridgeType">
				<id>
					<xsl:value-of select="$bridge_id"/>
				</id>
			</vza_networkm:net_device>
		</xsl:variable>
		<xsl:variable name="list-result" select="networkm:list($hw_id,exsl:node-set($req))"/>
		<xsl:variable name="result">
			<xsl:choose>
				<xsl:when test="$list-result/*">
					<xsl:copy-of select="$list-result/*[position() = 1]"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="vznet:vznet-error('Network switch not found.')"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<func:result select="exsl:node-set($result)/*"/>
	</func:function>

	<func:function name="vznet:add-switch">
		<xsl:param name="hw_id"/>
		<xsl:param name="switch"/>
		<xsl:variable name="req">
			<vza_networkm:net_device xsi:type="vza_networkm:net_bridgeType">
				<xsl:if test="$switch/id != ''">
					<id>
						<xsl:value-of select="$switch/id"/>
					</id>
				</xsl:if>
				<network_id>
					<xsl:value-of select="$switch/network_id"/>
				</network_id>
			</vza_networkm:net_device>
		</xsl:variable>
		<xsl:variable name="cmd-result" select="networkm:add($hw_id,exsl:node-set($req))"/>
		<xsl:variable name="result">
			<xsl:choose>
				<xsl:when test="not($cmd-result/error)">
					<xsl:copy-of select="$cmd-result/*"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="vznet:vznet-error(string($cmd-result/error/message))"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<func:result select="exsl:node-set($result)"/>
	</func:function>

	<func:function name="vznet:save-switch">
		<xsl:param name="hw_id"/>
		<xsl:param name="switch"/>
		<xsl:variable name="req">
			<vza_networkm:net_device xsi:type="vza_networkm:net_bridgeType">
				<xsl:copy-of select="$switch/*"/>
			</vza_networkm:net_device>
		</xsl:variable>
		<xsl:variable name="cmd-result" select="networkm:set($hw_id,exsl:node-set($req))"/>
		<xsl:variable name="result">
			<xsl:choose>
				<xsl:when test="not($cmd-result/error)">
					<xsl:copy-of select="$cmd-result/*"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="vznet:vznet-error(string($cmd-result/error/message))"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<func:result select="exsl:node-set($result)"/>
	</func:function>

	<func:function name="vznet:delete-switch">
		<xsl:param name="hw_id"/>
		<xsl:param name="bridge_id"/>
		<xsl:variable name="req">
			<vza_networkm:net_device xsi:type="vza_networkm:net_bridgeType">
				<id>
					<xsl:value-of select="$bridge_id"/>
				</id>
			</vza_networkm:net_device>
		</xsl:variable>
		<func:result select="networkm:delete($hw_id,exsl:node-set($req))"/>
	</func:function>

	<func:function name="vznet:switch-interfaces">
		<xsl:param name="hw_id"/>
		<xsl:param name="bridge_id"/>
		<xsl:variable name="bridge" select="vznet:get-switch($hw_id,$bridge_id)"/>
		<xsl:variable name="result">
			<xsl:choose>
				<xsl:when test="not($bridge/error)">
					<xsl:variable name="network_id" select="sw:base64-decode($bridge/network_id)"/>
					<xsl:variable name="req">
						<vza_networkm:net_device vzlt:ns="" xsi:type="vzlt:net_nicType">
							<network_id>
								<xsl:value-of select="$network_id"/>
							</network_id>
						</vza_networkm:net_device>
						<vza_networkm:net_device xsi:type="vza_networkm:net_vlanType">
							<network_id>
								<xsl:value-of select="$network_id"/>
							</network_id>
						</vza_networkm:net_device>
					</xsl:variable>
					<xsl:copy-of select="networkm:list($hw_id,exsl:node-set($req))/*"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="$bridge"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<func:result select="exsl:node-set($result)"/>
	</func:function>

	<func:function name="vznet:switch-attachable">
		<xsl:param name="hw_id"/>
		<xsl:param name="switch"/>
		<xsl:variable name="req">
			<vza_networkm:net_device vzlt:ns="" xsi:type="vzlt:net_nicType"/>
			<vza_networkm:net_device xsi:type="vza_networkm:net_vlanType"/>
		</xsl:variable>
		<xsl:variable name="list-result" select="networkm:list($hw_id,exsl:node-set($req))"/>
		<xsl:variable name="result">
			<xsl:choose>
				<xsl:when test="not($list-result/error)">
					<xsl:copy-of select="$list-result/*[not(network_id) or network_id != $switch/network_id]"
					/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="vznet:vznet-error(string($list-result/error/message))"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<func:result select="exsl:node-set($result)"/>
	</func:function>

	<func:function name="vznet:action-delete-switches">
		<xsl:param name="hw_id"/>
		<xsl:param name="bids"/>
		<func:result>
			<xsl:call-template name="action:make-packet">
				<xsl:with-param name="path" select="'actions/vzdir/infrman/hns/vznet/delete.xsl'"/>
				<xsl:with-param name="cookie">
					<msg>
						<sched>
							<sw:text>The network switches have been scheduled for deletion.</sw:text>
						</sched>
						<error>
							<sw:text>Failed to delete the network switches.</sw:text>
						</error>
					</msg>
					<operation>net_bridge.delete</operation>
					<redirect-last/>
				</xsl:with-param>
				<xsl:with-param name="input">
					<data>
						<hw_id>
							<xsl:copy-of select="$hw_id"/>
						</hw_id>
						<net_devices>
							<xsl:for-each select="$bids">
								<vza_networkm:net_device xsi:type="vza_networkm:net_bridgeType">
									<id>
										<xsl:value-of select="."/>
									</id>
								</vza_networkm:net_device>
							</xsl:for-each>
						</net_devices>
					</data>
				</xsl:with-param>
			</xsl:call-template>
		</func:result>
	</func:function>

	<sw:include href="/lib/common.xsl"/>
</xsl:stylesheet>
