<!--
	Copyright (c) SWsoft, 1999-2007
	All rights reserved.
-->
      
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
	extension-element-prefixes="sw exsl cred wiz func vznet" 
	xmlns:exsl				="http://exslt.org/common"
	xmlns:xsi					="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:sw					="http://www.swsoft.com/xsl/cp"
	xmlns:func				="http://exslt.org/functions"
	xmlns:ui					="http://www.swsoft.com/xsl/cp/ui"
	xmlns:wiz					="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:cred				="http://www.swsoft.com/xsl/cp/cred"
	xmlns:form				="http://www.swsoft.com/xsl/cp/form"
	xmlns:vznet				="http://www.swsoft.com/xsl/cp/vznet"
	xmlns:request			="http://www.swsoft.com/xsl/cp/request"
	xmlns:env					="http://www.swsoft.com/xsl/cp/env"
	xmlns:error				="http://www.swsoft.com/xsl/cp/error"
	xmlns:server_group		="http://www.swsoft.com/xsl/cp/server_group"	
>

	<sw:include href="/lib/swa/server-group.xsl"/>
	<sw:include href="/layout/forms-list.xsl"/>
	<sw:include href="/lib/vz/vznet-core.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>

	<func:function name="vznet:ui-networks-list">
		<xsl:param name="data"/>
		<xsl:param name="disabled" select="false()"/>
		<xsl:param name="offset" select="2"/>
		<xsl:param name="allow-empty" select="false()"/>
		<func:result>
			<ui:cell-list id="network_id" disabled="{$disabled}" width="170" offset="{$offset}" value="{$data/gen/net_device/network_id}">
				<xsl:if test="$allow-empty">
					<ui:list-item id="" title="{sw:text('Not Assigned')}"/>
				</xsl:if>
				<xsl:for-each select="$data/static/networks/network[not(@disabled = 'true')]">
					<xsl:sort select="@id"/>
					<ui:list-item id="{@id}" title="{@id}"/>
				</xsl:for-each>
			</ui:cell-list>
		</func:result>
	</func:function>
	
	
	<xsl:template name="vznet:init-networks">
		<xsl:param name="current-adapter-id" select="''"/>
		
		<!-- Load data -->
		<xsl:variable name="master-hn-eid"	select="sw:master-eid()"/>
		<xsl:variable name="hn-eid"		select="sw:hn-eid()"/>
		<xsl:variable name="hn-info"  select="env:eid2info($hn-eid)"/>
		  
		<xsl:variable name="all-interfaces" select="vznet:list-devices($hn-eid,/..)"/>
		<xsl:variable name="switches" 			select="vznet:filter-switches-from-all($all-interfaces)"/>
		<xsl:variable name="interfaces"			select="vznet:filter-interfaces-from-all($all-interfaces)"/>
		<xsl:variable name="global-network" select="server_group:get-config($master-hn-eid,true())/networks"/>
		<xsl:variable name="global-and-local-network" select="vznet:merge-global-and-local-network($global-network,$all-interfaces,$switches,$interfaces,$hn-info)"/>

		<!-- Post networks -->
		<networks>
			<xsl:for-each select="$global-and-local-network/network">
				<network id="{sw:base64-decode(id)}">
					<xsl:if test="connected-iface-id != '' and (connected-iface-id != $current-adapter-id)">
						<xsl:attribute name="disabled">true</xsl:attribute>
					</xsl:if>
				</network>
			</xsl:for-each>
		</networks>
	</xsl:template>

	<xsl:template name="vznet:new-virtual-network">
		<xsl:param name="data"/>
		<ui:row>
			<ui:cell-label>
				<sw:text>Assign Virtual Network</sw:text>
			</ui:cell-label>
			<xsl:copy-of select="vznet:ui-networks-list($data,false(),'0',true())"/>
		</ui:row>
	</xsl:template>


	<xsl:template name="vznet:edit-virtual-network">
		<xsl:param name="data"/>
		<xsl:variable name="cur-network-id" select="string($data/gen/net_device/network_id)"/>	
		<ui:row>
			<ui:cell-label>
				<sw:text>Network</sw:text>
			</ui:cell-label>
			<xsl:copy-of select="vznet:ui-networks-list($data,false(),'0',true())"/>
		</ui:row>
	</xsl:template>


	<func:function name="vznet:restore-virtual-network">
		<func:result>
			<network_id>
				<xsl:value-of select="sw:param('network_id')"/>
			</network_id>
		</func:result>
	</func:function>
	
	<!--
		Check Virtual Network selection.
	-->
	<func:function name="vznet:check-virtual-network">
		<xsl:param name="data"/>
		<xsl:variable name="id" select="$data/gen/net_device/network_id"/>	
		
		<xsl:choose>
			<!-- Allow drop network selection -->
			<xsl:when test="$id=''">
			</xsl:when>
			<!-- Deny already used network selection -->			
			<xsl:when test="$data/static/networks/network[@id=$id and @disabled='true']">
				<xsl:if test="error:put(
					sw:text('The selected network is already used by a network adapter. Please select another virtual network.'),
					'','network_id'
				)"/>
			</xsl:when>
		</xsl:choose>
		
	</func:function>

	<func:function name="vznet:ui-vn-connection-form">
		<xsl:param name="data"/>
		<xsl:variable name="master-hn-eid"	select="sw:master-eid()"/>
		<xsl:variable name="hn-eid" select="sw:hn-eid()"/>
		<xsl:variable name="hn-info" select="env:eid2info($hn-eid)"/>
		<xsl:variable name="all-interfaces" 		select="vznet:list-devices($hn-eid,/..)"/>
		<xsl:variable name="base64_network_id" 	select="sw:if($data/gen/network_id,sw:base64-encode($data/gen/network_id),'')"/>
		<xsl:variable name="free-interfaces" 		select="vznet:filter-interfaces-from-all($all-interfaces)[not(network_id != '') or (network_id = $base64_network_id)]"/>
		<xsl:variable name="global-network"			select="server_group:get-config($master-hn-eid,true())/networks"/>
		<func:result>
			<ui:rows title="Assign Interface" separate-tables="true">
				<xsl:variable name="if_checked"
					select="not($data/gen/conn_type != '') or $data/gen/conn_type = $vznet:not-connected"/>
				<ui:row>
					<ui:cell-radio cell-width="200" name="conn_type" value="{$vznet:not-connected}" id="conn_type_nc" checked="{$if_checked}">
						<xsl:if test="count($free-interfaces) &gt; 0">
							<ui:control-slave inverse="true">interface</ui:control-slave>
						</xsl:if>
						<sw:text>Not Configured</sw:text>
					</ui:cell-radio>
				</ui:row>
				<xsl:if test="vznet:is-network-local($global-network,$base64_network_id)">
					<!-- it's case edit (not create) of localy defined network -->
					<ui:hidden name="network_type" value="local"/>					
					<ui:row>
						<ui:cell>&#160;</ui:cell>
						<ui:cell-text>
							<span class="inactive"><sw:text>Warning: the network will be deleted from the Hardware Node because it is defined only locally.</sw:text></span>
						</ui:cell-text>
					</ui:row>
				</xsl:if>
				<ui:row>
					<ui:cell-radio cell-width="200" name="conn_type" value="{$vznet:connected-iface}" id="conn_type_if"
						checked="{$data/gen/conn_type = $vznet:connected-iface}">
						<xsl:if test="count($free-interfaces) = 0">
							<xsl:attribute name="disabled"/>
						</xsl:if>
						<xsl:if test="count($free-interfaces) &gt; 0">
							<ui:control-slave>interface</ui:control-slave>
						</xsl:if>
						<sw:text>Connect via</sw:text>
					</ui:cell-radio>
					<xsl:choose>
						<xsl:when test="count($free-interfaces) = 0">
							<ui:cell-label>
								<sw:text>No free interface available</sw:text>
							</ui:cell-label>
						</xsl:when>
						<xsl:otherwise>
							<ui:cell-list id="interface" value="{$data/gen/interface}" width="70"
								disabled="{not($data/gen/conn_type = $vznet:connected-iface)}">
								<xsl:for-each select="$free-interfaces">
									<xsl:sort select="id"/>
									<ui:list-item id="{string(id)}">
										<xsl:attribute name="title">
											<xsl:value-of select="id"/>
										</xsl:attribute>
									</ui:list-item>
								</xsl:for-each>
							</ui:cell-list>
							<ui:hidden name="current_device_name" value="{$data/gen/interface}"/>
						</xsl:otherwise>
					</xsl:choose>
				</ui:row>
				<xsl:if test="$hn-info/linux">
					<ui:row>
						<ui:cell-radio cell-width="200" name="conn_type" value="{$vznet:connected-switch}" id="conn_type_switch"
							checked="{$data/gen/conn_type = $vznet:connected-switch}">
							<xsl:if test="count($free-interfaces) &gt; 0">
								<ui:control-slave inverse="true">interface</ui:control-slave>
							</xsl:if>
							<sw:text>Use on the Node only</sw:text>
						</ui:cell-radio>
					</ui:row>
				</xsl:if>
			</ui:rows>
		</func:result>
	</func:function>

	<func:function name="vznet:ui-restore-vn-connection">
		<func:result>
			<conn_type>
				<xsl:value-of select="sw:param('conn_type')"/>
			</conn_type>
			<interface>
				<xsl:value-of select="sw:param('interface')"/>
			</interface>
			<network_type>
				<xsl:value-of select="sw:param('network_type')"/>
			</network_type>			
		</func:result>
	</func:function>

	<sw:include href="/lib/common.xsl"/>
</xsl:stylesheet>
