<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
	extension-element-prefixes="exsl func networkm vznet local action sw"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:exsl="http://exslt.org/common"
	xmlns:func="http://exslt.org/functions" xmlns:networkm="http://www.swsoft.com/xsl/cp/networkm"
	xmlns:vznet="http://www.swsoft.com/xsl/cp/vznet" xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:action="http://www.swsoft.com/xsl/cp/action" xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:vza_networkm="http://www.swsoft.com/webservices/vzl/4.0.0/networkm">

	<sw:include href="../vza/networkm.xsl"/>
	<sw:include href="vznet-core.xsl"/>
	<sw:include href="/lib/utils/action.xsl"/>

	<func:function name="vznet:get-vlan">
		<xsl:param name="hw_id"/>
		<xsl:param name="vlan_id"/>
		<xsl:variable name="req">
			<vza_networkm:net_device xsi:type="vza_networkm:net_vlanType">
				<id>
					<xsl:value-of select="$vlan_id"/>
				</id>
			</vza_networkm:net_device>
		</xsl:variable>
		<xsl:variable name="list-result" select="networkm:list($hw_id,exsl:node-set($req))"/>
		<xsl:variable name="result">
			<xsl:choose>
				<xsl:when test="$list-result/*">
					<xsl:copy-of select="$list-result/*[position() = 1]"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="vznet:vznet-error('Network adaptor no found')"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<func:result select="exsl:node-set($result)/*"/>
	</func:function>

	<func:function name="vznet:add-vlan">
		<xsl:param name="hw_id"/>
		<xsl:param name="vlan"/>
		<xsl:variable name="req">
			<vza_networkm:net_device xsi:type="vza_networkm:net_vlanType">
				<xsl:copy-of select="$vlan/*"/>
			</vza_networkm:net_device>
		</xsl:variable>
		<xsl:variable name="cmd-result" select="networkm:add($hw_id,exsl:node-set($req))"/>
		<xsl:variable name="result">
			<xsl:choose>
				<xsl:when test="not($cmd-result/error)">
					<xsl:copy-of select="$cmd-result/*"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="vznet:vznet-error(string($cmd-result/error/message))"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<func:result select="exsl:node-set($result)"/>
	</func:function>

	<func:function name="vznet:save-vlan">
		<xsl:param name="hw_id"/>
		<xsl:param name="vlan"/>
		<xsl:variable name="req">
			<vza_networkm:net_device xsi:type="vza_networkm:net_vlanType">
				<xsl:copy-of select="$vlan/*"/>
			</vza_networkm:net_device>
		</xsl:variable>
		<xsl:variable name="cmd-result" select="networkm:set($hw_id,exsl:node-set($req))"/>
		<xsl:variable name="result">
			<xsl:choose>
				<xsl:when test="not($cmd-result/error)">
					<xsl:copy-of select="$cmd-result/*"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="vznet:vznet-error(string($cmd-result/error/message))"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<func:result select="exsl:node-set($result)"/>
	</func:function>

	<func:function name="vznet:action-delete-vlans">
		<xsl:param name="hw_id"/>
		<xsl:param name="bids"/>
		<func:result>
			<xsl:call-template name="action:make-packet">
				<xsl:with-param name="path" select="'actions/vzdir/infrman/hns/vznet/delete.xsl'"/>
				<xsl:with-param name="cookie">
					<msg>
						<sched>
							<sw:text>The VLANs have been scheduled for deletion.</sw:text>
						</sched>
						<error>
							<sw:text>Failed to delete the VLANs.</sw:text>
						</error>
					</msg>
					<operation>net_vlan.delete</operation>
					<redirect-last/>
				</xsl:with-param>
				<xsl:with-param name="input">
					<data>
						<hw_id>
							<xsl:copy-of select="$hw_id"/>
						</hw_id>
						<net_devices>
							<xsl:for-each select="$bids">
								<vza_networkm:net_device xsi:type="vza_networkm:net_vlanType">
									<id>
										<xsl:value-of select="."/>
									</id>
									</vza_networkm:net_device>
							</xsl:for-each>
						</net_devices>
					</data>
				</xsl:with-param>
			</xsl:call-template>
		</func:result>
	</func:function>

	<sw:include href="/lib/common.xsl"/>
</xsl:stylesheet>
