<?xml version="1.0" encoding="UTF-8"?>
<!--
	== Public Functions ==

	Information Loading
		vznet:vn-hn-info()
		
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
	extension-element-prefixes="exsl func networkm vznet action sw server_group"
	xmlns:exsl="http://exslt.org/common" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:func="http://exslt.org/functions"
	xmlns:networkm="http://www.swsoft.com/xsl/cp/networkm"
	xmlns:vznet="http://www.swsoft.com/xsl/cp/vznet"
	xmlns:server_group="http://www.swsoft.com/xsl/cp/server_group"
	xmlns:action="http://www.swsoft.com/xsl/cp/action" xmlns:sw="http://www.swsoft.com/xsl/cp"
>

	<sw:include href="/lib/utils/action.xsl"/>
	<sw:include href="/lib/vz/vznet-switch.xsl"/>
	<sw:include href="/lib/vz/vznet-adaptor.xsl"/>
	<sw:include href="/lib/vz/vznet-vlan.xsl"/>

	<func:function name="vznet:add-vn">
		<xsl:param name="network-rtf"/>
		<xsl:variable name="network" select="exsl:node-set($network-rtf)"/>
		<xsl:variable name="curr-config" select="server_group:get-config()"/>
		<xsl:variable name="new-config-rtf">
			<config>
				<xsl:copy-of select="$curr-config/*[local-name() != 'networks']"/>
				<networks>
					<xsl:copy-of select="$curr-config/networks/network"/>
					<network>
						<id>
							<xsl:value-of select="sw:base64-encode($network/network_id)"/>
						</id>
						<description>
							<xsl:value-of select="sw:base64-encode($network/description)"/>
						</description>
					</network>
				</networks>
			</config>
		</xsl:variable>
		<xsl:variable name="new-config" select="exsl:node-set($new-config-rtf)"/>
		<xsl:variable name="cmd-result" select="server_group:set-config($new-config/config)"/>
		
		<xsl:variable name="result">
			<xsl:choose>
				<xsl:when test="not($cmd-result[self::error])">
					<xsl:copy-of select="$cmd-result/*"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="vznet:vznet-error(string($cmd-result/message))"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<func:result select="exsl:node-set($result)"/>
	</func:function>
	
	<func:function name="vznet:is-vn-bridged">
		<xsl:param name="hw_id"/>
		<xsl:param name="network_id"/>
		<xsl:variable name="base64_network_id" select="sw:base64-encode($network_id)"/>
		<xsl:variable name="switches" select="vznet:list-switches($hw_id)"/>
		<func:result select="sw:if(count($switches/*[network_id = $base64_network_id]) &gt; 0,true(),false())"/>
	</func:function>
	
	<!--
		Get information about Virtual Network & HN connection.
		Arguments
			hn-eid
			network-id
		Result
			ref to nodeset
				info
					bridged : boolean
	-->
	<func:function name="vznet:vn-hn-info">
		<xsl:param name="hn-eid"/>
		<xsl:param name="network-id"/>
	
		<xsl:variable name="devices" select="vznet:list-devices($hn-eid,/..)"/>
		<xsl:variable name="interface"
				select="$devices[( sw:split(@xsi:type,':')[last()] = 'net_nicType' or sw:split(@xsi:type,':')[last()] = 'net_vlanType' ) and network_id = sw:base64-encode($network-id)]"/>	
	
		<xsl:variable name="res-rtf">
			<info>
				<interface>
					<id><xsl:value-of select="$interface/id"/></id>
				</interface>
				<bridged><xsl:value-of select="boolean(not($interface/id) and vznet:is-vn-bridged($hn-eid,$network-id))"/></bridged>
			</info>
		</xsl:variable>
		
		<func:result select="exsl:node-set($res-rtf)/info"/>
	
	</func:function>
	
	<func:function name="vznet:add-vn-bridged">
		<xsl:param name="hw_id"/>
		<xsl:param name="vn"/>
		<xsl:variable name="result" select="vznet:add-vn($vn)"/>
		<xsl:variable name="new-switch">
			<network_id><xsl:value-of select="$vn/network_id"/></network_id>
		</xsl:variable>
		<func:result select="sw:if(not($result/error != ''),vznet:set-vn-bridged($hw_id,$vn),$result)"/>
	</func:function>
	
	<func:function name="vznet:set-vn-bridged">
		<xsl:param name="hw_id"/>
		<xsl:param name="vn"/>
		<xsl:variable name="new-switch">
			<network_id><xsl:value-of select="$vn/network_id"/></network_id>
		</xsl:variable>
		<func:result select="vznet:add-switch($hw_id,exsl:node-set($new-switch))"/>		
	</func:function>
	
	<func:function name="vznet:add-vn-connected">
		<xsl:param name="hw_id"/>
		<xsl:param name="vn"/>
		<xsl:param name="interface"/>
		<xsl:param name="is-linux" select="true()"/>
		<xsl:variable name="device" select="vznet:get-device($hw_id,$interface)"/>		
		<xsl:variable name="add-result-rtf">
			<xsl:choose>
				<xsl:when test="$is-linux">
					<xsl:copy-of select="vznet:add-vn-bridged($hw_id,$vn)"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="vznet:add-vn($vn)"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="add-result" select="exsl:node-set($add-result-rtf)"/>
		<xsl:choose>
			<xsl:when test="$add-result/error">
				<func:result select="$add-result"/>				
			</xsl:when>
			<xsl:when test="sw:split($device/@xsi:type,':')[last()] = 'net_vlanType'">
				<xsl:variable name="vlan">
					<xsl:copy-of select="$device/id"/>
					<xsl:copy-of select="$vn/network_id"/>
				</xsl:variable>
				<func:result select="vznet:save-vlan($hw_id,exsl:node-set($vlan))"/>
			</xsl:when>
			<xsl:when test="sw:split($device/@xsi:type,':')[last()] = 'net_nicType'">
				<xsl:variable name="nic">
					<xsl:copy-of select="$device/id"/>
					<xsl:copy-of select="$device/mac_address"/>
					<xsl:copy-of select="$vn/network_id"/>
				</xsl:variable>
				<func:result select="vznet:save-adaptor($hw_id,exsl:node-set($nic))"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="vznet:vznet-error(sw:text('Internal error'))"/>
			</xsl:otherwise>			
		</xsl:choose>
	</func:function>
	
	<func:function name="vznet:update-vn">
		<xsl:param name="network_id"/>
		<xsl:param name="network-rtf"/>
		<xsl:variable name="network" select="exsl:node-set($network-rtf)"/>
		<xsl:variable name="curr-config" select="server_group:get-config()"/>
		<xsl:variable name="new-config-rtf">
			<config>
				<xsl:copy-of select="$curr-config/*[local-name() != 'networks']"/>
				<networks>
					<xsl:copy-of select="$curr-config/networks/network[id != sw:base64-encode($network_id)]"/>
					<network>
						<id>
							<xsl:value-of select="sw:base64-encode($network_id)"/>
						</id>
						<description>
							<xsl:value-of select="sw:base64-encode($network/description)"/>
						</description>
					</network>
				</networks>
			</config>
		</xsl:variable>
		<xsl:variable name="new-config" select="exsl:node-set($new-config-rtf)"/>
		<xsl:variable name="cmd-result" select="server_group:set-config($new-config/config)"/>		
		
		<xsl:variable name="result">
			<xsl:choose>
				<xsl:when test="not($cmd-result[self::error])">
					<xsl:copy-of select="$cmd-result/*"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="vznet:vznet-error(string($cmd-result/message))"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<func:result select="exsl:node-set($result)"/>		
	</func:function>	

	<func:function name="vznet:action-vns-disconnect">
		<xsl:param name="hw_id"/>
		<xsl:param name="vn_ids"/>
		<xsl:param name="conn-type-is-local" select="false()"/>
		<func:result>
			<xsl:call-template name="action:make-packet">
				<xsl:with-param name="path"
					select="'actions/vzdir/infrman/hns/vznet/vns-disconnect.xsl'"/>
				<xsl:with-param name="cookie">
					<msg>
						<sched>
							<sw:text>The virtual networks have been scheduled for disconnecting.</sw:text>
						</sched>
						<error>
							<sw:text>Failed to disconnect the virtual networks.</sw:text>
						</error>
					</msg>
					<operation>vn.disconnect</operation>
					<xsl:choose>
						<xsl:when test="$conn-type-is-local">
							<redirect><xsl:value-of select="concat($baseurl,'/vzdir/infrman/hns/vznet/vns/index')"/></redirect>
						</xsl:when>
						<xsl:otherwise>
							<redirect-prev/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:with-param>
				<xsl:with-param name="input">
					<data>
						<hw_id>
							<xsl:value-of select="$hw_id"/>
						</hw_id>
						<xsl:for-each select="$vn_ids">
							<network>
								<network_id>
									<xsl:copy-of select="."/>
								</network_id>
							</network>
						</xsl:for-each>
					</data>
				</xsl:with-param>
			</xsl:call-template>
		</func:result>
	</func:function>
	
	<!--
		Wrapper for action of new VN creation.
		Parameters:
			vn-info
				|_network_id
				|_description
				|_conn_type
				|_interface
				|_network_type
			hn-info - see env:eid2info
	-->
	<func:function name="vznet:action-vn-add">
		<xsl:param name="vn-info"/>
		<xsl:param name="hn-info"/>
		<func:result>
			<xsl:call-template name="action:make-packet">
				<xsl:with-param name="path" 
					select="'actions/vzdir/infrman/hns/vznet/vn-add.xsl'"/>
				<xsl:with-param name="cookie">
					<msg>
						<sched>
							<sw:text>The virtual network has been scheduled for creating.</sw:text>
						</sched>
						<error>
							<sw:text>Failed to create the virtual network.</sw:text>
						</error>
					</msg>
					<operation>vn.add</operation>
					<redirect-prev/>
				</xsl:with-param>
				<xsl:with-param name="input">
					<data>
						<hn-info>
							<xsl:copy-of select="$hn-info/*"/>
						</hn-info>
						<vn-info>
							<xsl:copy-of select="$vn-info/*"/>
						</vn-info>
					</data>
				</xsl:with-param>
			</xsl:call-template>
		</func:result>
	</func:function>

	<sw:include href="/lib/common.xsl"/>
	
</xsl:stylesheet>
