<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="exsl sw env date math func vznet networkm set perfmon"
	xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl			="http://exslt.org/common"
	xmlns:sw				="http://www.swsoft.com/xsl/cp"
	xmlns:env				="http://www.swsoft.com/xsl/cp/env"
	xmlns:date			="http://exslt.org/dates-and-times"
	xmlns:math			="http://exslt.org/math"
	xmlns:func			="http://exslt.org/functions"
	xmlns:vznet			="http://www.swsoft.com/xsl/cp/vznet"
	xmlns:networkm	="http://www.swsoft.com/xsl/cp/networkm"
	xmlns:set				="http://exslt.org/sets"
	xmlns:perfmon		="http://www.swsoft.com/xsl/cp/perfmon"
	>

  <sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vza/networkm.xsl"/>
	<sw:include href="/lib/swa/perfmon.xsl"/>
	
	<xsl:template name="vznet:resource-network">
		<xsl:param name="ve-eid" select="sw:ve-eid()"/>
		<xsl:param name="netcounters" select="/.."/>
		<xsl:variable name="env" select="env:get-env($ve-eid)/env"/>
		<xsl:variable name="platform"   select="env:env2platform($env)"/>
    <xsl:variable name="is-windows" select="vt:is-platform-windows($platform)"/>
    
		<xsl:variable name="traffic-rtf">
			<last-one-record>
				<xsl:copy-of  select="perfmon:get($ve-eid,'counters_vz_net')/data"/>
			</last-one-record>
		</xsl:variable>
		<xsl:variable name="traffic" select="exsl:node-set($traffic-rtf)"/>

		<resources>
			<xsl:variable name="start_time" select="$traffic/last-one-record/data/interval/start_time"/>
			<xsl:variable name="end_time"		select="$traffic/last-one-record/data/interval/end_time"/>
			<xsl:variable name="interval">
				<xsl:value-of select="sw:vzatime2utime($end_time) - sw:vzatime2utime($start_time)"/>
			</xsl:variable>
			<!-- calc bandwidth. 
					 Bandwidth not defined for class "All" and for class 0 (trap for all not defined classes) 
			-->
			<!-- get hnode shaper settings -->
			<xsl:variable name="netconfig-raw" select="networkm:get-config(sw:hn-eid())"/>
			<!-- get ve all rates -->
			<xsl:variable name="ve-rates" select="$env/virtual_config/interface_rate"/>			
			<xsl:variable name="ve-use-default-rates" select="not($env/virtual_config/interface_rate)"/>
			<xsl:for-each select="$netcounters/range[not(class_id = -1) and  not(class_id = 0)]">
				<xsl:sort select="class_id" data-type="number"/>
				<xsl:variable name="current-class-id" select="class_id"/>
				<resource>
					<name>id</name>
					<class>
						<xsl:value-of select="$current-class-id"/>
					</class>
					<fraction>
						<xsl:variable name="output-byte-raw" select="$traffic/last-one-record/data/class/instance[name = $current-class-id]/counter[name = 'counter_net_outgoing_bytes']/value/avg"/>
						<!-- agent not report counters for never used class, handle this -->
						<xsl:variable name="output-byte" select="sw:if(not($output-byte-raw != ''),0,$output-byte-raw)"/>
						<!-- bandwith for last time is
								output_in_bytes / allowed_output_in_bytes
								allowed_output_in_bytes = interval * rate_in_bytes
								rate_in_bytes = (rate_in_kbit * 1000) / 8
								Equal formaula is:
								bandwith = output_in_bytes / (interval * rate_in_kbit * 125)
						--> 
						<!-- get rate for current class -->
						<xsl:variable name="ve-rate"			select="$ve-rates[class_id = $current-class-id]/rate"/>
						<xsl:variable name="ve-ratebound"	select="$env/virtual_config/rate_bound"/>
						<xsl:variable name="rate">
							<xsl:choose>
								<xsl:when test="$is-windows">
									<xsl:choose>
										<xsl:when test="$ve-rate &gt;= 0">
											<!-- ratebound is always on for windows, use ve-rate as limit -->
											<xsl:value-of select="$ve-rate"/>							                                    
										</xsl:when>
										<xsl:otherwise>
											<!-- rate configured to empty, no limit for current class -->
											<xsl:value-of select="-1"/>
										</xsl:otherwise>
									</xsl:choose>										
								</xsl:when>
								<xsl:otherwise>
									<xsl:choose>
										<xsl:when test="($ve-ratebound = 1) and ($ve-rate &gt;= 0)">
											<!-- ratebound is ON, use ve-rate as limit -->
											<xsl:value-of select="$ve-rate"/>
										</xsl:when>									
										<xsl:when test="not($ve-ratebound = 1) and ($ve-rate &gt;= 0)">
											<!-- ratebound is OFF, use hnode totalrate as limit -->
											<xsl:value-of select="$netconfig-raw/class[id = $current-class-id]/totalrate"/>
										</xsl:when>
										<xsl:when test="$ve-use-default-rates">
											<!-- NO ONE rate in ve configured, but use hnode default  -->
											<xsl:value-of select="$netconfig-raw/class[id = $current-class-id]/rate"/>
										</xsl:when>										
										<xsl:otherwise>
											<!-- current ve rate is empty and it's not default case. No limit for such class -->
											<xsl:value-of select="-1"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						<xsl:choose>											
							<xsl:when test="$interval &gt; 0 and $rate &gt; 0">
								<xsl:value-of select="$output-byte div ($interval * $rate * 125)"/>
							</xsl:when>
							<xsl:otherwise>-1</xsl:otherwise>
						</xsl:choose>
					</fraction>
				</resource>
			</xsl:for-each>
		</resources>
	</xsl:template>


	<!-- Merge vz network classes and vzcp classes.
     Synthetic class -1: for all class
     Synthetic class 0: if not defined vz class 0 it's means "all other class"	 
	-->
	<func:function name="vznet:merge-network-class">
		<xsl:variable name="netcounters-raw" select="set:distinct(networkm:get-config(sw:hn-eid())/range/class_id)/.."/>
		<xsl:variable name="netcounters-rtf">
			<xsl:if test="not(($netcounters-raw/class_id = 0) and (count($netcounters-raw) = 1))">
				<!-- not showded "All" in special case: define only class 0, and it's masked system class 0 
						In all others cases -  show.
				-->
				<range>
					<class_id>-1</class_id>
					<title>
						<sw:text>All</sw:text>
					</title>
					<synthetic/>
				</range>
			</xsl:if>
			<xsl:for-each select="$netcounters-raw">
				<range>
					<xsl:copy-of select="class_id|comment"/>
					<title>					
						<xsl:choose>
							<xsl:when test="not(comment='')">
								<xsl:value-of select="concat(class_id, ' (', sw:base64-decode(comment),')' )"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="class_id"/>
							</xsl:otherwise>													
						</xsl:choose>
					</title>
				</range>
			</xsl:for-each>
			<xsl:if test="not($netcounters-raw/class_id = 0) and (count($netcounters-raw) &gt; 0)">
				<!-- class 0 not defined, show system defined class 0 - know  as 'Other' -->
				<range>
					<class_id>0</class_id>
					<title>
						<sw:text>Other</sw:text>
					</title>
					<synthetic/>
				</range>
			</xsl:if>
		</xsl:variable>
		<xsl:variable name="netcounters" select="exsl:node-set($netcounters-rtf)"/>
		<func:result select="$netcounters"/>
	</func:function>


</xsl:stylesheet>
