<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func filem cred"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:func="http://exslt.org/functions"
	xmlns:filem="http://www.swsoft.com/xsl/cp/filem"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
>

	<sw:include href="../common.xsl"/>
	<sw:include href="../cred.xsl"/>

	<!-- get file -->
	<func:function name="filem:get">
		<xsl:param name="path"/>
		<xsl:param name="eid"/>
		<xsl:param name="base64-decode" select="false()"/>
		<xsl:param name="impersonate" select="false()"/>
		
		<xsl:variable name="req">
			<packet>
				<target>filer</target>
				<xsl:copy-of select="sw:env-dst($eid)"/>
				<data>
					<filer>
						<download>
							<cwd>Lw==</cwd>
							<file>
								<path>
									<xsl:value-of select="sw:base64-encode($path)"/>
								</path>
							</file>
							<!--<packet_mode/>-->
						</download>
					</filer>
				</data>
				<xsl:if test="$impersonate">
					<vzcpauth/>
				</xsl:if>
			</packet>
		</xsl:variable>
		<xsl:variable name="res-data" select="sw:xchg($req)/packet/data"/>
		<xsl:variable name="error" select="$res-data/error|$res-data/filer/error"/>

		<xsl:choose>
			<xsl:when test="$error">
				<func:result select="$error"/>
			</xsl:when>
			<xsl:when test="$res-data/filer/file">
				<xsl:choose>
					<xsl:when test="$base64-decode">
						<func:result>
							<xsl:value-of disable-output-escaping="yes" select="sw:base64-decode($res-data/filer/file/body)"/>
						</func:result>
					</xsl:when>
					<xsl:otherwise>
						<func:result>
							<xsl:value-of disable-output-escaping="yes" select="$res-data/filer/file/body"/>
						</func:result>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise/>
		</xsl:choose>

	</func:function>

	<!-- get file -->
	<func:function name="filem:stat">
		<xsl:param name="cwd"/>
		<xsl:param name="path"/>
		<xsl:param name="eid"/>
		<xsl:param name="input"/>
		<xsl:param name="impersonate" select="false()"/>

		<xsl:variable name="req">
			<packet>
				<target>filer</target>
				<xsl:copy-of select="sw:env-dst($eid)"/>
				<data>
					<filer>
						<stat>
							<xsl:if test="$cwd != ''">
								<cwd>
									<xsl:value-of select="sw:base64-encode($cwd)"/>
								</cwd>
							</xsl:if>
							<path>
								<xsl:value-of select="sw:base64-encode($path)"/>
							</path>
							<xsl:if test="$input">
								<xsl:copy-of select="$input"/>
							</xsl:if>
						</stat>
					</filer>
				</data>
				<xsl:if test="$impersonate">
					<vzcpauth/>
				</xsl:if>
			</packet>
		</xsl:variable>
		<xsl:variable name="rc" select="sw:xchg($req)"/>
		<func:result select="$rc/packet/data/filer/file"/>
	</func:function>

	<!-- list files -->
	<func:function name="filem:list">
		<xsl:param name="path"/>
		<xsl:param name="eid"/>
		<xsl:param name="input"/>
		<xsl:param name="cwd" select="/.."/>
		<!--|-->
		<xsl:variable name="req">
			<packet timeout="{$config/vzcpcon/timeout/vz_p2v_asknode}">
				<target>filer</target>
				<xsl:copy-of select="sw:env-dst($eid)"/>
				<data>
					<filer>
						<list>
							<path>
								<xsl:value-of select="sw:base64-encode($path)"/>
							</path>
							<xsl:if test="$cwd">
								<cwd>
									<xsl:value-of select="sw:base64-encode($cwd)"/>
								</cwd>
							</xsl:if>
							<xsl:copy-of select="$input"/>
						</list>
					</filer>
				</data>
			</packet>
		</xsl:variable>
		<!--|-->
		<xsl:variable name="ret" select="sw:xchg($req)/packet/data"/>

		<xsl:choose>
			<!-- error under data -->
			<xsl:when test="$ret/error">
				<func:result select="$ret"/>
			</xsl:when>
			
			<!-- usual result and filer errors -->
			<xsl:otherwise>
				<func:result select="$ret/filer"/>
			</xsl:otherwise>
		</xsl:choose>
		
		<!--|-->
	</func:function>

</xsl:stylesheet>
