<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func here"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl	="http://exslt.org/common"
	xmlns:func  ="http://exslt.org/functions"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:fwm		="http://www.swsoft.com/xsl/cp/fwm"
	xmlns:here	="http://www.swsoft.com/xsl/cp/here"
>  
	
	<!-- GET LIST list of rules -->
	<func:function name="fwm:get">
		<xsl:param name="eid" select="sw:ve-eid()"/>
    <xsl:variable name="req">
			<packet>
        <target>firewallm</target>
        <xsl:copy-of select="sw:env-dst($eid)"/>
        <data>
          <firewallm>
            <get/>
          </firewallm>
        </data>
				<vzcpauth/>
      </packet>
		</xsl:variable>
		<func:result select="sw:xchg($req)/packet/data/firewallm"/>
	</func:function>


	<!-- ENABLE/DISABLE  rule(s) -->
	<func:function name="fwm:rule-enable-disable">
		<xsl:param name="fwm-rules"/>
		<xsl:param name="uniq-rules-id"/>
		<xsl:param name="operation" select="'disable'"/>
		<xsl:param name="all-chains" select="false()"/>
		<xsl:param name="eid"	select="sw:ve-eid()"/>
		
    <xsl:choose>

			<xsl:when test="here:check-rules-present($fwm-rules,$uniq-rules-id)">
				<xsl:variable name="chain" select="$fwm-rules/chain/rule[fwm-rule-uniq-id = $uniq-rules-id[1]]/chain"/>
				<xsl:variable name="tab"	 select="$fwm-chain/chain[chain-name = $chain]/tab"/>
				<xsl:variable name="operation-id" select="sw:if($operation = 'enable',1,0)"/>
    		<xsl:variable name="req">
					<packet log="on">
    		    <target>firewallm</target>
    		    <xsl:copy-of select="sw:env-dst($eid)"/>
        		<cookie>
		          <msg>
								<ok>
									<sw:text>
										<xsl:with-param name="action" select="sw:if($operation = 'disable',sw:text('disabled'),sw:text('enabled'))"/>
											The firewall rule(s) has/have been successfully %{action}.
									</sw:text>
								</ok>
								<error>
									<sw:text>
										<xsl:with-param name="action" select="sw:if($operation = 'disable',sw:text('disabled'),sw:text('enabled'))"/>
											Failed to %{action} the firewall rule(s).
									</sw:text>
								</error>
    		      </msg>
        		  <operation>enable_disable_firewall_rule</operation>
							<redirect-last/>
    		    </cookie>
        		<data>
							<firewallm>
					      <delete>
									<xsl:for-each select="$fwm-rules/chain[name = $chain or $all-chains]/rule">
										<rule>
											<xsl:call-template name="copy-one-rule"/>
										</rule>
									</xsl:for-each>
				    	  </delete>
    					</firewallm>
			  		  <firewallm> 
      					<set>
									<xsl:for-each select="$fwm-rules/chain[name= $chain or $all-chains]/rule">
										<xsl:variable name="fwm-rule-uniq-id" select="fwm-rule-uniq-id"/>
		              	<rule>
		                	<xsl:copy-of select="*[name() != 'fwm-rule-uniq-id' and name() != 'fwm-rule-id' and name() != 'allowed']"/>
											<allowed>
												<xsl:value-of select="sw:if($uniq-rules-id[. = $fwm-rule-uniq-id],$operation-id,allowed)"/>
											</allowed>
										</rule>
									</xsl:for-each>
								</set>
							</firewallm>
		        </data>
						<vzcpauth/>
		      </packet>
				</xsl:variable>
				<func:result select="here:format-answer(sw:xchg($req))"/>
			</xsl:when>

			<xsl:otherwise>
				<!-- rule not present, report error. -->
				<func:result>
					<packet>
		        <target>firewallm</target>
		        <xsl:copy-of select="sw:env-dst($eid)"/>
  			    <cookie>
		  	    	<msg>
		  	      	<set-error>
		  	        	<sw:text>Failed to change the firewall rules status: one or more rules were not present at the moment of the operation.</sw:text>
			  	      </set-error>
			  	    </msg>
          		<redirect-last/>
	        	</cookie>
	        </packet>
				</func:result>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>


	<!-- DELETE rule(s) -->
	<func:function name="fwm:rule-delete">
		<xsl:param name="fwm-rules"/>
		<xsl:param name="uniq-rules-id"/>
		<xsl:param name="all-chains" select="false()"/>
		<xsl:param name="eid"	select="sw:ve-eid()"/>

    <xsl:choose>

			<xsl:when test="here:check-rules-present($fwm-rules,$uniq-rules-id)">
		    <xsl:variable name="chain" select="$fwm-rules/chain/rule[fwm-rule-uniq-id = $uniq-rules-id[1]]/chain"/>
				<xsl:variable name="tab"	 select="$fwm-chain/chain[chain-name = $chain]/tab"/>
				<xsl:variable name="req">
					<packet log="on">
		        <target>firewallm</target>
		        <xsl:copy-of select="sw:env-dst($eid)"/>
		        <cookie>
		          <msg>
								<ok>
									<sw:text>The firewall rule(s) has/have been successfully deleted.</sw:text>
								</ok>
								<error>
									<sw:text>Failed to delete the firewall rule(s).</sw:text>
								</error>
		          </msg>
		          <operation>delete_firewall_rule</operation>
							<redirect-last/>
		        </cookie>
		        <data>
					    <firewallm> 
		      			<delete>
									<xsl:for-each select="$fwm-rules/chain[name = $chain or $all-chains]/rule[fwm-rule-uniq-id = $uniq-rules-id]">
										<rule>							
											<xsl:call-template name="copy-one-rule"/>
										</rule>
									</xsl:for-each>
								</delete>
							</firewallm>
		        </data>
						<vzcpauth/>
		      </packet>
				</xsl:variable>
				<func:result select="here:format-answer(sw:xchg($req))"/>
			</xsl:when>

			<xsl:otherwise>
				<!-- rule not present, report error. -->
				<func:result>
					<packet>
		        <target>firewallm</target>
		        <xsl:copy-of select="sw:env-dst($eid)"/>
  			    <cookie>
		  	    	<msg>
		  	      	<set-error>
		  	        	<sw:text>Failed to delete the firewall rule(s): one or more rules were not present at the moment of the operation.</sw:text>
			  	      </set-error>
			  	    </msg>
          		<redirect-last/>
	        	</cookie>
	        </packet>
				</func:result>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>


	<!-- ADD rule -->
	<func:function name="fwm:rule-add">
		<xsl:param name="fwm-rules"/>
		<xsl:param name="rule-for-operation"/>
		<xsl:param name="position" select="'down'"/>
		<xsl:param name="eid" select="sw:ve-eid()"/>

		<xsl:variable name="chain" select="$rule-for-operation/rule/chain"/>
		<xsl:variable name="tab"	 select="$fwm-chain/chain[chain-name = $chain]/tab"/>
		<xsl:variable name="chain-title"	 select="$fwm-chain/chain[chain-name = $chain]/title"/>

		<xsl:variable name="req">
			<packet log="on">
        <target>firewallm</target>
        <xsl:copy-of select="sw:env-dst($eid)"/>
        <cookie>
          <msg>
						<ok>
							<sw:text>
								<xsl:with-param name="chain" select="$chain-title"/>
								The firewall rule has been successfully added to the %{chain} chain.
							</sw:text>
						</ok>
						<error>
							<sw:text>
								<xsl:with-param name="chain" select="$chain-title"/>
								Failed to add the firewall rule to the %{chain} chain.
							</sw:text>
						</error>
          </msg>
          <operation>add_firewall_rule</operation>
					<redirect-prev/>
        </cookie>			
				<!-- calc count rules for operations
						 if count zero - prevent grenerate 
						 "delete" and "set" part in case position 'up'
				-->
				<xsl:variable name="old-number-rules-in-chain" select="count($fwm-rules/chain[name = $chain]/rule)"/>
        <data>
			    <firewallm> 
						<xsl:if test="$position = 'up' and $old-number-rules-in-chain &gt; 0">
							<!-- add on top: first delete all rule set in chain -->
	      			<delete>
								<xsl:for-each select="$fwm-rules/chain[name = $chain]/rule">
									<rule>
										<xsl:call-template name="copy-one-rule"/>
									</rule>
								</xsl:for-each>
							</delete>							
						</xsl:if>
      			<set>
							<xsl:for-each select="$rule-for-operation/rule">
							  <rule>
									<xsl:call-template name="copy-one-rule"/>
								</rule>
							</xsl:for-each>
						</set>
						<xsl:if test="$position = 'up' and $old-number-rules-in-chain &gt; 0">
							<!-- add on top: second add all rules -->
              <set>
                <xsl:for-each select="$fwm-rules/chain[name = $chain]/rule">
                	<rule>
										<xsl:call-template name="copy-one-rule"/>
									</rule>
                </xsl:for-each>
              </set>
            </xsl:if>
					</firewallm>
        </data>
				<vzcpauth/>
      </packet>
		</xsl:variable>
		<func:result select="here:format-answer(sw:xchg($req))"/>
	</func:function>


	<!-- EDIT rule -->
	<func:function name="fwm:rule-edit">
		<xsl:param name="fwm-rules"/>
		<xsl:param name="rule-for-operation"/>
		<xsl:param name="eid" select="sw:ve-eid()"/>

		<xsl:choose>

      <xsl:when test="here:check-rules-present($fwm-rules,$rule-for-operation/rule/fwm-rule-uniq-id)">
				<xsl:variable name="new-chain"	select="$rule-for-operation/rule/chain"/>
				<xsl:variable name="old-chain"	select="$fwm-rules/chain/rule[fwm-rule-uniq-id = $rule-for-operation/rule/fwm-rule-uniq-id]/chain"/>
				<xsl:variable name="tab"	 			select="$fwm-chain/chain[chain-name = $new-chain]/tab"/>

				<xsl:variable name="new-chain-title"	 select="$fwm-chain/chain[chain-name = $new-chain]/title"/>	
		
		    <xsl:variable name="req">
					<packet log="on">
		        <target>firewallm</target>
		        <xsl:copy-of select="sw:env-dst($eid)"/>
		        <cookie>
		        	<msg>
								<ok>
									<sw:text>
										<xsl:with-param name="chain" select="$new-chain-title"/>
										The firewall rule has been successfully changed in the %{chain} chain.
									</sw:text>
								</ok>
								<error>
									<sw:text>
										<xsl:with-param name="chain" select="$new-chain-title"/>
										Failed to change the firewall rule in the %{chain} chain.
									</sw:text>
								</error>
		        	</msg>
		          <operation>edit_firewall_rule</operation>
							<redirect-prev/>
		        </cookie>			
		
		        <data>
					    <firewallm> 
					    	<xsl:choose>
					    		<xsl:when test="$old-chain = $new-chain">
					    			<xsl:call-template name="edit-rule-in-chain">
					    				<xsl:with-param name="fwm-rules" select="$fwm-rules"/>
					    				<xsl:with-param name="rule-for-operation" select="$rule-for-operation"/>
					    				<xsl:with-param name="chain" select="$old-chain"/>
					    			</xsl:call-template>
					    		</xsl:when>
					    		<xsl:otherwise>
					    			<xsl:call-template name="move-rule-to-other-chain">
					    				<xsl:with-param name="fwm-rules" select="$fwm-rules"/>
					    				<xsl:with-param name="rule-for-operation" select="$rule-for-operation"/>
					    				<xsl:with-param name="old-chain" select="$old-chain"/>
					    				<xsl:with-param name="new-chain" select="$new-chain"/>
					    			</xsl:call-template>			    		
					    		</xsl:otherwise>
					    	</xsl:choose>
					    </firewallm>
						</data>
						<vzcpauth/>
		      </packet>
				</xsl:variable>
				<func:result select="here:format-answer(sw:xchg($req))"/>
			</xsl:when>

			<xsl:otherwise>
				<!-- rule not present, report error. -->
				<func:result>
					<packet>
		        <target>firewallm</target>
		        <xsl:copy-of select="sw:env-dst($eid)"/>
  			    <cookie>
		  	    	<msg>
		  	      	<set-error>
		  	        	<sw:text>Failed to change the firewall rule: no such rule was present at the moment of the operation.</sw:text>
			  	      </set-error>
			  	    </msg>
          		<redirect-last/>
	        	</cookie>
	        </packet>
				</func:result>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
			

	<!-- UP rule on 1 position -->	
	<func:function name="fwm:rule-up">
		<xsl:param name="fwm-rules"/>
		<xsl:param name="uniq-rule-id"/>
		<xsl:param name="action" select="'up'"/>
		<xsl:param name="eid" select="sw:ve-eid()"/>

		<xsl:choose>

			<xsl:when test="here:check-rules-present($fwm-rules,$uniq-rule-id)">
				<xsl:variable name="chain" 		select="$fwm-rules/chain/rule[fwm-rule-uniq-id = $uniq-rule-id]/chain"/>
				<xsl:variable name="rule-id" 	select="$fwm-rules/chain/rule[fwm-rule-uniq-id = $uniq-rule-id]/fwm-rule-id"/>
				<xsl:variable name="tab"			select="$fwm-chain/chain[chain-name = $chain]/tab"/>
		
		    <xsl:variable name="req">
					<packet log="on">
		        <target>firewallm</target>
		        <xsl:copy-of select="sw:env-dst($eid)"/>
		        <cookie>
		        	<xsl:choose>
		        		<xsl:when test="$action = 'up'">
				          <msg>
										<ok><sw:text>The firewall rule has been successfully moved up.</sw:text></ok>
										<error><sw:text>Failed to move up the firewall rule.</sw:text></error>
				          </msg>
				      	</xsl:when>
		        		<xsl:otherwise>
				          <msg>
										<ok><sw:text>The firewall rule has been successfully moved down.</sw:text></ok>
										<error><sw:text>Failed to move down the firewall rule.</sw:text></error>
				          </msg>
				      	</xsl:otherwise>		      	
				      </xsl:choose>
		          <operation>move_firewall_rule</operation>
							<redirect-last/>
		        </cookie>			
		
		        <data>
					    <firewallm> 
								<!-- edit, first delete all rules in current chain -->
			      		<delete>
									<xsl:for-each select="$fwm-rules/chain[name= $chain]/rule">
									  <rule>
											<xsl:call-template name="copy-one-rule"/>
										</rule>
									</xsl:for-each>
								</delete>							
								<set>
									<xsl:for-each select="$fwm-rules/chain[name= $chain]/rule">
										<xsl:choose>
											<xsl:when test="fwm-rule-id = ($rule-id - 1)">
												<!-- it's rule for move down, instert insteed rule-id -->
												<xsl:for-each select="$fwm-rules/chain[name= $chain]/rule[fwm-rule-id = $rule-id]">
													<rule>	
														<xsl:call-template name="copy-one-rule"/>
													</rule>
												</xsl:for-each>
											</xsl:when>
											<xsl:when test="fwm-rule-id = $rule-id">
												<!-- put insteed rule from up -->
												<xsl:for-each select="$fwm-rules/chain[name= $chain]/rule[fwm-rule-id = ($rule-id - 1)]">
												  <rule>
														<xsl:call-template name="copy-one-rule"/>
													</rule>
												</xsl:for-each>
											</xsl:when>
											<xsl:otherwise>
												<!-- simple copy rule asis -->
												<rule>
													<xsl:call-template name="copy-one-rule"/>
												</rule> 
											</xsl:otherwise>
										</xsl:choose>
									</xsl:for-each>
								</set>
							</firewallm>
		        </data>
						<vzcpauth/>
		      </packet>
				</xsl:variable>
				<func:result select="here:format-answer(sw:xchg($req))"/>
			</xsl:when>

			<xsl:otherwise>
				<!-- rule not present,  report error. -->
				<func:result>
					<packet>
		        <target>firewallm</target>
		        <xsl:copy-of select="sw:env-dst($eid)"/>
  			    <cookie>
		  	    	<msg>
		  	      	<set-error>
		  	        	<sw:text>Failed to move up the firewall rule: no such rule was present at the moment of the operation.</sw:text>
			  	      </set-error>
			  	    </msg>
          		<redirect-last/>
	        	</cookie>
	        </packet>
				</func:result>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>


	<!-- DOWN rule to 1 position -->
	<func:function name="fwm:rule-down">
    <xsl:param name="fwm-rules"/>
    <xsl:param name="uniq-rule-id"/>
		<xsl:param name="eid" select="sw:ve-eid()"/>

		<xsl:choose>
			<xsl:when test="here:check-rules-present($fwm-rules,$uniq-rule-id)">
				<xsl:variable name="chain" select="$fwm-rules/chain/rule[fwm-rule-uniq-id = $uniq-rule-id]/chain"/>
				<xsl:variable name="down-rule-id" select="$fwm-rules/chain[name = $chain]/rule[fwm-rule-uniq-id = $uniq-rule-id]/fwm-rule-id + 1"/>
				<xsl:variable name="down-uniq-rule-id" select="$fwm-rules/chain[name  = $chain]/rule[fwm-rule-id = $down-rule-id]/fwm-rule-uniq-id"/>
				<func:result select="fwm:rule-up($fwm-rules,$down-uniq-rule-id,'down')"/>
			</xsl:when>
			<xsl:otherwise>
				<!-- rule not present,  report error. -->
				<func:result>
					<packet>
		        <target>firewallm</target>
		        <xsl:copy-of select="sw:env-dst($eid)"/>
  			    <cookie>
		  	    	<msg>
		  	      	<set-error>
		  	        	<sw:text>Failed to move down the firewall rule: no such rule was present at the moment of the operation.</sw:text>
			  	      </set-error>
			  	    </msg>
          		<redirect-last/>
	        	</cookie>
	        </packet>
				</func:result>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<!-- Change default firewall policy for advanced -->
	<func:function name="fwm:set-default-policy">
		<xsl:param name="policy"/>
		<xsl:param name="eid" select="sw:ve-eid()"/>
		
    <xsl:variable name="req">
      <packet>
        <target>firewallm</target>
        <xsl:copy-of select="sw:env-dst($eid)"/>
        <cookie>
          <msg>
						<ok>
							<sw:text>
								<xsl:with-param name="policy-name" select="$fwm-default-policy/policy[value = $policy]/title"/>
								The default policy has been successfully set to %{policy-name}.
							</sw:text>
						</ok>
						<error>
							<sw:text>
								<xsl:with-param name="policy-name" select="$fwm-default-policy/policy[value = $policy]/title"/>
									Failed to set the default policy to %{policy-name}.
							</sw:text>
						</error>
          </msg>
          <operation>firewall_change_policy</operation>
        </cookie>			
        <data>
          <firewallm>
						<xsl:choose>
							<xsl:when test="$policy = 'ACCEPT'">
		            <disable/>
							</xsl:when>
							<xsl:when test="$policy = 'DROP'">
		            <enable/>
							</xsl:when>
							<xsl:otherwise>
								<!-- by default - set policy to DROP ("enable firewall" in vzagent term) -->
		            <enable/>
							</xsl:otherwise>							
						</xsl:choose>
          </firewallm> 
        </data>
        <vzcpauth/>
      </packet>
    </xsl:variable>   
    <func:result select="here:format-answer(sw:xchg($req))"/>
	</func:function>

	
	<!-- get default firewall policy  -->
	<func:function name="fwm:get-default-policy">
		<xsl:param name="eid" select="sw:ve-eid()"/>
		
    <xsl:variable name="req">
      <packet>
        <target>firewallm</target>
        <xsl:copy-of select="sw:env-dst($eid)"/>
        <data>
          <firewallm>
						<is_enabled/>
          </firewallm>  
        </data>
        <vzcpauth/>
      </packet>
    </xsl:variable>   
		<func:result select="sw:if(sw:xchg($req)/packet/data/firewallm/status = 1,'DROP','ACCEPT')"/>
	</func:function>
	
	<!-- copy in output all rule subnode , EXCLUDE fwm-rule-id and fwm-rule-uniq-id -->
	<xsl:template name="copy-one-rule">
		<xsl:copy-of select="*[(name() != 'fwm-rule-id') and (name() != 'fwm-rule-uniq-id')]"/>
	</xsl:template>

	<!-- check that rule realy exists at the moment of the operation.
			 (not deleted from other window and from cli) -->
	<func:function name="here:check-rules-present">
		<xsl:param name="fwm-rules"/>
		<xsl:param name="uniq-rules-id"/>
		<xsl:choose>
			<xsl:when test="exsl:object-type($uniq-rules-id) = 'node-set'">
				<func:result select="$fwm-rules/chain/rule[fwm-rule-uniq-id = $uniq-rules-id]"/>
			</xsl:when>	
			<xsl:otherwise>
				<func:result select="$fwm-rules/chain/rule[fwm-rule-uniq-id = $uniq-rules-id]"/>			
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<!-- print packet for edit one rule in place (in same chain) -->
	<xsl:template name="edit-rule-in-chain">
		<xsl:param name="fwm-rules" select="/.."/>
		<xsl:param name="rule-for-operation"/>
		<xsl:param name="chain"/>
		<xsl:param name="eid" select="sw:ve-eid()"/>

		<!-- edit, first delete all rules from chain -->
		  <delete>
				<xsl:for-each select="$fwm-rules/chain[name = $chain]/rule">
					<rule>
						<xsl:call-template name="copy-one-rule"/>
					</rule>
				</xsl:for-each>
			</delete>							
		<!-- now add rules with changes -->
			<set>
				<xsl:for-each select="$fwm-rules/chain[name = $chain]/rule">
					<!-- rule stay in old chain, replace rule -->
					<xsl:choose>
						<xsl:when test="fwm-rule-uniq-id = $rule-for-operation/rule/fwm-rule-uniq-id">
							<!-- its' changed rule, insert it insteed old -->
							<xsl:for-each select="$rule-for-operation/rule">
								<rule>
									<xsl:call-template name="copy-one-rule"/>
								</rule>
							</xsl:for-each>
						</xsl:when>
						<xsl:otherwise>
							<!-- simple copy rule asis -->
							<rule>
								<xsl:call-template name="copy-one-rule"/>
							</rule>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:for-each>
			</set>
	</xsl:template>

	<!-- print packet for move edited rule from one chain to end of other chain  -->
	<xsl:template name="move-rule-to-other-chain">
		<xsl:param name="fwm-rules"/>
		<xsl:param name="rule-for-operation"/>
		<xsl:param name="old-chain"/>
		<xsl:param name="new-chain"/>		
		<xsl:param name="eid" select="sw:ve-eid()"/>

		<!-- edit, first delete rule (with old parameters) from old chain -->
		  <delete>
				<xsl:for-each select="$fwm-rules/chain[name = $old-chain]/rule[fwm-rule-uniq-id = $rule-for-operation/rule/fwm-rule-uniq-id]">
					<rule>
						<xsl:call-template name="copy-one-rule"/>
					</rule>
				</xsl:for-each>
			</delete>							
		<!-- now add rule to end of new chain (with new parameter)-->
			<set>
				<xsl:for-each select="$rule-for-operation/rule">
					<rule>
						<xsl:call-template name="copy-one-rule"/>
					</rule>
				</xsl:for-each>
			</set>
	</xsl:template>

	<!-- ruleset operation: simple rules -->

	<func:function name="fwm:simple-rule-add">
    <xsl:param name="fwm-rules"/>
    <xsl:param name="fwm-simple-rules"/>
    <xsl:param name="fwm-simple-rule-uniq-id"/>

		<xsl:variable name="simple-add-result-rtf">
			<xsl:for-each select="$fwm-simple-rules/set[fwm-simple-rule-uniq-id = $fwm-simple-rule-uniq-id/value]">
				<xsl:for-each select="rule">
					<xsl:variable name="rule-for-add-rtf">
						<rule>
							<xsl:copy-of select="*"/>
						</rule>
					</xsl:variable>
 					<xsl:copy-of select="fwm:rule-add($fwm-rules,exsl:node-set($rule-for-add-rtf))"/>
				</xsl:for-each>
			</xsl:for-each>
		</xsl:variable>
		<func:result select="exsl:node-set($simple-add-result-rtf)"/>
	</func:function>

	<func:function name="fwm:simple-rule-delete">
    <xsl:param name="fwm-rules"/>
    <xsl:param name="fwm-simple-rules"/>
    <xsl:param name="fwm-simple-rule-uniq-id"/>

		<xsl:variable name="simple-delete-result-rtf">
			<xsl:for-each select="$fwm-simple-rules/set[fwm-simple-rule-uniq-id = $fwm-simple-rule-uniq-id]">
 				<xsl:copy-of select="fwm:rule-delete($fwm-rules,rule/fwm-rule-uniq-id,true())"/>
			</xsl:for-each>
		</xsl:variable>
		<func:result select="exsl:node-set($simple-delete-result-rtf)"/>
	</func:function>

	<func:function name="fwm:simple-rule-reset">
		<xsl:param name="fwm-simple-rules"/>
		<xsl:param name="reset-mode" select="'default'"/>
		<xsl:param name="eid" select="sw:ve-eid()"/>

		<xsl:variable name="req">
			<packet log="on">
		  	<target>firewallm</target>
		  	<xsl:copy-of select="sw:env-dst($eid)"/>
		    <cookie>
		    	<msg>
						<ok>
							<sw:text>The firewall is now managed in the normal mode. The default set of access rules has been restored.</sw:text>
						</ok>
						<error>
							<sw:text>Failed to reset the access rules.</sw:text>
						</error>
					</msg>
		      <operation>reset_firewall_rule</operation>
				</cookie>
		    <data>
					<firewallm> 
		      	<delete/>
						<xsl:if test="$reset-mode != 'full'">
							<set>
						    <eid><xsl:value-of select="$eid"/></eid>
								<xsl:for-each select="$fwm-simple-rules/set[default]">
		  	        	<xsl:copy-of select="rule[name() != 'fwm-rule-uniq-id' and name() != 'fwm-rule-id']"/>
								</xsl:for-each>
							</set>
						</xsl:if>
		        <enable/>
          </firewallm>
        </data>
			</packet>
		</xsl:variable>
		<func:result select="here:format-answer(sw:xchg($req))"/>
	</func:function>

	<!-- utility templates and functions -->
	<func:function name="here:format-answer">
    <xsl:param name="vzagent-answer"/>
		<func:result>
			<packet>
  	  	<cookie>
					<msg>
	  	    	<xsl:choose>
  		      	<xsl:when test="$vzagent-answer/packet/data/firewallm/ok">
  		      		<set-ok>
									<xsl:value-of select="$vzagent-answer/packet/cookie/msg/ok"/>
  	    	  		</set-ok>
  	      		</xsl:when>

  		      	<xsl:when test="$vzagent-answer/packet/data/firewallm/error">
  	      			<set-error>
									<short-desc>
										<xsl:value-of select="$vzagent-answer/packet/cookie/msg/error"/>
									</short-desc>
									<detail>
										<xsl:value-of select="$vzagent-answer/packet/data/firewallm/error/message"/>
									</detail>
	  	      		</set-error>
  	      		</xsl:when>

  		      	<xsl:when test="$vzagent-answer/packet/data/progress">
  		      		<set-sched>
									<operation-id>
										<xsl:value-of select="$vzagent-answer/packet/@id"/>
									</operation-id>
									<short-desc>
										<xsl:value-of select="$vzagent-answer/packet/cookie/msg/sched"/>
									</short-desc>
  	    	  		</set-sched>
  	      		</xsl:when>
  		      </xsl:choose>
					</msg>
					<xsl:copy-of select="$vzagent-answer/packet/cookie/operation"/>
					<xsl:copy-of select="$vzagent-answer/packet/cookie/redirect"/>					
					<xsl:copy-of select="$vzagent-answer/packet/cookie/redirect-prev"/>					
					<xsl:copy-of select="$vzagent-answer/packet/cookie/redirect-last"/>					
    		</cookie>
			</packet>
		</func:result>
  </func:function>

</xsl:stylesheet>
