<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
	extension-element-prefixes="sw networkm func cred" xmlns:exsl="http://exslt.org/common"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:func="http://exslt.org/functions" xmlns:networkm="http://www.swsoft.com/xsl/cp/networkm"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:vza_networkm="http://www.swsoft.com/webservices/vzl/4.0.0/networkm"
>

	<sw:include href="/lib/common.xsl"/>

	<xsl:variable name="op-networkm" select="'vzanetworkm'"/>

	<xsl:template mode="composer" match="/">
		<xsl:apply-templates mode="composer" select="*"/>
	</xsl:template>

	<xsl:template mode="decomposer" match="/">
		<xsl:apply-templates mode="decomposer" select="*"/>
	</xsl:template>

	<xsl:template mode="composer" match="node()">
		<xsl:copy>
			<xsl:copy-of select="@*"/>
			<xsl:choose>
				<xsl:when test="local-name() = 'network_id' or local-name() = 'description'">
					<xsl:value-of select="sw:base64-encode(.)"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates mode="composer" select="* | text()"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:copy>
	</xsl:template>

	<xsl:template mode="decomposer" match="node()">
		<xsl:element name="{local-name()}">
			<xsl:copy-of select="@*"/>
			<xsl:apply-templates mode="decomposer" select="* | text()"/>
		</xsl:element>
	</xsl:template>

	<xsl:template mode="composer" match="text()">
		<xsl:copy-of select="."/>
		<!-- <xsl:copy-of select="sw:base64-encode(.)"/> -->
	</xsl:template>

	<xsl:template mode="decomposer" match="text()">
		<xsl:copy-of select="."/>
	</xsl:template>

	<func:function name="networkm:list">
		<xsl:param name="hw_id"/>
		<xsl:param name="net_devices"/>
		<xsl:variable name="result">
			<xsl:apply-templates mode="decomposer"
				select="sw:xchg(networkm:cmd-list($hw_id,$net_devices))/packet/data/vzanetworkm/*"/>
		</xsl:variable>
		<func:result select="exsl:node-set($result)"/>
	</func:function>

	<func:function name="networkm:delete">
		<xsl:param name="hw_id"/>
		<xsl:param name="net_device"/>
		<func:result select="sw:xchg(networkm:cmd-delete($hw_id,$net_device))/packet/data/vzanetworkm"/>
	</func:function>

	<func:function name="networkm:add">
		<xsl:param name="hw_id"/>
		<xsl:param name="net_device"/>
		<func:result select="sw:xchg(networkm:cmd-add($hw_id,$net_device))/packet/data/vzanetworkm"/>
	</func:function>

	<func:function name="networkm:set">
		<xsl:param name="hw_id"/>
		<xsl:param name="net_device"/>
		<func:result select="sw:xchg(networkm:cmd-set($hw_id,$net_device))/packet/data/vzanetworkm"/>
	</func:function>

	<func:function name="networkm:cmd-list">
		<xsl:param name="hw_id"/>
		<xsl:param name="net_devices"/>

		<func:result>
			<xsl:element name="packet">
				<target>
					<xsl:value-of select="$op-networkm"/>
				</target>
				<xsl:copy-of select="sw:hn-dst($hw_id)"/>
				<data>
					<xsl:element name="{$op-networkm}">
						<list>
							<xsl:apply-templates mode="composer" select="$net_devices/*"/>
						</list>
					</xsl:element>
				</data>
			</xsl:element>
		</func:result>
	</func:function>

	<func:function name="networkm:cmd-delete">
		<xsl:param name="hw_id"/>
		<xsl:param name="net_device"/>
		<func:result>
			<packet	xmlns:vzl_commontype="http://www.swsoft.com/webservices/vzl/4.0.0/types">
				<target>
					<xsl:value-of select="$op-networkm"/>
				</target>
				<xsl:copy-of select="sw:hn-dst($hw_id)"/>
				<data>
					<xsl:element name="{$op-networkm}">
						<del>
							<xsl:apply-templates mode="composer" select="$net_device"/>
						</del>
					</xsl:element>
				</data>
			</packet>
		</func:result>
	</func:function>

	<func:function name="networkm:connect">
		<xsl:param name="hw_id"/>
		<xsl:param name="net_device"/>
		<xsl:param name="network_id"/>
		<func:result
			select="sw:xchg(networkm:cmd-connect($hw_id,$net_device,$network_id))/packet/data/vzanetworkm"
		/>
	</func:function>

	<func:function name="networkm:disconnect">
		<xsl:param name="hw_id"/>
		<xsl:param name="net_device"/>
		<func:result
			select="sw:xchg(networkm:cmd-disconnect($hw_id,$net_device))/packet/data/vzanetworkm"/>
	</func:function>

	<func:function name="networkm:cmd-disconnect">
		<xsl:param name="hw_id"/>
		<xsl:param name="net_device"/>
		<xsl:variable name="dev_type" select="sw:split($net_device/@xsi:type,':')[last()]"/>
		<xsl:variable name="d_net_device">
			<xsl:choose>
				<xsl:when test="$dev_type = 'net_vlanType'">
					<vza_networkm:net_device xsi:type="vza_networkm:net_vlanType">
						<id>
							<xsl:value-of select="$net_device/id"/>
						</id>
						<network_id/>
					</vza_networkm:net_device>
				</xsl:when>
				<xsl:when test="$dev_type = 'net_nicType'">
					<vza_networkm:net_device xsi:type="vzl_commontype:net_nicType">
						<id>
							<xsl:value-of select="$net_device/id"/>
						</id>
						<network_id/>
					</vza_networkm:net_device>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<func:result select="networkm:cmd-set($hw_id,exsl:node-set($d_net_device))"/>
	</func:function>

	<func:function name="networkm:cmd-connect">
		<xsl:param name="hw_id"/>
		<xsl:param name="net_device"/>
		<xsl:param name="network_id"/>
		<xsl:variable name="dev_type" select="sw:split($net_device/@xsi:type,':')[last()]"/>
		<xsl:variable name="c_net_device-rtf">
			<xsl:choose>
				<xsl:when test="$dev_type = 'net_vlanType'">
					<vza_networkm:net_device xsi:type="vza_networkm:net_vlanType">
						<id>
							<xsl:value-of select="$net_device/id"/>
						</id>
						<network_id>
							<xsl:value-of select="$network_id"/>
						</network_id>
					</vza_networkm:net_device>
				</xsl:when>
				<xsl:when test="$dev_type = 'net_nicType'">
					<vza_networkm:net_device xsi:type="vzl_commontype:net_nicType">
						<id>
							<xsl:value-of select="$net_device/id"/>
						</id>
						<network_id>
							<xsl:value-of select="$network_id"/>
						</network_id>
						<mac_address>
							<xsl:value-of select="$net_device/mac_address"/>
						</mac_address>
					</vza_networkm:net_device>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="c_net_device" select="exsl:node-set($c_net_device-rtf)"/>
		<func:result select="networkm:cmd-set($hw_id,exsl:node-set($c_net_device))"/>
	</func:function>


	<func:function name="networkm:cmd-add">
		<xsl:param name="hw_id"/>
		<xsl:param name="net_device"/>
		<func:result>
			<packet xmlns:vzl_commontype="http://www.swsoft.com/webservices/vzl/4.0.0/types">
				<target>
					<xsl:value-of select="$op-networkm"/>
				</target>
				<xsl:copy-of select="sw:hn-dst($hw_id)"/>
				<data>
					<xsl:element name="{$op-networkm}">
						<add>
							<xsl:apply-templates mode="composer" select="$net_device"/>
						</add>
					</xsl:element>
				</data>
			</packet>
		</func:result>
	</func:function>

	<func:function name="networkm:cmd-set">
		<xsl:param name="hw_id"/>
		<xsl:param name="net_device"/>
		<func:result>
			<packet xmlns:vzl_commontype="http://www.swsoft.com/webservices/vzl/4.0.0/types">
				<target>
					<xsl:value-of select="$op-networkm"/>
				</target>
				<xsl:copy-of select="sw:hn-dst($hw_id)"/>
				<data>
					<xsl:element name="{$op-networkm}">
						<set>
							<xsl:apply-templates mode="composer" select="$net_device"/>
						</set>
					</xsl:element>
				</data>
			</packet>
		</func:result>
	</func:function>
	
	<func:function name="networkm:get-config">
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>
		<xsl:variable name="req">
    	<packet>
				<target>vzanetworkm</target> 
        <xsl:copy-of select="sw:hn-dst($hn-eid)"/>
        <data>
					<vzanetworkm>
						<get_config/>
					</vzanetworkm>
        </data>
      </packet>
    </xsl:variable>
    <xsl:variable name="raw-config"	select="sw:xchg($req)/packet/data/vzanetworkm/net_config"/>
    <!-- sort range by class_id --> 
    <xsl:variable name="sort-config">
    	<xsl:for-each select="$raw-config">
	    	<net_config>
  	  		<xsl:copy-of select="shaping|interface|class"/>
    			<xsl:for-each select="range">
						<xsl:sort select="class_id" data-type="number"/>
	    			<xsl:copy-of select="."/>
  	  		</xsl:for-each>
    		</net_config>
    	</xsl:for-each>
    </xsl:variable>
    <func:result select="exsl:node-set($sort-config)/net_config"/>
	</func:function>

	<func:function name="networkm:set-config-packet">
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>
		<xsl:param name="data"/>
		<xsl:param name="cookie"/>
		<func:result>
			<packet log="on">
				<target>vzanetworkm</target>
				<xsl:copy-of select="sw:hn-dst($hn-eid)"/>
				<xsl:copy-of select="$cookie"/>
				<data>
					<vzanetworkm>
						<set_config>
							<net_config>
								<xsl:copy-of select="$data/config/shaping"/>							
								<xsl:copy-of select="$data/config/range"/>
								<xsl:copy-of select="$data/config/interface"/>
								<xsl:copy-of select="$data/config/class"/>
							</net_config>
						</set_config>
					</vzanetworkm>
				</data>
			</packet>
		</func:result>
	</func:function>	

</xsl:stylesheet>
