<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet
	version="1.0"
	extension-element-prefixes="sw exsl func vzapackagem local math"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:math="http://exslt.org/math"
	xmlns:set="http://exslt.org/sets" 
	xmlns:date="http://exslt.org/dates-and-times"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:func="http://exslt.org/functions"
	xmlns:vzapackagem="http://www.swsoft.com/xsl/cp/vzapackagem"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:vt="http://www.swsoft.com/xsl/cp/vt"
	xmlns:vzenv="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:ve="http://www.swsoft.com/xsl/cp/ve"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:local="http://www.swsoft.com/xsl/cp/local">

	<sw:include href="/lib/vt/ve-core.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vz/vzenv-core.xsl"/>
	<sw:include href="/lib/core/user-attrs.xsl"/>

	<!-- creates valid os element (with xsi:type) -->
	<xsl:template name="local:os-element">
		<xsl:param name="name"/>
		<xsl:param name="platform"/>

		<os xmlns:os="http://www.swsoft.com/webservices/vzl/4.0.0/types">
			<xsl:attribute
				name="type"
				namespace="http://www.w3.org/2001/XMLSchema-instance">os:osType</xsl:attribute>
			<platform><xsl:value-of select="$platform"/></platform>
			<xsl:if test="not(string($name)='')">
				<name><xsl:value-of select="$name"/></name>
			</xsl:if>
		</os>
	</xsl:template>

	<!-- Returns package type: app, os or rpm-->
	<func:function name="vzapackagem:package-type">
		<xsl:param name="package"/>

		<func:result select="sw:if($package/os_template or $package[contains(@xsi:type, 'template')], sw:if($package/os_template='1', 'os', 'app'), 'rpm')"/>
	</func:function>

	<!-- generate id for passing thru get/post requests -->
	<!-- id is like '(linux|windows)/(app/osname|os)/name[/version]' for example: linux/os/redhat-as3-minimal/20061210 or linux/os/.fedora-core-4-x86-->
	<!-- rpm: linux/rpm/.fedora-core-4-x86/mysql -->
	<func:function name="vzapackagem:generate-id">
		<xsl:param name="package"/>
		<!-- app, os, rpm -->
		<xsl:param name="forced-type" select="/.."/>

		<xsl:choose>
			<xsl:when test="not($package) or exsl:object-type($package)!='node-set' or not($package/*)">
				<func:result select="$package"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="type" select="sw:if($forced-type, $forced-type, vzapackagem:package-type($package))"/>
				<func:result select="vzapackagem:create-package-id($type, 
										$package/name, 
										$package/version,
										$package/os/platform,
										($package/arch|$package/architecture)[1],
										$package/os/name)"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	
	<func:function name="vzapackagem:create-package-id">
		<xsl:param name="type"/>
		<xsl:param name="name"/>
		<xsl:param name="version"/>
		<xsl:param name="platform"/>
		<xsl:param name="arch"/>
		<xsl:param name="os-name" select="''"/>
		
		<func:result select="concat(
	  			$type, '/',
	  			$platform, '/',
	  			$arch, '/',
		  		sw:if($type='os', '', $os-name), '/',
		  		sw:if(string($version)='', $name, concat($name, '/', $version))
		  	)"/>
	</func:function>
	
	<func:function name="vzapackagem:pkg-arch2vza">
		<xsl:param name="arch"/>
		<func:result select="sw:if($arch='x86', 'i386', $arch)"/>
	</func:function>
	
	<func:function name="vzapackagem:vza-arch2pkg">
		<xsl:param name="arch"/>
		<func:result select="sw:if($arch='i386', 'x86', $arch)"/>
	</func:function>
	
	<func:function name="vzapackagem:generate-ids">
		<xsl:param name="packages"/>
		<xsl:param name="node" select="'id'"/>
		<xsl:variable name="res">
			<xsl:for-each select="$packages">
				<xsl:element name="{$node}"><xsl:value-of select="vzapackagem:generate-id(.)"/></xsl:element>
			</xsl:for-each>
		</xsl:variable>
		<func:result select="exsl:node-set($res)/*[name()=$node]"/>
	</func:function>

	<!-- restore template/package data from serialized ID -->
	<func:function name="vzapackagem:id2package">
		<xsl:param name="id"/>

		<xsl:variable name="fields" select="sw:split(string($id), '/')"/>

		<xsl:variable name="type" select="string($fields[1])"/>
		<xsl:variable name="platform" select="string($fields[2])"/>
		<xsl:variable name="arch" select="$fields[3]"/>
		<xsl:variable name="is-os" select="$type='os'"/>
		<xsl:variable name="os-name" select="$fields[4]"/>
		<xsl:variable name="name" select="$fields[5]"/>
		<xsl:variable name="version" select="$fields[6]"/>

		<xsl:variable name="result">
			<package xmlns:pkgm="http://www.swsoft.com/webservices/vza/4.0.0/vzatypes"
					 xmlns:vzlpkgm="http://www.swsoft.com/webservices/vzl/4.0.0/packagem">
				<xsl:choose>
					<xsl:when test="$type='rpm'">
						<xsl:attribute
							name="type"
							namespace="http://www.w3.org/2001/XMLSchema-instance">vzlpkgm:package_rpmType</xsl:attribute>
					</xsl:when>
					<xsl:when test="sw:is-ez-package($name)">
						<xsl:attribute
							name="type"
							namespace="http://www.w3.org/2001/XMLSchema-instance">pkgm:package_vztemplateType</xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<xsl:attribute
							name="type"
							namespace="http://www.w3.org/2001/XMLSchema-instance">pkgm:package_std_vztemplateType</xsl:attribute>
					</xsl:otherwise>
				</xsl:choose>
				<name><xsl:value-of select="$name"/></name>
				<xsl:if test="not(string($version)='')">
					<version><xsl:value-of select="$version"/></version>
				</xsl:if>
				<xsl:call-template name="local:os-element">
					<xsl:with-param name="name" select="$os-name"/>
					<xsl:with-param name="platform" select="$platform"/>
				</xsl:call-template>
				
				<xsl:if test="$type='os' or not($arch='')">
					<arch><xsl:value-of select="sw:if($arch='', 'x86', $arch)"/></arch>
				</xsl:if>
				<xsl:choose>
					<xsl:when test="$type='os'">
						<os_template>1</os_template>
					</xsl:when>
					<xsl:when test="$type='app'">
						<os_template>0</os_template>
					</xsl:when>
				</xsl:choose>
			</package>
		</xsl:variable>
		<func:result select="exsl:node-set($result)/package"/>
	</func:function>
	
	<!-- Utility function, allows other functions and templates to handle both package ID, and packages data -->
	<!-- as node-set (with or without xsi:type attributes)  -->
	<func:function name="local:convert-args">
		<xsl:param name="app-id"/>
		<xsl:param name="force" select="false()"/>

		<xsl:choose>
			<xsl:when test="string($app-id)=''">
				<func:result select="/.."/>
			</xsl:when>
			<xsl:when test="exsl:object-type($app-id)='node-set'">
				<xsl:choose>
					<xsl:when test="not($app-id/*)">
						<xsl:variable name="res">
							<xsl:for-each select="$app-id">
								<xsl:copy-of select="vzapackagem:id2package(.)"/>
							</xsl:for-each>
						</xsl:variable>
						<func:result select="exsl:node-set($res)/package"/>
					</xsl:when>
					<!-- pass good packages as is -->
					<xsl:when test="not($force) 
									or $app-id[contains(@xsi:type,'package')] or $app-id[self::installation_package]">
						<func:result select="$app-id"/>
					</xsl:when>
					<!-- convert bad package -->
					<xsl:otherwise>
						<xsl:variable name="res">
							<xsl:for-each select="$app-id">
								<xsl:copy-of select="vzapackagem:id2package(vzapackagem:generate-id(.))"/>
							</xsl:for-each>
						</xsl:variable>
						<func:result select="exsl:node-set($res)/package"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<!-- package id is passed -->
			<xsl:otherwise>
				<func:result select="vzapackagem:id2package($app-id)"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<!-- TODO deprecate -->
	<func:function name="local:get-context-eid">
		<xsl:param name="eid"/>
		<xsl:param name="type" select="'env'"/>

		<func:result select="sw:if(not(string($eid)=''), $eid, sw:if($type='env', sw:ve-eid(), sw:hn-eid()))"/>
	</func:function>

	<!-- Verifies that package (id, or node) is OS template -->
	<func:function name="vzapackagem:is-os">
		<xsl:param name="app-id"/>
		<xsl:variable name="package" select="local:convert-args($app-id)"/>

		<func:result select="not(not($package/os_template) or not(string($package/os_template)='1'))"/>
	</func:function>
	
	<func:function name="vzapackagem:is-ez">
		<xsl:param name="app-id"/>
		<xsl:variable name="package" select="local:convert-args($app-id)"/>

		<func:result select="starts-with($package/name, '.')"/>
	</func:function>
	
	<!-- Compares templates, templates are assumed as equal if name, OS name and platform are the same -->
	<func:function name="vzapackagem:equals">
		<xsl:param name="app1"/>
		<xsl:param name="app2"/>
		
		<func:result select="vzapackagem:generate-id($app1)=vzapackagem:generate-id($app2)"/>
	</func:function>

	<func:function name="vzapackagem:vztemplate-packages">
		<xsl:param name="app-ids"/>
		
		<func:result select="local:convert-args($app-ids, true())"/>
	</func:function>
	
	<!-- Converts argument to a valid package list suitable for sending to Agent -->
	<xsl:template name="vzapackagem:vztemplate-packages">
		<xsl:param name="app-ids"/>
		<xsl:copy-of select="local:convert-args($app-ids, true())"/>
	</xsl:template>
	
	<xsl:template name="vzapackagem:installation-package">
		<xsl:param name="app-id"/>
		<xsl:param name="path"/>

		<installation_package>
			<xsl:choose>
				<xsl:when test="string($path)=''">
					<xsl:copy-of select="local:convert-args($app-id, true())"/>
				</xsl:when>
				<xsl:otherwise>
					<path><xsl:value-of select="$path"/></path>
				</xsl:otherwise>
			</xsl:choose>
		</installation_package>
	</xsl:template>

	<!-- Converts argument to a valid installation package list suitable for sending to Agent -->
	<xsl:template name="vzapackagem:installation-packages">
		<xsl:param name="app-ids"/>
		
		<xsl:for-each select="local:convert-args($app-ids, true())">
			<xsl:choose>
				<xsl:when test="self::installation_package">
					<xsl:call-template name="vzapackagem:installation-package">
						<xsl:with-param name="app-id" select="package"/>
						<xsl:with-param name="path" select="path"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<installation_package>
						<xsl:copy-of select="."/>
					</installation_package>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>
	</xsl:template>
	
	<func:function name="vzapackagem:app-title">
		<xsl:param name="app-id"/>
		<xsl:variable name="app" select="local:convert-args($app-id)"/>
		
		<xsl:choose>
			<xsl:when test="$app[contains(@xsi:type, ':package_rpmType')]">
				<func:result select="concat($app/name, '-', $app/version)"/> 
			</xsl:when>
			<xsl:otherwise>
				<func:result select="sw:app-id2title($app/name, $app/version)"/> 
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	
	<func:function name="vzapackagem:get-env-templates">
		<xsl:param name="env"/>
		<xsl:param name="force" select="false()"/>

		<xsl:choose>
			<xsl:when test="$force or ((vt:is-platform-windows($env/virtual_config/platform) or not($env/virtual_config))
								and $env/eid)">
				<func:result 
					select="vzapackagem:list4env($env/eid, 'all', true(), true())/packet/data/vzapackagem/packages/package"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="vzapackagem:get-env-config-templates($env/virtual_config)"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	
	<!-- Gets a list of templates installed/provider in VE/Sample only using information from VE/Sample config. -->
	<func:function name="vzapackagem:get-env-config-templates">
		<xsl:param name="conf"/>
		
		<xsl:variable name="platform">
			<xsl:choose>
				<xsl:when test="not(string($conf/os/platform)='')">
					<xsl:value-of select="$conf/os/platform"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="vt:platform2vza($conf/platform)"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<xsl:variable name="os-pkg">
			<xsl:if test="not(string($conf/os_template/name)='')">
				<package>
					<name><xsl:value-of select="$conf/os_template/name"/></name>
					<xsl:if test="not(string($conf/os_template/version)='')">
						<version><xsl:value-of select="$conf/os_template/version"/></version>
					</xsl:if>
					<xsl:call-template name="local:os-element">
						<xsl:with-param name="name"></xsl:with-param>
						<xsl:with-param name="platform" select="$platform"/>
					</xsl:call-template>
					<arch><xsl:value-of select="vzapackagem:vza-arch2pkg($conf/architecture)"/></arch>
					<os_template>1</os_template>
				</package>
			</xsl:if>
		</xsl:variable>

		<xsl:variable name="os" select="exsl:node-set($os-pkg)/package"/>
		<xsl:variable name="all-pkgs">
			<xsl:copy-of select="$os-pkg"/>
			<xsl:for-each select="$conf/template|$conf/apps/app">
				<xsl:if test="not(string(.)='')">
					<package>
						<name><xsl:value-of select="name"/></name>
						<xsl:if test="not(string(version)='')">
							<version><xsl:value-of select="version"/></version>
						</xsl:if>
						<xsl:choose>
							<xsl:when test="name=$conf/os_template/name">
								<xsl:call-template name="local:os-element">
									<xsl:with-param name="platform" select="$platform"/>
								</xsl:call-template>
								<arch><xsl:value-of select="vzapackagem:vza-arch2pkg($conf/architecture)"/></arch>
								<os_template>1</os_template>
							</xsl:when>
							<xsl:otherwise>
								<xsl:call-template name="local:os-element">
									<xsl:with-param name="name" select="$os/name"/>
									<xsl:with-param name="platform" select="$platform"/>
								</xsl:call-template>
								<os_template>0</os_template>
							</xsl:otherwise>
						</xsl:choose>
						
					</package>
				</xsl:if>
			</xsl:for-each>
		</xsl:variable>
		
		<func:result select="local:convert-args(exsl:node-set($all-pkgs)/package, true())"/>
	</func:function>
	
	<!-- Gets a list of templates installed into VE using only information provided in environment config. -->
	<func:function name="vzapackagem:eid2templates">
		<xsl:param name="eid"/>

		<xsl:variable name="env" select="env:get-env($eid)/env"/>
		<func:result select="vzapackagem:get-env-templates($env)"/>
	</func:function>
	
	<!-- Creates valid OS template specification from VE config -->
	<func:function name="vzapackagem:eid2os-template">
		<xsl:param name="eid"/>
		<func:result select="vzapackagem:eid2templates($eid)[vzapackagem:is-os(.)][1]"/>
	</func:function>
	
	<xsl:template name="local:header-packet">
		<xsl:param name="packet-id" select="/.."/>
		<xsl:param name="command"/>
		<xsl:param name="hn-eid"/>
		<xsl:param name="log" select="true()"/>
		<xsl:param name="progress" select="false()"/>
		<xsl:param name="cookie" select="/.."/>
		
		<xsl:if test="$packet-id">
				<xsl:attribute name="id"><xsl:value-of select="$packet-id"/></xsl:attribute>
		</xsl:if>
		<!-- add log handlers if requested -->
		<xsl:if test="$log">
			<xsl:attribute name="log">on</xsl:attribute>
		</xsl:if>
		<xsl:if test="$progress">
			<xsl:attribute name="progress">on</xsl:attribute>
		</xsl:if>

		<!-- detect and add timeout -->
		<xsl:if test="$config/vzcpcon/timeout/*[name()=concat('vz_pkgm_', $command)]">
			<xsl:attribute name="timeout"><xsl:value-of
				select="$config/vzcpcon/timeout/*[name()=concat('vz_pkgm_', $command)]"/></xsl:attribute>
		</xsl:if>

		<!-- main packet part -->
		<target>vzapackagem</target>

		<xsl:if test="$command!='migrate'">
			<xsl:copy-of select="sw:hn-dst($hn-eid)"/>
		</xsl:if>

		<!-- Output cookies -->			
		<xsl:copy-of select="$cookie"/>
	</xsl:template>
	
	<xsl:template name="vzapackagem:command-data">
		<xsl:param name="command"/>
		<xsl:param name="app-id" select="/.."/>
		<xsl:param name="options" select="/.."/>
		<xsl:param name="hn-eid"/>
		<xsl:param name="target-eid" select="/.."/>
		
		<vzapackagem>
			<xsl:element name="{$command}">
				<xsl:choose>
					<!-- Handle migrate command -->
					<xsl:when test="$command='migrate'">
						<xsl:if test="$hn-eid">
							<src>
								<address><xsl:value-of select="$hn-eid"/></address>
								<protocol>agent</protocol>
							</src>
						</xsl:if>
						<xsl:if test="$target-eid">
							<dst>
								<address><xsl:value-of select="$target-eid"/></address>
								<protocol>agent</protocol>
							</dst>
						</xsl:if>
					</xsl:when>
					<!-- other commands -->
					<xsl:otherwise>
						<xsl:if test="not(string($target-eid)='')">
							<xsl:copy-of select="ve:eids2nodes($target-eid)"/>
						</xsl:if>
					</xsl:otherwise>
				</xsl:choose>
				
				<xsl:choose>
					<xsl:when test="not($app-id) or string($app-id)=''"></xsl:when>
					<xsl:when test="$command='install' or $command='update'">
						<xsl:call-template name="vzapackagem:installation-packages">
							<xsl:with-param name="app-ids" select="$app-id"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<packages>
							<xsl:call-template name="vzapackagem:vztemplate-packages">
								<xsl:with-param name="app-ids" select="$app-id"/>
							</xsl:call-template>
						</packages>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:if test="$options">
					<xsl:copy-of select="$options"/>
				</xsl:if>
			</xsl:element>
		</vzapackagem>
	</xsl:template>
	
	<!-- General vzapackagem packet template -->
	<!-- command     : action to perform -->
	<!-- app-id      : package id(s) or node(s) -->
	<!-- options     : options node to path to Agent -->
	<!-- hn-eid      : host HN EID -->
	<!-- target-eid  : action target EID (usually VE EID) -->
	<!-- log         : enable actions logging/progress -->
	<xsl:template name="vzapackagem:action-packet">
		<xsl:param name="packet-id" select="/.."/>
		<xsl:param name="command"/>
		<xsl:param name="app-id" select="/.."/>
		<xsl:param name="options" select="/.."/>
		<xsl:param name="hn-eid"/>
		<xsl:param name="target-eid" select="/.."/>
		<xsl:param name="log" select="true()"/>
		<xsl:param name="progress" select="false()"/>
		<xsl:param name="cookie" select="/.."/>
		<xsl:param name="auth" select="false()"/>
	
		<packet>
			<xsl:call-template name="local:header-packet">
				<xsl:with-param name="packet-id" select="$packet-id"/>
				<xsl:with-param name="command" select="$command"/>
				<xsl:with-param name="hn-eid" select="$hn-eid"/>
				<xsl:with-param name="log" select="$log"/>
				<xsl:with-param name="progress" select="$progress"/>
				<xsl:with-param name="cookie" select="$cookie"/>
			</xsl:call-template>
			
			<data>
				<xsl:call-template name="vzapackagem:command-data">
					<xsl:with-param name="command" select="$command"/>
					<xsl:with-param name="app-id" select="$app-id"/>
					<xsl:with-param name="options" select="$options"/>
					<xsl:with-param name="hn-eid" select="$hn-eid"/>
					<xsl:with-param name="target-eid" select="$target-eid"/>
				</xsl:call-template>
			</data>
			<xsl:if test="$auth">
				<vzcpauth/>
			</xsl:if>
		</packet>
	</xsl:template>
	
	<xsl:template name="vzapackagem:chain-packet">
		<xsl:param name="packet-id" select="/.."/>
		<xsl:param name="commands"/>
		<xsl:param name="options" select="/.."/>
		<xsl:param name="hn-eid"/>
		<xsl:param name="target-eid" select="/.."/>
		<xsl:param name="log" select="true()"/>
		<xsl:param name="progress" select="false()"/>
		<xsl:param name="cookie" select="/.."/>
	
		<packet>
			<xsl:call-template name="local:header-packet">
				<xsl:with-param name="packet-id" select="$packet-id"/>
				<xsl:with-param name="command" select="''"/>
				<xsl:with-param name="hn-eid" select="$hn-eid"/>
				<xsl:with-param name="log" select="$log"/>
				<xsl:with-param name="progress" select="$progress"/>
				<xsl:with-param name="cookie" select="$cookie"/>
			</xsl:call-template>
			
			<data>
				<xsl:for-each select="$commands">
					<xsl:call-template name="vzapackagem:command-data">
						<xsl:with-param name="command" select="string(command)"/>
						<xsl:with-param name="app-id" select="app-id/*"/>
						<xsl:with-param name="options" select="options/*"/>
						<xsl:with-param name="hn-eid" select="$hn-eid"/>
						<xsl:with-param name="target-eid" select="sw:if(eid, eid, $target-eid)"/>
					</xsl:call-template>
				</xsl:for-each>
			</data>
		</packet>
	</xsl:template>

	<!-- List RPMS for a template  without VE filtering -->
	<func:function name="vzapackagem:list-app-rpms">
		<xsl:param name="app-id"/>
		<xsl:param name="hn-eid" select="''"/>

		<xsl:variable name="req">
			<xsl:call-template name="vzapackagem:action-packet">
				<xsl:with-param name="command" select="'list'"/>
				<xsl:with-param name="app-id" select="$app-id"/>
				<xsl:with-param name="options">
					<options>
						<type>rpm</type>
					</options>
				</xsl:with-param>
				<xsl:with-param name="hn-eid" select="$hn-eid"/>
				<xsl:with-param name="log" select="false()"/>
			</xsl:call-template>
		</xsl:variable>
		<func:result select="sw:xchg($req)"/>
	</func:function>

	<!-- List templates on HN -->
	<!-- WARNING LISTS ONLY EZ TEMPLATES FOR COMPATIBILITY REASONS -->
	<func:function name="vzapackagem:list4hn">
		<xsl:param name="type" select="'all'"/><!-- os=OSses app=Applications ''=All -->
		<xsl:param name="hn-eid" select="''"/><!-- '' = all HNS -->

		<xsl:variable name="req">
			<xsl:call-template name="vzapackagem:action-packet">
				<xsl:with-param name="command" select="'list'"/>
				<xsl:with-param name="options">
					<options>
						<summary/>
						<xsl:choose>
							<xsl:when test="$type='os'">
								<type>os</type>
							</xsl:when>
							<xsl:when test="$type='app'">
								<type>app</type>
							</xsl:when>
						</xsl:choose>
					</options>
				</xsl:with-param>
				<xsl:with-param name="hn-eid" select="$hn-eid"/>
				<xsl:with-param name="log" select="false()"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="res" select="sw:xchg($req)"/>

		<xsl:choose>
			<xsl:when test="$res/packet/data/error|$res/packet/data/vzapackagem/error">
				<func:result select="$res"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="rtf">
					<packet>
						<data>
							<vzapackagem>
								<packages>
									<xsl:copy-of 
										select="vzapackagem:get($res/packet/data/vzapackagem/packages/package[
														contains(@xsi:type,':package_vztemplateType')
													])/packet/data/vzapackagem/packages/package"/>
								</packages>
							</vzapackagem>
						</data>
					</packet>
				</xsl:variable>
				<func:result select="exsl:node-set($rtf)"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	
	<xsl:template name="local:select-type">
		<xsl:param name="type"/>
		<xsl:choose>
			<xsl:when test="$type=''">
			</xsl:when>
			<xsl:when test="$type='all'">
				<type>os</type>
				<type>app</type>
			</xsl:when>
			<xsl:otherwise>
				<type><xsl:value-of select="$type"/></type>
			</xsl:otherwise>
		</xsl:choose> 
	</xsl:template>

	<!-- List templates for VE-->
	<func:function name="vzapackagem:list4env">
		<xsl:param name="env-eid"/>
		<xsl:param name="type" select="'all'"/><!-- os=OSses app=Applications ''=All -->
		<xsl:param name="summary" select="true()"/>
		<xsl:param name="auth" select="false()"/>

		<xsl:variable name="req">
			<xsl:call-template name="vzapackagem:action-packet">
				<xsl:with-param name="command" select="'list'"/>
				<xsl:with-param name="options">
					<options>
						<xsl:if test="$summary">
							<summary/>
						</xsl:if>
						<xsl:call-template name="local:select-type">
							<xsl:with-param name="type" select="$type"/>
						</xsl:call-template>
					</options>
				</xsl:with-param>
				<xsl:with-param name="hn-eid" select="sw:ve-parent($env-eid)"/>
				<xsl:with-param name="target-eid" select="$env-eid"/>
				<xsl:with-param name="log" select="false()"/>
				<xsl:with-param name="auth" select="$auth"/>
			</xsl:call-template>
		</xsl:variable>
		<func:result select="sw:xchg($req)"/>
	</func:function>
	
	<!-- List templates for VE-->
	<func:function name="vzapackagem:list-compatible4env">
		<xsl:param name="env-eid"/>
		<xsl:param name="type" select="'all'"/><!-- os=OSses app=Applications 'all'=All, ''= all+rpms -->
		<xsl:param name="summary" select="false()"/>

		<xsl:variable name="req">
			<xsl:call-template name="vzapackagem:action-packet">
				<xsl:with-param name="command" select="'list'"/>
				<xsl:with-param name="options">
					<options>
						<compatible/>
						<xsl:if test="$summary">
							<summary/>
						</xsl:if>
						<xsl:call-template name="local:select-type">
							<xsl:with-param name="type" select="$type"/>
						</xsl:call-template>
					</options>
				</xsl:with-param>
				<xsl:with-param name="hn-eid" select="sw:ve-parent($env-eid)"/>
				<xsl:with-param name="target-eid" select="$env-eid"/>
				<xsl:with-param name="log" select="false()"/>
			</xsl:call-template>
		</xsl:variable>
		<func:result select="sw:xchg($req)"/>
	</func:function>
	
	<!-- List templates for VE-->
	<func:function name="vzapackagem:list-compatible4os">
		<xsl:param name="app-id"/>
		<xsl:param name="hn-eid"/>
		<xsl:param name="type" select="'all'"/><!-- os=OSses app=Applications 'all'=All, ''= all+rpms -->
		<xsl:param name="summary" select="true()"/>
		<xsl:param name="auth" select="false()"/>

		<xsl:variable name="req">
			<xsl:call-template name="vzapackagem:action-packet">
				<xsl:with-param name="command" select="'list'"/>
				<xsl:with-param name="app-id" select="local:convert-args($app-id)"/>
				<xsl:with-param name="options">
					<options>
						<compatible/>
						<xsl:if test="$summary">
							<summary/>
						</xsl:if>
						<xsl:call-template name="local:select-type">
							<xsl:with-param name="type" select="$type"/>
						</xsl:call-template>
					</options>
				</xsl:with-param>
				<xsl:with-param name="hn-eid" select="$hn-eid"/>
				<xsl:with-param name="log" select="false()"/>
				<xsl:with-param name="auth" select="$auth"/>
			</xsl:call-template>
		</xsl:variable>
		<func:result select="sw:xchg($req)"/>
	</func:function>

	<!-- Put some operation data to private area of SVE as cache file
		eid 		- EID of VE/HN where operation tackes place
		tag 		- cache file name prefix, used to distinguish operations
		new-private - data to save 
	 -->
	<func:function name="local:save-package-cache">
		<xsl:param name="eid"/>
		<xsl:param name="tag"/>
		<xsl:param name="new-private"/>
		
		<xsl:variable name="to-save">
			<data>
				<eid><xsl:value-of select="$eid"/></eid>
				<timestamp><xsl:value-of select="sw:time2vzatime(date:date-time())"/></timestamp>
				<xsl:copy-of select="$new-private"/>
			</data>
		</xsl:variable>
		<func:result select="sw:put-private($to-save, vzenv:veid-to-eid(1), concat($tag, '.', $eid))" />
	</func:function>
	
	<!-- Get some operation data from private area of SVE from a cache file  
		eid 		- EID of VE/HN where operation took place
		tag 		- cache file name prefix, used to distinguish operations 
	 -->
	<func:function name="local:get-package-cache">
		<xsl:param name="eid"/>
		<xsl:param name="tag"/>
		<func:result select="sw:get-private(vzenv:veid-to-eid(1), concat($tag, '.', $eid))/data" />
	</func:function>
	
	<func:function name="local:cache-outdated">
		<xsl:param name="cache"/>
		<xsl:param name="timeout"/>
		<xsl:variable name="time" select="date:seconds() - date:seconds(sw:vzatime2time($cache/timestamp))"/>
		<func:result select="not($cache/timestamp) or $time &gt; $timeout or not($cache/packet)"/>
	</func:function>
	
	<func:function name="vzapackagem:has-rpms-cache">
		<xsl:param name="eid"/>
		<xsl:param name="include-repository" select="false()"/>
		<xsl:param name="timeout" select="1 * 60 * 60"/>
		
		<xsl:choose>
			<xsl:when test="$include-repository">
				<func:result select="not(
											local:cache-outdated(local:get-package-cache($eid, 'rpms'), $timeout)
												or
											local:cache-outdated(local:get-package-cache($eid, 'rpmsav'), $timeout)
										)"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="not(
											local:cache-outdated(local:get-package-cache($eid, 'rpms'), $timeout)
												or
											local:cache-outdated(local:get-package-cache($eid, 'rpmsupd'), $timeout)
										)"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	
	<!-- Clears operation data from private area of SVE in a cache file  
		eid 		- EID of VE/HN where operation took place
		tag 		- cache file name prefix, used to distinguish operations 
	 -->
	<func:function name="vzapackagem:clear-call-cache">
		<xsl:param name="eid"/>
		<xsl:param name="tag"/>
		
		<func:result select="local:save-package-cache($eid, $tag, /..)"/>
	</func:function>
	
	<!-- Sends agent a packet and caches operation data in private area of SVE in a cache file if operation was successful  
		eid 		- EID of VE/HN where operation took place
		tag 		- cache file name prefix, used to distinguish operations 
		packet 		- packet to send to agent
		timeout		- cache data expiration timeout 
	 -->
	<func:function name="vzapackagem:cache-call-result">
		<xsl:param name="eid"/>
		<xsl:param name="tag"/>
		<xsl:param name="packet"/>
		<xsl:param name="timeout" select="1 * 60 * 60"/>
		
		<xsl:variable name="cached" select="local:get-package-cache($eid, $tag)"/>
		
		<xsl:choose>
			<xsl:when test="local:cache-outdated($cached, $timeout)">
				<xsl:variable name="res" select="sw:xchg($packet)"/>
				<xsl:if test="not($res//error)">
					<xsl:if test="local:save-package-cache($eid, $tag, $res/packet)"/>
				</xsl:if>
				<func:result select="$res"/>		
			</xsl:when>
			<xsl:otherwise>
				<func:result select="$cached"/>		
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<!-- Get info for specified template -->
	<func:function name="vzapackagem:get">
		<xsl:param name="app-id"/>
		<xsl:param name="hn-eid" select="''"/>

		<xsl:variable name="req">
			<xsl:call-template name="vzapackagem:action-packet">
				<xsl:with-param name="command" select="'get_info'"/>
				<xsl:with-param name="app-id" select="$app-id"/>
				<xsl:with-param name="hn-eid" select="$hn-eid"/>
				<xsl:with-param name="log" select="false()"/>
			</xsl:call-template>
		</xsl:variable>

		<func:result select="sw:xchg($req)"/>
	</func:function>

	<!-- Get info for specified RPM package -->
	<func:function name="vzapackagem:get-rpm">
		<xsl:param name="rpm-id"/>
		<xsl:param name="hn-eid" select="''"/>

		<xsl:variable name="req">
			<xsl:call-template name="vzapackagem:action-packet">
				<xsl:with-param name="command" select="'get_info'"/>
				<xsl:with-param name="app-id" select="$rpm-id"/>
				<xsl:with-param name="hn-eid" select="$hn-eid"/>
				<xsl:with-param name="log" select="false()"/>
			</xsl:call-template>
		</xsl:variable>

		<func:result select="sw:xchg($req)"/>
	</func:function>
	
	<!-- Lists RPMS installed into VE
		Caches results in SVE private area 
	-->
	<func:function name="vzapackagem:list-installed-rpms">
		<xsl:param name="eid"/>
		<xsl:param name="summary" select="false()"/>

		<xsl:variable name="req">
			<xsl:call-template name="vzapackagem:action-packet">
				<xsl:with-param name="command" select="'list'"/>
				<xsl:with-param name="options">
					<options>
						<xsl:if test="$summary">
							<summary/>
						</xsl:if>
						<xsl:call-template name="local:select-type">
							<xsl:with-param name="type" select="'rpm'"/>
						</xsl:call-template>
					</options>
				</xsl:with-param>
				<xsl:with-param name="hn-eid" select="sw:ve-parent($eid)"/>
				<xsl:with-param name="target-eid" select="$eid"/>
				<xsl:with-param name="log" select="false()"/>
			</xsl:call-template>
		</xsl:variable>
		<func:result select="vzapackagem:cache-call-result($eid, 'rpms', $req)"/>
	</func:function>

	<!-- List RPMS available for installation to VE (makes sense for EZ VEs)
		Caches results in SVE private area  
	-->
	<func:function name="vzapackagem:list-available-rpms">
		<xsl:param name="eid"/>

		<xsl:variable name="pkg" select="vzapackagem:eid2os-template($eid)"/>

		<xsl:variable name="req">
			<xsl:call-template name="vzapackagem:action-packet">
				<xsl:with-param name="command" select="'list'"/>
				<xsl:with-param name="app-id" select="$pkg"/>
				<xsl:with-param name="options">
					<options>
						<summary/>
						<compatible/>
						<type>rpm</type>
					</options>
				</xsl:with-param>
				<xsl:with-param name="hn-eid" select="sw:ve-parent($eid)"/>
				<xsl:with-param name="log" select="false()"/>
				<xsl:with-param name="auth" select="true()"/>
			</xsl:call-template>
		</xsl:variable>

		<func:result select="vzapackagem:cache-call-result($eid, 'rpmsav', $req)"/>
	</func:function>

	<!-- Lists updates available for RPMs installed into VE (makes sense for EZ VEs)
		Caches results in SVE private area  
	-->
	<func:function name="vzapackagem:list-rpm-updates">
		<xsl:param name="eid"/>

		<xsl:variable name="req">
			<xsl:call-template name="vzapackagem:action-packet">
				<xsl:with-param name="command" select="'update'"/>
				<xsl:with-param name="options">
					<options>
						<check/>
					</options>
				</xsl:with-param>
				<xsl:with-param name="hn-eid" select="sw:ve-parent($eid)"/>
				<xsl:with-param name="target-eid" select="$eid"/>
				<xsl:with-param name="log" select="false()"/>
				<xsl:with-param name="progress" select="false()"/>
			</xsl:call-template>
		</xsl:variable>

		<func:result select="vzapackagem:cache-call-result($eid, 'rpmsupd', $req)"/>
	</func:function>
	
	<!-- Clears RPM lists caches in SVE private area for the selected VE. 
		Does not clear available RPMs list because user operations can't change it.-->
	<func:function name="vzapackagem:clear-rpms-cache">
		<xsl:param name="eid"/>
		<xsl:variable name="data">
			<data/>
		</xsl:variable>
		
		<xsl:variable name="res-list" select="local:save-package-cache($eid, 'rpms', $data)"/>
		<xsl:variable name="res-updates" select="local:save-package-cache($eid, 'rpmsupd', $data)"/>
		<func:result select="$res-list and $res-updates"/>
	</func:function>
	
	<func:function name="vzapackagem:has-ve-updates">
		<xsl:param name="eid"/>
		<xsl:param name="only-os" select="false()"/>
		
		<xsl:variable name="pkg" select="vzapackagem:eid2os-template($eid)"/>
		
		<xsl:choose>
			<xsl:when test="sw:is-ez-package($pkg/name)">
				<xsl:variable name="list" select="vzapackagem:list4env($eid, 'os', false())/packet/data/vzapackagem/packages/package"/>
				<func:result select="not(string($list[vzapackagem:equals(self::package, $pkg)]/uptodate)='1')"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="count(vzapackagem:list-ve-updates($eid, $only-os))>0"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	
	<func:function name="vzapackagem:find-ve-updates">
		<xsl:param name="list"/>
		<xsl:param name="compatible"/>
		
		<xsl:variable name="updates">
			<xsl:for-each select="set:distinct($list/name)">
				<xsl:variable name="name" select="."/>
				<xsl:variable name="version" select="math:max($list[name=$name]/version)"/>

				<xsl:variable name="new-version" select="math:max($compatible[name=$name]/version)"/>
				<xsl:if test="not(string($new-version)='NaN')">
					<xsl:if test="$new-version>$version">
						<xsl:copy-of select="vzapackagem:vztemplate-packages($compatible[name=$name and version=$new-version])"/>
					</xsl:if>
				</xsl:if>
			</xsl:for-each>
		</xsl:variable>
		
		<func:result select="exsl:node-set($updates)/package"/>
	</func:function>

	<func:function name="vzapackagem:list-ve-updates">
		<xsl:param name="eid"/>
		<xsl:param name="only-os" select="false()"/>
		
		<xsl:variable name="pkg" select="vzapackagem:eid2os-template($eid)"/>
		<xsl:choose>
			<xsl:when test="sw:is-ez-package($pkg/name)">
				<func:result select="vzapackagem:list-rpm-updates($eid)/packet/data/vzapackagem/packages/package"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="list" select="vzapackagem:list4env($eid, sw:if($only-os, 'os', 'all'))/packet/data/vzapackagem/packages/package"/>
				<xsl:variable name="compatible" select="vzapackagem:list-compatible4env($eid, sw:if($only-os, 'os', 'all'))/packet/data/vzapackagem/packages/package"/>
				
				<func:result select="vzapackagem:find-ve-updates($list, $compatible)"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	
	<func:function name="vzapackagem:ve-apps-summary">
		<xsl:param name="eid"/>
		
		<xsl:variable name="list" select="vzapackagem:list4env($eid)/packet/data/vzapackagem/packages/package"/>
		<xsl:variable name="oses" select="$list[vzapackagem:is-os(.)]"/>
		<xsl:variable name="apps" select="$list[not(vzapackagem:is-os(.))]"/>
		<xsl:variable name="compatible"
			select="vzapackagem:list-compatible4env($eid, 'app')/packet/data/vzapackagem/packages/package"/>
			
		<xsl:variable name="updates" select="vzapackagem:find-ve-updates($apps, $compatible)"/>
			
		<xsl:variable name="data">
			<apps>
				<type><xsl:value-of select="sw:if(sw:is-ez-package($oses[1]/name), 'ez', 'standard')"/></type>
				<installed>
					<xsl:copy-of select="$apps"/>
				</installed>
				<xsl:choose>
					<xsl:when test="sw:is-ez-package($oses[1]/name)">
						<xsl:if test="not($oses[1]/uptodate='1')">
							<updates>
								<check/>
							</updates>
						</xsl:if>
					</xsl:when>
					<xsl:when test="$updates">
						<updates>
							<xsl:copy-of select="$updates"/>
						</updates>
					</xsl:when>
				</xsl:choose>
				<available>
					<xsl:copy-of select="$compatible[name!=$list/name]"/>
				</available>
			</apps>
		</xsl:variable>
		<func:result select="exsl:node-set($data)/apps"/>
	</func:function>
	
	<xsl:template name="vzapackagem:update-ve-packet">
		<xsl:param name="eid"/>
		<xsl:param name="cookie" select="/.."/>
		<xsl:param name="force" select="false()"/>
		<xsl:param name="log" select="false()"/>
		<xsl:param name="progress" select="false()"/>
		
		<xsl:variable name="pkg" select="vzapackagem:eid2os-template($eid)"/>
		<xsl:choose>
			<xsl:when test="sw:is-ez-package($pkg/name)">
				<xsl:call-template name="vzapackagem:action-packet">
					<xsl:with-param name="command" select="'update'"/>
					<xsl:with-param name="hn-eid" select="sw:ve-parent($eid)"/>
					<xsl:with-param name="target-eid" select="$eid"/>
					<xsl:with-param name="log" select="$log"/>
					<xsl:with-param name="progress" select="$progress"/>
					<xsl:with-param name="cookie" select="$cookie"/>
					<xsl:with-param name="options">
						<xsl:if test="$force">
							<options>
								<force/>
							</options>
						</xsl:if>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="updates" select="vzapackagem:list-ve-updates($eid)"/>
				<xsl:choose>
					<xsl:when test="$updates">
						<xsl:call-template name="vzapackagem:action-packet">
							<xsl:with-param name="command" select="'install'"/>
							<xsl:with-param name="app-id" select="$updates"/>
							<xsl:with-param name="hn-eid" select="sw:ve-parent($eid)"/>
							<xsl:with-param name="target-eid" select="$eid"/>
							<xsl:with-param name="log" select="$log"/>
							<xsl:with-param name="progress" select="$progress"/>
							<xsl:with-param name="cookie" select="$cookie"/>
							<xsl:with-param name="options">
								<xsl:if test="$force">
									<options>
										<force/>
									</options>
								</xsl:if>
							</xsl:with-param>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<packet>
							<xsl:copy-of select="$cookie"/>
						</packet>
					</xsl:otherwise>
				</xsl:choose>					
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!--Updates software in VE -->
	<func:function name="vzapackagem:update-ve">
		<xsl:param name="eid"/>
		<xsl:param name="cookie" select="/.."/>
		<xsl:param name="log" select="false()"/>
		
		<xsl:variable name="pkg" select="vzapackagem:eid2os-template($eid)"/>
		<xsl:variable name="req">
			<xsl:call-template name="vzapackagem:update-ve-packet">
				<xsl:with-param name="eid" select="$eid"/>
				<xsl:with-param name="cookie" select="$cookie"/>
				<xsl:with-param name="log" select="$log"/>
			</xsl:call-template>
		</xsl:variable>

		<func:result select="sw:xchg($req)"/>
	</func:function>
</xsl:stylesheet>
