<!--
	Copyright (c) SWsoft, 1999-2007
	All rights reserved.
-->

<xsl:stylesheet	version="1.0"	extension-element-prefixes="sw exsl math cred hwm hn computerm proc func format"
exclude-result-prefixes="exsl math hwm computerm cred proc local func hn env format vzcpsummary xsi"
	xmlns:xsl					="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl				="http://exslt.org/common"
	xmlns:math				="http://exslt.org/math"
	xmlns:sw					="http://www.swsoft.com/xsl/cp"
	xmlns:hwm					="http://www.swsoft.com/xsl/cp/hwm"
	xmlns:computerm		="http://www.swsoft.com/xsl/cp/computerm"
	xmlns:cred				="http://www.swsoft.com/xsl/cp/cred"
	xmlns:proc				="http://www.swsoft.com/xsl/cp/proc"
	xmlns:local				="http://www.swsoft.com/xsl/cp/local"
	xmlns:func				="http://exslt.org/functions"
	xmlns:hn					="http://www.swsoft.com/xsl/cp/hn"
	xmlns:env					="http://www.swsoft.com/xsl/cp/env"
	xmlns:format			="http://www.swsoft.com/xsl/cp/format"	
	xmlns:vzcpsummary ="http://www.swsoft.com/xsl/cp/vzcpsummary"
	xmlns:xsi					="http://www.w3.org/2001/XMLSchema-instance"
>
	
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vt/hn-core.xsl"/>
	<sw:include href="/lib/swa/computerm.xsl"/>
	<sw:include href="/lib/vt/hn-core.xsl"/>
	<sw:include href="/lib/swa/computerm.xsl"/>
	<sw:include href="/lib/utils/format-resusage.xsl"/>
	<sw:include href="/lib/utils/format-number.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/vza/hwm.xsl"/>
	<sw:include href="/lib/proc.xsl"/>
	<sw:include href="/lib/swa/vzcpsummary.xsl"/>

	<xsl:output method="xml"/>

	<func:function name="local:is-requested">
		<xsl:param name="resource-id"/>
		<xsl:param name="requested"/>
		<func:result select="$requested='all' or $resource-id=$requested"/>
	</func:function>
	
	<xsl:template name="hn:get-resource-summary">
		<xsl:param name="resource-id" select="'all'"/>
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>
		<xsl:variable name="hn-info" select="env:eid2info($hn-eid)"/>

		<!-- prepare data -->
		<xsl:variable name="hn-resource-rtf">
			<xsl:if test="local:is-requested('mem', $resource-id)">
				<xsl:copy-of	select="computerm:get-system($hn-eid)"/>
			</xsl:if>
			<xsl:if test="local:is-requested('diskspace', $resource-id) or local:is-requested('diskinodes', $resource-id)">
				<xsl:copy-of select="computerm:get-disk($hn-eid)"/>
			</xsl:if>
		</xsl:variable>
		<xsl:variable name="hn-resource" select="exsl:node-set($hn-resource-rtf)"/>

		<xsl:variable name="mem-swap-total" select="$hn-resource/system/swap/total + $hn-resource/system/memory/total"/>
		<xsl:variable name="disk-stat-rtf">
			<xsl:for-each select="$hn-resource/disk/partition">
				<resource>
					<name><xsl:value-of select="mount_point"/></name>
					<values>
						<total>
							<size>
								<xsl:value-of select="blocks/total * block_size"/>
							</size>
						</total>
					</values>
				</resource>
			</xsl:for-each>
		</xsl:variable>
		<xsl:variable name="hn-summary-state"	select="hn:get-vzcp-summary($hn-eid,$mem-swap-total,exsl:node-set($disk-stat-rtf)/resource,$resource-id)"/>

		<xsl:variable name="hn-mem-commitment"	select="$hn-summary-state/commitment/mem-swap"/>
		<xsl:variable name="hn-disk-commitment" select="$hn-summary-state/commitment/disks"/>

		<resources>
			<xsl:if test="local:is-requested('cpu', $resource-id)">
				<xsl:variable name="sysinfo-rtf">
					<xsl:call-template name="proc:sysinfo">
						<xsl:with-param name="eid" select="$hn-eid"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:variable name="sysinfo" select="exsl:node-set($sysinfo-rtf)"/>				
				<xsl:variable name="load-average" select="proc:calc-cpu-load($sysinfo/system)"/>
				<group>
					<id>cpu</id>
					<title><sw:text>CPU</sw:text></title>
					<resource>
						<id>cpu</id>
						<gauge>hw_cpu</gauge>
						<name><sw:text>Load</sw:text></name>
						<fraction>
							<xsl:value-of select="$load-average"/>
						</fraction>
					</resource>
					<xsl:if test="$hn-info/linux">
						<resource>
							<name><sw:text>Load Average</sw:text></name>
							<value>
								<xsl:variable name="l1" select="format-number($sysinfo/system/load_avg/l1,'0.0#')"/>
								<xsl:variable name="l2" select="format-number($sysinfo/system/load_avg/l2,'0.0#')"/>
								<xsl:variable name="l3" select="format-number($sysinfo/system/load_avg/l3,'0.0#')"/>
								<xsl:value-of select="concat($l1,', ',$l2,', ',$l3)"/>
							</value>		
						</resource>							
					</xsl:if>
				</group>
			</xsl:if>
			<xsl:if test="local:is-requested('mem', $resource-id)">
				<!-- memory and swap -->
				<xsl:variable name="total-memory" select="$hn-resource/system/memory"/>
				<xsl:variable name="total-swap" 	select="$hn-resource/system/swap"/>				
				<group>
					<id>mem</id>
					<title><sw:text>Memory</sw:text></title>
					<resource>
						<id>mem</id>
						<gauge>hw_mem</gauge>
						<name><sw:text>Physical Memory</sw:text></name>
						<fraction>
							<xsl:value-of select="$total-memory/used div $total-memory/total"/>
						</fraction>
						<values>
							<total><size><xsl:value-of select="$total-memory/total"/></size></total>
							<cur><size><xsl:value-of select="$total-memory/used"/></size></cur>
							<free><size><xsl:value-of select="$total-memory/free"/></size></free>
						</values>
					</resource>
					<resource>
						<id>swap</id>
						<gauge>hw_swap</gauge>
						<xsl:variable name="current-class-alert" select="sw:get-fake-alerts($total-swap/used,$total-swap/total)"/>
						<alert>
							<type><xsl:value-of select="exsl:node-set($current-class-alert)/level"/></type>
							<show-by-meter/>
						</alert>							
						<name><sw:text>Swap Space</sw:text></name>
						<fraction>
							<xsl:value-of select="$total-swap/used div $total-swap/total"/>
						</fraction>
						<values>
							<total><size><xsl:value-of select="$total-swap/total"/></size></total>
							<cur><size><xsl:value-of select="$total-swap/used"/></size></cur>
							<free><size><xsl:value-of select="$total-swap/free"/></size></free>
						</values>
					</resource>
					<resource>
						<id>mem_swap</id>
						<gauge>hw_mem_swap</gauge>
						<name><sw:text>RAM+Swap</sw:text></name>
						<fraction>
							<xsl:value-of select="($total-memory/used + $total-swap/used)  div ($total-memory/total + $total-swap/total)"/>
						</fraction>
						<values>
							<total><size><xsl:value-of select="$total-memory/total + $total-swap/total"/></size></total>
							<cur><size><xsl:value-of select="$total-memory/used + $total-swap/used"/></size></cur>
							<free><size><xsl:value-of select="$total-memory/free + $total-swap/free"/></size></free>
						</values>
						<commitment>
							<fraction>
								<xsl:value-of select="$hn-mem-commitment/fraction"/>
							</fraction>
							<value>
								<xsl:value-of select="$hn-mem-commitment/value"/>
							</value>
						</commitment>
					</resource>					
				</group>
			</xsl:if>
			<xsl:if test="local:is-requested('diskspace', $resource-id) or local:is-requested('diskinodes', $resource-id)">
				<!-- DiskSpace -->
				<xsl:for-each select="$hn-resource/disk/partition">
					<xsl:variable name="cur-disk" select="mount_point"/>
					<group>
						<id>disk</id>
						<title><sw:text>Disk partition</sw:text> "<xsl:value-of select="$cur-disk"/>"</title>
						<xsl:if test="local:is-requested('diskspace', $resource-id)">
							<resource>
								<id>diskspace</id>
								<gauge>hw_diskspace</gauge>
								<xsl:variable name="current-class-alert" select="sw:get-fake-alerts(blocks/used,blocks/total)"/>
								<alert>
									<type><xsl:value-of select="exsl:node-set($current-class-alert)/level"/></type>
									<show-by-meter/>
								</alert>
								<name><sw:text>Size</sw:text></name>
								<fraction>
									<xsl:value-of select="blocks/used div blocks/total"/>
								</fraction>
								<values>
									<total><size><xsl:value-of select="blocks/total * block_size"/></size></total>
									<cur><size><xsl:value-of select="blocks/used * block_size"/></size></cur>
									<free><size><xsl:value-of select="blocks/free * block_size"/></size></free>
								</values>
								<commitment>
									<fraction>
										<xsl:value-of select="$hn-disk-commitment/disk[name = $cur-disk]/fraction"/>
									</fraction>
									<value>
										<xsl:value-of select="$hn-disk-commitment/disk[name = $cur-disk]/value"/>
									</value>
								</commitment>								
							</resource>							
						</xsl:if>
						<xsl:if test="local:is-requested('diskinodes', $resource-id) and $hn-info/linux">
							<resource>
								<id>diskinodes</id>
								<gauge>hw_diskinodes</gauge>
								<xsl:variable name="current-class-alert" select="sw:get-fake-alerts(inodes/used,inodes/total)"/> 
								<alert>
									<type><xsl:value-of select="exsl:node-set($current-class-alert)/level"/></type>
									<show-by-meter/>
								</alert>
								<name><sw:text>Inodes</sw:text></name>
								<fraction>
									<xsl:value-of select="inodes/used div inodes/total"/>
								</fraction>
								<values>
									<total><xsl:value-of select="format:res2str(inodes/total,'',true())"/></total>
									<cur><xsl:value-of select="format:res2str(inodes/used,'',true())"/></cur>
									<free><xsl:value-of select="format:res2str(inodes/free,'',true())"/></free>
								</values>
							</resource>
						</xsl:if>
					</group>
				</xsl:for-each>
			</xsl:if>
		</resources>
	</xsl:template>


	<func:function name="hn:get-vzcp-summary">
		<xsl:param name="hn-eid"/>
		<xsl:param name="hn-mem-plus-swap-total"/>
		<xsl:param name="disk-stat"/>
		<xsl:param name="mode" select="'all'"/> <!-- can be mem, diskspace, all -->
		<xsl:variable name="hn-summary"	select="vzcpsummary:get-env-summary($hn-eid)"/>
		<xsl:variable name="rc-rtf">
			<xsl:variable name="ve-running"	select="format:normalize-number($hn-summary/ve_summary/group[name = 'running']/count)"/>
			<xsl:variable name="ve-total"		select="format:normalize-number($hn-summary/ve_summary/total)"/>
			<vestat>
				<running>
					<xsl:value-of select="$ve-running"/>
				</running>
				<total>
					<xsl:value-of select="$ve-total"/>
				</total>
				<stopped>
					<xsl:value-of	select="$ve-total - $ve-running"/>
				</stopped>
				<alerted>
					<xsl:variable name="ve-alerted"	select="format:normalize-number($hn-summary/ve_summary/group[name = 'alerted']/count)"/>
				</alerted>
			</vestat>
			<commitment>
				<xsl:if test="local:is-requested('mem', $mode)">
					<!-- Memory commitment constant , 2^38 = 256 Gb, any value above - unlimited -->
					<xsl:variable name="mem-committed-unlimited" select="274877906944"/>
					<mem-swap>
						<xsl:variable	name="mem-plus-swap-committed"					select="$hn-summary/ve_summary/group[name = 'mem_swap_commitment']/count"/>
						<xsl:variable name="mem-plus-swap-committed-fraction"	select="$mem-plus-swap-committed div $hn-mem-plus-swap-total"/>
						<xsl:choose>
							<xsl:when test="$mem-committed-unlimited &lt;= $mem-plus-swap-committed">
								<!-- unlimited case -->
								<value>
									<xsl:value-of select="-1"/>
								</value>
								<fraction>
									<xsl:value-of select="-1"/>
								</fraction>
							</xsl:when>
							<xsl:otherwise>
								<!-- usual case -->				
								<value>
									<xsl:value-of select="$mem-plus-swap-committed"/>
								</value>
								<fraction>
									<xsl:value-of select="$mem-plus-swap-committed-fraction"/>
								</fraction>
							</xsl:otherwise>
						</xsl:choose>
					</mem-swap>
				</xsl:if>
				<xsl:if test="local:is-requested('diskspace', $mode)">				
					<!-- Disk commitment constant , in byte,  any value above - unlimited -->
					<xsl:variable name="disk-committed-unlimited" select="2199023254528"/>
					<disks>
						<xsl:variable name="disk-committed" select="$hn-summary/ve_summary/group[sw:re-test(@xsi:type,'^([^:]+:)?ve_disk_type$')]"/>
						<xsl:for-each select="$disk-committed">
							<xsl:variable name="cur-name" select="name"/>
							<xsl:variable name="cur-count" select="count * 1024"/>
							<disk>
								<name>
									<xsl:value-of select="$cur-name"/>
								</name>
								<xsl:choose>
									<xsl:when test="$disk-committed-unlimited &lt;= $cur-count">
										<!-- unlimited case -->
										<value>
											<xsl:value-of select="-1"/>
										</value>
										<fraction>
											<xsl:value-of select="-1"/>
										</fraction>
									</xsl:when>
									<xsl:otherwise>
										<!-- usual case -->
										<value>
											<xsl:value-of select="$cur-count"/>
										</value>
										<fraction>
											<xsl:value-of select="$cur-count div $disk-stat[name = $cur-name]/values/total/size"/>
										</fraction>									
									</xsl:otherwise>
								</xsl:choose>
							</disk>
						</xsl:for-each>
						<xsl:variable name="total-disk-commitment" select="sum($disk-committed/count) * 1024"/>
						<xsl:variable name="total-disk-used-in-vz" select="sum($disk-stat[name = $disk-committed/name]/values/total/size)"/>
						<total>
							<xsl:choose>
								<xsl:when test="$disk-committed-unlimited &lt;= $total-disk-commitment">
									<!-- unlimited case -->
									<value>
										<xsl:value-of select="-1"/>
									</value>
									<fraction>
										<xsl:value-of select="-1"/>
									</fraction>
								</xsl:when>
								<xsl:otherwise>
									<!-- usual case -->
									<value>
										<xsl:value-of select="$total-disk-commitment"/>
									</value>
									<fraction>
										<xsl:value-of select="$total-disk-commitment div $total-disk-used-in-vz"/>
									</fraction>
								</xsl:otherwise>
							</xsl:choose>
						</total>
					</disks>
				</xsl:if>
			</commitment>
		</xsl:variable>
		<func:result select="exsl:node-set($rc-rtf)"/>
	</func:function>


</xsl:stylesheet>
