<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func set browse vzapackagem tem error local"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"   
	xmlns:templates	="http://www.swsoft.com/xsl/cp/templates"
	xmlns:func		="http://exslt.org/functions"
	xmlns:browse	="http://www.swsoft.com/xsl/cp/browse"   
	xmlns:tem		="http://www.swsoft.com/xsl/cp/tem"
	xmlns:vzapackagem	="http://www.swsoft.com/xsl/cp/vzapackagem"
	xmlns:set		="http://exslt.org/sets" 
	xmlns:vz		="http://www.swsoft.com/xsl/cp/vz"
	xmlns:vt		="http://www.swsoft.com/xsl/cp/vt"
	xmlns:hn		="http://www.swsoft.com/xsl/cp/hn"
	xmlns:env		="http://www.swsoft.com/xsl/cp/env"
	xmlns:vzenv		="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:error		="http://www.swsoft.com/xsl/cp/error"
	xmlns:units 	="http://www.swsoft.com/xsl/cp/units"
	xmlns:local		="http://www.swsoft.com/xsl/cp/local">
  
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/core/browse-filter-raw.xsl"/>
	<sw:include href="/lib/core/browse-filter-vza.xsl"/>	
	<sw:include href="/lib/vza/tem.xsl"/>  
	<sw:include href="/lib/vz/apps.xsl"/>  
	<sw:include href="/lib/vz/vzenv-os.xsl"/>  
	<sw:include href="/lib/vt/env-list.xsl"/>  
	<sw:include href="/lib/vt/hn-list.xsl"/>  
	<sw:include href="/lib/vza/vzapackagem.xsl"/>    
	<sw:include href="/lib/core/units-core.xsl"/>
	
	<xsl:key name="app-ids-key" match="row" use="vzapackagem:generate-id(packages)"/>
	
	<func:function name="templates:make-global-browse-filter">
		<xsl:param name="template-type"/>
		<xsl:param name="url"/>
		<xsl:param name="item-url"/>
		<xsl:param name="hn-eid" select="/.."/>
		
		<!-- group templates -->
		<xsl:variable name="all-templates" select="vz:list-group-templates($hn-eid, '', sw:if($hn-eid, '', units:current-dn()))" />
		
		<!-- list of templates -->
		<xsl:variable name="templates" select="vz:filter-templates($all-templates, $app-list-type='os')" />
		
		<xsl:variable name="filter_init_">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="apps-{$app-list-type}" url="{$url}" item-url="{$item-url}">
					</ui:browse-setup>
					<ui:cols sorting-col="app-name">
						<ui:column id="app-id" hidden="yes" for-url="yes" for-select="yes"/>
						<ui:column id="hn-eid" hidden="yes" for-url="yes" for-select="yes"/>
						
						<ui:column id="app-name" apply-templates="yes" title="{sw:text('Name')}"
							filter="auto" show-url="yes"/>
						
						<ui:column id="app-version" title="{sw:text('Version')}" align="center" filter="auto"/>
						<ui:column id="vzpkg-type" hidden="yes" title="{sw:text('Type')}"/>
						<ui:column id="vzpkg-type-str" title="{sw:text('Type')}" align="center" filter="select">
							<ui:filter-option value="{sw:text('EZ')}" title="{sw:text('EZ')}" />
							<ui:filter-option value="{sw:text('Standard')}" title="{sw:text('Standard')}" />
						</ui:column>
						<ui:column id="descr" title="{sw:text('Description')}" filter="auto" />
						<ui:column id="platform-os" title="{sw:text('Platform')}" filter="select" apply-templates="yes" 
								align="center">
							<xsl:copy-of select="vt:vza-platform-oses()"/>
						</ui:column>
						<!-- no architecture for ap templates -->
						<xsl:if test="$app-list-type='os'">
							<ui:column id="arch" title="{sw:text('Architecture')}" filter="select" align="center">
								<xsl:for-each select="set:distinct($templates/packages/arch)">
									<xsl:sort select="."/>
									<ui:filter-option value="{.}" title="{.}"/>
								</xsl:for-each>
							</ui:column>
							<!-- local HN browse columns -->
							<xsl:if test="$hn-eid">
								<ui:column id="cached" title="{sw:text('Cached')}" filter="auto" data-type="bool" align="center"/>
							</xsl:if>
						</xsl:if>
						<xsl:if test="not($app-list-type='os')">
							<xsl:variable name="os" select="set:distinct($templates/packages/os/name[not(string(.)='')])" />

							<ui:column id="os" title="{sw:text('OS')}" filter="select" custom-filter-hidden="yes">
								<xsl:for-each select="$os">
									<xsl:sort select="." />
									<xsl:variable name="title" select="sw:app-id2title(.)" />
									<ui:filter-option value="{$title}" title="{$title}" />
								</xsl:for-each>
							</ui:column>
						</xsl:if>
						<xsl:if test="string($hn-eid)=''">
							<ui:column id="available" title="{sw:text('Available')}" filter="auto" data-type="bool"
								align="center"/>
							<ui:column id="origin" custom-hidden="yes" title="{sw:text('Original HN')}" filter="auto" custom-filter-hidden="yes"/>
						</xsl:if>
					</ui:cols>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="filter-init" select="exsl:node-set($filter_init_)" />
		
		<xsl:variable name="filter-rtf">
			<xsl:call-template name="browse:fill-filter">
				<xsl:with-param name="filter" select="$filter-init" />
				<xsl:with-param name="rows">
					<ui:browse-rows>
						<!-- Show New Packages -->
						<xsl:choose>
							<xsl:when test="$all-templates/error|$all-templates/pager/error">
								<xsl:if
									test="error:put(sw:text('An error occurred during the templates retrieval.'),	
										$all-templates/error|$all-templates/pager/error)" />
							</xsl:when>
							<xsl:otherwise>
								<xsl:apply-templates select="$templates"/>
							</xsl:otherwise>
						</xsl:choose>
					</ui:browse-rows>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>
		<func:result select="$filter-rtf"/>
	</func:function>
	
	<xsl:template match="row">
	
		<xsl:variable name="origin" select="env" />

		<ui:row>
			<xsl:if test="not($origin/state=$env-state/running)">
				<xsl:attribute name="disable-item-url">true</xsl:attribute>
			</xsl:if>
			<app-id><xsl:value-of select="vzapackagem:generate-id(packages)"/></app-id>
			
			<xsl:choose>
				<xsl:when test="sw:is-ez-package(packages/name)">
					<vzpkg-type-str>
						<sw:text>EZ</sw:text>
					</vzpkg-type-str>
					<vzpkg-type>new</vzpkg-type>
				</xsl:when>
				<xsl:otherwise>
					<vzpkg-type-str>
						<sw:text>Standard</sw:text>
					</vzpkg-type-str>
					<vzpkg-type>old</vzpkg-type>
				</xsl:otherwise>
			</xsl:choose>
			
			<app-name><xsl:value-of select="sw:app-id2title(packages/name)" /></app-name>
			<app-version><xsl:value-of select="sw:if(not(packages/version=''), packages/version, sw:text('n/a'))"/></app-version>
			<version><xsl:value-of select="packages/version"/></version>
			<hn-eid>
				<xsl:value-of select="$origin/eid" />
			</hn-eid>
			
			<descr>
				<xsl:value-of select="packages/summary" />
			</descr>
			<os><xsl:value-of select="sw:app-id2title(packages/os/name)" /></os>
			<platform-os><xsl:value-of select="vt:os2vza(vt:vza2os(packages/os/platform))"/></platform-os>
			<arch><xsl:value-of select="packages/arch" /></arch>
			<available><xsl:value-of select="sw:if($origin/state=$env-state/running, 1, 0)" /></available>
			
			<cached><xsl:value-of select="packages/cached"/></cached>

			<xsl:call-template name="local:set-origin">
				<xsl:with-param name="origin" select="$origin" />
			</xsl:call-template>
		</ui:row>
	</xsl:template>
	
	<xsl:template name="local:set-origin">
		<xsl:param name="origin" />
		<origin>
			<xsl:choose>
				<xsl:when test="$origin">
					<ui:link>
						<xsl:attribute name="href"><xsl:value-of select="concat($baseurl,'/vzdir/infrman/hns/hn?id=',sw:base64-encode($origin/eid))" /></xsl:attribute>
						<xsl:value-of select="env:env2title($origin)" />
					</ui:link>
				</xsl:when>
				<xsl:otherwise>
					<sw:text>n/a</sw:text>
				</xsl:otherwise>
			</xsl:choose>
		</origin>
	</xsl:template>
	
	<xsl:template name="templates:list-ves">
		<xsl:param name="app-id" />
		<xsl:param name="url" />
		<xsl:param name="hn-eid" select="''"/>
		<xsl:param name="actions" select="'app-control'" />
		
		<xsl:variable name="pkg" select="vzapackagem:id2package($app-id)"/>
		
		<!-- Prepare VEs Browse Filter -->
		<xsl:variable name="ve_filter_init_">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="app-ve" url="{$url}"
						item-url="/vzdir/infrman/envs/env" items-title="{sw:text('Added to Containers')}">
					</ui:browse-setup>
					<ui:cols sorting-col="id-int">
						<xsl:call-template name="env:get-browse-cols">
							<xsl:with-param name="show-os" select="false()" />
							<xsl:with-param name="ext-cols">
								<ui:column id="eid" hidden="yes" vza-id="env.eid" nav-type="id">
									<xsl:if test="not(string($actions)='') and $app-type='app'">
										<xsl:attribute name="for-select">yes</xsl:attribute>
										<xsl:attribute name="for-select-condition">ve-status=<xsl:value-of select="$env-state/running"/> 
											and transition=<xsl:value-of select="$env-trans/none"/></xsl:attribute>
									</xsl:if>
								</ui:column>
								<ui:column id="id" vza-id="env.eid"  nav-type="id" hidden="yes"/> 
								<!--  <ui:column id="id-int" vza-id="env.vconfig.veid" show-url="yes" data-type="int"
									title="{sw:text('ID')}" filter="auto" />-->

								<xsl:variable name="key" select="sw:if(vzapackagem:is-os($pkg), 'env.vconfig.os_template', 'env.vconfig.template')"/>
																	
								<ui:column id="tmp-name" vza-id="{$key}.name" hidden="yes" value="{$pkg/name}"
									filter="equal"/>
								<xsl:if test="not(sw:is-ez-package($pkg/name) 
												or vt:is-platform-windows(
													vt:vza2platform($pkg/os/platform,
														vzapackagem:pkg-arch2vza($pkg/arch))))">
									<ui:column id="tmp-ver" vza-id="{$key}.version" hidden="yes" filter="equal"
										value="{$pkg/version}"/>
								</xsl:if>
								<xsl:if test="not(string($hn-eid)='')">
									<ui:column id="hn-eid" hidden="yes" vza-id="env.parent_eid" value="{$hn-eid}" filter="equal" />
								</xsl:if>
								
								<!-- filter by DN -->
								<xsl:variable name="filter-dn" select="units:current-dn()"/>
								<xsl:if test="not(string($filter-dn)='')">
									<ui:column id="unit" hidden="yes" vza-id="env.eid">
										<ui:cond expr="in-unit-recursive"><xsl:value-of select="units:decode-dn($filter-dn)"/></ui:cond>
									</ui:column>
								</xsl:if>
							</xsl:with-param>
							<xsl:with-param name="show-url" select="true()" />
						</xsl:call-template>
					</ui:cols>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>
		<!-- /Prepare VEs Browse Filter -->

		<!-- Show VEs -->
		<ui:browse>
			<xsl:attribute name="title">
				<xsl:if test="$app-type='os'">
					<sw:text>Containers based on this OS</sw:text>
				</xsl:if>
				<xsl:if test="$app-type='app'">
					<sw:text>Installed in Containers</sw:text>
				</xsl:if>
			</xsl:attribute>

			<ui:filter>
				<xsl:call-template name="env:fill-filter">
					<xsl:with-param name="filter-rtf" select="$ve_filter_init_"/>	
					<xsl:with-param name="filter-hn-eid" select="$hn-eid"/>			
					<xsl:with-param name="filter-dn" select="units:current-dn()"/>
				</xsl:call-template>
			</ui:filter>

			<ui:browse-js-many>
				<ui:warn>
					<sw:text>Select at least one Container!</sw:text>
				</ui:warn>
			</ui:browse-js-many>

			<xsl:if test="not(string($actions)='') and $app-type='app'">
				<ui:form action="app-control" />

				<ui:browse-buttons type="list-selection">
					<ui:button type="list-selection" tip="deinstall_app" icon="delete" name="deinstall_app"
						width="150" script="if (!atLeastOne()) return false;">
						<xsl:if test="$actions">
							<xsl:attribute name="submit-href"><xsl:value-of select="$actions" /></xsl:attribute>
						</xsl:if>
						<sw:text>Uninstall From Containers</sw:text>
					</ui:button>
				</ui:browse-buttons>
			</xsl:if>

			<ui:browse-empty-msg stop-sign="no">
				<xsl:if test="$app-type='os'">
					<sw:text>No Container is based on this OS template.</sw:text>
				</xsl:if>
				<xsl:if test="$app-type='app'">
					<sw:text>This application is not installed in any Container.</sw:text>
				</xsl:if>
			</ui:browse-empty-msg>
		</ui:browse>
		<!-- /Show VEs -->
	</xsl:template>

	<xsl:template name="templates:list-hns">
		<xsl:param name="url" />
		<xsl:param name="app-id" />
		<xsl:param name="actions" select="'list-control'"/>
		
		<xsl:variable name="pkg" select="vzapackagem:id2package($app-id)"/>

		<!-- Prepare Filter -->
		<xsl:variable name="filter-init-rtf">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="vz_tmpl_hns" url="{$url}"
						items-title="{sw:text('Installed on HNs')}" item-url="/vzdir/infrman/hns/templates/index">
					</ui:browse-setup>
					<ui:cols sorting-col="hostname">
						<xsl:call-template name="hn:get-browse-cols">
							<xsl:with-param name="id-cols">
								<ui:column id="eid" hidden="yes" vza-id="env.eid" nav-type="id">
									<xsl:if test="not(string($actions)='')">
										<xsl:attribute name="for-select">yes</xsl:attribute>
										<xsl:attribute name="for-select-condition">hn-status=<xsl:value-of select="$env-state/running"/>
											and transition=<xsl:value-of select="$env-trans/none"/></xsl:attribute>
									</xsl:if>
								</ui:column>
								<ui:column id="pkg-name" hidden="yes" vza-id="packages.name" for-url="no" for-select="no" />
								<ui:column id="pkg-ver" hidden="yes" vza-id="packages.version" for-url="no" for-select="no" />
								<ui:column id="pkg-os-pl" hidden="yes" vza-id="packages.os.platform" for-url="no" for-select="no" />
								<ui:column id="pkg-os-name" hidden="yes" vza-id="packages.os.name" for-url="no" for-select="no" />
								<ui:column id="pkg-app-type" hidden="yes" vza-id="packages.os_template" for-url="no" for-select="no" />
								<!-- Filter by DN -->
								<xsl:variable name="filter-dn" select="units:current-dn()"/>
								<xsl:if test="not(string($filter-dn)='')">
									<ui:column id="unit" hidden="yes" vza-id="env.eid">
										<ui:cond expr="in-unit-recursive"><xsl:value-of select="units:decode-dn($filter-dn)"/></ui:cond>
									</ui:column>
								</xsl:if>
							</xsl:with-param>
							<xsl:with-param name="show-url" select="true()" />
						</xsl:call-template>
						<xsl:if test="vzapackagem:is-os($pkg)">
							<ui:column id="pkg-app-cached" title="{sw:text('Cached')}" vza-id="packages.cached"
								for-url="no" for-select="no" filter="auto" data-type="bool"/>
						</xsl:if>

					</ui:cols>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>
		<!-- /Prepare Filter -->

		<!-- Show screen -->
		<ui:block width="full">
			<ui:browse>
				<xsl:attribute name="title">
					<sw:text>Installed on Hardware Nodes</sw:text>
				</xsl:attribute>

				<ui:filter>
					<!-- Get data -->
					<xsl:call-template name="browse:fill-from-vza">
						<xsl:with-param name="sql-where">
							(
							<xsl:if test="not(string($pkg/version)='')">
								pager.packages.version='<xsl:value-of select="sw:sql-escape($pkg/version)" />' and 
							</xsl:if>
								lower(pager.packages.os.platform)='<xsl:value-of select="sw:sql-escape(sw:lc($pkg/os/platform))" />' and 
							<xsl:if test="not(string($pkg/os/name)='')">
								pager.packages.os.name='<xsl:value-of select="sw:sql-escape($pkg/os/name)" />' and
							</xsl:if>
								pager.packages.name='<xsl:value-of select="sw:sql-escape($pkg/name)" />'  
							)
						</xsl:with-param>
						<xsl:with-param name="filter" select="exsl:node-set($filter-init-rtf)" />
					</xsl:call-template>
				</ui:filter>

				<ui:browse-js-many>
					<ui:warn>
						<sw:text>To perform any action on HNs in this list, you have to select at least one.</sw:text>
					</ui:warn>
				</ui:browse-js-many>
				
				<xsl:if test="not(string($actions)='')">
					<xsl:if test="vzapackagem:is-os($pkg) and vt:is-platform-linux(vt:vza2platform($pkg/os/platform))">
						<ui:browse-buttons>
							<ui:button type="list-selection" icon="cache_vz_template" tip="tmpl_cache" 
								script="if (!atLeastOne()) return false;" name="cache">
								<xsl:if test="$actions">
									<xsl:attribute name="submit-href"><xsl:value-of select="$actions" /></xsl:attribute>
								</xsl:if>
								<sw:text>Cache Template</sw:text>
							</ui:button>
						</ui:browse-buttons>
					</xsl:if>
					<ui:browse-buttons>
						<ui:button type="list-selection" tip="deinstall_vz_tmpl_hn" icon="delete"
							script="if (!atLeastOne()) return false;" name="deinstall">
							<xsl:if test="$actions">
								<xsl:attribute name="submit-href"><xsl:value-of select="$actions" /></xsl:attribute>
							</xsl:if>
							<sw:text>Uninstall Template</sw:text>
						</ui:button>
					</ui:browse-buttons>
				</xsl:if>

				<ui:browse-empty-msg>
					<sw:text>There are no available HNs.</sw:text>
				</ui:browse-empty-msg>

			</ui:browse>

		</ui:block>
		<!-- /Show screen -->
	</xsl:template>
	
	<!-- Show some VZA error -->
	<xsl:template name="templates:show-error">
		<xsl:param name="error" select="/.."/>
		<xsl:param name="message" select="/.."/>
		
		<ui:block>
			<ui:operation-problem>
				<ui:type>vza-error</ui:type>
				<ui:descr>
					<xsl:choose>
						<xsl:when test="$message">
							<xsl:copy-of select="$message" />
						</xsl:when>
						<xsl:otherwise>
							<sw:text>Error reading the template information.</sw:text>
						</xsl:otherwise>
					</xsl:choose>
				</ui:descr>
				<ui:vza-error>
					<xsl:copy-of select="$error/*"/>
				</ui:vza-error>
				<ui:reason>
					<sw:text>The requested template was removed from the Hardware Node.</sw:text>
				</ui:reason>
				<ui:solution>
					<sw:text>Return to the list of the templates and select another template.</sw:text>
				</ui:solution>
			</ui:operation-problem>
		</ui:block>
	</xsl:template>
	
	<xsl:template name="templates:show-rpm-error">
		<xsl:param name="error" select="/.." />
		<xsl:param name="message" select="/.." />

		<ui:block>
			<ui:operation-problem>
				<ui:type>vza-error</ui:type>
				<ui:descr>
					<xsl:choose>
						<xsl:when test="$message">
							<xsl:copy-of select="$message" />
						</xsl:when>
						<xsl:otherwise>
							<sw:text>Error loading the RPM information.</sw:text>
						</xsl:otherwise>
					</xsl:choose>
				</ui:descr>
				<ui:vza-error>
					<xsl:copy-of select="$error/*" />
				</ui:vza-error>
				<ui:reason>
					<sw:text>The requested RPM was removed from the Hardware Node.</sw:text>
				</ui:reason>
				<ui:solution>
					<sw:text>Return to the list of RPMs and select another application.</sw:text>
				</ui:solution>
			</ui:operation-problem>
		</ui:block>
	</xsl:template>
	
	<xsl:template name="templates:show-summary-block">
		<xsl:param name="pkg"/>
		<xsl:param name="show-cached" select="false()"/>
		
		
		<ui:block width="full">
			<ui:rows title="{sw:text('Summary')}">
				<ui:row>
					<ui:cell-label>
						<sw:text>Type</sw:text>
					</ui:cell-label>
					<ui:cell-value>
						<xsl:value-of select="sw:if(sw:is-ez-package($pkg/name), 
														sw:text('EZ'), sw:text('Standard'))"/>
					</ui:cell-value>
				</ui:row>
				<xsl:if test="not(string($pkg/version)='')">
					<ui:row>
						<ui:cell-label>
							<sw:text>Version</sw:text>
						</ui:cell-label>
						<ui:cell-value>
							<xsl:value-of select="$pkg/version"/>
							<xsl:if test="not($pkg/base) or string($pkg/base)='0'"><xsl:text select="' '"/>
								<ui:disabled-text>
									<sw:text>(update)</sw:text>
								</ui:disabled-text>
							</xsl:if>
						</ui:cell-value>
					</ui:row>
				</xsl:if>
				<xsl:choose>
					<xsl:when test="vzapackagem:is-os($pkg)">
						<xsl:if test="$show-cached">
							<ui:row>
								<ui:cell-label>
									<sw:text>Cached</sw:text>
								</ui:cell-label>
								<ui:cell-value>
									<xsl:value-of
										select="sw:if(string($pkg/cached)='1', sw:text('Yes'), sw:text('No'))"/>
								</ui:cell-value>
							</ui:row>
						</xsl:if>
						<ui:row>
							<ui:cell-label>
								<sw:text>Architecture</sw:text>
							</ui:cell-label>
							<ui:cell-value>
								<xsl:value-of select="$pkg/arch"/>
							</ui:cell-value>
						</ui:row>
					</xsl:when>
					<xsl:otherwise>
						<ui:row>
							<ui:cell-label>
								<sw:text>OS Template</sw:text>
							</ui:cell-label>
							<ui:cell-value>
								<xsl:value-of select="sw:app-id2title($pkg/os/name)"/>
							</ui:cell-value>
						</ui:row>
					</xsl:otherwise>
				</xsl:choose>
				<ui:row>
					<ui:cell-label>
						<sw:text>Platform</sw:text>
					</ui:cell-label>
					<ui:cell-value>
						<xsl:value-of select="$pkg/os/platform"/>
					</ui:cell-value>
				</ui:row>
				<xsl:if test="not(string($pkg/technology)='')">
					<ui:row>
						<ui:cell-label>
							<sw:text>Supported technologies</sw:text>
						</ui:cell-label>
						<ui:cell-value>
							<xsl:for-each select="$pkg/technology">
								<xsl:value-of select="."/><xsl:text> </xsl:text>
							</xsl:for-each>
						</ui:cell-value>
					</ui:row>
				</xsl:if>
			</ui:rows>
		</ui:block>
	</xsl:template>
	
	<func:function name="vz:filter-templates">
		<xsl:param name="data"/>
		<xsl:param name="is-os"/>
		
		<xsl:variable name="ids" 
			select="set:distinct(
				vzapackagem:generate-ids(
					$data/pager/row_set/row/packages[
						($is-os and os_template='1') 
						or (not($is-os) and not(os_template='1'))]))"/>
		
		<xsl:variable name="res">
			<xsl:for-each select="$ids">
				<xsl:variable name="id" select="."/>
				<xsl:for-each select="$data">
					<xsl:variable name="pkgs" select="key('app-ids-key', $id)"/>
					<xsl:copy-of
						select="sw:if($pkgs[env/state=$env-state/running], $pkgs[env/state=$env-state/running], $pkgs)[1]"/>
				</xsl:for-each>
			</xsl:for-each>
		</xsl:variable>
		<func:result select="exsl:node-set($res)/row|$data[name()='error']" />
	</func:function>
	
	<!-- Show link for single template, template is specified by id (in term of vzapackagem:generate-id()) or  
		package info as node, template info is requested from HN specified with hn-eid-->
	<xsl:template name="templates:show-app-name-link">
		<xsl:param name="app-id"/>
		<xsl:param name="hn-eid"/>
		<xsl:param name="show-version" select="true()"/>
		
		<xsl:variable name="pkg" select="vzapackagem:vztemplate-packages($app-id)"/>
		
		<xsl:variable name="app-name" select="sw:app-id2title($pkg/name, sw:if($show-version, $pkg/version, /..))"/> 		
		<a 
			href="javascript:open_details('{$baseurl}/vzdir/infrman/templates/info-popup?app-id={sw:base64-encode(vzapackagem:generate-id($app-id))}&amp;hn-eid={sw:base64-encode($hn-eid)}');">
			<xsl:value-of select="$app-name" />
		</a>
	</xsl:template>
	
</xsl:stylesheet>
