<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl sw func local templates vt"
	exclude-result-prefixes="sw exsl sw func local vz set hn vt"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" 
	xmlns:func="http://exslt.org/functions"
	xmlns:vzapackagem="http://www.swsoft.com/xsl/cp/vzapackagem" 
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:hn="http://www.swsoft.com/xsl/cp/hn"
	xmlns:action="http://www.swsoft.com/xsl/cp/action"
	xmlns:set="http://exslt.org/sets" 
	xmlns:vz="http://www.swsoft.com/xsl/cp/vz"
	xmlns:vt="http://www.swsoft.com/xsl/cp/vt"
	xmlns:templates="http://www.swsoft.com/xsl/cp/templates"
	xmlns:units="http://www.swsoft.com/xsl/cp/units"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui">
	
	<sw:include href="/lib/common.xsl" />
	<sw:include href="/lib/cred-filter.xsl"/>
	<sw:include href="/lib/core/units-core.xsl" />
	<sw:include href="/lib/utils/action.xsl"/>
	<sw:include href="/lib/vz/apps.xsl" />
	<sw:include href="/lib/vz/vzenv-os.xsl"/>
	<sw:include href="/lib/vza/vzapackagem.xsl" />
	<sw:include href="/lib/vt/hn-select.xsl" />
	<sw:include href="/lib/vt/env-select.xsl" />
	<sw:include href="/lib/vzdir/infrman/templates/browse.xsl"/>
	
	<xsl:output method="xml" />
	
	<!-- Reqest handler part -->
	
	<!-- Initial screen -->
	<xsl:template match="action[screen and not(local:is-submit(.))]" mode="templates:req">
		<!-- Prepare data -->
		<xsl:variable name="apps" select="local:get-apps(.)"/>
		<xsl:variable name="error" select="local:report-incompatible-templates($apps, envs)"/>
		
		<xsl:choose>
			<xsl:when test="not(string($error)='')">
				<packet>
					<cookie>
						<redirect-last/>
					</cookie>
				</packet>
				<xsl:if test="error:put(error, $error)"/>
				<xsl:value-of select="sw:response('lib/opredirect.xsl')" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="data">
					<info>
						<xsl:copy-of select="$apps"/>
					</info>
				</xsl:variable>
				
				<!-- Cache data for submit action-->
				<xsl:if test="sw:sesput(local:get-data-id(.), exsl:node-set($data))" />
				
				<!-- Propagate screen description -->
				<packet>
					<xsl:copy-of select="." />
					<xsl:copy-of select="$data" />
				</packet>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<!-- Report error when user selects templates that can't be processed as one transaction i.e. 
	different platforms for HN specific ops and different base OS for VE specific ops-->
	<func:function name="local:report-incompatible-templates">
		<xsl:param name="apps"/>
		<xsl:param name="envs"/>
		
		<xsl:variable name="pkg" select="vzapackagem:vztemplate-packages($apps/id)"/>
		<func:result>		
			<xsl:choose>
				<xsl:when test="$envs/@type='hn' and count(set:distinct($pkg/os/platform)) &gt; 1">
					<sw:text>For the templates to be processed in a single operation, they should have compatible platforms and architectures.</sw:text>
				</xsl:when>
				<xsl:when test="$envs/@type='ve' and count(set:distinct($pkg/os)) &gt; 1">
					<sw:text>For the templates to be processed in a single operation, they should have compatible OSs, platforms, and architectures.</sw:text>
				</xsl:when>
				<xsl:when test="$envs/@type='hn'">
					<xsl:variable name="platforms" select="vz:get-templates-platform($pkg)"/>
					<xsl:if test="count(local:correct-platforms($platforms)) &gt; 1">
						<sw:text>For the templates to be processed in a single operation, they should have compatible platforms and architectures.</sw:text>
					</xsl:if>
				</xsl:when>					
			</xsl:choose>
		</func:result>
	</func:function>
	
	<func:function name="local:correct-platforms">
		<xsl:param name="platforms-data"/>
		
		<xsl:variable name="platforms" select="set:distinct($platforms-data/platform)"/>
		<xsl:choose>
			<xsl:when test="count($platforms)=1">
				<func:result select="$platforms"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="res">
					<xsl:for-each select="$platforms">
						<xsl:variable name="pos" select="position()"/>
						<xsl:variable name="cur" select="."/>
						<xsl:if test="not($platforms[position() != $pos][vt:platform-backwards-compatible(., $cur)])">
							<xsl:copy-of select="."/>
						</xsl:if>
					</xsl:for-each>
				</xsl:variable>	
				<func:result select="exsl:node-set($res)/platform"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	
	<!-- Reaction on submit -->
	<xsl:template match="action[screen and local:is-submit(.)]" mode="templates:req">
		<xsl:variable name="data" select="local:get-submit-data(.)"/>
		
		<xsl:choose>
			<xsl:when test="$data/eid">
				<xsl:apply-templates select="." mode="templates:packet">
					<xsl:with-param name="data" select="$data"/>
				</xsl:apply-templates>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="error:put(sw:if(envs/@type='hn', 
												sw:text('Please specify at least one HN.'), 
												sw:text('Please specify at least one Container.')), 
										'', local:get-submit-id(.))"/>

				<!-- Propagate screen description -->
				<packet>
					<xsl:copy-of select="."/>
					<xsl:copy-of select="sw:sesget(local:get-data-id(.))"/>
					<submit>
						<xsl:copy-of select="$data/*"/>
					</submit>
				</packet>
			</xsl:otherwise>
		</xsl:choose>
		
	</xsl:template>
	
	<!-- Simple action without screen -->
	<xsl:template match="action[not(screen)]" mode="templates:req">
		<xsl:apply-templates select="." mode="templates:packet">
			<xsl:with-param name="data" select="local:get-action-data(.)"/>
		</xsl:apply-templates>
	</xsl:template>
	
	<xsl:template match="action" mode="templates:packet">
		<xsl:param name="data"/>
		
		<xsl:call-template name="local:create-action-packet">
			<xsl:with-param name="action" select="."/>
			<xsl:with-param name="input" select="$data"/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template match="action[@id='deinstall']" mode="templates:packet">
		<xsl:param name="data"/>
		
		<xsl:variable name="ves" select="vz:get-templates-ves-count($data/app/id, $data/eid)"/>
		
		<xsl:choose>
			<xsl:when test="$ves/ve-count &gt; 0">
				<packet>
					<cookie>
						<xsl:call-template name="local:redirect">
							<xsl:with-param name="action" select="."/>
						</xsl:call-template>
					</cookie>
				</packet>
				<xsl:variable name="err">
					<xsl:for-each select="$ves[ve-count &gt; 0]">
						<xsl:if test="position() &gt; 1"><br/></xsl:if>
						<sw:text>
							<xsl:with-param name="count" select="ve-count"/>
							<xsl:with-param name="app-title" select="vzapackagem:app-title(app)"/>
							The %{app-title} template is installed in %{count} Containers.
						</sw:text>
					</xsl:for-each>
				</xsl:variable>
				<xsl:if test="error:put(sw:text('The selected templates could not be uninstalled because some of them are added to one or more Containers.'), $err)"/>
				<xsl:value-of select="sw:response('lib/opredirect.xsl')" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="local:create-action-packet">
					<xsl:with-param name="action" select="."/>
					<xsl:with-param name="input" select="$data"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="local:create-action-packet">
		<xsl:param name="action"/>
		<xsl:param name="input"/>
		
		<!-- detect that some EIDs are invalid -->
		<xsl:variable name="eids" select="$input/eid"/>
		<xsl:variable name="valid-eids" select="local:get-valid-eids($eids, $action/envs/@type='hn')"/>
			
		<xsl:choose>
			<xsl:when test="count($eids)!=count($valid-eids)">
				<packet>
					<cookie>
						<xsl:call-template name="local:redirect">
							<xsl:with-param name="action" select="."/>
						</xsl:call-template>
					</cookie>
				</packet>
					
				<xsl:variable name="error-msg">
					<xsl:for-each select="set:difference($eids, $valid-eids)">
						<xsl:if test="position() &gt; 1">
							<br/>
						</xsl:if>
						<xsl:choose>
							<xsl:when test="$action/envs/@type='hn'">
								<sw:text>
									<xsl:with-param name="env-title" select="env:eid2info(.)/title"/>
									The operation is not allowed for HN %{env-title}.
								</sw:text>
							</xsl:when>
							<xsl:otherwise>
								<sw:text>
									<xsl:with-param name="env-title" select="env:eid2info(.)/title"/>
									The operation is not allowed for Container %{env-title}.
								</sw:text>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
				</xsl:variable>
				<xsl:if test="error:put(error, $error-msg)"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:for-each select="$action">
					<xsl:call-template name="action:make-packet">
						<xsl:with-param name="path"
							select="concat('actions/vzdir/infrman/templates/', local:get-action-file(.))" />
						<xsl:with-param name="cookie">
							<msg>
								<sched>
									<xsl:value-of select="message" />
								</sched>
								<error>
									<xsl:value-of select="error" />
								</error>
							</msg>
							<xsl:call-template name="local:redirect">
								<xsl:with-param name="action" select="."/>
							</xsl:call-template>
							<operation><xsl:value-of select="@id" />_templates</operation>
						</xsl:with-param>
						<xsl:with-param name="input" select="$input" />
					</xsl:call-template>
				</xsl:for-each>
			</xsl:otherwise>
		</xsl:choose>
		
		<xsl:value-of select="sw:response('lib/opredirect.xsl')" />
	</xsl:template>
	
	<func:function name="local:get-valid-eids">
		<xsl:param name="eids"/>
		<xsl:param name="is-hns"/>
		
		<xsl:variable name="valid-envs-rtf">
			<xsl:choose>
				<xsl:when test="$is-hns">
					<xsl:copy-of select="cred:filter-valid-hw('vzcp.template', $eids, false())"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="cred:filter-valid-env('vzcp.template', $eids, false())"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<func:result select="exsl:node-set($valid-envs-rtf)/eid"/>
	</func:function>
	
	<xsl:template name="local:redirect">
		<xsl:param name="action"/>
		<xsl:choose>
			<xsl:when test="$action/no-redirect"/>
			<xsl:when test="$action/redirect">
				<xsl:copy-of select="$action/redirect"/>
			</xsl:when>
			<xsl:when test="$action/screen">
				<redirect-prev/>
			</xsl:when>
			<xsl:otherwise>
				<redirect-last/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<!-- Screen part -->
	<xsl:template match="action[screen and @id='cache']" mode="templates:screen">
		<xsl:variable name="action-ref" select="."/>
		<ui:screen id="{screen/@id}" icon="app_tmpl">
			<ui:properties>
				<ui:refresh-type>none</ui:refresh-type>
				<ui:form-get/>
				<ui:description mandatory="yes" width="full">
					<xsl:apply-templates select="screen/description" mode="local:screen" />
				</ui:description>
			</ui:properties>

			<ui:content>
				<ui:block width="full" mode="edit">
					<ui:rows title="{screen/apps}">
						<ui:row>
							<ui:cell>
								<xsl:for-each select="/packet/info/app">
									<xsl:if test="position() &gt; 1">
										<xsl:text>, </xsl:text>
									</xsl:if>
									<xsl:call-template name="templates:show-app-name-link">
										<xsl:with-param name="app-id" select="id"/>
										<xsl:with-param name="hn-eid" select="hn-eid"/>
									</xsl:call-template>
								</xsl:for-each>
							</ui:cell>
						</ui:row>
					</ui:rows>
					
					<xsl:choose>
						<xsl:when test="count(/packet/info/app/id[vzapackagem:is-ez(.)]) &gt; 0">
							<ui:rows title="{sw:text('Select Cache Options')}">
								<ui:row>
									<ui:cell-check id="do_cache" checked="{not(/packet/submit) or /packet/submit/do_cache='true'}" close="false" colspan="2"/>
									<ui:cell open="false">
										<sw:text>Cache OS template for Container creation</sw:text>
									</ui:cell>
								</ui:row>
								<ui:row>
									<ui:cell-check id="do_fetch" checked="{/packet/submit/do_fetch='true'}" close="false" colspan="2"/>
									<ui:cell open="false">
										<sw:text>Cache application packages</sw:text>
									</ui:cell>
								</ui:row>
							</ui:rows>
						</xsl:when>
						<xsl:otherwise>
							<ui:hidden name="do_cache" value="1"/>							
						</xsl:otherwise>
					</xsl:choose>
					
					<ui:rows title="{envs}">
						<xsl:apply-templates select="envs" mode="local:screen">
							<xsl:with-param name="eids" 
								select="sw:if(single-mode, local:get-action-data($action-ref)/eid, /..)"/>
						</xsl:apply-templates>
					</ui:rows>

					<!-- Show submit buttons -->
					<ui:buttons>
						<ui:button id="ok" type="ok" tip="wizard_finish" name="ok" sandclock="false">
							<xsl:if test="count(/packet/info/app/id[vzapackagem:is-ez(.)]) &gt; 0">
								<xsl:attribute name="script">
									if (document.getElementById('do_cache').checked != true &amp;&amp; document.getElementById('do_fetch').checked != true) {
										alert('<sw:text>You should select at least one cache option.</sw:text>');
										return false;
									}
								</xsl:attribute>
							</xsl:if>
							<xsl:value-of select="screen/submit" />
						</ui:button>
						<ui:button type="cancel" sandclock="false"
							tip="wizard_cancel">
							<sw:text>Cancel</sw:text>
						</ui:button>
					</ui:buttons>
				</ui:block>
				
				<ui:hidden name="{@id}" value="1" />
			</ui:content>
		</ui:screen>
	</xsl:template>
	
	<xsl:template match="action[screen and @id!='cache']" mode="templates:screen">
		<ui:screen id="{screen/@id}" icon="app_tmpl">
			<ui:properties>
				<ui:refresh-type>none</ui:refresh-type>
				<ui:description mandatory="yes" width="full">
					<xsl:apply-templates select="screen/description" mode="local:screen" />
				</ui:description>
			</ui:properties>

			<ui:content>
				<ui:block width="full" mode="edit">
					<ui:rows title="{screen/apps}">
						<ui:row>
							<ui:cell>
								<xsl:for-each select="/packet/info/app">
									<xsl:if test="position() &gt; 1">
										<xsl:text>, </xsl:text>
									</xsl:if>
									<xsl:call-template name="templates:show-app-name-link">
										<xsl:with-param name="app-id" select="id"/>
										<xsl:with-param name="hn-eid" select="hn-eid"/>
									</xsl:call-template>
								</xsl:for-each>
							</ui:cell>
						</ui:row>
					</ui:rows>
					
					<ui:rows title="{envs}">
						<xsl:apply-templates select="envs" mode="local:screen" />
					</ui:rows>

					<!-- Show submit buttons -->
					<ui:buttons>
						<ui:button id="ok" type="ok" tip="wizard_finish" name="ok" sandclock="false">
							<xsl:value-of select="screen/submit" />
						</ui:button>
						<ui:button type="cancel" sandclock="false"
							tip="wizard_cancel">
							<sw:text>Cancel</sw:text>
						</ui:button>
					</ui:buttons>
				</ui:block>
				
				<ui:hidden name="{@id}" value="1" />
			</ui:content>
		</ui:screen>
	</xsl:template>
	
	<xsl:template match="envs[@type='hn']" mode="local:screen">
		<xsl:param name="eids" select="/.."/>
		<xsl:variable name="pkg" select="vzapackagem:vztemplate-packages(/packet/info/app/id)"/>
		<xsl:variable name="platform" select="local:correct-platforms(vz:get-templates-platform($pkg))"/>
		
		<xsl:call-template name="hn:multi-selector">
			<xsl:with-param name="eids" select="$eids"/>
			<xsl:with-param name="control-id" select="local:get-submit-id(..)" />
			<xsl:with-param name="parent-dn" select="units:current-dn()"/>
			<xsl:with-param name="state" select="$env-state/running"/>
			<xsl:with-param name="size" select="'10'" />
			<xsl:with-param name="platform" select="vt:platform2vza($platform)"/>
			<xsl:with-param name="architecture" 
				select="sw:if(vt:compare-platforms($platform, vt:platform-linux()),
								'', 
								vt:platform2vza-architecture($platform))"/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template match="envs[@type='ve']" mode="local:screen">
		<xsl:param name="eids" select="/.."/>
		<xsl:variable name="pkg" select="vzapackagem:vztemplate-packages(/packet/info/app/id)"/>
		<xsl:call-template name="env:multi-selector">
			<xsl:with-param name="eids" select="$eids"/>
			<xsl:with-param name="size" select="'10'" />
			<xsl:with-param name="control-id" select="local:get-submit-id(..)" />
			<xsl:with-param name="parent-dn" select="units:current-dn()"/>
			<xsl:with-param name="hn-eid" select="sw:if(@hn-eid, string(@hn-eid), '')"/>
			<xsl:with-param name="state" select="$env-state/running"/>
			<xsl:with-param name="os" select="$pkg/os/name[1]"/> 
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="description" mode="local:screen">
		<xsl:copy-of select="node()" />
	</xsl:template>
	
	<xsl:template match="node()|@*" mode="templates:screen" />


	<!-- Local functions and templates -->	
	
	<func:function name="local:is-submit">
		<xsl:param name="screen-def" />
		
		<func:result select="sw:param('ok')" />
	</func:function>
	
	<func:function name="local:get-apps">
		<xsl:param name="action-ref"/>
		
		<xsl:variable name="apps">
			<xsl:choose>
				<xsl:when test="$action-ref/single-mode='both'">
					<app>
						<id><xsl:value-of select="sw:sesget('app-id')" /></id>
						<hn-eid><xsl:value-of select="sw:if(string($action-ref/envs/@hn-eid)='', sw:hn-eid(), string($action-ref/envs/@hn-eid))" /></hn-eid>
					</app>
				</xsl:when>
				<xsl:when test="$action-ref/single-mode='template'">
					<app>
						<id><xsl:value-of select="sw:sesget('app-id')"/></id>
						<hn-eid><xsl:value-of select="string(sw:sesget('app-hn-eid'))"/></hn-eid>
					</app>
				</xsl:when>
				<xsl:when test="$action-ref/single-mode='env'">
					<xsl:for-each select="sw:param(local:app-get-id($action-ref))">
						<app>
							<id><xsl:value-of select="substring-before(., '|')"/></id>
							<hn-eid><xsl:value-of select="sw:if(string($action-ref/envs/@hn-eid)='', sw:hn-eid(), string($action-ref/envs/@hn-eid))" /></hn-eid>
						</app>
					</xsl:for-each>
				</xsl:when>
				<xsl:otherwise>
					<xsl:for-each select="sw:param(local:app-get-id($action-ref))">
						<app>
							<id><xsl:value-of select="substring-before(., '|')"/></id>
							<hn-eid><xsl:value-of select="substring-after(., '|')"/></hn-eid>
						</app>
					</xsl:for-each>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<func:result select="exsl:node-set($apps)/app" />
	</func:function>
	
	<func:function name="local:get-action-data">
		<xsl:param name="action-def" />
		
		<xsl:variable name="data">
			<data>
				<xsl:copy-of select="local:get-apps($action-def)" />
				<xsl:choose>
					<xsl:when test="$action-def/single-mode='both' or $action-def/single-mode='env'">
						<eid><xsl:value-of select="sw:if($action-def/envs[@type='hn'], sw:hn-eid(), sw:ve-eid())"/></eid>
					</xsl:when>
					<xsl:otherwise>
						<xsl:variable name="submit" select="sw:param(local:get-submit-id($action-def))"/>
						<xsl:for-each select="set:distinct($submit)">
							<eid><xsl:value-of select="sw:if($action-def/single-mode='template', string(.), substring-after(., '|'))"/></eid>
						</xsl:for-each>
					</xsl:otherwise>
				</xsl:choose>
			</data>
		</xsl:variable>
		<func:result select="exsl:node-set($data)/data"/>
	</func:function>
	
	<func:function name="local:get-submit-data">
		<xsl:param name="action-def" />
		
		<xsl:variable name="data" select="sw:sesget(local:get-data-id($action-def))" />
		<xsl:variable name="submit" select="sw:param(local:get-submit-id($action-def))" />
		
		<xsl:variable name="res">
			<data>
				<xsl:copy-of select="$data/info/app" />
				<xsl:for-each select="set:distinct($submit)">
					<eid><xsl:value-of select="." /></eid>
				</xsl:for-each>
				<xsl:if test="$action-def/@id='cache'">
					<do_cache>
						<xsl:value-of select="not($action-def/screen) or sw:param('do_cache')='1'"/>
					</do_cache>
					<do_fetch>
						<xsl:value-of select="sw:param('do_fetch')='1'"/>
					</do_fetch>
				</xsl:if>
			</data>
		</xsl:variable>
		<func:result select="exsl:node-set($res)/data"/>
	</func:function>
	
	<func:function name="local:get-action-file">
		<xsl:param name="action-def" />
		
		<func:result select="sw:if($action-def/@file, string($action-def/@file), concat($action-def/@id, '.xsl'))" />
	</func:function>
	
	<func:function name="local:get-data-id">
		<xsl:param name="action-def" />
		
		<func:result select="concat('templates-', envs/@type)" />
	</func:function>
	
	<func:function name="local:get-submit-id">
		<xsl:param name="action-def" />
		
		<func:result select="'eid'" />
	</func:function>
	
	<func:function name="local:app-get-id">
		<xsl:param name="action-def" />
		
		<func:result select="sw:if($action-def/single-mode and not($action-def/single-mode='env'), 
									'id', 
									'app-id')" />
	</func:function>
	
	<!-- Process errors -->
	<xsl:template match="packet[self::packet//error]" mode="results">
		<xsl:param name="op-code" select="''"/> 
		<xsl:variable name="errors" select="current()//error"/>
		<xsl:copy-of select="$errors"/>
		<xsl:if test="action:log-error($errors, $op-code)"/>
	</xsl:template>
	
	<func:function name="templates:run-child">
		<xsl:param name="action" />
		<xsl:param name="name" />
		<xsl:param name="id" />
		<xsl:param name="eid" select="/.."/>

		<xsl:variable name="res" select="action:run-child($action, $name, $id, $eid)"/>
		<func:result select="sw:if($res, $res, /..)" />
	</func:function>
</xsl:stylesheet>