<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred check local"
	xmlns:xsl					="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl				="http://exslt.org/common"
	xmlns:sw					="http://www.swsoft.com/xsl/cp"
	xmlns:error				="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz					="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local				="http://www.swsoft.com/xsl/cp/local"	
  xmlns:func				="http://exslt.org/functions"	
	xmlns:cred				="http://www.swsoft.com/xsl/cp/cred"
	xmlns:check				="http://www.swsoft.com/xsl/cp/check"
	xmlns:backups			="http://www.swsoft.com/xsl/cp/backups"	
	xmlns:vzat				="http://www.swsoft.com/webservices/vzl/4.0.0/types"
>

	<!-- Functionality  modules -->
	<sw:include href="/lib/vt/backups-core.xsl"/>
	<sw:include href="/lib/vt/backups-forms.xsl"/>
	

	<xsl:output method="xml"/>
	
	<xsl:param name="wiz_code" select="'backups-setup-global'"/>	
	<xsl:variable name="step" select="wiz:processing-step-id()"/>	
  <xsl:variable name="form" select="local:init-form()"/>

	<xsl:template match="node()|@*">
		<xsl:choose>
			<!-- Step "General Settings" -->
			<xsl:when test="$step='gen'">
			
				<xsl:variable name="new-form-rtf">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="name()='core-options'"></xsl:when>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<core-options>
						<xsl:call-template name="backups:restore-core-options">
							<xsl:with-param name="old-options" select="$form/core-options"/>
						</xsl:call-template>
					</core-options>
				</xsl:variable>
				<xsl:variable name="new-form" select="exsl:node-set($new-form-rtf)"/>
				
				<xsl:if test="sw:param('next')">
					<!-- check data -->		
					<xsl:if test="backups:check-core-options($new-form/core-options)"/>
				</xsl:if>
				
				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new-form"/>
				</xsl:call-template>
					
			</xsl:when>
				
		</xsl:choose>
		
		<xsl:copy/>
	</xsl:template>
	
	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->		
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
    				<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:if test="cred:detail-check('vzcp.hn.backups.configure')"/>
					    	<xsl:choose>
		    					<xsl:when test="error:is-empty()">
										<xsl:copy-of select="local:getFinalPacket($data)"/>
										<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>	
					      	</xsl:when>
									<xsl:otherwise>
										<packet/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
		          <xsl:otherwise>
              	<packet/>
            	</xsl:otherwise>
          	</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>
					
	</xsl:template>
	
	<func:function name="local:init-form">
		<sw:noauth-redirect select="not(cred:check('vzcp.hn.backups.configure'))"/>
		<xsl:if test="$step = ''">		
			<!-- Get data. We know that options can be <error> node itself. -->
			<xsl:variable name="core-options" select="backups:get-core-options(sw:master-eid())"/>
			<!-- Init form data -->
			<xsl:variable name="new_form">
				<core-options>			
					<xsl:copy-of select="$core-options"/>
				</core-options>
			</xsl:variable>
			<!-- Init steps -->
			<xsl:variable name="new_steps_">
				<step id="gen" screen-id="50.00.00.00.00"/>
			</xsl:variable>
			<!-- Save wizard initial settings -->
			<xsl:if test="error:is-empty()">
				<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
				<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
				<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
				<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
				<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
			</xsl:if>
		</xsl:if>
		<func:result select="wiz:init-data()"/>		
	</func:function>
	
	<!-- *********************************************************** -->
	<func:function name="local:getFinalPacket">
		<xsl:param name="data"/>
		<!-- Save new data -->
		<xsl:variable name="error" select="backups:set-core-options(sw:master-eid(),$data/core-options)"/>
		<xsl:choose>
			<!-- Saved -->
			<xsl:when	test="$error=''">
				<!-- Return back -->
				<func:result>
		 			<packet>
		        <cookie>
		          <msg>
		            <set-ok><sw:text>The settings have been changed.</sw:text></set-ok>
		          </msg>		          
		        </cookie>						
					</packet>
				</func:result>
			</xsl:when>
			<!-- /Saved -->
			<xsl:otherwise>
				<!-- Error occure  -->
				<func:result>
		 			<packet>
		        <cookie>
		          <msg>
		            <set-error>
		            	<short-desc>
		            		<sw:text>Error saving the backups configuration.</sw:text>
		            	</short-desc>
		            	<detail>
		            		<xsl:value-of select="$error"/>
		            	</detail>
		            </set-error>
		          </msg>
		        </cookie>						
					</packet>		
				</func:result>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

  <!-- credentials -->	
	<sw:include href="/lib/cred.xsl"/>  
	
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>

	<sw:include href="/lib/vocabulary.xsl"/>					
	
</xsl:stylesheet>
