<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred check local"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:check="http://www.swsoft.com/xsl/cp/check" 
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:res-log="http://www.swsoft.com/xsl/cp/res-log" 		
>

	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/core/check-funcs.xsl"/>
	<sw:include href="/lib/swa/res-log.xsl"/>

	<xsl:output method="xml"/>

	<xsl:variable name="curr-hwid" select="sw:hn-eid()"/>

	<xsl:variable name="step" select="wiz:processing-step-id()"/>
	<xsl:param name="wiz_code" select="'hw-config-logging'"/>
	<xsl:variable name="form" select="local:init-form()"/>

	<xsl:template match="node()|@*">

		<xsl:choose>
			<!-- Step "General Settings" -->
			<xsl:when test="$step='gen'">

				<xsl:variable name="new-form-rtf">
					<xsl:copy-of select="$form/*[not(self::periods)]"/>
					<periods>
						<xsl:for-each select="$form/periods/period">					
							<period>
								<xsl:copy-of select="id"/>
								<value><xsl:value-of select="sw:param(concat('value_',position()))"/></value>
								<factor><xsl:value-of select="sw:param(concat('factor_',position()))"/></factor>
							</period>
						</xsl:for-each>
					</periods>
				</xsl:variable>
				<xsl:variable name="new-form" select="exsl:node-set($new-form-rtf)"/>

				<xsl:if test="sw:param('next')">
					<!-- check periods -->
					<xsl:for-each select="$new-form/periods/period">
						<xsl:choose>
							<!-- check period for specified value -->
							<xsl:when test="value=''">
								<xsl:variable name="error">
									Period should be specified.
								</xsl:variable>
								<xsl:value-of
									select="error:put($error,'',concat('value_',position()))"
								/>
							</xsl:when>						
							<!-- check period for valid chars -->
							<xsl:when test="not( check:num(value))">
								<xsl:variable name="error">
									Period contains invalid characters.
								</xsl:variable>
								<xsl:value-of
									select="error:put($error,'',concat('value_',position()))"
								/>
							</xsl:when>
						</xsl:choose>
					</xsl:for-each>
				</xsl:if>

				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new-form"/>
				</xsl:call-template>

			</xsl:when>

		</xsl:choose>

		<xsl:copy/>
	</xsl:template>

	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
						<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:if
									test="cred:detail-check-hw('vzcp.hn.manage.config.network',sw:hn-eid())"/>
								<xsl:choose>
									<xsl:when test="error:is-empty()">
										<xsl:copy-of select="local:getFinalPacket($data)"/>
										<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
									</xsl:when>
									<xsl:otherwise>
										<packet/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
							<xsl:otherwise>
								<packet/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

	<func:function name="local:init-form">
		<sw:noauth-redirect select="not(cred:check-hw('vzcp.hn.manage.config.network',$curr-hwid))"/>
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:init-new"/>
		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>

	<xsl:template name="local:init-new">
		<xsl:variable name="hn-eid" select="sw:hn-eid()"/>
			<!-- Get VZA data -->
			<xsl:variable name="log-settings" select="res-log:get-settings($hn-eid)"/>
			<!-- Init form data -->
			<xsl:variable name="new_form">
				<def>
					<hn-eid><xsl:value-of select="$hn-eid"/></hn-eid>
				</def>
				<periods>
					<xsl:for-each select="$log-settings">
						<xsl:sort select="class"/>
						<xsl:variable name="factor" select="local:find-factor(period)"/>
						<period>
							<id><xsl:value-of select="class"/></id>
							<value><xsl:value-of select="format-number(period div $factor,'#')"/></value>
							<factor><xsl:value-of select="$factor"/></factor>
						</period>
					</xsl:for-each>
				</periods>
			</xsl:variable>
			<!-- Init steps -->
			<xsl:variable name="new_steps_">
				<step id="gen" screen-id="01.01.00.00.00"/>
			</xsl:variable>
			<!-- Save wizard initial settings -->
			<xsl:if test="error:is-empty()">
				<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
				<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
				<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
				<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
				<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
			</xsl:if>
	</xsl:template>

	<func:function name="local:find-factor">
		<xsl:param name="value"/>	
		<func:result>
			<xsl:choose>
				<xsl:when test="check:nan($value)">
					<xsl:value-of select="1"/>
				</xsl:when>
				<xsl:when test="
					not($value mod 3600)
				">
					<xsl:value-of select="3600"/>
				</xsl:when>
				<xsl:when test="
					not($value mod 60)
				">
					<xsl:value-of select="60"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="1"/>
				</xsl:otherwise>
			</xsl:choose>
		</func:result>
	</func:function>
	
	<!-- *********************************************************** -->
	<func:function name="local:getFinalPacket">
		<xsl:param name="data"/>
		<!--|-->
		<func:result>
			<packet log="on">
				<target>res_log</target>
				<xsl:copy-of select="sw:hn-dst($data/def/hn-eid)"/>
				<cookie>
					<msg>
						<ok>
							<sw:text>The logging settings have been successfully updated.</sw:text>
						</ok>
						<error>
							<sw:text>Failed to update the logging settings.</sw:text>
						</error>
					</msg>
					<operation>hn_configure_logging</operation>
					<redirect-prev/>
				</cookie>
				<data>
					<xsl:for-each select="$data/periods/period">				
						<res_log>
							<set_log>
								<class><name><xsl:value-of select="id"/></name></class>
								<period><xsl:value-of select="factor * value"/></period>
							</set_log>
						</res_log>
					</xsl:for-each>
				</data>
				<vzcpauth/>
			</packet>
		</func:result>
	</func:function>
</xsl:stylesheet>
