<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl sw func vzenv cred local file"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:error="http://www.swsoft.com/xsl/cp/error"
  xmlns:hwm="http://www.swsoft.com/xsl/cp/hwm"
  xmlns:vzenv="http://www.swsoft.com/xsl/cp/vzenv"
  xmlns:func="http://exslt.org/functions"
	xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
  xmlns:local	="http://www.swsoft.com/xsl/cp/local"
  xmlns:backups		="http://www.swsoft.com/xsl/cp/backups"
  xmlns:file="http://www.swsoft.com/xsl/cp/file"
>
  <xsl:output method="xml"/>
  
  <sw:include href="/lib/vt/backups-core.xsl"/>
	<sw:include href="/lib/utils/file.xsl"/>

	<xsl:variable name="selected-files"	 	select="sw:param('file-name')"/>
	<xsl:variable name="fm-path" 					select="sw:sesget('browse-backup-path')"/>
	
	<xsl:variable name="backup-id" 				select="sw:sesgetstr('vz-backup-id')"/>		
	<xsl:variable name="backup" 					select="backups:find-backup($backup-id)"/>		

	<!-- check permissions to this page -->
	<xsl:param name="access-denied" select="not(cred:check-env('vzcp.env.backups.restore',$backup/eid))"/>
	
	<xsl:template match="/">
		<xsl:choose>
			<!-- no restore cred -->
			<xsl:when test="sw:param('restore') and $access-denied">	
				<packet/>
			</xsl:when>
      <!-- there is no post -->
      <xsl:when test="not(/http_request/*[self::post or self::get]/parameter)">
        <packet/>
      </xsl:when>
      <!-- there is no current PATH -->
      <xsl:when test="not($fm-path and $fm-path!='')">
        <packet/>
      </xsl:when>

      <!-- Check selected files -->
      <xsl:when test="not($selected-files)">
        <xsl:if test="error:put(sw:text('Please select at least one file.'),'')"/>
        <packet/>
      </xsl:when>

      <!-- Restore Files-->
      <xsl:when test="sw:param('restore')">
       	<xsl:copy-of select="local:restore($selected-files)"/>
		    <xsl:if test="sw:response('lib/opredirect.xsl')"/>	
      </xsl:when>

      <!-- Unknown post -->
      <xsl:otherwise>
        <packet/>
      </xsl:otherwise>

    </xsl:choose>
	</xsl:template>
  
  <func:function name="local:restore">
  	<xsl:param name="files"/>
  	<func:result>
 			<packet log="on" progress="on">
				<target>backupm</target>
        <cookie>
          <msg>
            <ok><sw:text>The file(s) has/have been restored.</sw:text></ok>
            <error><sw:text>Failed to restore the file(s).</sw:text></error>
          </msg>
          <operation>restore_files</operation>
          <redirect-last/>
        </cookie>			
				<data>
					<backupm>
						<selective_restore_env>
							<eid><xsl:value-of select="$backup/eid"/></eid>
							<backup_id><xsl:value-of select="$backup-id"/></backup_id>
							<xsl:for-each select="$files">
								<path>
		            	<xsl:value-of select="sw:base64-encode(concat(file:path4vza($fm-path),.))"/>
								</path>
							</xsl:for-each>
						</selective_restore_env>
					</backupm>
				</data>
			</packet>
 		</func:result>
  </func:function>
 
  <sw:include href="/lib/cred.xsl"/>
  <sw:include href="/lib/common.xsl"/>
 
</xsl:stylesheet>
