<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz env vzenv voc cred local action envm vzaconfig ips system"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:error		="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz		="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:env		="http://www.swsoft.com/xsl/cp/env"	
	xmlns:vzenv		="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"
	xmlns:func		="http://exslt.org/functions"	
	xmlns:cred		="http://www.swsoft.com/xsl/cp/cred"
	xmlns:envm		="http://www.swsoft.com/xsl/cp/envm"
	xmlns:voc		="http://www.swsoft.com/xsl/cp/voc"
	xmlns:action	="http://www.swsoft.com/xsl/cp/action"
	xmlns:vzaconfig	="http://www.swsoft.com/xsl/cp/vzaconfig"
	xmlns:ips		="http://www.swsoft.com/xsl/cp/ips"
	xmlns:system	="http://www.swsoft.com/xsl/cp/system"
	xmlns:check		="http://www.swsoft.com/xsl/cp/check"	
	xmlns:redirect="http://www.swsoft.com/xsl/cp/redirect"
>
	<!-- Import required modules -->
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/core/check-funcs.xsl"/>	
	<sw:include href="/lib/swa/envm.xsl"/>
	<sw:include href="/lib/swa/system.xsl"/>
	<sw:include href="/lib/utils/action.xsl"/>
	<sw:include href="/lib/vz/ips.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>	
	<sw:include href="/lib/vz/vzenv-core.xsl"/>
	<sw:include href="/lib/vz/vzenv-net.xsl"/>
	<sw:include href="/lib/vz/vzenv-net-core.xsl"/>
	<sw:include href="/lib/vz/vzenv-net-ui.xsl"/>	
	<sw:include href="/lib/vz/vzenv-clone.xsl"/>	
	<sw:include href="/lib/vz/vzhn-redirects.xsl"/>
	<sw:include href="/lib/vz/vzenv-offline.xsl"/>
	
	<!-- Import required modules -->

	<xsl:output method="xml"/>

	<xsl:variable name="step" select="wiz:processing-step-id()"/>
	<xsl:param name="wiz_code" select="'cloneve'"/>
	<xsl:variable name="old-form" select="local:init-form()"/>

	<xsl:template match="node()|@*">

		<!-- /Init Form Data -->
	
		<xsl:choose>
			<!-- Step "General Settings" -->
			<xsl:when test="$step='gen'">
			
				<xsl:variable name="ask-veid" select="sw:param('ask_veid')"/>	
					
				<xsl:variable name="new-form-rtf">
					<xsl:for-each select="$old-form/*">
						<xsl:choose>
							<xsl:when test="name()=$step "></xsl:when>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<gen>
						<root_pwd><xsl:value-of select="sw:param('root_pwd')"/></root_pwd>
						<root_pwd_re><xsl:value-of select="sw:param('root_pwd_re')"/></root_pwd_re>
						<name><xsl:value-of select="normalize-space(sw:param('name'))"/></name>
						<hostname><xsl:value-of select="normalize-space(sw:param('hostname'))"/></hostname>
						<offline_type><xsl:value-of select="sw:param('offline_type')"/></offline_type>
						<xsl:variable name="selected-services" select="sw:param('selected_offline_service')"/>
						<selected_offline_service>
							<xsl:for-each select="$selected-services">
								<value>
									<xsl:value-of select="."/>
								</value>
							</xsl:for-each>
						</selected_offline_service>						
						<ask_veid><xsl:value-of select="$ask-veid"/></ask_veid>	
						<xsl:if test="$ask-veid='1'">
							<ve_id><xsl:value-of select="normalize-space(sw:param('ve_id'))"/></ve_id>	
						</xsl:if>
						<start_after_create><xsl:value-of select="sw:param('start_after_create')"/></start_after_create>
						<show_adv><xsl:value-of select="sw:param('show_adv')"/></show_adv>
						<show_offline><xsl:value-of select="sw:param('show_offline')"/></show_offline>
					</gen>
				</xsl:variable>
			
				<xsl:variable name="new-form" select="exsl:node-set($new-form-rtf)"/>
			
				<!-- Complete or go next -->
				<xsl:if test="sw:param('next') or sw:param('ok')">
				
					<!-- Check data -->
					<!-- check name presence -->
					<xsl:if test="vzenv:check-ve-name($new-form/gen/name,$new-form/src-env/hn-eid)"/>
					<!-- validate hostname -->
					<xsl:if test="vzenv:check-ve-hostname(
						$new-form/gen/hostname,$new-form/src-env/hn-eid
					)"/>
					<!-- Check password -->
					<xsl:choose>
						<xsl:when test="not(string($new-form/gen/root_pwd)) and not(string($new-form/gen/root_pwd_re))">
							<!-- password can be empty -->
						</xsl:when>
						<xsl:when test="string($new-form/gen/root_pwd) != string($new-form/gen/root_pwd_re)">
							<!-- check password presence -->
							<xsl:value-of select="error:put(sw:text('The passwords do not match.'),'','root_pwd')"/>
							<xsl:value-of select="error:add-control('root_pwd_re')"/>
						</xsl:when>
					</xsl:choose>
					<!-- check VE ID-->
					<xsl:if test="string($new-form/gen/ask_veid)!=''">
						<xsl:if test="vzenv:check-ve-id( $new-form/gen/ve_id,sw:hn-eid(),$new-form/def/end_veid  )"/>
					</xsl:if>
					<!-- Check offline management -->
					<xsl:choose>
						<xsl:when test="$new-form/gen/offline_type = 'custom' and count($new-form/gen/selected_offline_service/value) = 0">
							<xsl:if test="error:put(sw:text('Select at least one service for custom offline management.'),'','selected_offline_service')"/>
						</xsl:when>
						<xsl:when test="sw:param('ok') and not(local:check-offline-allowed($new-form))">
							<xsl:variable name="error">	
								<sw:text>
									The Container cannot be cloned as its offline management is enabled and at least one IP address of the new Container is identical to that of the source Container.
									<br/>To be able to clone the Container, either disable its offline management or click Customize and change the IP addresses on the next step.
								</sw:text>
							</xsl:variable>
							<xsl:if test="error:put($error)"/>
						</xsl:when>
					</xsl:choose>
					
					<!-- /Check data -->
										
				</xsl:if>
				<!-- /Complete or go next -->					
				
				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new-form"/>
				</xsl:call-template>
					
			</xsl:when>
			<!-- /Step "General Settings" -->
			
			<!-- Step "Network Interfaes" -->
			<xsl:when test="$step='net'">
			
				<!-- Restore form's data  -->
				<xsl:variable name="new-form-rtf">
					<xsl:copy-of select="$old-form/*[not(self::net)]"/>
					<net>
						<xsl:call-template name="vzenv:restore-net-ifaces">
							<xsl:with-param name="env-form" select="$old-form"/>
							<xsl:with-param name="options-rtf">
								<exclude-hostname/>
							</xsl:with-param>							
						</xsl:call-template>
					</net>
				</xsl:variable>
				<!-- /Restore form's data  -->					
				
				<xsl:variable name="new-form" select="exsl:node-set($new-form-rtf)"/>
								
				<!-- Check data -->
				<xsl:choose>					
					<xsl:when test="sw:param('next') or sw:param('ok')">
						<xsl:call-template name="vzenv:check-net-ifaces">
							<xsl:with-param name="env-form" select="$new-form"/>
						</xsl:call-template>
						<xsl:if test="not(local:check-offline-allowed($new-form))">
							<xsl:variable name="error">	
								<sw:text>
									The Container cannot be cloned as its offline management is enabled and at least one IP address of the new Container is identical to that of the source Container.
									<br/>To be able to clone the Container, either change the IP addresses of the new Container or return to the previous step and disable offline management.
								</sw:text>
							</xsl:variable>
							<xsl:if test="error:put($error)"/>
						</xsl:if>
					</xsl:when>
				</xsl:choose>
					
				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new-form"/>
				</xsl:call-template>
					
			</xsl:when>
			<!-- /Step "Network Interfaes" -->
				
		</xsl:choose>
		<packet/>
		
	</xsl:template>
	
	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>		
		<!--|-->				
		<xsl:choose>
			<xsl:when test="(sw:param('next') or sw:param('ok')) and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep() or sw:param('ok')">
    				<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
								<xsl:copy-of select="local:do-clone($data)"/>
								<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>	
							</xsl:when>
		          <xsl:otherwise>
              	<packet/>
            	</xsl:otherwise>
          	</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<func:function name="local:init-form">
		<sw:noauth-redirect select="not(cred:check-context('vzcp.env.clone','ve.vz.vt'))"/>
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:init-new"/>				
 		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>
 	
	<xsl:template name="local:init-new">
			<!-- Init default data -->
			<xsl:variable name="env" select="env:get-env(sw:ve-eid())/env"/>						
			<xsl:variable name="env-info" select="env:env2info($env)"/>			
			<xsl:variable name="hn-info" select="env:eid2info($env-info/hn-eid)"/>
			<xsl:variable name="vzaconfig" select="system:get-configuration($env-info/hn-eid)"/>			
			<xsl:variable name="vzconfig" select="envm:get-vt-settings($env-info/hn-eid)"/>
			<xsl:variable name="ve-offline-service" select="$env/virtual_config/offline_service"/>
			<xsl:variable name="all-offline-service" select="redirect:load($env-info/hn-eid)"/>
			<xsl:variable name="offline-type" select="vzenv:get-offline-type($env/virtual_config/offline_management,$ve-offline-service)"/>
			<!-- /Init default data -->
			<xsl:variable name="new-form-rtf">
				<src-env>
					<xsl:copy-of select="$env-info"/>
				</src-env>
				<hn>
					<xsl:copy-of select="$hn-info"/>
				</hn>
				<gen>
					<hostname>
						<xsl:if test="$env/virtual_config/hostname!=''">
							<xsl:value-of select="concat('cloned-',$env/virtual_config/hostname)"/>
						</xsl:if>
					</hostname>
					<name>
						<xsl:if test="$env/virtual_config/name!=''">
							<xsl:value-of select="concat('cloned ',$env/virtual_config/name)"/>
						</xsl:if>
					</name>
					<selected_offline_service>
						<xsl:for-each select="$ve-offline-service">
							<value>
								<xsl:value-of select="."/>
							</value>
						</xsl:for-each>
					</selected_offline_service>
					<offline_type>
						<xsl:value-of select="$offline-type"/>
					</offline_type>
				</gen>
				<xsl:variable name="ve-net">
					<xsl:call-template name="vzenv:env2net">
						<xsl:with-param name="env" select="$env"/>
						<xsl:with-param name="hn-platform" select="$env-info/platform"/>
						<xsl:with-param name="reset-mac-addresses" select="true()"/>
					</xsl:call-template>
				</xsl:variable>
				<net>
					<xsl:copy-of select="$ve-net"/>
				</net>
				<data>
				</data>
				<def>
					<xsl:if test="ips:pool-enabled()">
						<ips-pool-enabled/>
					</xsl:if>
					<xsl:variable name="first_ve_id" select="$vzconfig/parameter[id='vzprivrange']/value"/>
					<ve_id>
						<xsl:choose>
							<xsl:when test="$first_ve_id!=''">
								<xsl:value-of select="number(substring-after($first_ve_id,' ')+1)"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="''"/>
							</xsl:otherwise>
						</xsl:choose>
					</ve_id>
					<end_veid><xsl:value-of select="$vzaconfig/packet/data/global/configuration/pool/user_veid_range/end_veid"/></end_veid>
					<all_offline_service><xsl:copy-of select="$all-offline-service/service"/></all_offline_service>					
					<src-ve-net>
						<xsl:copy-of select="$ve-net"/>
					</src-ve-net>	
				</def>
			</xsl:variable>
			<!-- Init steps -->
			<xsl:variable name="new_steps_">
					<step id="gen" screen-id="03.02.01.05.01"/>
					<step id="net" screen-id="03.02.01.05.03"/>
			</xsl:variable>
			<!-- Save wizard initial settings -->
			<xsl:if test="error:is-empty()">
				<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
				<xsl:variable name="new_step"		select="string($new_steps/step[1]/@id)"/>
				<xsl:if test="sw:sesput($wiz_data,$new-form-rtf)"/>
				<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
				<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
			</xsl:if>
	</xsl:template>
	
	<!-- *********************************************************** -->
	<func:function name="local:do-clone">
		<xsl:param name="data"/>
		<!--|-->
		<func:result>
			<xsl:call-template name="action:make-packet">
				<xsl:with-param name="path" select="'actions/vzdir/infrman/envs/clone.xsl'"/>
				<xsl:with-param name="cookie">
					<msg>
						<sched>
							<sw:text>The Container has been scheduled for cloning.</sw:text>
						</sched>
						<error>Failed to clone the VE.</error>
					</msg>
					<operation>clone_ve</operation>
					<redirect-prev/>
				</xsl:with-param>
				<xsl:with-param name="input">
					<data>
						<xsl:copy-of select="$data/src-env"/>
						<new-ve>
							<xsl:if test="$data/gen/ask_veid='1'">
								<ve-id><xsl:value-of select="$data/gen/ve_id"/></ve-id>
							</xsl:if>
							<hn-eid><xsl:value-of select="$data/src-env/hn-eid"/></hn-eid>
							<xsl:copy-of select="$data/gen/hostname"/>
							<xsl:copy-of select="$data/gen/name"/>
							<user>
								<password><xsl:value-of select="$data/gen/root_pwd"/></password>
							</user>
							<xsl:copy-of select="$data/net"/>							
							<xsl:copy-of select="$data/gen/offline_type"/>
							<xsl:copy-of select="$data/gen/selected_offline_service"/>
						</new-ve>
						<xsl:if test="$data/gen/start_after_create=1">
							<start/>
						</xsl:if>
					</data>
				</xsl:with-param>
			</xsl:call-template>
					
			<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
		</func:result>
	</func:function>
	
	<func:function name="local:check-offline-allowed">
		<xsl:param name="new-form"/>
		
		<xsl:variable name="result" select="vzenv:are-offline-services-allowed(
			$new-form/net,$new-form/def/src-ve-net,
			$new-form/gen/offline_type,$new-form/gen/selected_offline_service,
			$new-form/def/all_offline_service
		)"/>
		
		<func:result select="$result"/>
			
	</func:function>
	
  <!-- credentials -->
  <sw:include href="/lib/cred.xsl"/>
	
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>

	<sw:include href="/lib/vzaconfig.xsl"/>	
	
	<sw:include href="/lib/vocabulary.xsl"/>		
	<sw:include href="/lib/globals.xsl"/>
	
</xsl:stylesheet>
