<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl sw func env vzenv units hn error"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:hwm="http://www.swsoft.com/xsl/cp/hwm"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:vzenv="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:units		="http://www.swsoft.com/xsl/cp/units"
	xmlns:hn="http://www.swsoft.com/xsl/cp/hn"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:ve		="http://www.swsoft.com/xsl/cp/ve"
>

	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/> 
	<sw:include href="/lib/vt/ve-core.xsl"/>
	<sw:include href="/lib/vz/vzenv-core.xsl"/> 
	<sw:include href="/lib/vt/hn-core.xsl"/>	
	<sw:include href="/lib/core/units-core.xsl"/>

  
	<xsl:output method="xml"/>
	
	<xsl:template match="/">
		<!-- Handle current VE changing -->
		<xsl:variable name="get-eid" select="sw:base64-decode(string(sw:param('id')))"/>
		<xsl:variable name="special-mode" select="sw:param('mode')"/>
		<xsl:variable name="current-eid">
			<xsl:choose>
				<!-- Handle special mode manage_sve -->
				<xsl:when test="$special-mode = 'manage_sve'">
					<xsl:variable name="service-eid" select="string(vzenv:veid-to-eid(1,sw:hn-eid()))"/>
					<sw:noauth-redirect select="not(cred:check-env('vzcp.env.view',$service-eid))"/>
					<xsl:variable name="current-ve" select="vzenv:set-current($service-eid,true())"/>					
					<xsl:value-of select="$service-eid"/>					
				</xsl:when>
				<!-- Change current VE -->				
				<xsl:when test="$get-eid!=''">
					<sw:noauth-redirect select="not(cred:check-env('vzcp.env.view',$get-eid))"/>
					<xsl:variable name="current-ve" select="vzenv:set-current($get-eid,true())"/>
					<xsl:value-of select="$current-ve/eid"/>					
				</xsl:when>
				<!-- Leave old current VE -->
				<xsl:otherwise>
					<sw:noauth-redirect select="not(cred:check-env('vzcp.env.view',sw:ve-eid()))"/>
					<xsl:value-of select="sw:ve-eid()"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<!-- /Handle current VE changing -->
		<xsl:variable name="env"						select="env:get-env($current-eid)/env"/>
		<xsl:variable name="ve-state"				select="$env/status/state"/>
		<xsl:variable name="ve-transition"	select="$env/status/transition"/>
		<xsl:choose>
			<xsl:when test="($ve-state = $env-state/unknown) or ($ve-state = $env-state/unexist) or ($ve-state = $env-state/nolicense)">
				<xsl:variable name="ve-state-in-locale" select="ve:state2info($ve-state)/text"/>
				<packet>
        	<cookie> 
          	<msg>
              <set-error>
              	<short-desc>
              		<sw:text>
										<xsl:with-param name="ve-state-title" select="$ve-state-in-locale"/>
										The Container has the "%{ve-state-title}" status and so cannot be managed at this moment.
									</sw:text>
              	</short-desc>
            	</set-error>
          	</msg>
						<redirect>
							<xsl:value-of select="concat($baseurl,'/vt/hns/index')"/>
						</redirect>
        	</cookie>
      	</packet>
				<xsl:if test="sw:response('lib/opredirect.xsl')"/>
			</xsl:when>
			<xsl:when test="$current-eid!=''">
			
				<!-- Reload VE name, workaround for #82461 -->
				<xsl:if test="sw:sesputstr('vzenv-title', env:env2title($env))"/>

				
				<!-- Check tabs autoredirect -->
				<xsl:variable name="redirect" select="units:tab-redirect('ve.vz.vt','summary')"/>
				
				<xsl:choose>
					<xsl:when test="$redirect=''">
						<packet />
					</xsl:when>			
					<xsl:otherwise>
						<xsl:copy-of select="$redirect"/>
						<xsl:if test="sw:response('lib/opredirect.xsl')" />
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="error:put(sw:text('The requested Container could not be found. It might have been deleted or moved.'))"/>
				<packet>
					<cookie>
						<redirect><xsl:value-of select="concat($baseurl,'/farmdir/unitman/units/index?tree-id=infrastructure&amp;tab-force=envs')"/></redirect>
					</cookie>
				</packet>
				<xsl:if test="sw:response('lib/opredirect.xsl')" />
			</xsl:otherwise>
		</xsl:choose>
		
	
	</xsl:template>

	<sw:include href="/lib/common.xsl"/> 
	<sw:include href="/lib/cred.xsl"/> 
	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
