<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func voc filem cred local check wiz file"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl	="http://exslt.org/common"
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:error	="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz		="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local	="http://www.swsoft.com/xsl/cp/local"
  xmlns:func	="http://exslt.org/functions"	
	xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
	xmlns:voc		="http://www.swsoft.com/xsl/cp/voc"
	xmlns:filem	="http://www.swsoft.com/xsl/cp/filem"
	xmlns:check	="http://www.swsoft.com/xsl/cp/check"
	xmlns:file="http://www.swsoft.com/xsl/cp/file"
>
	<xsl:output method="xml"/>
	<sw:include href="/lib/core/check-funcs.xsl"/>
	<sw:include href="/lib/utils/file.xsl"/>
	
	<xsl:param name="wiz_code" select="'ve-create-folder'"/>
  <xsl:variable name="step" select="wiz:processing-step-id()"/>	
  <xsl:variable name="form" select="local:init-form()"/>		

	<xsl:template match="node()|@*">
	
		<xsl:choose>
			<!-- Step "General Settings" -->
			<xsl:when test="$step='gen'">
			
					<xsl:variable name="new_form_">
						<xsl:for-each select="$form/*">
							<xsl:choose>
								<xsl:when test="name()=$step"></xsl:when>
								<xsl:otherwise>
									<xsl:copy-of select="."/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
						<gen>
							<folder><xsl:value-of select="sw:param('folder')"/></folder>
						</gen>
					</xsl:variable>
					<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
										
					<xsl:if test="wiz:clicked-back()">
						<xsl:if test="wiz:goBack()"/>
					</xsl:if>
					<xsl:if test="wiz:check-form-id($new_form) and wiz:clicked-next()">
						<!-- Check data -->
			      <!-- check folder -->
			      <xsl:choose>
			      	<!-- check folder name presence -->
				      <xsl:when test="string($new_form/gen/folder)=''">
				      	<xsl:if test="error:put(sw:text('You should specify a new folder name.'),'','folder')"/>
				      </xsl:when>
				      <!-- check folder name for valid chars -->
				      <xsl:when test="not(check:fileName($new_form/gen/folder))">
				      	<xsl:if test="error:put(sw:text('The folder name is invalid. Please correct it.'),'','folder')"/>
				      </xsl:when>
				      <!-- check folder name for existing -->
				      <xsl:when test="filem:stat(file:path4vza($new_form/fm-path),$new_form/gen/folder,$new_form/eid)">
				        <xsl:if test="error:put(sw:text('The folder with this name already exists. Please select another name.'),'','folder')"/>
				      </xsl:when>
						</xsl:choose>
			      <!-- Move to next step -->
			      <xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:copy-of select="local:final($new_form)"/>
								<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>		
							</xsl:when>
						</xsl:choose>
					</xsl:if>
					
					<!-- Store form values-->
					<xsl:variable name="res">
						<xsl:value-of select="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
					</xsl:variable>
					
			</xsl:when>
				
		</xsl:choose>
		
		<xsl:copy/>
		
	</xsl:template>
	
	<func:function name="local:init-form">
		<xsl:if test="$step = ''">
			<!-- Init default data -->
			<!-- /Init default data -->
			<xsl:variable name="new_form">
				<wizard-id><xsl:value-of select="sw:generate-id()"/></wizard-id>
				<gen/>
				<eid><xsl:value-of select="sw:ve-eid()"/></eid>
				<fm-path><xsl:value-of select="sw:sesget('ve-fm-path')"/></fm-path>
			</xsl:variable>
			<!-- Init steps -->
			<xsl:variable name="new_steps_">
				<step id="gen" screenid="03.02.01.12.02" cred="vzcp.env.manage.services_and_files" security-obj-type="ve.vz.vt"/>
			</xsl:variable>
			<!-- Save wizard initial settings -->
			<xsl:if test="error:is-empty()">
				<xsl:variable name="new_steps_filtered">
					<xsl:copy-of	select="exsl:node-set($new_steps_)/step[(not(@cred) or cred:check-context(@cred,@security-obj-type))]"/>
				</xsl:variable>
				<xsl:variable name="new_steps"	select="exsl:node-set($new_steps_filtered)"/>
				<xsl:variable name="new_step"		select="string($new_steps/step[1]/@id)"/>
				<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
				<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
				<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
			</xsl:if>
		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>
	
	<!-- *********************************************************** -->
	<func:function name="local:final">
		<xsl:param name="data"/>
		<!--|-->
		<func:result>
 			<packet log="on">
				<target>filer</target>
				<xsl:copy-of select="sw:env-dst($data/eid)"/>
        <cookie>
          <msg>
            <ok><sw:text>The folder has been created.</sw:text></ok>
            <error><sw:text>Failed to create the folder.</sw:text></error>
          </msg>
          <operation>create_folder</operation>
          <redirect-prev/>
        </cookie>			
				<data>
					<filer>
						<mkdir>
							<xsl:for-each select="$data/gen/folder">
								<path>
		            	<xsl:value-of select="sw:base64-encode(file:path4vza(concat($data/fm-path,'/',.)))"/>
								</path>
							</xsl:for-each>
						</mkdir>
					</filer>
				</data>
				<vzcpauth/>
			</packet>
 		</func:result>
	</func:function>
	
  <!-- credentials -->
  <sw:include href="/lib/cred.xsl"/>
	
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>

	<sw:include href="/lib/vza/filem.xsl"/>		

	<sw:include href="/lib/vocabulary.xsl"/>		
	<sw:include href="/lib/globals.xsl"/>
	
</xsl:stylesheet>
