<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl sw func cred local file"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:file="http://www.swsoft.com/xsl/cp/file"
>

	<xsl:output method="xml"/>

	<sw:include href="/lib/utils/file.xsl"/>

	<xsl:variable name="eid" select="sw:ve-eid()"/>

	<xsl:variable name="fm-name"
		select="sw:base64-decode(sw:param('fm-name'))"/>
	<xsl:variable name="fm-path" select="sw:sesget('ve-fm-path')"/>
	<xsl:variable name="full-path-to-file" select="concat(file:path4vza($fm-path,false()),'/',$fm-name)"/>

	<xsl:template match="/">
		<sw:noauth-redirect select="not(cred:check-env('vzcp.env.manage.services_and_files',$eid))"/>
		<xsl:variable name="file-access" select="local:check-file-access($eid,$full-path-to-file)"/>
		<xsl:choose>
			<xsl:when test="$file-access/error">
				<!-- no file access -->
				<packet>
					<cookie>
						<msg>
							<set-error>
								<short-desc>
									<sw:text>Cannot access the file because it is being used by another process</sw:text>
								</short-desc>
								<detail>
									<xsl:value-of select="$file-access/error/message"/>
								</detail>
							</set-error>
						</msg>
						<redirect-last/>
					</cookie>
				</packet>
				<xsl:if test="sw:response('lib/opredirect.xsl')"/>
			</xsl:when>
			<xsl:otherwise>
				<packet/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<func:function name="local:check-file-access">
		<xsl:param name="eid"/>
		<xsl:param name="full-path"/>
		<xsl:variable name="req">
			<packet>
				<target>filer</target>
				<xsl:copy-of select="sw:env-dst($eid)"/>
				<data>
					<filer>
						<download>
							<cwd>Lw==</cwd>
							<file>
								<path>
									<xsl:value-of select="sw:base64-encode($full-path)"/>
								</path>
								<offset>0</offset>
								<size>0</size>
							</file>
							<packet_mode/>
						</download>
					</filer>
				</data>
			</packet>
		</xsl:variable>
		<func:result select="sw:xchg($req)/packet/data/filem"/>
	</func:function>

	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/common.xsl"/>

</xsl:stylesheet>
