<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func voc filem cred local check wiz file"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl	="http://exslt.org/common"
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:error	="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz		="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local	="http://www.swsoft.com/xsl/cp/local"
  xmlns:func	="http://exslt.org/functions"	
	xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
	xmlns:voc		="http://www.swsoft.com/xsl/cp/voc"
	xmlns:ui	="http://www.swsoft.com/xsl/cp/ui"
	xmlns:filem	="http://www.swsoft.com/xsl/cp/filem"
	xmlns:check	="http://www.swsoft.com/xsl/cp/check"
	xmlns:file="http://www.swsoft.com/xsl/cp/file"
>
	<xsl:output method="xml"/>

	<sw:include href="/lib/utils/file.xsl"/>

	<xsl:param name="wiz_code" select="'vzenv-files-edit'"/>
  <xsl:variable name="step" select="wiz:processing-step-id()"/>	
  <xsl:variable name="form" select="local:init-form()"/>	
  
	<xsl:template match="node()|@*">
	
		<xsl:choose>
			<!-- Some error occured while form initing-->
			<xsl:when test="not($form)">
				<ui:redirect location="/vz/cp/vzdir/infrman/envs/files/index"/>
			</xsl:when>
			<!-- Step "General Settings" -->
			<xsl:when test="$step='gen'">
			
					<xsl:variable name="new_form_">
						<xsl:for-each select="$form/*">
							<xsl:choose>
								<xsl:when test="name()=$step"></xsl:when>
								<xsl:otherwise>
									<xsl:copy-of select="."/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
						<gen>
							<xsl:for-each select="$form/file">
								<xsl:variable name="pos" select="position()"/>
								<xsl:variable name="name" select="concat('body_',$pos)"/>
								<file>
									<xsl:value-of select="sw:param($name)"/>
								</file>
							</xsl:for-each>
						</gen>
					</xsl:variable>
					<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
										
					<xsl:if test="wiz:clicked-back()">
						<xsl:if test="wiz:goBack()"/>
					</xsl:if>
					<xsl:if test="wiz:clicked-next()">
						<!-- Check data -->
						<!-- ... nothing to check -->
			      <!-- Move to next step -->
			      <xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:copy-of select="local:final($new_form)"/>
								<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>		
							</xsl:when>
						</xsl:choose>
					</xsl:if>
					
					<!-- Store form values-->
					<!-- .. nothing to store
					<xsl:variable name="res">
						<xsl:value-of select="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
					</xsl:variable>
					-->
					
			</xsl:when>
				
		</xsl:choose>
		
		<!-- Wizard was canceled in init-form() template -->
		<!--<xsl:if test="$form_=''">
			<xsl:copy/>
		</xsl:if>-->
		
	</xsl:template>
	
	<func:function name="local:init-form">
		<xsl:if test="$step = ''">
			<!-- Init default data -->
			<xsl:variable name="selected-file" select="sw:base64-decode(sw:param('file-name'))"/>
			<!-- /Init default data -->
			<xsl:variable name="new_form">
				<gen/>
				<eid><xsl:value-of select="sw:ve-eid()"/></eid>
				<fm-path><xsl:value-of select="sw:sesget('ve-fm-path')"/></fm-path>
				<file><xsl:value-of select="$selected-file"/></file>
			</xsl:variable>
			<xsl:if test="sw:param('file-type')=4">
				<xsl:if test="error:put(sw:text('You cannot edit the folder.'))"/>
			</xsl:if>
			<!-- Init steps -->
			<xsl:variable name="new_steps_">
				<step id="gen" screenid="03.02.01.12.07" cred="vzcp.env.manage.services_and_files" security-obj-type="ve.vz.vt"/>
			</xsl:variable>
			<!-- Save wizard initial settings -->
			<xsl:choose>
				<xsl:when test="error:is-empty()">
					<xsl:variable name="new_steps_filtered">
						<xsl:copy-of	select="exsl:node-set($new_steps_)/step[(not(@cred) or cred:check-context(@cred,@security-obj-type))]"/>
					</xsl:variable>
					<xsl:variable name="new_steps"	select="exsl:node-set($new_steps_filtered)"/>
					<xsl:variable name="new_step"		select="string($new_steps/step[1]/@id)"/>
					<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
					<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
					<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:if test="sw:sesput($wiz_data,/..)"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>
	
	<!-- *********************************************************** -->
	<func:function name="local:final">
		<xsl:param name="data"/>
		<!--|-->
		<func:result>
 			<packet log="on">
				<target>filer</target>
				<xsl:copy-of select="sw:env-dst($data/eid)"/>
        <cookie>
          <msg>
            <ok><sw:text>The files have been changed.</sw:text></ok>
            <error><sw:text>Failed to change the files.</sw:text></error>
          </msg>
          <operation>ve_edit_files</operation>
          <redirect-prev/>
        </cookie>			
				<data>
					<xsl:for-each select="$data/file">
						<xsl:variable name="pos" select="position()"/>
						<filer>
							<upload>
								<file>
									<path>
			            	<xsl:value-of select="sw:base64-encode(concat(file:path4vza($data/fm-path),.))"/>
									</path>
									<body>
										<xsl:value-of select="sw:base64-encode($data/gen/file[$pos])"/>
									</body>
									<size><xsl:value-of select="sw:size-of($data/gen/file[$pos])"/></size>
								</file>
								<packet_mode/>
								<force />
							</upload>
						</filer>
					</xsl:for-each>
				</data>
				<vzcpauth/>
			</packet>
 		</func:result>
	</func:function>
	
  <!-- credentials -->
  <sw:include href="/lib/cred.xsl"/>
	
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>

	<sw:include href="/lib/vza/filem.xsl"/>		

	<sw:include href="/lib/vocabulary.xsl"/>		
	<sw:include href="/lib/globals.xsl"/>
	
</xsl:stylesheet>
