<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl sw func vzenv cred local file"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:hwm="http://www.swsoft.com/xsl/cp/hwm"
	xmlns:vzenv="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:file="http://www.swsoft.com/xsl/cp/file"
>

	<xsl:output method="xml"/>

	<sw:include href="/lib/utils/file.xsl"/>

	<!-- check permissions to this page -->
	<xsl:variable name="eid" select="sw:ve-eid()"/>
	<xsl:variable name="cr-delete" select="cred:check-env('vzcp.env.manage.services_and_files',$eid)"/>
	<xsl:variable name="selected-files"	select="sw:param('file-name')"/>
	<xsl:variable name="fm-path" select="sw:sesget('ve-fm-path')"/>

	<xsl:template match="/">
		<xsl:choose>
			<!-- no destroy cred -->
			<xsl:when test="sw:param('delete') and not($cr-delete)">
				<packet/>
			</xsl:when>
			<!-- there is no current PATH -->
			<xsl:when test="not($fm-path and $fm-path!='')">
				<packet/>
			</xsl:when>

			<!-- Check selected VE -->
			<xsl:when test="not($selected-files)">
				<xsl:if test="error:put(sw:text('Please select at least one file.'),'')"/>
				<packet/>
			</xsl:when>

			<!-- Delete Files-->
			<xsl:when test="sw:param('delete')">
				<xsl:copy-of select="local:delete($selected-files)"/>
				<xsl:if test="sw:response('lib/opredirect.xsl')"/>
			</xsl:when>

			<!-- Unknown post -->
			<xsl:otherwise>
				<packet/>
			</xsl:otherwise>

		</xsl:choose>
	</xsl:template>

	<func:function name="local:delete">
		<xsl:param name="files"/>
		<func:result>
			<packet log="on">
				<target>filer</target>
				<xsl:copy-of select="sw:env-dst($eid)"/>
				<cookie>
					<msg>
						<ok>
							<sw:text>The object(s) has/have been deleted.</sw:text>
						</ok>
						<error>
							<sw:text>Failed to delete the object(s).</sw:text>
						</error>
					</msg>
					<operation>delete_files</operation>
					<redirect-last/>
				</cookie>
				<data>
					<filer>
						<remove>
							<xsl:for-each select="$files">
								<path>
									<xsl:value-of select="sw:base64-encode(file:path4vza(concat($fm-path,'/',.)))"/>
								</path>
							</xsl:for-each>
							<recursively/>
						</remove>
					</filer>
				</data>
				<vzcpauth/>
			</packet>
		</func:result>
	</func:function>

	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/common.xsl"/>

</xsl:stylesheet>
