<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func voc filem cred local check wiz file"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl	="http://exslt.org/common"
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:error	="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz		="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local	="http://www.swsoft.com/xsl/cp/local"
  xmlns:func	="http://exslt.org/functions"	
	xmlns:vt 		="http://www.swsoft.com/xsl/cp/vt"  
	xmlns:env	  ="http://www.swsoft.com/xsl/cp/env"  	
	xmlns:ve	  ="http://www.swsoft.com/xsl/cp/ve"  
	xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
	xmlns:voc		="http://www.swsoft.com/xsl/cp/voc"
	xmlns:filem	="http://www.swsoft.com/xsl/cp/filem"
	xmlns:check	="http://www.swsoft.com/xsl/cp/check"
	xmlns:ui	="http://www.swsoft.com/xsl/cp/ui"
	xmlns:file="http://www.swsoft.com/xsl/cp/file"
>
	<xsl:output method="xml"/>

	<sw:include href="/lib/core/check-funcs.xsl"/>
	<sw:include href="/lib/vt/core.xsl"/>		
	<sw:include href="/lib/vt/ve-core.xsl"/>		
	<sw:include href="/lib/utils/file.xsl"/>

	<xsl:param name="wiz_code" select="'ve-props'"/>
  <xsl:variable name="step" select="wiz:processing-step-id()"/>	
  <xsl:variable name="form" select="local:init-form()"/>		

	<xsl:template match="node()|@*">
		
		<xsl:choose>
			<!-- Step "General Settings" -->
			<xsl:when test="$step='gen'">
			
					<xsl:variable name="new_form_">
						<xsl:for-each select="$form/*">
							<xsl:choose>
								<xsl:when test="name()=$step"></xsl:when>
								<xsl:otherwise>
									<xsl:copy-of select="."/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
						<gen>
							<xsl:for-each select="$form/file">
								<file>
									<name><xsl:value-of select="sw:param('name')"/></name>
									<xsl:if test="$form/linux"> 					 		
										<uid><xsl:value-of select="sw:param('uid')"/></uid>
										<gid><xsl:value-of select="sw:param('gid')"/></gid>
										<mode>	
											<src>
												<xsl:value-of select="sw:param('mode')"/>
											</src>
											<owner>
												<xsl:variable name="tag" select="'owner'"/>
												<read><xsl:value-of select="sw:param(concat($tag,'_read'))"/></read>
												<write><xsl:value-of select="sw:param(concat($tag,'_write'))"/></write>
												<exec><xsl:value-of select="sw:param(concat($tag,'_exec'))"/></exec>
											</owner>
											<group>
												<xsl:variable name="tag" select="'group'"/>
												<read><xsl:value-of select="sw:param(concat($tag,'_read'))"/></read>
												<write><xsl:value-of select="sw:param(concat($tag,'_write'))"/></write>
												<exec><xsl:value-of select="sw:param(concat($tag,'_exec'))"/></exec>
											</group>
											<others>
												<xsl:variable name="tag" select="'others'"/>
												<read><xsl:value-of select="sw:param(concat($tag,'_read'))"/></read>
												<write><xsl:value-of select="sw:param(concat($tag,'_write'))"/></write>
												<exec><xsl:value-of select="sw:param(concat($tag,'_exec'))"/></exec>
											</others>
										</mode>
									</xsl:if>
								</file>
							</xsl:for-each>
						</gen>
					</xsl:variable>
					<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
										
					<xsl:if test="wiz:clicked-back()">
						<xsl:if test="wiz:goBack()"/>
					</xsl:if>
					<xsl:if test="wiz:check-form-id($new_form) and wiz:clicked-next()">
						<!-- Check data -->
			      <!-- check files -->
			      <xsl:for-each select="$new_form/gen/file">
				      <xsl:choose>
				      	<!-- check file name presence -->
					      <xsl:when test="name=''">
					      	<xsl:if test="error:put(sw:text('You should specify the file name.'),'','name')"/>
					      </xsl:when>
					      <!-- check file name for valid chars -->
					      <xsl:when test="not(check:fileName(name))">
					      	<xsl:if test="error:put(sw:text('The new file name is invalid. Please correct it.'),'','name')"/>
					      </xsl:when>
					      <!-- check file  name for existing -->
					      <xsl:when test="name!=$new_form/file/name and filem:stat(file:path4vza($new_form/fm-path),name,$new_form/eid)">
					      	<xsl:if test="error:put(sw:text('The file with this name already exists. Please select another name.'),'','name')"/>
					      </xsl:when>
							</xsl:choose>
						</xsl:for-each>
						
						<!-- Try to rename -->
						<xsl:if test="error:is-empty() and $new_form/file/name!=$new_form/gen/file/name and local:rename($new_form)"/>
						
						<!-- Try to chown -->
						<xsl:if test="$form/linux"> 					 		
							<xsl:if test="error:is-empty() and ($new_form/file/uid!=$new_form/gen/file/uid or $new_form/file/gid!=$new_form/gen/file/gid) and local:chown($new_form)"/>
							<xsl:if test="error:is-empty() and local:chmod($new_form)"/>
						</xsl:if>
						
			      <!-- Move to next step -->
			      <xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:if test="sw:sesput('msg',sw:text('The file has been updated.'))"/>	
								<ui:redirect location="/vz/cp/vzdir/infrman/envs/files/index"/>
							</xsl:when>
						</xsl:choose>
					</xsl:if>
					
					<!-- Store form values-->
					<xsl:variable name="res">
						<xsl:value-of select="sw:sesput($wiz_data,$new_form)"/>
					</xsl:variable>
					
			</xsl:when>
				
		</xsl:choose>
		
		<xsl:copy/>
		
	</xsl:template>
	
	<func:function name="local:init-form">
		<xsl:if test="$step = ''">
			<!-- Init default data -->
			<xsl:variable name="selected-file" select="sw:base64-decode(sw:param('file-name'))"/>
			<!-- /Init default data -->
			<!-- Load Permissions -->
			<xsl:variable name="fm-list-input">
				<info>
					<name/><mode/><user/><group/><size/><date/><uid/><gid/><type/>
				</info>
				<follow_links/>
			</xsl:variable>
		  <xsl:variable name="fm-res" select="filem:list(file:path4vza(sw:sesget('ve-fm-path')),sw:ve-eid(),$fm-list-input)"/>
		  <xsl:variable name="info" 	select="$fm-res/file[sw:base64-decode(name)=$selected-file]"/>
 		  <xsl:variable name="env" 		select="env:get-env(sw:ve-eid())/env"/>
 			<xsl:variable name="env-platform"	select="ve:ve2platform($env)"/>
			<!-- /Load Permissions -->
			<xsl:variable name="new_form">
				<wizard-id><xsl:value-of select="sw:generate-id()"/></wizard-id>			
				<gen>
					<xsl:variable name="name" select="$selected-file"/>
					<xsl:variable name="mode-src" select="$info/mode"/>
					<xsl:variable name="mode" select="sw:permissions-str($mode-src)"/>
					<file>							
						<mode>
							<src>
								<xsl:value-of select="$mode-src"/>
							</src>
							<owner>
								<xsl:copy-of select="local:mode-human(substring($mode,2))"/>
							</owner>
							<group>
								<xsl:copy-of select="local:mode-human(substring($mode,5))"/>
							</group>
							<others>
								<xsl:copy-of select="local:mode-human(substring($mode,8))"/>
							</others>
						</mode>
						<name><xsl:value-of select="$name"/></name>
						<xsl:copy-of select="$info/uid"/>
						<xsl:copy-of select="$info/gid"/>						
					</file>
				</gen>
				<eid><xsl:value-of select="$env/eid"/></eid>
				<xsl:if test="vt:is-platform-linux($env-platform)">
					<linux/>
				</xsl:if>
				<fm-path><xsl:value-of select="sw:sesget('ve-fm-path')"/></fm-path>
				<file>
					<name><xsl:value-of select="$selected-file"/></name>
					<xsl:copy-of select="$info/*[name()!='name']"/>
				</file>
			</xsl:variable>
			<!-- Init steps -->
			<xsl:variable name="new_steps_">
				<step id="gen" screenid="03.02.01.12.09" cred="vzcp.env.manage.services_and_files" security-obj-type="ve.vz.vt"/>
			</xsl:variable>
			<!-- Save wizard initial settings -->
			<xsl:if test="error:is-empty()">
				<xsl:variable name="new_steps_filtered">
					<xsl:copy-of	select="exsl:node-set($new_steps_)/step[(not(@cred) or cred:check-context(@cred,@security-obj-type))]"/>
				</xsl:variable>
				<xsl:variable name="new_steps"	select="exsl:node-set($new_steps_filtered)"/>
				<xsl:variable name="new_step"		select="string($new_steps/step[1]/@id)"/>
				<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
				<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
				<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
			</xsl:if>
		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>
	
	<func:function name="local:mode-human">
		<xsl:param name="mode"/>
		<func:result>
			<read><xsl:value-of select="sw:if(substring($mode,1,1)!='-','1','')"/></read>
			<write><xsl:value-of select="sw:if(substring($mode,2,1)!='-','1','')"/></write>
			<exec><xsl:value-of select="sw:if(substring($mode,3,1)!='-','1','')"/></exec>
		</func:result>
	</func:function>
	
	<!-- *********************************************************** -->
	<func:function name="local:final">
		<xsl:param name="data"/>
		<!--|-->
		<func:result>
 			<packet log="on">
				<target>filer</target>
				<xsl:copy-of select="sw:env-dst($data/eid)"/>
        <cookie>
          <msg>
            <ok><sw:text>The file has been changed.</sw:text></ok>
            <error><sw:text>Failed to change the file.</sw:text></error>
          </msg>
          <operation>ve_rename_files</operation>
          <redirect-prev/>
        </cookie>
				<data>
					<xsl:for-each select="$data/gen/file">
						<filer>
							<chmod>
								<cwd><xsl:value-of select="sw:base64-encode(file:path4vza($data/fm-path))"/></cwd>
								<xsl:variable name="pos" select="position()"/>
								<path>
		            	<xsl:value-of select="sw:base64-encode(name)"/>
								</path>
								<mode>
									<xsl:value-of select="
										sw:bitwise-and(mode/src,sw:bitwise-not(512-1))+
										sw:if(mode/owner/read='1',256,0)+
										sw:if(mode/owner/write='1',128,0)+
										sw:if(mode/owner/exec='1',64,0)+
										sw:if(mode/group/read='1',32,0)+
										sw:if(mode/group/write='1',16,0)+
										sw:if(mode/group/exec='1',8,0)+
										sw:if(mode/others/read='1',4,0)+
										sw:if(mode/others/write='1',2,0)+
										sw:if(mode/others/exec='1',1,0)
									"/>
								</mode>
							</chmod>
						</filer>
					</xsl:for-each>
				</data>
				<vzcpauth/>
			</packet>
 		</func:result>
	</func:function>
	
	<func:function name="local:rename">
		<xsl:param name="data"/>
		<!--|-->
		<xsl:variable name="file" select="$data/gen/file"/>
		
		<xsl:variable name="packet">
 			<packet>
				<target>filer</target>
				<xsl:copy-of select="sw:env-dst($data/eid)"/>
				<data>
					<filer>							
						<move>
							<recursively/>
							<cwd><xsl:value-of select="sw:base64-encode(file:path4vza($data/fm-path))"/></cwd>
							<path>
	            	<xsl:value-of select="sw:base64-encode($data/file/name)"/>
							</path>				
							<dst_path>
								<xsl:value-of select="sw:base64-encode($file/name)"/>
							</dst_path>			
						</move>
					</filer>
				</data>
				<vzcpauth/>
			</packet>
 		</xsl:variable>
 		
 		<xsl:variable name="res" select="sw:xchg($packet)/packet/data"/>
 		
 		<xsl:if test="$res[error|filer/error]">
			<xsl:if test="error:put(sw:text('Error renaming the file.'),$res/error/message|$res/filer/error/message)"/>	
		</xsl:if>
 		
	</func:function>
	
	<func:function name="local:chmod">
		<xsl:param name="data"/>
		<!--|-->
		<xsl:variable name="file" select="$data/gen/file"/>
		
		<xsl:variable name="packet">
 			<packet log="on">
				<target>filer</target>
				<xsl:copy-of select="sw:env-dst($data/eid)"/>        	
				<data>
					<xsl:for-each select="$data/gen/file">
						<filer>
							<chmod>
								<cwd><xsl:value-of select="sw:base64-encode(file:path4vza($data/fm-path))"/></cwd>
								<xsl:variable name="pos" select="position()"/>
								<path>
		            	<xsl:value-of select="sw:base64-encode(name)"/>
								</path>
								<mode>
									<xsl:value-of select="
										sw:bitwise-and(mode/src,sw:bitwise-not(512-1))+
										sw:if(mode/owner/read='1',256,0)+
										sw:if(mode/owner/write='1',128,0)+
										sw:if(mode/owner/exec='1',64,0)+
										sw:if(mode/group/read='1',32,0)+
										sw:if(mode/group/write='1',16,0)+
										sw:if(mode/group/exec='1',8,0)+
										sw:if(mode/others/read='1',4,0)+
										sw:if(mode/others/write='1',2,0)+
										sw:if(mode/others/exec='1',1,0)
									"/>
								</mode>
							</chmod>
						</filer>
					</xsl:for-each>
				</data>
				<vzcpauth/>
			</packet>
 		</xsl:variable>
 		
 		<xsl:variable name="res" select="sw:xchg($packet)/packet/data"/>
 		
 		<xsl:if test="$res[error|filem/error]">
			<xsl:if test="error:put(sw:text('Error changing the permissions.'),$res/error/message|$res/filem/error/message)"/>	
		</xsl:if>
 		
	</func:function>
	
	<func:function name="local:chown">
		<xsl:param name="data"/>
		<!--|-->
		<xsl:variable name="file" select="$data/gen/file"/>
		
		<xsl:variable name="packet">
 			<packet>
				<target>filer</target>
				<xsl:copy-of select="sw:env-dst($data/eid)"/>
				<data>
					<filer>							
						<chown>
							<cwd><xsl:value-of select="sw:base64-encode(file:path4vza($data/fm-path))"/></cwd>
							<path>
	            	<xsl:value-of select="sw:base64-encode($file/name)"/>
							</path>												
							<owner>	
								<uid><xsl:value-of select="$file/uid"/></uid>
								<gid><xsl:value-of select="$file/gid"/></gid>
							</owner>
						</chown>
					</filer>
				</data>
				<vzcpauth/>
			</packet>
 		</xsl:variable>
 		
 		<xsl:variable name="res" select="sw:xchg($packet)/packet/data"/>
 		
 		<xsl:if test="$res[error|filem/error]">
			<xsl:if test="error:put(sw:text('Error changing the ownership.'),$res/error/message|$res/filem/error/message)"/>	
		</xsl:if>
 		
	</func:function>
	
  <!-- credentials -->
  <sw:include href="/lib/cred.xsl"/>
	
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>

	<sw:include href="/lib/vza/filem.xsl"/>		

	<sw:include href="/lib/vocabulary.xsl"/>		
	<sw:include href="/lib/globals.xsl"/>
	
</xsl:stylesheet>
