<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func voc filem cred local check wiz file"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl	="http://exslt.org/common"
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:error	="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz		="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local	="http://www.swsoft.com/xsl/cp/local"
  xmlns:func	="http://exslt.org/functions"	
	xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
	xmlns:voc		="http://www.swsoft.com/xsl/cp/voc"
	xmlns:filem	="http://www.swsoft.com/xsl/cp/filem"
	xmlns:check	="http://www.swsoft.com/xsl/cp/check"
	xmlns:form	="http://www.swsoft.com/xsl/cp/form"
	xmlns:ui	="http://www.swsoft.com/xsl/cp/ui"
	xmlns:file="http://www.swsoft.com/xsl/cp/file"
>
	<xsl:output method="xml"/>

	<sw:include href="/lib/utils/file.xsl"/>

	<xsl:param name="wiz_code" select="'fm_upload'"/>
  <xsl:variable name="step" select="wiz:processing-step-id()"/>	
  <xsl:variable name="form" select="local:init-form()"/>
  
	<xsl:template match="node()|@*">
	
		<xsl:choose>
			<!-- Step "General Settings" -->
			<xsl:when test="$step='gen'">
			
					<xsl:variable name="new_form_">
						<xsl:for-each select="$form/*">
							<xsl:choose>
								<xsl:when test="name()=$step"></xsl:when>
								<xsl:otherwise>
									<xsl:copy-of select="."/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
						<gen>
							<xsl:for-each select="/http_request/files/file">
								<xsl:if test="remote_path!='' and local_path!=''">
								<file>
									<local-path><xsl:value-of select="local_path"/></local-path>
									<remote-path><xsl:value-of select="remote_path"/></remote-path>
								</file>
								</xsl:if>
							</xsl:for-each>
						</gen>
					</xsl:variable>
					<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
										
					<xsl:if test="sw:param('back')">
						 <!-- Move to back -->
						<xsl:if test="wiz:goBack()"/>
					</xsl:if>
					<xsl:if test="wiz:check-form-id($new_form) and wiz:clicked-next()">					
						<!-- Check data -->
						<xsl:if test="not($new_form/gen/file)">
			      	<xsl:if test="error:put(sw:text('You should select at least one file.'))"/>
			      </xsl:if>
			      <!-- Move to next step -->
			      <xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:copy-of select="local:final($new_form)"/>
							</xsl:when>
						</xsl:choose>
					</xsl:if>
					
					<!-- Store form values-->
					<xsl:variable name="res">
						<xsl:value-of select="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
					</xsl:variable>
					
			</xsl:when>
				
		</xsl:choose>
		
		<xsl:copy/>
		
	</xsl:template>
	
	<func:function name="local:init-form">
		<xsl:if test="$step = ''">
			<xsl:variable name="new_form">
				<wizard-id><xsl:value-of select="sw:generate-id()"/></wizard-id>			
				<gen/>
				<eid><xsl:value-of select="sw:ve-eid()"/></eid>
				<fm-path><xsl:value-of select="sw:sesget('ve-fm-path')"/></fm-path>
			</xsl:variable>
			<!-- Init steps -->
			<xsl:variable name="new_steps_">
				<step id="gen" screenid="03.02.01.12.04" cred="vzcp.env.manage.services_and_files" security-obj-type="ve.vz.vt"/>
			</xsl:variable>
			<!-- Save wizard initial settings -->
			<xsl:if test="error:is-empty()">
				<xsl:variable name="new_steps_filtered">
					<xsl:copy-of	select="exsl:node-set($new_steps_)/step[(not(@cred) or cred:check-context(@cred,@security-obj-type))]"/>
				</xsl:variable>
				<xsl:variable name="new_steps"	select="exsl:node-set($new_steps_filtered)"/>
				<xsl:variable name="new_step"		select="string($new_steps/step[1]/@id)"/>
				<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
				<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
				<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
			</xsl:if>
		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>	
	<!-- *********************************************************** -->
	<func:function name="local:final">
		<xsl:param name="data"/>
		<!--|-->
		<func:result>
			<xsl:for-each select="$data/gen/file">
				<xsl:variable name="remote" select="concat(file:path4vza($data/fm-path),remote-path)"/>
				<xsl:variable name="res" select="sw:upload-file(local-path,$remote,$data/eid)"/>
				<xsl:choose>
					<xsl:when test="$res=''">
						<xsl:variable name="ok">
							<sw:text>
								The file has been uploaded.
							</sw:text>
						</xsl:variable>
						<xsl:value-of select="sw:sesput('msg', $ok)"/>
					</xsl:when>
					<xsl:otherwise>								
						<xsl:message>
							Some system error occured while <xsl:value-of select="file:path4screen($remote)"/> uploading.
							Error: 
							<xsl:value-of select="$res"/>
						</xsl:message>
						<xsl:variable name="error">
							<sw:text>
								<xsl:with-param name="name" select="$remote"/>
								A system error occurred during the uploading of %{name}.
							</sw:text>
						</xsl:variable>
						<xsl:if test="error:put($error)"/>  
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
			<ui:redirect location="/vz/cp/vzdir/infrman/envs/files/index"/>
 		</func:result>
	</func:function>
	
  <!-- credentials -->
  <sw:include href="/lib/cred.xsl"/>
	
	<sw:include href="../../../../../layout/forms-list.xsl"/>	

	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>

	<sw:include href="/lib/vza/filem.xsl"/>		

	<sw:include href="/lib/vocabulary.xsl"/>		
	<sw:include href="/lib/globals.xsl"/>
	
</xsl:stylesheet>
