<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred env"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:fwm="http://www.swsoft.com/xsl/cp/fwm"
	xmlns:fwm-util="http://www.swsoft.com/xsl/cp/fwm-util"
	xmlns:voc="http://www.swsoft.com/xsl/cp/voc"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
>

	<sw:include href="/lib/vt/env-core.xsl"/>

	<xsl:output method="xml"/>
	<xsl:variable name="eid" select="sw:ve-eid()"/>
	<xsl:variable name="env" select="env:get-env($eid)"/>

	<xsl:template match="/">
		<!-- for group operations -->
		<xsl:variable name="fwm-rule-uniq-id"
			select="sw:param('fwm-rule-uniq-id')"/>
		<xsl:variable name="cr-fwm" select="cred:check-env('vzcp.env.manage.services_and_files',$eid)"/>
		<sw:noauth-redirect select="not($cr-fwm)"/>

		<!-- for up/down operation with one rule -->
		<xsl:variable name="move-rule-uniq-id"
			select="string(sw:param('move-rule-uniq-id'))"/>
		<xsl:variable name="move-direction"
			select="string(sw:param('direction'))"/>

		<!-- action here -->
		<xsl:variable name="doRuleEnable"	select="sw:param('fwm-rule-enable')"/>
		<xsl:variable name="doRuleDisable"	select="sw:param('fwm-rule-disable')"/>
		<xsl:variable name="doRuleDelete"	select="sw:param('fwm-rule-delete')"/>
		<xsl:variable name="doRuleUp" select="($move-direction = 'up') and $move-rule-uniq-id != ''"/>
		<xsl:variable name="doRuleDown" select="($move-direction = 'down') and $move-rule-uniq-id != ''"/>

		<xsl:variable name="doAction"
			select="$doRuleEnable or $doRuleDisable or $doRuleDelete or $doRuleUp or $doRuleDown"/>
		<xsl:variable name="fwm-rules-session" select="sw:sesget('fwm-rules')"/>
		<xsl:variable name="fwm-rules-raw">
			<xsl:choose>
				<xsl:when test="$cr-fwm">
					<xsl:choose>
						<xsl:when test="not($doAction)">
							<!-- recalc rules only of no action specified -->
							<xsl:call-template name="fwm-calc-rules"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:copy-of select="sw:sesget('fwm-rules')"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="/.."/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="fwm-rules" select="exsl:node-set($fwm-rules-raw)"/>

		<!-- for check low level error -->
		<xsl:variable name="oper-problem" select="voc:check-operation('firewallm')"/>
		<xsl:variable name="fmw-list" select="fwm:get()"/>

		<xsl:choose>
			<!-- check premissions before execute request -->
			<xsl:when test="not($cr-fwm)">
				<packet/>
			</xsl:when>

			<xsl:when test="$oper-problem != ''">
				<!-- vzenv in not correct state (not run at least)-->
				<packet>
					<cookie>
						<redirect>
							<xsl:value-of select="concat($baseurl,'/vzdir/infrman/envs/fwm/setup')"/>
						</redirect>
					</cookie>
				</packet>
				<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
			</xsl:when>

			<xsl:when test="$fmw-list/error">
				<!-- fwm return error -->
				<packet>
					<cookie>
						<redirect>
							<xsl:value-of select="concat($baseurl,'/vzdir/infrman/envs/fwm/setup')"/>
						</redirect>
					</cookie>
				</packet>
				<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
			</xsl:when>

			<!-- enbale one or group rules  -->
			<xsl:when test="$doRuleEnable">
				<xsl:if test="error:is-empty()">
					<xsl:if
						test="cred:detail-check-env('vzcp.env.manage.services_and_files',$eid)"
					/>
				</xsl:if>
				<xsl:choose>
					<xsl:when test="error:is-empty()">
						<xsl:copy-of select="fwm:rule-enable-disable($fwm-rules,$fwm-rule-uniq-id,'enable')"/>
					</xsl:when>
					<xsl:otherwise>
						<packet/>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:call-template name="finish-action"/>
			</xsl:when>

			<!-- disable one or group rules  -->
			<xsl:when test="$doRuleDisable">
				<xsl:if test="error:is-empty()">
					<xsl:if
						test="cred:detail-check-env('vzcp.env.manage.services_and_files',$eid)"
					/>
				</xsl:if>
				<xsl:choose>
					<xsl:when test="error:is-empty()">
						<xsl:copy-of select="fwm:rule-enable-disable($fwm-rules,$fwm-rule-uniq-id,'disable')"/>
					</xsl:when>
					<xsl:otherwise>
						<packet/>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:call-template name="finish-action"/>
			</xsl:when>

			<!-- delete one or group rules  -->
			<xsl:when test="$doRuleDelete">
				<xsl:if test="error:is-empty()">
					<xsl:if
						test="cred:detail-check-env('vzcp.env.manage.services_and_files',$eid)"/>
				</xsl:if>
				<xsl:choose>
					<xsl:when test="error:is-empty()">
						<xsl:copy-of select="fwm:rule-delete($fwm-rules,$fwm-rule-uniq-id)"/>
					</xsl:when>
					<xsl:otherwise>
						<packet/>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:call-template name="finish-action"/>
			</xsl:when>

			<!-- up one rule -->
			<xsl:when test="$doRuleUp">
				<xsl:if test="error:is-empty()">
					<xsl:if
						test="cred:detail-check-env('vzcp.env.manage.services_and_files',$eid)"/>
				</xsl:if>
				<xsl:choose>
					<xsl:when test="error:is-empty()">
						<xsl:copy-of select="fwm:rule-up($fwm-rules,$move-rule-uniq-id)"/>
					</xsl:when>
					<xsl:otherwise>
						<packet/>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:call-template name="finish-action"/>
			</xsl:when>

			<!-- down one rule -->
			<xsl:when test="$doRuleDown">
				<xsl:if test="error:is-empty()">
					<xsl:if
						test="cred:detail-check-env('vzcp.env.manage.services_and_files',$eid)"/>
				</xsl:if>
				<xsl:choose>
					<xsl:when test="error:is-empty()">
						<xsl:copy-of select="fwm:rule-down($fwm-rules,$move-rule-uniq-id)"/>
					</xsl:when>
					<xsl:otherwise>
						<packet/>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:call-template name="finish-action"/>
			</xsl:when>

			<xsl:otherwise>
				<packet/>
				<xsl:if test="fwm-util:set-mode('advanced')"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="finish-action">
		<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
	</xsl:template>

	<!-- credentials -->
	<sw:include href="/lib/cred.xsl"/>

	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/vza/fwm.xsl"/>
	<sw:include href="/lib/fwm.xsl"/>
	<sw:include href="/lib/vt/env-private.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
