<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl func wiz cred error local check str env"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:fwm="http://www.swsoft.com/xsl/cp/fwm"
	xmlns:check="http://www.swsoft.com/xsl/cp/check"
	xmlns:str="http://exslt.org/strings"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
>
	<sw:include href="/lib/core/check-funcs.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>

	<xsl:output method="xml"/>
	<xsl:variable name="eid" select="sw:ve-eid()"/>
	<xsl:variable name="env" select="env:get-env($eid)"/>

	<!-- Load data -->
	<xsl:variable name="fwm-rule-uniq-id"
		select="sw:param('fwm-rule-uniq-id')"/>

	<xsl:variable name="action" select="sw:if($fwm-rule-uniq-id != '','edit','add')"/>
	<xsl:variable name="fwm-rules" select="sw:sesget('fwm-rules')"/>
	<xsl:variable name="tab" select="string(sw:param('tab'))"/>
	<xsl:variable name="cur-rule" select="$fwm-rules/chain/rule[fwm-rule-uniq-id = $fwm-rule-uniq-id]"/>

	<xsl:variable name="step" select="wiz:processing-step-id()"/>

	<xsl:param name="wiz_code" select="'ve-fwm-rule'"/>
	<xsl:variable name="form" select="local:init-form()"/>

	<xsl:template match="node()|@*">
		<xsl:choose>
			<!-- Step "Add" and "New" -->
			<xsl:when
				test="$step='edit' or $step='add'">
				<xsl:variable name="new_form_">
					<fwm-rule-uniq-id>
						<xsl:value-of select="sw:param('fwm-rule-uniq-id')"/>
					</fwm-rule-uniq-id>
					<name>
						<xsl:value-of select="sw:param('name')"/>
					</name>
					<protocol>
						<xsl:value-of select="sw:param('protocol')"/>
					</protocol>
					<chain>
						<xsl:value-of select="sw:param('chain')"/>
					</chain>
					<policy>
						<xsl:value-of select="sw:param('policy')"/>
					</policy>
					<position>
						<xsl:value-of select="sw:param('position')"/>
					</position>
					<allowed>
						<xsl:value-of select="sw:if(sw:param('allowed'),1,0)"/>
					</allowed>

					<xsl:variable name="src-host-mask"
						select="normalize-space(sw:param('src-addr'))"/>
					<xsl:if test="$src-host-mask != ''">
						<xsl:variable name="src-mask-present" select="contains($src-host-mask,'/')"/>
						<xsl:choose>
							<xsl:when test="$src-mask-present">
								<xsl:variable name="src-host"
									select="normalize-space(substring-before($src-host-mask,'/'))"/>
								<xsl:variable name="src-mask"
									select="normalize-space(substring-after($src-host-mask,'/'))"/>
								<src_addr>
									<host>
										<xsl:value-of select="$src-host"/>
									</host>
									<mask>
										<xsl:value-of select="$src-mask"/>
									</mask>
								</src_addr>
							</xsl:when>
							<xsl:otherwise>
								<src_addr>
									<host>
										<xsl:value-of select="$src-host-mask"/>
									</host>
								</src_addr>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:if>

					<xsl:variable name="src-ports"
						select="normalize-space(sw:param('src-ports'))"/>
					<xsl:if test="$src-ports != ''">
						<xsl:variable name="src-range-present" select="contains($src-ports,'-')"/>
						<xsl:choose>
							<xsl:when test="$src-range-present">
								<xsl:variable name="src-first-port"
									select="normalize-space(substring-before($src-ports,'-'))"/>
								<xsl:variable name="src-last-port"
									select="normalize-space(substring-after($src-ports,'-'))"/>
								<src_ports>
									<first_port>
										<xsl:value-of select="$src-first-port"/>
									</first_port>
									<last_port>
										<xsl:value-of select="$src-last-port"/>
									</last_port>
								</src_ports>
							</xsl:when>
							<xsl:otherwise>
								<src_ports>
									<first_port>
										<xsl:value-of select="$src-ports"/>
									</first_port>
								</src_ports>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:if>

					<xsl:variable name="dst-host-mask"
						select="normalize-space(sw:param('dst-addr'))"/>
					<xsl:if test="$dst-host-mask != ''">
						<xsl:variable name="dst-mask-present" select="contains($dst-host-mask,'/')"/>
						<xsl:choose>
							<xsl:when test="$dst-mask-present">
								<xsl:variable name="dst-host"
									select="normalize-space(substring-before($dst-host-mask,'/'))"/>
								<xsl:variable name="dst-mask"
									select="normalize-space(substring-after($dst-host-mask,'/'))"/>
								<dst_addr>
									<host>
										<xsl:value-of select="$dst-host"/>
									</host>
									<mask>
										<xsl:value-of select="$dst-mask"/>
									</mask>
								</dst_addr>
							</xsl:when>
							<xsl:otherwise>
								<dst_addr>
									<host>
										<xsl:value-of select="$dst-host-mask"/>
									</host>
								</dst_addr>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:if>

					<xsl:variable name="dst-ports"
						select="normalize-space(sw:param('dst-ports'))"/>
					<xsl:if test="$dst-ports != ''">
						<xsl:variable name="dst-range-present" select="contains($dst-ports,'-')"/>
						<xsl:choose>
							<xsl:when test="$dst-range-present">
								<xsl:variable name="dst-first-port"
									select="normalize-space(substring-before($dst-ports,'-'))"/>
								<xsl:variable name="dst-last-port"
									select="normalize-space(substring-after($dst-ports,'-'))"/>
								<dst_ports>
									<first_port>
										<xsl:value-of select="$dst-first-port"/>
									</first_port>
									<last_port>
										<xsl:value-of select="$dst-last-port"/>
									</last_port>
								</dst_ports>
							</xsl:when>
							<xsl:otherwise>
								<dst_ports>
									<first_port>
										<xsl:value-of select="$dst-ports"/>
									</first_port>
								</dst_ports>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:if>
				</xsl:variable>

				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
				<xsl:if test="sw:param('next')">
					<!-- CHECK DATA -->
					<xsl:choose>
						<xsl:when test="not($new_form/name != '')">
							<xsl:if test="error:put(sw:text('You should specify a name.'),'','name')"/>
						</xsl:when>

						<xsl:when test="not(local:check-addr($new_form/src_addr,'source'))">
							<!-- error occured, not proceed more -->
						</xsl:when>
						<xsl:when test="not(local:check-ports($new_form/src_ports,'source'))">
							<!-- error occured, not proceed more -->
						</xsl:when>

						<xsl:when test="not(local:check-addr($new_form/dst_addr,'destination'))">
							<!-- error occured, not proceed more -->
						</xsl:when>
						<xsl:when test="not(local:check-ports($new_form/dst_ports,'destination'))">
							<!-- error occured, not proceed more -->
						</xsl:when>

					</xsl:choose>
					<!-- /CHECK DATA -->
				</xsl:if>

				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new_form"/>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>

		<xsl:copy/>
	</xsl:template>

	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
						<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
								<xsl:copy-of select="local:final($data)"/>
								<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
							</xsl:when>
							<xsl:otherwise>
								<packet/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

	<func:function name="local:init-form">
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:init-new"/>				
 		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>
 	
	<xsl:template name="local:init-new">

		<xsl:variable name="new_form">
			<xsl:copy-of select="$cur-rule/*"/>
			<xsl:choose>
				<xsl:when test="$action = 'add'">
					<!-- on new rule all selector set to any -->
					<chain>
						<xsl:value-of select="$fwm-chain/chain[tab = $tab]/chain-name"/>
					</chain>
					<allowed>1</allowed>
					<position>down</position>
				</xsl:when>
				<xsl:otherwise>
					<!-- it's edit rule, do nothing -->
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<!-- Init steps -->
		<xsl:variable name="new_steps_">
			<xsl:choose>
				<xsl:when test="$action = 'add'">
					<step id="add" screen-id="03.02.01.18.04"
						cred="vzcp.env.manage.services_and_files"
						security-obj-type="ve.vz.vt"
						screen-title="{sw:text('Add Rule')}"/>
				</xsl:when>
				<xsl:when test="$action = 'edit'">
					<step id="edit" screen-id="03.02.01.18.05"
						cred="vzcp.env.manage.services_and_files"
						security-obj-type="ve.vz.vt"
						screen-title="{sw:text('Edit Rule')}"/>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:variable name="new_steps_filtered">
				<xsl:copy-of
					select="exsl:node-set($new_steps_)/step[(not(@cred) or cred:check-context(@cred,@security-obj-type)) and (not(@platform) or (@platform = $platform))]"
				/>
			</xsl:variable>
			<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
			<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
			<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
			<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>
	</xsl:template>

	<!-- *********************************************************** -->
	<func:function name="local:final">
		<xsl:param name="data"/>
		<!-- prepare form data to rule structure -->
		<xsl:variable name="rule-for-operation-rtf">
			<rule>
				<xsl:copy-of select="$data/*[not(position)]"/>
			</rule>
		</xsl:variable>
		<xsl:variable name="rule-for-operation" select="exsl:node-set($rule-for-operation-rtf)"/>
		<func:result>
			<xsl:choose>
				<xsl:when test="$action = 'add'">
					<xsl:if test="error:is-empty()">
						<xsl:if
							test="cred:detail-check-env('vzcp.env.manage.services_and_files',$eid)"/>
					</xsl:if>
					<xsl:choose>
						<xsl:when test="error:is-empty()">
							<xsl:copy-of select="fwm:rule-add($fwm-rules,$rule-for-operation,$data/position)"/>
						</xsl:when>
						<xsl:otherwise>
							<packet/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="$action = 'edit'">
					<xsl:if test="error:is-empty()">
						<xsl:if
							test="cred:detail-check-env('vzcp.env.manage.services_and_files',$eid)"/>
					</xsl:if>
					<xsl:choose>
						<xsl:when test="error:is-empty()">
							<xsl:copy-of select="fwm:rule-edit($fwm-rules,$rule-for-operation)"/>
						</xsl:when>
						<xsl:otherwise>
							<packet/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
			</xsl:choose>
		</func:result>
	</func:function>

	<!-- check input host/mask -->
	<func:function name="local:check-addr">
		<xsl:param name="addr"/>
		<xsl:param name="direction"/>
		<xsl:if test="$addr/host">
			<!-- start check and parse ip/mask only if input is  not empty -->
			<xsl:choose>
				<xsl:when test="not($addr/host != '')">
					<xsl:choose>
						<xsl:when test="$direction = 'source'">
							<xsl:if test="error:put(sw:text('Please specify a source IP address.'),'','src-addr')"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:if
								test="error:put(sw:text('Please specify a destination IP address.'),'','dst-addr')"
							/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="not(check:ip($addr/host))">
					<xsl:choose>
						<xsl:when test="$direction = 'source'">
							<xsl:if
								test="error:put( sw:text('Please correct the source IP address.'),'','src-addr')"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:if
								test="error:put( sw:text('Please correct the destination IP address.'),'','dst-addr')"
							/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="$addr/mask">
					<!-- check mask -->
					<xsl:choose>
						<xsl:when test="not($addr/mask != '')">
							<xsl:choose>
								<xsl:when test="$direction = 'source'">
									<xsl:if
										test="error:put(sw:text('Please specify a source network mask.'),'','src-addr')"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:if
										test="error:put(sw:text('Please specify a destination network mask.'),'','dst-addr')"
									/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:when>
						<xsl:when test="not(check:ip($addr/mask))">
							<!-- check ip mask validity -->
							<xsl:choose>
								<xsl:when test="$direction = 'source'">
									<xsl:if
										test="error:put( sw:text('Please correct the source network mask.'),'','src-addr')"
									/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:if
										test="error:put( sw:text('Please correct the destination network mask.'),'','dst-addr')"
									/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:when>
					</xsl:choose>
				</xsl:when>
			</xsl:choose>
		</xsl:if>
		<func:result select="error:is-empty()"/>
	</func:function>

	<!-- check input port or portrange -->
	<func:function name="local:check-ports">
		<xsl:param name="ports"/>
		<xsl:param name="direction"/>
		<xsl:if test="$ports/first_port">
			<xsl:choose>
				<xsl:when test="not($ports/first_port != '') and not($ports/last_port)">
					<xsl:choose>
						<xsl:when test="$direction = 'source'">
							<xsl:if test="error:put(sw:text('Please specify a source port.'),'','src-ports')"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:if test="error:put(sw:text('Please specify a destination port.'),'','dst-ports')"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="not($ports/first_port != '') and $ports/last_port">
					<xsl:choose>
						<xsl:when test="$direction = 'source'">
							<xsl:if test="error:put(sw:text('Please specify the first source port.'),'','src-ports')"
							/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:if
								test="error:put(sw:text('Please specify the first destination port.'),'','dst-ports')"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="not(check:port($ports/first_port))">
					<xsl:choose>
						<xsl:when test="$direction = 'source'">
							<xsl:if
								test="error:put( sw:text('Please correct the source port - it must be an integer ranging from 1 to 65535.'),'','src-ports')"
							/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:if
								test="error:put( sw:text('Please correct the destination port - it must be an integer ranging from 1 to 65535.'),'','dst-ports')"
							/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="$ports/last_port">
					<xsl:choose>
						<xsl:when test="$ports/last_port = ''">
							<xsl:choose>
								<xsl:when test="$direction = 'source'">
									<xsl:if
										test="error:put(sw:text('Please specify the last source port.'),'','src-ports')"
									/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:if
										test="error:put(sw:text('Please specify the last destination port.'),'','dst-ports')"
									/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:when>
						<xsl:when test="not(check:port($ports/last_port))">
							<!-- check last port validity -->
							<xsl:choose>
								<xsl:when test="$direction = 'source'">
									<xsl:if
										test="error:put( sw:text('Please correct the last source port - it must be an integer ranging from 1 to 65535.'),'','src-ports')"
									/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:if
										test="error:put( sw:text('Please correct the last destination port - it must be an integer ranging from 1 to 65535.'),'','dst-ports')"
									/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:when>
						<xsl:when test="$ports/first_port &gt;= $ports/last_port">
							<xsl:choose>
								<xsl:when test="$direction = 'source'">
									<xsl:if
										test="error:put( sw:text('Please correct the source ports - the first port number must be lower than the second port number.'),'','src-ports')"
									/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:if
										test="error:put( sw:text('Please correct the destination ports values - the first port number must be less than the second port number.'),'','dst-ports')"
									/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:when>
					</xsl:choose>
				</xsl:when>
			</xsl:choose>
		</xsl:if>
		<func:result select="error:is-empty()"/>
	</func:function>

	<!-- credentials -->
	<sw:include href="/lib/cred.xsl"/>

	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/fwm.xsl"/>
	<sw:include href="/lib/vza/fwm.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
