<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl func wiz cred error check local fwm fwm-util env"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:fwm="http://www.swsoft.com/xsl/cp/fwm"
	xmlns:fwm-util="http://www.swsoft.com/xsl/cp/fwm-util"
	xmlns:check="http://www.swsoft.com/xsl/cp/check"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
>

	<sw:include href="/lib/vt/env-core.xsl"/>

	<xsl:output method="xml"/>

	<xsl:variable name="eid" select="sw:ve-eid()"/>
	<xsl:variable name="env" select="env:get-env($eid)"/>
	<xsl:variable name="cr-normal"
		select="cred:check-env('vzcp.env.manage.services_and_files',$eid)"/>
	<xsl:variable name="cr-advanced"
		select="$cr-normal"/>
	<xsl:variable name="cur-mode" select="fwm-util:get-mode()"/>

	<xsl:variable name="check-cred">
		<xsl:choose>
			<xsl:when test="$cur-mode = 'normal' and not($cr-normal)">
				<xsl:if test="fwm-util:set-mode('advanced')"/>
				<!-- user like normal, but no cred. Redirect to advanced -->
				<packet>
					<cookie>
						<redirect>
							<xsl:value-of select="concat($baseurl,'/vzdir/infrman/envs/fwm/fwm')"/>
						</redirect>
					</cookie>
				</packet>
				<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
			</xsl:when>
			<xsl:when test="$cur-mode = 'advanced' and not($cr-advanced)">
				<!-- user like advanced, but no cred. Check fwm integrity as usual -->
				<xsl:if test="fwm-util:set-mode('normal')"/>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>

	<xsl:variable name="step" select="wiz:processing-step-id()"/>

	<xsl:param name="wiz_code" select="'ve-fwm-setup'"/>
	<xsl:variable name="form" select="local:init-form()"/>

	<xsl:template match="node()|@*">
		<xsl:choose>
			<xsl:when
				test="$step='setup'">
				<xsl:variable name="new_form_">
					<xsl:variable name="mode-policy"
						select="sw:split(sw:param('fwm-mode'),'-')"/>
					<mode>
						<xsl:value-of select="$mode-policy[1]"/>
					</mode>
					<policy>
						<xsl:value-of select="$mode-policy[2]"/>
					</policy>
					<reset>
						<xsl:value-of
							select="sw:if(sw:param('reset') = 'reset','reset','none')"
						/>
					</reset>
					<need-reset>
						<xsl:value-of
							select="sw:if(sw:param('need-reset') = 'need-reset','need-reset','none')"
						/>
					</need-reset>
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
				<xsl:if test="sw:param('next')">
					<!-- CHECK DATA, handle special case: normal mode requested, but normal is inconsistens and no reset checked  -->
					<xsl:if
						test="$new_form/need-reset = 'need-reset' and $new_form/mode='normal' and $new_form/reset='none'">
						<packet>
							<cookie>
								<msg>
									<set-error>
										<short-desc>
											<sw:text>
							   				The Normal firewall mode option can be selected only together with the Reset the firewall option.
											</sw:text>
										</short-desc>
									</set-error>
								</msg>
								<redirect>
									<xsl:value-of
										select="concat($baseurl,'/vzdir/infrman/envs/fwm/setup?mode-selector=1')"/>
								</redirect>
							</cookie>
						</packet>
						<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
					</xsl:if>
				</xsl:if>

				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new_form"/>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>

		<xsl:copy/>
	</xsl:template>

	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
						<xsl:if test="error:is-empty()">
							<xsl:variable name="old-policy" select="fwm:get-default-policy()"/>
							<xsl:variable name="new-policy" select="$data/policy"/>
							<xsl:variable name="old-mode" select="fwm-util:get-mode()"/>
							<xsl:variable name="new-mode" select="$data/mode"/>
							<xsl:if test="$old-policy != $new-policy or $data/reset = 'reset'">
								<xsl:choose>
									<xsl:when test="$new-mode = 'advanced'">
										<xsl:if
											test="cred:detail-check-env('vzcp.env.manage.services_and_files',$eid)"
										/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:if
											test="cred:detail-check-env('vzcp.env.manage.services_and_files',$eid)"
										/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:if>
						</xsl:if>
						<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:copy-of select="local:final($data)"/>
								<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
							</xsl:when>
							<xsl:otherwise>
								<packet/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

	<func:function name="local:init-form">
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:init-new"/>				
 		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>
 	
	<xsl:template name="local:init-new">

		<xsl:variable name="new_form">
			<policy>
				<!-- get real policy from system -->
				<xsl:value-of select="fwm:get-default-policy()"/>
			</policy>
			<mode>
				<!-- restore mode from private area -->
				<xsl:value-of select="fwm-util:get-mode()"/>
			</mode>
			<reset>
				<!-- applyed only for normal mode, not reset by default -->
				<xsl:value-of select="'none'"/>
			</reset>
		</xsl:variable>
		<!-- Init steps -->
		<xsl:variable name="new_steps_">
			<!-- need check cred while show radio button selector , later. No check cred here -->
			<step id="setup" screen-id="03.02.01.18.06" screen-title="{sw:text('Firewall Setup')} "/>
		</xsl:variable>

		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:variable name="new_steps_filtered">
				<xsl:copy-of
					select="exsl:node-set($new_steps_)/step[(not(@cred) or cred:check(@cred)) and (not(@platform) or (@platform = $platform))]"
				/>
			</xsl:variable>
			<xsl:variable name="new_steps" select="exsl:node-set($new_steps_filtered)"/>
			<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
			<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
			<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>
	</xsl:template>

	<!-- *********************************************************** -->
	<func:function name="local:final">
		<xsl:param name="data"/>
		<xsl:variable name="set-result-rtf">
			<mode-set>
				<xsl:value-of select="sw:if(fwm-util:set-mode($data/mode),1,0)"/>
			</mode-set>
			<policy-set>
				<xsl:copy-of select="fwm:set-default-policy($data/policy)"/>
			</policy-set>
		</xsl:variable>
		<xsl:variable name="set-result" select="exsl:node-set($set-result-rtf)"/>
		<xsl:variable name="operation-ok"
			select="$set-result/mode-set = 1 and $set-result/policy-set/packet/cookie/msg/set-ok"/>
		<xsl:variable name="return-packet-rtf">
			<packet>
				<cookie>
					<xsl:choose>
						<xsl:when test="$operation-ok">
							<xsl:call-template name="format-ok-message">
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:when>
						<xsl:when test="not($operation-ok)">
							<xsl:call-template name="format-fail-message">
								<xsl:with-param name="data" select="$data"/>
								<xsl:with-param name="set-result" select="$set-result"/>
							</xsl:call-template>
						</xsl:when>
					</xsl:choose>
				</cookie>
			</packet>
		</xsl:variable>
		<func:result select="exsl:node-set($return-packet-rtf)"/>
	</func:function>

	<xsl:template name="format-ok-message">
		<xsl:param name="data"/>
		<xsl:choose>
			<xsl:when test="$data/mode = 'normal' and $data/reset = 'reset'">
				<msg>
					<set-ok>
						<sw:text>
							The firewall is now managed in the normal mode. The default set of access rules has been restored.
						</sw:text>
					</set-ok>
				</msg>
				<redirect>
					<xsl:value-of select="concat($baseurl,'/vzdir/infrman/envs/fwm/simple?reset=1')"/>
				</redirect>
			</xsl:when>
			<xsl:when test="$data/mode = 'normal' and $data/reset = 'none'">
				<msg>
					<set-ok>
						<sw:text>
							The firewall is now managed in the normal mode.
						</sw:text>
					</set-ok>
				</msg>
				<redirect>
					<xsl:value-of select="concat($baseurl,'/vzdir/infrman/envs/fwm/simple')"/>
				</redirect>
			</xsl:when>
			<xsl:when test="$data/mode = 'advanced'">
				<msg>
					<set-ok>
						<sw:text>
							<xsl:with-param name="default-policy-name"
								select="$fwm-default-policy/policy[value = $data/policy]/title"
							/>
							The firewall is now managed in the advanced mode with %{default-policy-name} as the default policy.
						</sw:text>
					</set-ok>
				</msg>
				<redirect>
					<xsl:value-of select="concat($baseurl,'/vzdir/infrman/envs/fwm/fwm')"/>
				</redirect>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="format-fail-message">
		<xsl:param name="data"/>
		<xsl:param name="set-result"/>
		<msg>
			<xsl:choose>
				<xsl:when test="$data/mode = 'normal' and $set-result/mode-set = 0">
					<set-error>
						<short-desc>
							<sw:text>Failed to set the normal firewall mode.</sw:text>
						</short-desc>
						<detail>
							<sw:text>Failed to save the firewall settings to the Container private area.</sw:text>
						</detail>
					</set-error>
				</xsl:when>
				<xsl:when
					test="$data/mode = 'normal' and $set-result/policy-set/packet/cookie/msg/set-error">
					<set-error>
						<short-desc>
							<sw:text>Failed to set the normal firewall mode.</sw:text>
						</short-desc>
						<detail>
							<xsl:copy-of select="$set-result/policy-set/packet/cookie/msg/set-error/detail"/>
						</detail>
					</set-error>
				</xsl:when>
				<xsl:when test="$data/mode = 'advanced' and $set-result/mode-set = 0">
					<set-error>
						<short-desc>
							<sw:text>
								<xsl:with-param name="default-policy-name"
									select="$fwm-default-policy/policy[value = $data/policy]/title"
								/>
									Failed to set the advanced firewall mode with the default policy of %{default-policy-name}.
							</sw:text>
						</short-desc>
						<detail>
							<sw:text>Failed to save the firewall settings to the Container private area.</sw:text>
						</detail>
					</set-error>
				</xsl:when>
				<xsl:when
					test="$data/mode = 'advanced' and $set-result/policy-set/packet/cookie/msg/set-error">
					<set-error>
						<short-desc>
							<sw:text>
								<xsl:with-param name="default-policy-name"
									select="$fwm-default-policy/policy[value = $data/policy]/title"
								/>
									Failed to set the advanced firewall mode with the default policy of %{default-policy-name}.
							</sw:text>
						</short-desc>
						<detail>
							<xsl:copy-of select="$set-result/policy-set/packet/cookie/msg/set-error/detail"/>
						</detail>
					</set-error>
				</xsl:when>
			</xsl:choose>
		</msg>
		<redirect>
			<xsl:value-of select="concat($baseurl,'/vzdir/infrman/envs/fwm/setup?mode-selector=1')"/>
		</redirect>
	</xsl:template>

	<!-- credentials -->
	<sw:include href="/lib/cred.xsl"/>

	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/fwm.xsl"/>
	<sw:include href="/lib/vza/fwm.xsl"/>
	<sw:include href="/lib/vt/env-private.xsl"/>

</xsl:stylesheet>
