<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred local func env"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:fwm="http://www.swsoft.com/xsl/cp/fwm"
	xmlns:fwm-util="http://www.swsoft.com/xsl/cp/fwm-util"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:func="http://exslt.org/functions"
	xmlns:voc="http://www.swsoft.com/xsl/cp/voc"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
>

	<sw:include href="/lib/vt/env-core.xsl"/>

	<xsl:output method="xml"/>

	<xsl:variable name="eid" select="sw:ve-eid()"/>
	<xsl:variable name="env" select="env:get-env($eid)"/>

	<xsl:template match="/">
		<!-- for group operations -->
		<xsl:variable name="fwm-simple-rule-uniq-id"
			select="sw:param('fwm-simple-rule-uniq-id')"/>
		<xsl:variable name="cr-fwm-simple"
			select="cred:check-env('vzcp.env.manage.services_and_files',$eid)"/>

		<!-- action here -->
		<xsl:variable name="doRuleDelete"
			select="sw:param('fwm-rule-delete')"/>
		<xsl:variable name="doReset" select="string(sw:param('reset'))"/>
		<xsl:variable name="doAction" select="$doRuleDelete or $doReset"/>

		<xsl:variable name="fwm-simple-rules-raw">
			<xsl:choose>
				<xsl:when test="$cr-fwm-simple">
					<xsl:choose>
						<xsl:when test="not($doAction)">
							<!-- recalc rules only if no action specified -->
							<xsl:call-template name="fwm-calc-simple-rules"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:copy-of select="sw:sesget('fwm-simple-rules')"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="/.."/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="fwm-simple-rules" select="exsl:node-set($fwm-simple-rules-raw)"/>
		<!-- raw rules calc as side-effect for fwm-simple-rules. -->
		<xsl:variable name="fwm-rules" select="sw:sesget('fwm-rules')"/>
		<!-- calc that simple rule consistens -->
		<xsl:variable name="fwm-simple-consistens">
			<xsl:variable name="fwm-system-default-policy" select="fwm:get-default-policy()"/>
			<xsl:variable name="diff-between-rulesset-and-raw"
				select="count($fwm-simple-rules/set[selected]/rule) - count($fwm-rules/chain/rule)"/>
			<xsl:value-of
				select="sw:if($fwm-system-default-policy = 'DROP' and $diff-between-rulesset-and-raw = 0,1,0)"
			/>
		</xsl:variable>

		<!-- for check low level error -->
		<xsl:variable name="oper-problem" select="voc:check-operation('firewallm')"/>
		<xsl:variable name="fmw-list" select="fwm:get()"/>

		<xsl:choose>
			<!-- check top firewall premissions before execute request -->
			<xsl:when test="not($cr-fwm-simple)">
				<packet/>
			</xsl:when>

			<xsl:when test="$oper-problem != ''">
				<!-- vzenv in not correct state (not run at least)-->
				<packet>
					<cookie>
						<redirect>
							<xsl:value-of select="concat($baseurl,'/vzdir/infrman/envs/fwm/setup')"/>
						</redirect>
					</cookie>
				</packet>
				<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
			</xsl:when>

			<xsl:when test="$fmw-list/error">
				<!-- fwm return error -->
				<packet>
					<cookie>
						<redirect>
							<xsl:value-of select="concat($baseurl,'/vzdir/infrman/envs/fwm/setup')"/>
						</redirect>
					</cookie>
				</packet>
				<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
			</xsl:when>

			<xsl:when test="($fwm-simple-consistens != 1) and ($doReset != 1)">
				<!-- simple rule not consistent -->
				<packet>
					<cookie>
						<redirect>
							<xsl:value-of select="concat($baseurl,'/vzdir/infrman/envs/fwm/setup')"/>
						</redirect>
					</cookie>
				</packet>
				<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
			</xsl:when>

			<!-- delete one or group rules  -->
			<xsl:when test="$doRuleDelete">
				<xsl:if test="error:is-empty()">
					<xsl:if
						test="cred:detail-check-env('vzcp.env.manage.services_and_files',$eid)"/>
				</xsl:if>
				<xsl:choose>
					<xsl:when test="error:is-empty()">
						<xsl:copy-of
							select="fwm:simple-rule-delete($fwm-rules,$fwm-simple-rules,$fwm-simple-rule-uniq-id)"
						/>
					</xsl:when>
					<xsl:otherwise>
						<packet/>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:call-template name="finish-action"/>
			</xsl:when>

			<!-- delete all rules and setup policy to DROP -->
			<xsl:when test="$doReset">
				<xsl:choose>
					<xsl:when test="error:is-empty()">
						<xsl:copy-of select="fwm:simple-rule-reset($fwm-simple-rules,'default')"/>
					</xsl:when>
					<xsl:otherwise>
						<packet/>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:call-template name="finish-action"/>
			</xsl:when>
			<xsl:otherwise>
				<packet/>
				<xsl:if test="fwm-util:set-mode('normal')"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="finish-action">
		<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
	</xsl:template>

	<!-- credentials -->
	<sw:include href="/lib/cred.xsl"/>

	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/vza/fwm.xsl"/>
	<sw:include href="/lib/fwm.xsl"/>
	<sw:include href="/lib/vt/env-private.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
