
<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl func wiz local cred check vzenv voc envm action tem vzaconfig system env-samplem"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:check="http://www.swsoft.com/xsl/cp/check"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:request="http://www.swsoft.com/xsl/cp/request"	
	xmlns:form="http://www.swsoft.com/xsl/cp/form"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:tem="http://www.swsoft.com/xsl/cp/tem"
	xmlns:vt="http://www.swsoft.com/xsl/cp/vt"
	xmlns:hn="http://www.swsoft.com/xsl/cp/hn"	
	xmlns:vzenv="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"	
	xmlns:envm="http://www.swsoft.com/xsl/cp/envm"
	xmlns:env-samplem="http://www.swsoft.com/xsl/cp/env-samplem"
	xmlns:voc			="http://www.swsoft.com/xsl/cp/voc"
	xmlns:action="http://www.swsoft.com/xsl/cp/action"
	xmlns:vzaconfig="http://www.swsoft.com/xsl/cp/vzaconfig"
	xmlns:system="http://www.swsoft.com/xsl/cp/system"
	xmlns:ips		="http://www.swsoft.com/xsl/cp/ips"	
	xmlns:authm="http://www.swsoft.com/xsl/cp/authm"
>

	<!-- Import required modules -->
	<sw:include href="/lib/core/check-funcs.xsl"/>	
	<sw:include href="/lib/swa/system.xsl"/>
	<sw:include href="/lib/swa/authm.xsl"/>
	<sw:include href="/lib/swa/envm.xsl"/>
	<sw:include href="/lib/swa/env-samplem.xsl"/>
	<sw:include href="/lib/utils/action.xsl"/>

	<sw:include href="/lib/vt/env-core.xsl"/>	
	<sw:include href="/lib/vt/hn-core.xsl"/>
	
	<sw:include href="/lib/vz/ips.xsl"/>	
	<sw:include href="/lib/vz/vzenv-net-core.xsl"/>
	<sw:include href="/lib/vz/vzenv-net-ui.xsl"/>
	<sw:include href="/lib/vz/vzenv-net.xsl"/>
	<sw:include href="/lib/vz/vzenv-os.xsl"/>
	<sw:include href="/lib/vz/vzenv-qos.xsl"/>

	<!-- Import required modules -->

	<xsl:output method="xml"/>

	<xsl:variable name="step" select="wiz:processing-step-id()"/>

	<xsl:param name="wiz_code" select="'migrate-ve'"/>

	<xsl:variable name="form" select="local:init-form()"/>

	<xsl:template match="node()|@*">

		<xsl:choose>
			<!-- Step "Start" -->
			<xsl:when test="$step='start'">

				<!-- Read HN Selection -->
				<xsl:variable name="hn-eid" select="sw:param('hn')"/>
				<xsl:variable name="hn-rtf">
					<xsl:if test="$hn-eid!=''">
						<xsl:copy-of select="env:eid2info($hn-eid)"/>
					</xsl:if>
				</xsl:variable>
				<xsl:variable name="hn" select="exsl:node-set($hn-rtf)"/>	
				<xsl:variable name="vzconfig" select="envm:get-vt-settings($hn-eid)"/>
				<xsl:variable name="vzaconfig" select="system:get-configuration($hn-eid)"/>
				
		
				<!-- Restore form's data  -->
				<xsl:variable name="restored_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="name()='connect' or self::hn-def"/>
							<xsl:when test="name()='hw' or self::hn"/>
							<xsl:when test="name()='ve'"/>
							<xsl:when test="name()='warning'"/>
							<xsl:when test="name()='ve-qos'"/>
							<xsl:when test="name()='ve-qos-precalc'"/>
							<xsl:when test="name()='distr'"/>
							<xsl:when test="name()='distr-precalc'"/>
							<xsl:when test="name()='paths'"/>
							<xsl:when test="name()='paths-req'"/>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<ve>
						<xsl:variable name="first-ve-id" select="$vzconfig/parameter[id='vzprivrange']/value"/>		
						<ve_id>
							<xsl:choose>
								<xsl:when test="$first-ve-id!=''">
									<xsl:value-of select="number(substring-after($first-ve-id,' ')+1)"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="101"/>
								</xsl:otherwise>
							</xsl:choose>
						</ve_id>					
					</ve>
					<hn>
						<xsl:copy-of select="$hn"/>
					</hn>
					<hn-def>
						<xsl:if test="$vzconfig/parameter[id='slm']/value='yes'">
							<slm-hw-enabled/>
						</xsl:if>
						<end_veid>
							<xsl:value-of select="$vzaconfig/packet/data/global/configuration/pool/user_veid_range/end_veid"/>
						</end_veid>					
						<disk-quota-enabled>
							<xsl:value-of select="sw:if($vzconfig/parameter[id='disk_quota']/value='yes','true','false')"/>
						</disk-quota-enabled>
						<ve_private>
							<xsl:value-of select="$vzconfig/parameter[id='ve_private']/value"/>
						</ve_private>
						<xsl:for-each select="voc:get('relocator', env:make-platform-ref($hn-eid))[id='p2v_supported_filesystems']/data">
							<disk-supported-fs>
								<xsl:value-of select="."/>
							</disk-supported-fs>
						</xsl:for-each>
					</hn-def>
					<connect>
						<ip>
							<xsl:value-of select="sw:param('ip')"/>
						</ip>
						<user>
							<xsl:value-of select="sw:param('user')"/>
						</user>
						<password>
							<xsl:value-of select="sw:param('password')"/>
						</password>
					</connect>
				</xsl:variable>
				<xsl:variable name="restored_form" select="exsl:node-set($restored_form_)"/>
				<!-- /Restore form's data  -->

				<xsl:if test="sw:param('back')">
					<!-- Move to back -->
					<xsl:if test="wiz:goBack()"/>
					<xsl:if test="sw:sesput($wiz_data,$restored_form)"/>
				</xsl:if>
				<xsl:if test="sw:param('next')">

					<!-- Check data -->
					<!-- Check HN -->
					<xsl:if test="not($restored_form/hn/eid!='')">
						<xsl:if test="error:put(sw:text('You should select the Destination Node.'),'','hn')"/>
					</xsl:if>
					<!-- /Check HN -->
					<!-- Check Passwords -->
					<xsl:choose>
						<xsl:when
							test="not(string($restored_form/connect/password)) and not(string($restored_form/connnect/password))">
							<!-- check password presence -->
							<xsl:value-of
								select="error:put(sw:text('The password field must not be empty.'),'','password')"/>
						</xsl:when>
					</xsl:choose>
					<!-- Check User Name -->
					<xsl:choose>
						<xsl:when test="string($restored_form/connect/user)=''">
							<xsl:if test="error:put(sw:text('You should specify the user name.'),'','user')"/>
						</xsl:when>
					</xsl:choose>
					<!-- @Check data -->
					<!-- Check IP -->
					<xsl:choose>
						<xsl:when test="string($restored_form/connect/ip)=''">
							<xsl:if test="error:put(sw:text('You should specify an IP address.'),'','ip')"/>
						</xsl:when>
					</xsl:choose>
					<!-- @Check data -->

					<xsl:choose>
						<!-- Move to next step -->
						<!-- Try To Connect to HW -->
						<xsl:when test="error:is-empty()">
						
							<!-- Distribute agent -->
							<xsl:if test="error:is-empty()">
								<xsl:variable name="distribute-res" select="
									local:distribute-agent($restored_form/hn,$restored_form/connect)
								"/>
								<xsl:if test="$distribute-res[error|system/error]">
									<xsl:if
										test="error:put(sw:text('Error distributing VZagent to the physical server.'),$distribute-res/error/message|$distribute-res/system/error/message)"
									/>
								</xsl:if>
							</xsl:if>
							<!-- /Distribute agent -->

							<!-- Connect to Node -->
							<xsl:variable name="connect-id">
								<xsl:if test="error:is-empty()">
									<xsl:variable name="connect-res" select="local:connect-box($restored_form/hn,$restored_form/connect)"/>
									
									<xsl:choose>
										<xsl:when test="$connect-res[error|system/error]">
											<xsl:if
												test="error:put(sw:text('Error connecting to the physical server.'),$connect-res/error/message|$connect-res/system/error/message)"
											/>
										</xsl:when>
										<xsl:when test="$connect-res/system/id">
											<xsl:value-of select="$connect-res/system/id"/>
										</xsl:when>
										<xsl:otherwise>
											<sw:die>
												Unknown packet.<xsl:copy-of select="$connect-res"/>
											</sw:die>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:if>
							</xsl:variable>
							<!-- /Connect to Node -->
		
							<!-- Requist Node Info -->
							<xsl:variable name="node-info">
								<xsl:if test="error:is-empty()">
									<xsl:variable name="node-res" select="local:get-node-info($restored_form/hn,$connect-id)"/>
									<hw>
										<id>
											<xsl:value-of select="$connect-id"/>
										</id>
										<xsl:choose>
											<xsl:when test="$node-res[error|system/error]">
												<xsl:if
													test="error:put(sw:text('Error requesting the physical server system information.'),$node-res/error/message|$node-res/system/error/message)"
												/>
											</xsl:when>
											<xsl:when test="$node-res/computerm/system">
												<xsl:copy-of select="$node-res/computerm/system"/>
												<xsl:copy-of select="$node-res/computerm/disk"/>
												<xsl:copy-of select="$node-res/computerm/network"/>
											</xsl:when>
											<xsl:otherwise>
												<sw:die>
													Unknown packet <xsl:copy-of select="$node-res"/>
												</sw:die>
											</xsl:otherwise>
										</xsl:choose>
									</hw>
								</xsl:if>
							</xsl:variable>
							<!-- /Requist Node Info -->

							<!-- Request Node VE Config -->
							<xsl:variable name="node-ve-conf">
								<xsl:if test="error:is-empty()">
									<xsl:variable name="info" select="local:get-server-conf($restored_form/hn,$connect-id)"/>
									<xsl:choose>
										<xsl:when test="$info/vzarelocator/config">
											<xsl:if test="$info/vzarelocator/warning">
												<warning>
													<xsl:copy-of select="$info/vzarelocator/warning/message"/>
												</warning>
											</xsl:if>
											<paths>
												<xsl:for-each select="$info/vzarelocator/exclude[discardable='1']/path">
													<path>
														<xsl:value-of select="sw:base64-decode(.)"/>
													</path>
												</xsl:for-each>
											</paths>
											<paths-req>
												<xsl:for-each select="$info/vzarelocator/exclude[discardable='0']/path">
													<path>
														<xsl:value-of select="sw:base64-decode(.)"/>
													</path>
												</xsl:for-each>
											</paths-req>
											<ve>
												<xsl:copy-of select="$info/vzarelocator/config/hostname"/>
												<net>
													<xsl:call-template name="vzenv:env2net">
														<xsl:with-param name="env" select="$info/vzarelocator"/>
														<xsl:with-param name="hn-platform" select="$restored_form/hn/platform"/>
														<xsl:with-param name="reset-mac-addresses" select="true()"/>
													</xsl:call-template>
												</net>
												<os_template/>
											</ve>
											<ve-other>
												<xsl:copy-of
													select="$info/vzarelocator/config/*[not(
														self::net_device or self::hostname or self::base_set
														or self::qos or self::ip or self::address
														or self::distribution or self::offline_management or self::disabled
													)]"
												/>
											</ve-other>
											<ve-qos-precalc>
												<xsl:for-each select="$info/vzarelocator/config/qos">
													<res>
														<xsl:copy-of select="*"/>
														<soft_src>
															<xsl:value-of select="soft"/>
														</soft_src>
														<hard_src>
															<xsl:value-of select="hard"/>
														</hard_src>
													</res>
												</xsl:for-each>
											</ve-qos-precalc>
											<xsl:variable name="distr-ver"
												select="$info/vzarelocator/config/distribution/version"/>
											<xsl:variable name="distr-id"
												select="concat(
													$info/vzarelocator/config/distribution/name,
													sw:if($distr-ver!='',concat('-',$distr-ver),'')
												)"/>
											<distr>
												<xsl:value-of select="$distr-id"/>
											</distr>
											<distr-precalc>
												<xsl:value-of select="$distr-id"/>
											</distr-precalc>
										</xsl:when>
										<xsl:otherwise>
											<xsl:if
												test="error:put(sw:text('Error getting the physical server system configuration.'),$info/vzarelocator/error/message)"
											/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:if>
							</xsl:variable>
							<!-- /Request Node VE Config -->


							<!-- Store new session data -->
							<xsl:variable name="new_form_">
								<xsl:if test="$connect-id!=''">
									<xsl:copy-of select="$node-info"/>
									<xsl:copy-of select="$node-ve-conf"/>
								</xsl:if>
								<xsl:copy-of select="$restored_form"/>
							</xsl:variable>
							<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>

							<xsl:if test="sw:sesput($wiz_data,$new_form)"/>
							<xsl:choose>
								<xsl:when test="error:has-errors()"> </xsl:when>
								<xsl:otherwise>
								
									<xsl:if test="wiz:setStepEnabled('prepare_hw',$new_form/hn/linux)"/>
									<xsl:if test="wiz:setStepEnabled('prepare_hw_windows',$new_form/hn/windows)"/>									
									<xsl:if test="wiz:setStepEnabled('config',true())"/>
									<xsl:if test="wiz:setStepEnabled('custom',true())"/>
																		
									<!-- Store data and go to the next step -->
									<xsl:call-template name="local:goNext">
										<xsl:with-param name="data" select="$new_form"/>
									</xsl:call-template>
								</xsl:otherwise>
							</xsl:choose>

						</xsl:when>
						<!-- @Move to next step -->

						<xsl:otherwise>
							<!-- Store data and stay on current step -->
							<xsl:if test="sw:sesput($wiz_data,$restored_form)"/>
						</xsl:otherwise>

					</xsl:choose>

				</xsl:if>

			</xsl:when>

			<!-- Step "Review HW" -->
			<xsl:when
				test="$step='review_hw'">

				<!-- Restore form's data  -->
				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="name()='review_hw'"/>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
				<!-- /Restore form's data  -->

				<xsl:if test="sw:param('back')">
					<!-- Move to back -->
					<xsl:if test="wiz:goBack()"/>
				</xsl:if>
				<xsl:if test="sw:param('next')">
					<!-- Check data -->
					<!-- Move to next step -->
					<xsl:choose>
						<xsl:when test="error:is-empty()">
							<xsl:if test="wiz:goNext()"/>
						</xsl:when>
					</xsl:choose>
				</xsl:if>
				<xsl:value-of select="sw:sesput($wiz_data,$new_form)"/>
			</xsl:when>

			<!-- Step "Prepare HW" -->
			<xsl:when
				test="$step='prepare_hw' and string(sw:param('step'))=$step">

				<!-- Restore form's data  -->
				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="name()='review_hw'"/>
							<xsl:when test="name()='paths'"/>
							<xsl:when test="name()='services'"/>
							<xsl:when test="name()='distr'"/>
							<xsl:when test="name()='quota'"/>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<distr>
						<xsl:value-of
							select="normalize-space(sw:param('distr'))"/>
					</distr>
					<quota>
						<partition>
							<xsl:value-of
								select="normalize-space(sw:param('quota_partition'))"
							/>
						</partition>
					</quota>
					<paths>
						<xsl:call-template name="form:restore-list">
							<xsl:with-param name="code" select="'paths'"/>
							<xsl:with-param name="row-node-name" select="''"/>
						</xsl:call-template>
					</paths>
					<services>
						<xsl:for-each select="/http_request/*[self::post or self::get]/parameter[starts-with(name,'srv_')]/value">
							<srv>
								<xsl:value-of select="."/>
							</srv>
						</xsl:for-each>
					</services>
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
				<!-- /Restore form's data  -->

				<xsl:if test="sw:param('back')">
					<!-- Move to back -->
					<xsl:if test="wiz:goBack()"/>
				</xsl:if>
				<xsl:if test="sw:param('next')">
					<!-- Check data -->
					<!-- Check distr presence -->
					<xsl:choose>
						<xsl:when test="string($new_form/distr)=''">
							<xsl:if test="error:put(sw:text('You should specify the Linux OS distribution.'),'','distr')"/>
						</xsl:when>
					</xsl:choose>
					<!-- Move to next step -->
					<xsl:choose>
						<xsl:when test="error:is-empty()">
							<xsl:if test="wiz:goNext()"/>
						</xsl:when>
					</xsl:choose>
				</xsl:if>
				<xsl:value-of select="sw:sesput($wiz_data,$new_form)"/>
			</xsl:when>

			<!-- Step "Prepare HW" on WIN32 -->
			<xsl:when
				test="$step='prepare_hw_windows'">

				<!-- Restore form's data  -->
				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="name()='review_hw'"/>
							<xsl:when test="name()='paths'"/>
							<xsl:when test="name()='services'"/>
							<xsl:when test="name()='distr'"/>
							<xsl:when test="name()='quota'"/>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<paths>
						<xsl:for-each select="$form/hw/disk/partition[fs_type=$form/hn-def/disk-supported-fs]">
							<xsl:variable name="id" select="string(mount_point)"/>
							<xsl:if
								test="$id!='C:\' and not(sw:param('disk-id')=$id)">
								<path>
									<xsl:value-of select="$id"/>
								</path>
							</xsl:if>
						</xsl:for-each>
					</paths>
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
				<!-- /Restore form's data  -->

				<xsl:if test="sw:param('back')">
					<!-- Move to back -->
					<xsl:if test="wiz:goBack()"/>
				</xsl:if>
				<xsl:if test="sw:param('next')">
					<!-- Check data -->
					<!-- Move to next step -->
					<xsl:choose>
						<xsl:when test="error:is-empty()">
							<xsl:if test="wiz:goNext()"/>
						</xsl:when>
					</xsl:choose>
				</xsl:if>
				<xsl:value-of select="sw:sesput($wiz_data,$new_form)"/>
			</xsl:when>


			<!-- Step "Configure VE" -->
			<xsl:when
				test="$step='config'">

				<!-- Restore form's data  -->
				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="name()='ve'"/>
							<xsl:when test="name()='ve-qos'"/>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<xsl:variable name="template-id-name"
						select="string(sw:param('config'))"/>
					<xsl:variable name="template-id" 		select="string(sw:split($template-id-name,'|')[1])"/>
					<xsl:variable name="template-name"	select="string(sw:split($template-id-name,'|')[2])"/>					
					<xsl:variable name="template-old-id" select="$form/ve/template-id"/>
					<ve>
						<name><xsl:value-of select="normalize-space(sw:param('name'))"/></name>
						<slm>
							<xsl:value-of select="sw:param('slm')"/>
						</slm>
						<template-id>
							<xsl:value-of select="$template-id"/>
						</template-id>
						<template-name>
							<xsl:value-of select="$template-name"/>
						</template-name>						
						<ask_veid>
							<xsl:value-of select="sw:param('ask_veid')"/>
						</ask_veid>
						<ve_id>
							<xsl:value-of
								select="normalize-space(sw:param('ve_id'))"
							/>
						</ve_id>
						<show_adv>
							<xsl:value-of select="sw:param('show_adv')"/>
						</show_adv>
						<hostname>
							<xsl:value-of
								select="normalize-space(sw:param('hostname'))"
							/>
						</hostname>
						<custom>
							<xsl:value-of
								select="string(sw:param('custom'))"/>
						</custom>
						<custom-net>
							<xsl:value-of
								select="string(sw:param('custom_net'))"/>
						</custom-net>
						<xsl:copy-of select="vzenv:restore-os()"/>
						<xsl:copy-of select="$form/ve/net"/>
					</ve>
					<ve-qos>
						<xsl:choose>
							<!-- use precalculated QoS -->
							<xsl:when test="$template-id=''">
								<xsl:copy-of select="$form/ve-qos-precalc/*"/>
							</xsl:when>
							<!-- template was not changed, use old QoS -->
							<xsl:when test="$template-id=$template-old-id">
								<xsl:copy-of select="$form/ve-qos/*"/>
							</xsl:when>
							<!-- copy QoS from template -->
							<xsl:otherwise>
								<xsl:variable name="config" select="env-samplem:get-sample($template-id)"/>
								<xsl:for-each select="$config/env_config/qos">
									<res>
										<xsl:copy-of select="*"/>
										<soft_src>
											<xsl:value-of select="soft"/>
										</soft_src>
										<hard_src>
											<xsl:value-of select="hard"/>
										</hard_src>
									</res>
								</xsl:for-each>
							</xsl:otherwise>
						</xsl:choose>
					</ve-qos>
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
				<!-- /Restore form's data  -->

				<!-- Turn Custom steps On/Off -->
				<xsl:if test="wiz:setStepEnabled('custom',$new_form/ve/custom='1')"/>
				<xsl:if test="wiz:setStepEnabled('net',$new_form/ve/custom-net='1')"/>

				<xsl:if test="sw:param('back')">
					<!-- Move to back -->
					<xsl:if test="wiz:goBack()"/>
				</xsl:if>
				<xsl:if test="sw:param('next')">
					<!-- Check data -->
					<!-- Check name presence -->
					<xsl:if test="vzenv:check-ve-name($new_form/ve/name,$new_form/hn/eid)"/>
					<!-- Check hostname presence -->
					<xsl:choose>
						<xsl:when test="string($new_form/ve/hostname)=''">
							<xsl:if test="error:put(sw:text('You should specify a hostname.'),'','hostname')"/>
						</xsl:when>
						<xsl:when
							test="not(check:hostname(env:make-platform-ref($new_form/hn/eid,$new_form/platform),$new_form/ve/hostname))">
							<xsl:if test="error:put(sw:text('The hostname is invalid.'),'','hostname')"/>
						</xsl:when>
					</xsl:choose>
					<!-- Check VE ID-->
					<xsl:if test="string($new_form/ve/ask_veid)!=''">
						<xsl:if
							test="vzenv:check-ve-id( $new_form/ve/ve_id, $new_form/hn/eid, $new_form/hn-def/end_veid  )"/>
					</xsl:if>
					<!-- Move to next step -->
					<xsl:choose>
						<xsl:when test="error:is-empty()">
							<xsl:if test="wiz:goNext()"/>
						</xsl:when>
					</xsl:choose>
				</xsl:if>
				<xsl:value-of select="sw:sesput($wiz_data,$new_form)"/>
			</xsl:when>

			<!-- Step "Configure VE(windows)" -->
			<xsl:when
				test="$step='config_windows'">

				<xsl:variable name="ask_veid"
					select="sw:if(sw:param('id_type')='set','1','')"/>

				<!-- Restore form's data  -->
				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="name()='ve'"/>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<ve>
						<name><xsl:value-of select="normalize-space(sw:param('name'))"/></name>
						<ask_veid>
							<xsl:value-of select="$ask_veid"/>
						</ask_veid>
						<ve_id>
							<xsl:value-of
								select="normalize-space(sw:param('ve_id'))"
							/>
						</ve_id>
					</ve>
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
				<!-- /Restore form's data  -->

				<xsl:if test="sw:param('back')">
					<!-- Move to back -->
					<xsl:if test="wiz:goBack()"/>
				</xsl:if>
				<xsl:if test="sw:param('next')">
					<!-- Check data -->
					<!-- Check name presence -->
					<xsl:if test="vzenv:check-ve-name($new_form/ve/name,$new_form/hn/eid)"/>					
					<!-- Check VE ID-->
					<xsl:if test="string($new_form/ve/ask_veid)!=''">
						<xsl:if	test="vzenv:check-ve-id( $new_form/ve/ve_id, $new_form/hn/eid, $new_form/hn-def/end_veid )"/>
					</xsl:if>
					<!-- Move to next step -->
					<xsl:choose>
						<xsl:when test="error:is-empty()">
							<xsl:if test="wiz:goNext()"/>
						</xsl:when>
					</xsl:choose>
				</xsl:if>
				<xsl:value-of select="sw:sesput($wiz_data,$new_form)"/>
			</xsl:when>

			<!-- Step "Custom QoS" -->
			<xsl:when
				test="$step='custom' and string(sw:param('step'))=$step">

				<xsl:variable name="platform-ref" select="env:make-platform-ref($form/hn/eid)"/>

				<!-- Restore form's data  -->
				<xsl:variable name="new_form_">
					<xsl:copy-of select="$form/*[not(self::ve-qos)]"/>
					<ve-qos>
						<xsl:copy-of select="sw:restoreQoS($platform-ref,$form/ve-qos)"/>
					</ve-qos>
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>				
				<!-- /Restore form's data  -->
				
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<!-- Move to back -->
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
					<xsl:when test="sw:param('validate')">
						<!-- Validate QoS -->
						<xsl:if test="sw:checkQoS($platform-ref,$new_form/ve-qos)"/>
					</xsl:when>
					<xsl:when test="sw:param('next')">
						<!-- Check data -->
						<xsl:if test="sw:checkQoS($platform-ref,$new_form/ve-qos)"/>
						<!-- Move to next step -->
						<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:if test="wiz:goNext()"/>
							</xsl:when>
						</xsl:choose>
					</xsl:when>
				</xsl:choose>

				<!-- Store form values-->
				<xsl:value-of select="sw:sesput($wiz_data,$new_form)"/>

			</xsl:when>
			
			<!-- Step "Network Interfaces" -->
			<xsl:when test="$step='net'">
			
				<!-- Restore form's data  -->
				<xsl:variable name="new-form-rtf">
					<xsl:copy-of select="$form/*[not(self::ve)]"/>
					<ve>
						<xsl:copy-of select="$form/ve/*[not(self::net)]"/>
						<net>
							<xsl:call-template name="vzenv:restore-net-ifaces">
								<xsl:with-param name="env-form" select="$form"/>
								<xsl:with-param name="ve-net" select="$form/ve/net"/>	
								<xsl:with-param name="options-rtf">
									<exclude-hostname/>
								</xsl:with-param>															
							</xsl:call-template>
						</net>
					</ve>
				</xsl:variable>
				<!-- /Restore form's data  -->					
				
				<xsl:variable name="new-form" select="exsl:node-set($new-form-rtf)"/>
								
				<!-- Check data -->
				<xsl:choose>					
					<xsl:when test="sw:param('next')">
						<xsl:call-template name="vzenv:check-net-ifaces">
							<xsl:with-param name="env-form" select="$new-form"/>
							<xsl:with-param name="ve-net" select="$new-form/ve/net"/>								
						</xsl:call-template>
					</xsl:when>
				</xsl:choose>
					
				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new-form"/>
				</xsl:call-template>
					
			</xsl:when>
			<!-- /Step "Network Interfaes" -->			
			

			<!-- Step "Confirmation" -->
			<xsl:when	test="$step='final'">

				<!-- Restore form's data  -->
				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="name()='final'"/>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<final>
						<start>
							<xsl:value-of
								select="string(sw:param('start'))"/>
						</start>
					</final>
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
				<!-- /Restore form's data  -->

				<xsl:if test="sw:param('back')">
					<!-- Move to back -->
					<xsl:if test="wiz:goBack()"/>
				</xsl:if>
				<xsl:if test="sw:param('next')">
					<!-- Check data -->
					<!-- Move to next step -->
					<xsl:choose>
						<xsl:when test="error:is-empty()">
							<xsl:call-template name="local:goNext">
								<xsl:with-param name="data" select="$new_form"/>
							</xsl:call-template>
						</xsl:when>
					</xsl:choose>
				</xsl:if>
				<xsl:value-of select="sw:sesput($wiz_data,$new_form)"/>
			</xsl:when>
		</xsl:choose>

		<xsl:copy/>
	</xsl:template>

	<xsl:template name="local:goNext">
		<xsl:param name="data"/>
		<!--|-->
		<xsl:choose>
			<xsl:when test="wiz:isLastStep()">

				<xsl:choose>
					<xsl:when test="error:is-empty()">
						<!-- Final -->

						<xsl:call-template name="local:sendFinalPacket">
							<xsl:with-param name="data" select="$data"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<packet/>
					</xsl:otherwise>
				</xsl:choose>

			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="wiz:goNext()"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<func:function name="local:init-form">
		<sw:noauth-redirect select="not(cred:check('vzcp.env.import'))"/>
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:init-new"/>				
 		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>
 	
	<xsl:template name="local:init-new">
			<!-- Init steps -->
			<xsl:variable name="all_steps_">
				<step id="start" screen-id="03.02.01.04.00"/>
				<step id="review_hw" screen-id="03.02.01.04.01"/>
				<!-- windows-specific -->
				<step id="prepare_hw_windows" screen-id="03.02.01.04.02"/>
<!--		<step id="config_windows" screen-id="03.02.01.04.03"/>
-->					
				<!-- linux-specific -->
				<step id="prepare_hw" screen-id="03.02.01.04.02"/>
				<!--|-->					
				<step id="config" screen-id="03.02.01.04.03"/>
				<step id="custom" screen-id="03.02.01.04.04"/>
				<step id="net" screen-id="03.02.01.04.06"/>
				<step id="final" screen-id="03.02.01.04.05"/>
			</xsl:variable>

			<!-- Init Step -->
			<xsl:variable name="new_step">
				<xsl:choose>
					<xsl:when test="string(sw:param('tab'))!=''">
						<xsl:value-of select="string(sw:param('tab'))"/>
					</xsl:when>
					<xsl:otherwise>start</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
			<xsl:variable name="new_steps"
				select="exsl:node-set($all_steps_)/step"/>

			<!-- Init default data -->
			<!-- /Init default data -->

			<!-- Prepare data -->
			<xsl:variable name="new_form">
				<hn>
					<eid>
						<xsl:value-of select="sw:if(sw:hn-eid()!='' and env:get-env(sw:hn-eid())/env/status/state!=$env-state/unexist ,sw:hn-eid(),sw:master-eid())"/>
					</eid>
				</hn>
				<hw>
					<id/>
					<name>local</name>
					<!-- TODO: set real local node -->
				</hw>
				<connect>
					<ip/>
					<user>
					</user>
					<password/>
				</connect>
				<def>
					<xsl:if test="ips:pool-enabled()">
						<ips-pool-enabled/>
					</xsl:if>
				</def>
			</xsl:variable>

			<!-- Save wizard initial settings -->
			<xsl:if test="error:is-empty()">
				<xsl:if test="sw:sesput($wiz_data,$new_form)"/>
				<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
				<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
			</xsl:if>
	</xsl:template>


	<xsl:template name="local:sendFinalPacket">
		<xsl:param name="data"/>

		<xsl:call-template name="action:make-packet">
			<xsl:with-param name="path" select="'actions/vzdir/infrman/envs/import.xsl'"/>
			<xsl:with-param name="cookie">
				<msg>
					<sched>The server migration into a Container has been scheduled</sched>
					<error>Failed to migrate the server into a Container.</error>
				</msg>
				<operation>import_ve</operation>
				<redirect-prev/>
			</xsl:with-param>
			<xsl:with-param name="input">
				<data>
					<node>
						<connect-id>
							<xsl:value-of select="$data/hw/id"/>
						</connect-id>
						<ip>
							<xsl:value-of select="$data/connect/ip"/>
						</ip>
						<user>
							<xsl:value-of select="$data/connect/user"/>
						</user>
						<password>
							<xsl:value-of select="$data/connect/password"/>
						</password>
						<exclude-paths>
							<xsl:copy-of select="$data/paths/*"/>
							<xsl:copy-of select="$data/paths-req/*"/>
						</exclude-paths>
						<xsl:copy-of select="$data/distr"/>
						<stop-services>
							<xsl:copy-of select="$data/services/*"/>
						</stop-services>
						<xsl:copy-of select="$data/quota"/>
					</node>
					<xsl:copy-of select="$data/hn"/>
					<xsl:copy-of select="$data/ve"/>
					<xsl:copy-of select="$data/ve-qos"/>
					<xsl:copy-of select="$data/final/start"/>
					<xsl:copy-of select="$data/ve-other"/>
				</data>
			</xsl:with-param>
		</xsl:call-template>
		<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
	</xsl:template>
	
	
	<!-- ****************** Internal Functions ************************* -->
	
	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>		
		<!--|-->				
		<xsl:choose>
			<xsl:when test="(sw:param('next') or sw:param('ok')) and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep() or sw:param('ok')">
    				<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
								<xsl:copy-of select="local:sendFinalPacket($data)"/>
								<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>	
							</xsl:when>
		          <xsl:otherwise>
              	<packet/>
            	</xsl:otherwise>
          	</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>
					
	</xsl:template>	
	
	<!-- Setup connection to Linux Box and return the EID of this node s-->
	<func:function name="local:connect-box">
		<xsl:param name="hn"/>
		<xsl:param name="connect"/>
		
		<xsl:variable name="req">
			<packet timeout="{$config/vzcpcon/timeout/vz_p2v_asknode}">
				<!--<dst> 
					<host><xsl:value-of select="$hn/eid"/></host>
				</dst>-->
				<data>
					<system>
						<connect>
							<conn_info>
								<address><xsl:value-of select="$connect/ip"/></address>
								<login>
									<xsl:copy-of select="authm:auth-name($connect/user, $env:empty-eid)"/>
								</login>
								<password>
									<xsl:value-of select="sw:base64-encode($connect/password)"/>
								</password>
							</conn_info>
						</connect>
					</system>
				</data>
				<vzcpauth/>
			</packet>
		</xsl:variable>
		<xsl:variable name="res" select="sw:xchg($req)"/>
		<func:result select="$res/packet/data"/>
	</func:function>

	<!-- Ask VZA about Linux Box ID -->
	<func:function name="local:distribute-agent">
		<xsl:param name="hn"/>
		<xsl:param name="connect"/>
		<xsl:variable name="req">
			<packet timeout="{$config/vzcpcon/timeout/vz_p2v_asknode}">
				<dst> 
					<host><xsl:value-of select="$hn/eid"/></host>
				</dst>	
				<data>
					<system>
						<distribute>
							<dst>
								<address><xsl:value-of select="$connect/ip"/></address>
								<login>
									<xsl:copy-of select="authm:auth-name($connect/user)"/>
								</login>
								<password>
									<xsl:value-of select="sw:base64-encode($connect/password)"/>
								</password>
							</dst>
						</distribute>
					</system>
				</data>
			</packet>
		</xsl:variable>
		<func:result select="sw:xchg($req)/packet/data"/>
	</func:function>

	<!-- Ask VZA about Linux Box System Info-->
	<func:function name="local:get-node-info">
		<xsl:param name="hn"/>	
		<xsl:param name="connect-id"/>
		<xsl:variable name="req">
			<packet timeout="{$config/vzcpcon/timeout/vz_p2v_asknode}">
				<target><xsl:value-of select="$connect-id"/></target>		
				<dst>
					<!--<host><xsl:value-of select="$hn/eid"/></host>-->
					<target>computerm</target>
				</dst>
				<data>
					<computerm>
						<get_system/>
						<get_disk/>
						<get_network/>
					</computerm>
				</data>
				<vzcpauth/>
			</packet>
		</xsl:variable>
		<func:result select="sw:xchg($req)/packet/data"/>
	</func:function>

	<!-- Ask VZA about Linux Box QoS-->
	<func:function name="local:get-server-conf">
		<xsl:param name="hn"/>		
		<xsl:param name="connect-id"/>

		<xsl:variable name="req">
			<packet timeout="{$config/vzcpcon/timeout/vz_p2v_asknode}">
				<target><xsl:value-of select="$connect-id"/></target>
				<dst>
					<!--<host><xsl:value-of select="$hn/eid"/></host>-->
					<target>vzarelocator</target>
				</dst>
				<data>
					<vzarelocator>
						<calc_env_config/>
					</vzarelocator>
				</data>
				<vzcpauth/>
			</packet>
		</xsl:variable>

		<func:result select="sw:xchg($req)/packet/data"/>

	</func:function>


	<!-- credentials -->
	<sw:include href="/lib/cred.xsl"/>

	<sw:include href="/lib/vza/tem.xsl"/>
	<sw:include href="/lib/vzaconfig.xsl"/>

	<sw:include href="/lib/vocabulary.xsl"/>

	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>


</xsl:stylesheet>
