<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred check local error action ve env vzenv envm system"
	xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl			="http://exslt.org/common"
	xmlns:sw				="http://www.swsoft.com/xsl/cp"
	xmlns:error			="http://www.swsoft.com/xsl/cp/error"
	xmlns:check			="http://www.swsoft.com/xsl/cp/check"
	xmlns:wiz				="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local			="http://www.swsoft.com/xsl/cp/local"
  xmlns:func			="http://exslt.org/functions"	
	xmlns:cred			="http://www.swsoft.com/xsl/cp/cred"
	xmlns:action		="http://www.swsoft.com/xsl/cp/action"	
	xmlns:env				="http://www.swsoft.com/xsl/cp/env"	
	xmlns:ve				="http://www.swsoft.com/xsl/cp/ve"		
	xmlns:vzenv			="http://www.swsoft.com/xsl/cp/vzenv"	
	xmlns:envm			="http://www.swsoft.com/xsl/cp/envm"	
	xmlns:system		="http://www.swsoft.com/xsl/cp/system"
	xmlns:ips				="http://www.swsoft.com/xsl/cp/ips"	
>

	<!-- UI modules -->
	<sw:include href="/lib/wizard.xsl"/>
	
	<!-- System modules -->
	<sw:include href="/lib/cred-filter.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/utils/action.xsl"/>			
	
	<!-- Import required modules -->
	<sw:include href="/lib/swa/envm.xsl"/>
	<sw:include href="/lib/swa/system.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vt/ve-core.xsl"/>	
	<sw:include href="/lib/vz/ips.xsl"/>	
	<sw:include href="/lib/vz/vzenv-core.xsl"/>	
	<sw:include href="/lib/vz/vzenv-net.xsl"/>
	<sw:include href="/lib/vz/vzenv-net-ui.xsl"/>	
	<sw:include href="/lib/vz/vzenv-net-core.xsl"/>	
	<!-- Import required modules -->

	<xsl:output method="xml"/>
	
  <xsl:variable name="step" select="wiz:processing-step-id()"/>

	<xsl:param name="wiz_code" select="'ves_list_clone'"/>
 	<xsl:variable name="form" select="local:init-form()"/>

	<xsl:template match="node()|@*">
		<xsl:choose>
			<xsl:when test="not($step!='')">
				<xsl:choose>
					<xsl:when test="count($form/env) = 0">
						<xsl:if 
							test="error:put(sw:text('No Containers have been selected or you are not authorized to clone the selected Containers.'),'')"/>
						<packet>
							<cookie>
								<redirect-last/>
							</cookie>
						</packet>
						<xsl:if test="sw:response('lib/opredirect.xsl')"/>
					</xsl:when>
					<xsl:when test="count($form/env) = 1">
						<xsl:if test="vzenv:set-current($form/env/src/eid,true(),'current')"/>
						<packet>
							<cookie>
								<redirect>/vz/cp/vzdir/infrman/envs/clone</redirect>
							</cookie>
						</packet>
						<xsl:if test="sw:response('lib/opredirect.xsl')"/>
					</xsl:when>
				</xsl:choose>
			</xsl:when>
			<!-- Step "Clone" -->
			<xsl:when test="$step='clone'">
						
					<xsl:variable name="data" select="$request/http_request/*[self::post or self::get]/parameter[starts-with(name,'__')]"/>
					
					<xsl:variable name="new_form_">
						<xsl:copy-of select="$form/*[not(self::clone or self::env)]"/>
						<clone>							
							<start><xsl:value-of select="sw:if(sw:param('start')='1','true','false')"/></start>
						</clone>
						<xsl:for-each select="$form/env">
							<xsl:variable name="env" select="."/>
							<xsl:variable name="index" select="position()"/>
							<env>
								<xsl:copy-of select="src"/>
								<hostname>
									<xsl:value-of select="normalize-space(sw:param(concat('hostname_',$index)))"/>
								</hostname>
								<name>
									<xsl:value-of select="normalize-space(sw:param(concat('name_',$index)))"/>
								</name>
								<net>
									<routed>
										<xsl:copy-of select="local:restore-iface($env/net/routed,$index)"/>
									</routed>
									<bridged>
										<xsl:for-each select="$env/net/bridged/iface">
											<iface>
												<xsl:copy-of select="local:restore-iface(.,$index)"/>
											</iface>
										</xsl:for-each>
									</bridged>
								</net>
							</env>
						</xsl:for-each>
					</xsl:variable>
					<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
					
					<xsl:if test="sw:param('next')">
						<!-- CHECK DATA -->	
						<xsl:for-each select="$new_form/env">
							<xsl:variable name="env" select="."/>
							<xsl:variable name="index" select="position()"/>
							<!-- check hostname -->
							<xsl:variable name="platform-ref" select="env:make-platform-ref($env/src/hn-eid,$env/src/platform)"/>
							<xsl:if test="vzenv:check-ves-hostname($platform-ref,.,$index,$env/title)"/>
							<!-- check name -->
					  	<xsl:if test="vzenv:check-ve-name(name,$env/src/hn-eid,'',concat('name_',$index))"/>
					  	<!-- Check IP addresses -->
					  	<xsl:if test="local:check-iface($env/net/routed,$env)"/>
							<xsl:for-each select="$env/net/bridged/iface">
								<xsl:if test="local:check-iface(.,$env)"/>
							</xsl:for-each>
						</xsl:for-each>
						<!-- /CHECK DATA -->
					</xsl:if>
					
					<xsl:call-template name="local:completeFormHandling">
						<xsl:with-param name="data" select="$new_form"/>
					</xsl:call-template>
					
			</xsl:when>		
			
		</xsl:choose>
		
		<xsl:copy/>	
	</xsl:template>
	
	<func:function name="local:restore-iface">
		<xsl:param name="iface"/>
		<xsl:param name="ve-index"/>

		<func:result>
			<xsl:for-each select="$iface">
			
				<xsl:variable name="code" select="concat( sw:if(self::routed,'routed','bridged'), '_ip_',$ve-index,'_',index,'_')"/>
						
				<xsl:choose>
					<xsl:when test="not(to-edit)">
						<xsl:copy-of select="*"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="*[not(self::ips)]"/>
						<ips>
							<xsl:copy-of select="ips/ip[not(to-edit)]"/>
							<!-- Cycle on ip -->
							<xsl:for-each select="ips/ip[to-edit]">
								<ip>
									<xsl:copy-of select="*[not(self::address or self::mask)]"/>
									<xsl:copy-of select="vzenv:restore-ip(concat($code,index))"/>
								</ip>
							</xsl:for-each>
							<!-- /Cycle on ip -->							
						</ips>
					</xsl:otherwise>
				</xsl:choose>
			
			</xsl:for-each>
		</func:result>
	</func:function>
	
	
	<func:function name="local:check-iface">
		<xsl:param name="iface"/>
		<xsl:param name="env"/>		

		<xsl:for-each select="$iface[to-edit]">
			<xsl:variable name="code" select="concat( sw:if(self::routed,'routed','bridged'), '_ip_',index,'_')"/>
			<xsl:for-each select="ips/ip[to-edit]">
				<xsl:call-template name="vzenv:check-ip">
					<xsl:with-param name="ip" select="."/>
					<xsl:with-param name="hn-platform" select="$env/src/platform"/>
					<xsl:with-param name="code" select="concat($code,index)"/>
					<xsl:with-param name="pool-enabled" select="$form/def/ips-pool-enabled"/>
				</xsl:call-template>
			</xsl:for-each>			
		</xsl:for-each>
	</func:function>
	
	
	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->		
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
    				<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
								<xsl:copy-of select="local:get-final-packet($data)"/>
								<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>	
							</xsl:when>
		          <xsl:otherwise>
              	<packet/>
            	</xsl:otherwise>
          	</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>
					
	</xsl:template>
	
	<func:function name="local:init-form">
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:init-new"/>				
 		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>
 	
	<xsl:template name="local:init-new">
		<!-- Init default data -->
		<xsl:variable name="valid-eids" 
			select="cred:filter-valid-env('vzcp.env.clone',ve:post2eids(),false())"/>

		<xsl:variable name="eids" select="ve:eids2nodes($valid-eids)"/>
		<xsl:variable name="envs" select="ve:eids2nodes($valid-eids)"/>
		
		<xsl:variable name="new_form">						
			<def>
				<xsl:copy-of select="$eids"/>
				<xsl:if test="ips:pool-enabled()">
					<ips-pool-enabled/>
				</xsl:if>				
			</def>
			<xsl:for-each select="$eids">
				<xsl:variable name="env" select="env:get-env(.)/env"/>
				<xsl:variable name="env-info" select="env:env2info($env)"/>
				<xsl:variable name="index" select="position()"/>				
				<xsl:variable name="net-rtf">
					<xsl:call-template name="vzenv:env2net">
						<xsl:with-param name="env" select="$env"/>
						<xsl:with-param name="hn-platform" select="$env-info/platform"/>
						<xsl:with-param name="reset-mac-addresses" select="true()"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:variable name="net" select="exsl:node-set($net-rtf)"/>
				<env>
					<src>
						<xsl:copy-of select="$env-info/*"/>
						<!--<net>
							<xsl:copy-of select="$net-rtf"/>
						</net>-->
					</src>
					<hostname>
					</hostname>
					<name>
						<xsl:value-of select="concat('cloned ',$env-info/title)"/>
					</name>
					<net>
						<routed>
							<xsl:copy-of select="local:iface2edit($net/routed,1)"/>
						</routed>
						<bridged>
							<xsl:for-each select="$net/bridged/iface">
								<iface>
									<xsl:copy-of select="local:iface2edit(.,position())"/>
								</iface>
							</xsl:for-each>
						</bridged>
					</net>
				</env>
			</xsl:for-each>
		</xsl:variable>
		<!-- Init steps -->
		<xsl:variable name="new_steps_">
			<step id="clone" screen-id="03.02.01.31.08"/>			
		</xsl:variable>
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
			<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
			<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
			<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>
	</xsl:template>
	
	<func:function name="local:iface2edit">
		<xsl:param name="iface"/>
		<xsl:param name="index"/>

			
		<func:result>
			<xsl:for-each select="$iface">
			
				<xsl:variable name="is-routed" select="boolean(self::routed)"/>
				<xsl:variable name="is-enabled" select="($is-routed and enabled='true') or (not($is-routed) and ../enabled='true')"/>
		
				<index><xsl:value-of select="$index"/></index>
				<xsl:copy-of select="*[not(self::ips)]"/>
				<xsl:choose>
					<xsl:when test="$is-enabled and ips/ip[address!='' and (
						($is-routed and address!=$def-ip-auto-vzcp) or ( not($is-routed) and not($iface/dhcp='true') ) 
					)]">
						<to-edit/>
						<ips>
							<xsl:copy-of select="ips/*[not(self::ip)]"/>						
							<xsl:for-each select="ips/ip">
								<ip>
									<index><xsl:value-of select="position()"/></index>
									<xsl:copy-of select="*"/>
									<xsl:if test="address!='' and 
										($is-routed and address!=$def-ip-auto-vzcp) or 
										( not($is-routed) and  not($iface/dhcp='true') ) 
									">
										<to-edit/>
									</xsl:if>
								</ip>
							</xsl:for-each>
						</ips>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="ips"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
		</func:result>
	</func:function>
	
	<!-- *********************************************************** -->
	<func:function name="local:get-final-packet">
		<xsl:param name="data"/>
		<!--|-->
		<func:result>
			<xsl:call-template name="action:make-packet">
				<xsl:with-param name="path" select="'actions/vzdir/infrman/envs/group-change/clone.xsl'"/>
				<xsl:with-param name="cookie">
					<msg>
						<sched><sw:text>The Container(s) has/have been scheduled for cloning.</sw:text></sched>
						<error><sw:text>Failed to clone the Container(s).</sw:text></error>
					</msg>
					<operation>ve_groupchange_clone</operation>
					<redirect-prev/>
				</xsl:with-param>
				<xsl:with-param name="input">
					<data>
						<xsl:if test="$data/clone/start='true'">
							<start/>
						</xsl:if>
						<xsl:copy-of select="$data/env"/>
					</data>
				</xsl:with-param>
			</xsl:call-template>			
		</func:result>
	</func:function>
	  	
</xsl:stylesheet>
