<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred check local error action env ve hn vzenv envm hwm ips system"
	xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl			="http://exslt.org/common"
	xmlns:sw				="http://www.swsoft.com/xsl/cp"
	xmlns:error			="http://www.swsoft.com/xsl/cp/error"
	xmlns:check			="http://www.swsoft.com/xsl/cp/check"
	xmlns:wiz				="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local			="http://www.swsoft.com/xsl/cp/local"
  xmlns:func			="http://exslt.org/functions"	
	xmlns:cred			="http://www.swsoft.com/xsl/cp/cred"
	xmlns:action		="http://www.swsoft.com/xsl/cp/action"	
	xmlns:vt				="http://www.swsoft.com/xsl/cp/vt"		
	xmlns:env				="http://www.swsoft.com/xsl/cp/env"	
	xmlns:ve				="http://www.swsoft.com/xsl/cp/ve"	
	xmlns:hn				="http://www.swsoft.com/xsl/cp/hn"	
	xmlns:vzenv			="http://www.swsoft.com/xsl/cp/vzenv"	
	xmlns:envm			="http://www.swsoft.com/xsl/cp/envm"	
	xmlns:hwm				="http://www.swsoft.com/xsl/cp/hwm"	
	xmlns:vzaconfig	="http://www.swsoft.com/xsl/cp/vzaconfig"
	xmlns:ips				="http://www.swsoft.com/xsl/cp/ips"
	xmlns:system		="http://www.swsoft.com/xsl/cp/system"
>

	<!-- UI modules -->
	<sw:include href="/lib/wizard.xsl"/>
	
	<!-- System modules -->
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/utils/action.xsl"/>				
	
	<!-- VZA functionality modules -->	
	<sw:include href="/lib/vzaconfig.xsl"/>
	<sw:include href="/lib/vt/core.xsl"/>	
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vt/hn-core.xsl"/>
	<sw:include href="/lib/vt/ve-core.xsl"/>


	<!-- Import required modules -->
	<sw:include href="/lib/swa/envm.xsl"/>
	<sw:include href="/lib/swa/system.xsl"/>
	<sw:include href="/lib/vz/ips.xsl"/>
	<sw:include href="/lib/vz/vzenv-net.xsl"/>
	<!-- Import required modules -->

	<xsl:output method="xml"/>
	
	<xsl:variable name="step" select="wiz:processing-step-id()"/>

	<xsl:param name="wiz_code" select="'ves_list_migrate'"/>
 	<xsl:variable name="form" select="local:init-form()"/>

	<xsl:template match="node()|@*">
		<xsl:choose>
			<!-- Step "Migrate" -->
			<xsl:when test="$step='migrate'">
						
					<xsl:variable name="new_form_">
						<xsl:for-each select="$form/*">
							<xsl:choose>
								<xsl:when test="name()='migrate'"></xsl:when>
								<xsl:otherwise>
									<xsl:copy-of select="."/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
						<migrate>
							<options>
								<clean><xsl:value-of select="sw:param('clean')"/></clean>
								<notstart><xsl:value-of select="sw:param('notstart')"/></notstart>
								<force><xsl:value-of select="sw:param('force')"/></force>
								<zero><xsl:value-of select="sw:param('zero')"/></zero>
							</options>
							<xsl:for-each select="$form/def/hn">
								<xsl:variable name="name" select="concat('hn_',position())"/>
								<hn>
									<src><xsl:value-of select="eid"/></src>
									<dst><xsl:value-of select="sw:param($name)"/></dst>
								</hn>
							</xsl:for-each>
						</migrate>
					</xsl:variable>
					<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
					
					<xsl:if test="sw:param('next')">
						<!-- CHECK DATA -->
						<!-- Check HN-->
						<xsl:if test="not($new_form/migrate/hn[dst!=''])">
							<xsl:value-of select="error:put(sw:text('You should select at least one migration destination.'),'','hn')"/>
						</xsl:if>
						<!-- /Check HN -->
						<!-- /CHECK DATA -->
					</xsl:if>
					
					<xsl:call-template name="local:completeFormHandling">
						<xsl:with-param name="data" select="$new_form"/>
					</xsl:call-template>
					
			</xsl:when>			
			
		</xsl:choose>
		
		<xsl:copy/>
	</xsl:template>
	
	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->		
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
    				<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
								<xsl:copy-of select="local:get-final-packet($data)"/>
								<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>	
							</xsl:when>
		          <xsl:otherwise>
              	<packet/>
            	</xsl:otherwise>
          	</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>
					
	</xsl:template>
	
	<func:function name="local:init-form">
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:init-new"/>				
 		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>
 	
	<func:function name="local:eid2node">
		<xsl:variable name="rtf">
			<eid><xsl:value-of select="sw:ve-eid()"/></eid>
		</xsl:variable>
		<func:result select="exsl:node-set($rtf)/eid"/>
	</func:function>
	
	<xsl:template name="local:init-new">
		<!-- Init default data -->
		
		<xsl:variable name="env-src" select="sw:param('env-src')"/>		
		<xsl:variable name="eids" select="sw:if(
			$env-src='context',
			local:eid2node(),
			ve:eids2nodes(ve:post2eids())
		)"/>
		
		<xsl:variable name="envs" select="ve:eids2envs($eids)"/>
		
		<xsl:variable name="new_form">						
			<def>
				<xsl:copy-of select="$envs"/>
				<xsl:variable name="hns" select="env:get-env(ve:group-by-hn($envs))/env"/>
				<xsl:for-each select="$hns">
					<hn>
						<eid><xsl:value-of select="eid"/></eid>
						<hostname><xsl:value-of select="config/hostname"/></hostname>
						<platform><xsl:value-of select="hn:hn2platform(.)"/></platform>
						<title><xsl:value-of select="env:env2title(.)"/></title>
					</hn>
				</xsl:for-each>
			</def>			
		</xsl:variable>
		<!-- Init steps -->
		<xsl:variable name="new_steps_">
			<step id="migrate" screen-id="03.02.01.31.02"/>			
		</xsl:variable>
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
			<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
			<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
			<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>
	</xsl:template>
	
	<!-- *********************************************************** -->
	<func:function name="local:get-final-packet">
		<xsl:param name="data"/>
		<!--|-->
		<func:result>
			<xsl:call-template name="action:make-packet">
				<xsl:with-param name="path" select="'actions/vzdir/infrman/envs/group-change/migrate.xsl'"/>
				<xsl:with-param name="cookie">
					<msg>
						<sched><sw:text>The migration of the Container(s) has been scheduled.</sw:text></sched>
						<error><sw:text>Failed to migrate the Container(s).</sw:text></error>
					</msg>
					<operation>ve_groupchange_migrate</operation>
					<redirect-prev/>
				</xsl:with-param>
				<xsl:with-param name="input">
					<data>
						<xsl:copy-of select="$data/migrate"/>
						<xsl:copy-of select="$data/def/env[hn-eid=$data/migrate/hn[dst!='']/src]"/>
						<xsl:copy-of select="$data/def/hn"/>
					</data>
				</xsl:with-param>
			</xsl:call-template>
		</func:result>
	</func:function>
	  	
</xsl:stylesheet>
