<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl func wiz envm vzenv cred voc ips proc local xsi"
	xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:sw			="http://www.swsoft.com/xsl/cp"
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"	
	xmlns:error		="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz			="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:vzenv		="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:vt			="http://www.swsoft.com/xsl/cp/vt"
	xmlns:ve			="http://www.swsoft.com/xsl/cp/ve"
	xmlns:hn			="http://www.swsoft.com/xsl/cp/hn"	
	xmlns:env			="http://www.swsoft.com/xsl/cp/env"
	xmlns:envm		="http://www.swsoft.com/xsl/cp/envm"
	xmlns:func		="http://exslt.org/functions"
	xmlns:cred		="http://www.swsoft.com/xsl/cp/cred"
	xmlns:voc			="http://www.swsoft.com/xsl/cp/voc"
	xmlns:redirect="http://www.swsoft.com/xsl/cp/redirect"
	xmlns:ips			="http://www.swsoft.com/xsl/cp/ips"
	xmlns:system	="http://www.swsoft.com/xsl/cp/system"
	xmlns:proc		="http://www.swsoft.com/xsl/cp/proc"
	xmlns:vzapackagem	="http://www.swsoft.com/xsl/cp/vzapackagem"
	xmlns:xsi			="http://www.w3.org/2001/XMLSchema-instance"	
	xmlns:ts			="http://www.swsoft.com/xsl/cp/ts"
	xmlns:units 	="http://www.swsoft.com/xsl/cp/units"		
	xmlns:action	="http://www.swsoft.com/xsl/cp/action"
	xmlns:request ="http://www.swsoft.com/xsl/cp/request"	
	xmlns:math		="http://exslt.org/math"
	xmlns:set			="http://exslt.org/sets" 
	xmlns:ubcs  	="http://www.swsoft.com/xsl/cp/ubcs"
>

	<!-- Import required modules -->
	<sw:include href="/lib/swa/system.xsl"/>
	<sw:include href="/lib/swa/envm.xsl"/>

	<sw:include href="/lib/vt/core.xsl"/>
	<sw:include href="/lib/vt/ve-core.xsl"/>
	<sw:include href="/lib/vt/hn-core.xsl"/>

	<sw:include href="/lib/core/units-core.xsl"/>	
	<sw:include href="/lib/core/action-funcs.xsl"/>

	<sw:include href="/lib/vz/vzenv-apps.xsl"/>
	<sw:include href="/lib/vz/ips.xsl"/>
	<sw:include href="/lib/vz/vzenv-qos.xsl"/>
	<sw:include href="/lib/vz/vzenv-net-core.xsl"/>
	<sw:include href="/lib/vz/vzenv-net-ui.xsl"/>
	<sw:include href="/lib/vz/vzenv-os.xsl"/>
	<sw:include href="/lib/vz/vzenv-offline.xsl"/>

	<sw:include href="/lib/vza/vzapackagem.xsl"/>
	<sw:include href="/lib/ts.xsl"/>	

	<xsl:output method="xml"/>
	<xsl:param name="wiz_code" select="'manageve'"/>
	
  <xsl:variable name="step" select="wiz:processing-step-id()"/>	
  <xsl:variable name="form" select="local:init-form()"/>	

	<xsl:template match="node()|@*">
	
		<xsl:choose>
			<!-- Step "General Settings" -->
			<xsl:when
				test="$step='gen'">

				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="name()=$step"/>
							<xsl:when test="name()='capabilities'"/>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<capabilities>
						<xsl:copy-of select="vzenv:restore-net-capabilities($form/voc-capabilities)"/>
					</capabilities>
					<gen>
						<name>
							<xsl:value-of select="sw:param('name')"/>
						</name>
						<description>
							<xsl:value-of select="sw:param('description')"/>
						</description>
						<start_after_boot>
							<xsl:value-of select="sw:param('start_after_boot')"/>
						</start_after_boot>
						<offline_type>
							<xsl:value-of select="sw:param('offline_type')"/>
						</offline_type>
						<xsl:variable name="selected-services" select="sw:param('selected_offline_service')"/>
						<selected_offline_service>
							<xsl:for-each select="$selected-services">
								<value>
									<xsl:value-of select="."/>
								</value>
							</xsl:for-each>
						</selected_offline_service>
						<disabled>
							<xsl:value-of select="sw:if($form/ve-id=1,$form/gen/disabled,sw:param('disabled'))"/>
							<!-- don`t change for Service VE -->
						</disabled>
						<os_version>
							<xsl:choose>
								<!-- If OS Version control was enabled -->
								<xsl:when
									test="sw:param('os_version')!=''"
								>
									<xsl:value-of select="sw:param('os_version')"/>
								</xsl:when>
								<!-- If OS Version control was disabled -->
								<xsl:otherwise>
									<xsl:value-of select="$form/gen/os_version"/>
								</xsl:otherwise>
							</xsl:choose>
						</os_version>
						<show_adv>
							<xsl:value-of select="sw:param('show_adv')"/>
						</show_adv>
						<show_os>
							<xsl:value-of select="sw:param('show_os')"/>
						</show_os>
						<show_offline>
							<xsl:value-of	select="sw:param('show_offline')"/>
						</show_offline>
						<xsl:if test="$form/hn/windows">
							<tsmode>
								<xsl:value-of 
									select="sw:param('tsmode')"/>
							</tsmode>
							<tslicservers>
								<xsl:copy-of select="ts:restore-lic-servers()"/>
							</tslicservers>
						</xsl:if>						
					</gen>
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
				<xsl:if test="sw:param('back')">
					<!-- Move to back -->
					<xsl:if test="wiz:goBack()"/>
				</xsl:if>
				<xsl:if test="sw:param('next')">
					<!-- Check data -->
					<xsl:if test="vzenv:check-ve-name($new_form/gen/name,$new_form/hn/eid,$new_form/eid,'name',not($new_form/def/have_empty_name))"/>
				  <xsl:if test="$new_form/gen/offline_type = 'custom' and count($new_form/gen/selected_offline_service/value) = 0">
						<xsl:if test="error:put(sw:text('Select at least one service for custom offline management.'),'','selected_offline_service')"/>
					</xsl:if>
					<!-- Move to next step -->
					<xsl:choose>
						<xsl:when test="error:is-empty()">
							<xsl:if
								test="cred:detail-check-env('vzcp.env.manage.properties.preferences',$new_form/eid)"/>
							<xsl:choose>
								<xsl:when test="error:is-empty()">
									<xsl:copy-of select="vzenv:getFinalPacket($step,$new_form)"/>
									<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
								</xsl:when>
								<xsl:otherwise>
									<packet/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:when>
					</xsl:choose>
				</xsl:if>

				<!-- Store form values-->
				<xsl:variable name="res">
					<xsl:value-of select="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
				</xsl:variable>

			</xsl:when>

			<!-- Step "net" -->
			<xsl:when
				test="$step='net'">

				<!-- Restore form's data  -->
				<xsl:variable name="new_form_">
					<xsl:copy-of select="$form/*[not( self::net or self::net-flags )]"/>
					<net>
						<xsl:call-template name="vzenv:restore-net-ifaces">
							<xsl:with-param name="env-form" select="$form"/>
						</xsl:call-template>
					</net>
					<net-flags>
						<xsl:copy-of select="$form/net-flags/*"/>
						<xsl:if test="sw:param('new_iface') and not($form/net-flags/new-iface)">
							<new-iface/>
						</xsl:if>
						<xsl:if test="sw:param('restart_ve') and not($form/net-flags/restart-ve)">
							<restart-ve><xsl:value-of select="sw:param('restart_ve')"/></restart-ve>
						</xsl:if>
					</net-flags>
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
				<!-- /Restore form's data  -->

				<xsl:if test="sw:param('back')">
					<!-- Move to back -->
					<xsl:if test="wiz:goBack()"/>
				</xsl:if>
				<xsl:if test="sw:param('next')">
					<!-- Check data -->
					<xsl:call-template name="vzenv:check-net-ifaces">
						<xsl:with-param name="env-form" select="$new_form"/>
					</xsl:call-template>
					<!-- Move to next step -->
					<xsl:choose>
						<xsl:when test="error:is-empty()">
							<xsl:if
								test="cred:detail-check-env('vzcp.env.manage.properties.preferences',$new_form/eid)"/>
							<xsl:choose>
								<xsl:when test="error:is-empty()">
									<xsl:copy-of select="vzenv:getFinalPacket($step,$new_form)"/>
									<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
								</xsl:when>
								<xsl:otherwise>
									<packet/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:when>
					</xsl:choose>
				</xsl:if>

				<!-- Store form values-->
				<xsl:value-of select="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
			</xsl:when>

			<!-- Step "qos" -->
			<xsl:when test="$step='qos'">

				<xsl:variable name="platform-ref" select="env:make-platform-ref($form/hn/eid,$form/hn/platform)"/>

				<!-- Restore form's data  -->
				<xsl:variable name="qos" select="exsl:node-set(sw:restoreQoS($platform-ref,$form/qos))"/>
				<xsl:variable name="new_form_">
					<xsl:copy-of select="$form/*[not(self::qos)]"/>
					<qos>
						<xsl:copy-of select="$qos"/>
					</qos>
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
				<!-- /Restore form's data  -->

				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<!-- Move to back -->
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
					<xsl:when test="sw:param('validate')">
						<!-- Validate QoS -->
						<xsl:if test="sw:checkQoS($platform-ref,$qos,$form/qos-mode)"/>
					</xsl:when>
					<xsl:when test="sw:param('next')">
						<!-- Check data -->
						<xsl:if test="sw:checkQoS($platform-ref,$qos,$form/qos-mode)"/>
						<!-- Move to next step -->
						<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:if test="cred:detail-check-env('vzcp.env.manage.properties.preferences',$new_form/eid)"/>
								<xsl:choose>
									<xsl:when test="error:is-empty()">
										<xsl:copy-of select="vzenv:getFinalPacket($step,$new_form)"/>
										<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
									</xsl:when>
									<xsl:otherwise>
										<packet/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
						</xsl:choose>
					</xsl:when>
				</xsl:choose>

				<!-- Store form values-->
				<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
			</xsl:when>

			<!-- Sceen "Application" -->
			<xsl:when
				test="$step='apps'">

				<!-- Restore form's data  -->
				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="name()='apps'"/>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<apps>
						<xsl:copy-of select="vzenv:restore-apps()"/>
					</apps>
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
				<!-- /Restore form's data  -->

				<xsl:if test="sw:param('back')">
					<!-- Move to back -->
					<xsl:if test="wiz:goBack()"/>
				</xsl:if>
				<xsl:if test="sw:param('next')">
					<!-- Check data -->
					<xsl:if test="vzenv:check-apps($new_form/apps, $form/hn-eid)"/>
					<!-- Move to next step -->
					<xsl:choose>
						<xsl:when test="error:is-empty()">
							<xsl:if
								test="cred:detail-check-env('vzcp.env.manage.properties.application',$new_form/eid)"/>
							<xsl:choose>
								<xsl:when test="error:is-empty()">
									<xsl:copy-of select="vzenv:getFinalPacket($step,$new_form)"/>
									<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
								</xsl:when>
								<xsl:otherwise>
									<packet/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:when>
					</xsl:choose>
				</xsl:if>

				<!-- Store form values-->
				<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
			</xsl:when>

			<!-- Step "Apply VE Sample" -->
			<xsl:when
				test="$step='apply'">

				<!-- Restore form's data  -->
				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="name()='ve-template'"/>
							<xsl:when test="name()='apply'"/>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<apply>
						<restart>
							<xsl:choose>
								<xsl:when test="$form/hn/linux">
									<xsl:value-of	select="sw:param('restart')"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="$form/apply/restart"/>
								</xsl:otherwise>
							</xsl:choose>
						</restart>
						<options>
							<xsl:value-of select="sw:param('options')"/>
						</options>
					</apply>
					<ve-template>
						<id>
							<xsl:value-of	select="sw:param('id')"/>
						</id>
					</ve-template>
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
				<!-- /Restore form's data  -->

				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<!-- Move to back -->
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
					<xsl:when	test="sw:param('next')">
						<!-- Check data -->
						<xsl:if test="not($new_form/ve-template/id!='')">
							<xsl:if test="error:put(sw:text('You should select some Container sample.'),'','')"/>	
						</xsl:if>
						<!-- Move to next step -->
						<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:if test="cred:detail-check-env('vzcp.env.manage.properties.preferences',$new_form/eid)"/>
								<xsl:choose>
									<xsl:when test="error:is-empty()">
										<xsl:copy-of select="vzenv:getFinalPacket($step,$new_form)"/>
										<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
									</xsl:when>
									<xsl:otherwise>
										<packet/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
						</xsl:choose>
					</xsl:when>
				</xsl:choose>
			</xsl:when>

		</xsl:choose>

		<xsl:copy/>
				
	</xsl:template>
	
	<!-- Init form data -->
	<func:function name="local:init-form">
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:init-new"/>				
		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>	

	<!-- Init form default data -->
	<xsl:template name="local:init-new">
			
		<xsl:variable name="eid" select="sw:ve-eid()"/>
		<!-- Init steps -->
		<xsl:variable name="all_steps_">
			<step id="gen" screenid="03.02.01.03.00" title="{sw:text('Edit General Settings')}"/>
			<!-- Disabled due to wrong Configure QoS buttons function,baza@ 
				<xsl:variable name="qos-mode" select="sw:sesget('ve-resource-mode')"/>
			-->
			<xsl:variable name="qos-mode" select="'all'"/>				
			<xsl:choose>
				<xsl:when test="$qos-mode='cpu'">
					<step id="qos" screenid="03.02.01.03.07" title="{sw:text('Configure')}"/>
				</xsl:when>
				<xsl:when test="$qos-mode='disk'">
					<step id="qos" screenid="03.02.01.03.08" title="{sw:text('Configure')}"/>
				</xsl:when>
				<xsl:when test="$qos-mode='memory'">
					<step id="qos" screenid="03.02.01.03.09" title="{sw:text('Configure')}"/>
				</xsl:when>
				<xsl:otherwise>
					<step id="qos" screenid="03.02.01.03.01" title="{sw:text('Configure')}"/>
				</xsl:otherwise>
			</xsl:choose>
			<step id="net" screenid="03.02.01.03.13" title="{sw:text('Configure Network')}"/>
			<step id="apps" screenid="03.02.01.03.14" title="{sw:text('Add or Remove Applications')}"/>
			<step id="apply" screenid="03.02.01.03.04" title="{sw:text('Apply Sample to Container')}"/>
		</xsl:variable>
		<!-- Init Step -->
		<xsl:variable name="new_step">
			<xsl:choose>
				<xsl:when test="sw:param('tab')">
					<xsl:value-of select="string(sw:param('tab'))"/>
				</xsl:when>
				<xsl:otherwise>gen</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="new_steps"
			select="exsl:node-set($all_steps_)/step[@id=$new_step and (not(@cred) or cred:check-context(@cred,@security-obj-type)) ]"/>
		<!-- Check startup conditions -->
		<xsl:variable name="new_form">
			<sw:die test="count($new_steps)=0">
				Requested tab '<xsl:value-of select="$new_step"
				/>' is unknown for VE Management code.
			</sw:die>
			<sw:die test="$eid=''">
				VE ID should be specified.
			</sw:die>
			<xsl:call-template name="local:init-new-data">
				<xsl:with-param name="step" select="$new_step"/>
				<xsl:with-param name="eid" select="$eid"/>			
			</xsl:call-template>
		</xsl:variable>
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:variable name="saved_form" select="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
			<xsl:variable name="saved_steps" select="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:variable name="saved_step" select="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>

	</xsl:template>

	<!-- Fill wizard data  -->
	<xsl:template name="local:init-new-data">
		<xsl:param name="step"/>
		<xsl:param name="eid"/>

		<xsl:variable name="env" select="env:get-env($eid)/env"/>
		<xsl:variable name="hn-eid" select="$env/parent_eid"/>
		<xsl:variable name="hn-info" select="env:eid2info($hn-eid)"/>
		
		<!-- Load data for General Settings -->
		<xsl:variable name="config" select="$env/virtual_config"/>
		<xsl:choose>
			<xsl:when test="$step='gen'">

				<xsl:variable name="hw-ask">
					<get-redirect/>
				</xsl:variable>

				<xsl:variable name="installed-os" select="vzapackagem:get-env-templates($env)[vzapackagem:is-os(.)]"/>
				<!--|-->
				<xsl:variable name="voc-args">
					<category>capabilities</category>
				</xsl:variable>
				<xsl:variable name="voc" select="voc:get($voc-args, env:make-platform-ref($hn-eid))"/>
				<!--|-->
				<voc-capabilities>
					<xsl:copy-of select="$voc"/>
				</voc-capabilities>
				<capabilities>
					<xsl:copy-of select="$config/capability[value=1]"/>
				</capabilities>
				<!--|-->
				<xsl:variable name="ve-offline-service" select="$config/offline_service"/>
				<xsl:variable name="all-offline-service" select="redirect:load($hn-eid)"/>
				<xsl:variable name="offline-type" select="vzenv:get-offline-type($config/offline_management,$ve-offline-service)"/>
				<!--|-->
				<def>
					<all_offline_service>
						<xsl:copy-of select="$all-offline-service/service"/>
					</all_offline_service>
					<xsl:if test="not(string($config/name))">
						<have_empty_name/>
					</xsl:if>
				</def>
				<gen>
					<xsl:copy-of select="$config/*[self::name]"/>
					<description>
						<xsl:value-of select="sw:base64-decode($config/description)"/>
					</description>
					<start_after_boot>
						<xsl:value-of select="$config/on_boot"/>
					</start_after_boot>
					<selected_offline_service>
						<xsl:for-each select="$ve-offline-service">
							<value>
								<xsl:value-of select="."/>
							</value>
						</xsl:for-each>
					</selected_offline_service>
					<offline_type>
						<xsl:value-of select="$offline-type"/>
					</offline_type>
					<disabled>
						<xsl:value-of select="$config/disabled"/>
					</disabled>
					<os_version>
						<xsl:value-of select="$config/os_template/version"/>
					</os_version>
					<xsl:if test="$hn-info/windows">
						<tsmode>
							<xsl:value-of select="$config/ts_mode"/>
						</tsmode>
						<tslicservers>
							<xsl:for-each select="$config/ts_license_server">
								<tslicserver>
									<xsl:value-of select="."/>
								</tslicserver>
							</xsl:for-each>
						</tslicservers>
					</xsl:if>
				</gen>
				<os_template>
					<xsl:copy-of select="$config/os_template/*"/>
				</os_template>
			</xsl:when>
			<!-- Init data for "Apply Template" -->
			<xsl:when test="$step='apply'">
				<xsl:variable name="tmpl-info"
					select="ve:get-sample-info(true(),$config/origin_sample,$config/config_customized)"/>
				<!--|-->
				<apply>
					<restart>
						<xsl:value-of select="sw:if($hn-info/linux,'1','0')"/>
					</restart>
				</apply>
				<ve-template>
					<xsl:copy-of select="$tmpl-info"/>
				</ve-template>
				<ve-template-src>
					<xsl:copy-of select="$tmpl-info"/>
				</ve-template-src>
				<os-name>
					<xsl:value-of select="$config/os_template/name"/>
				</os-name>
			</xsl:when>
			<!-- Init data for "Network Settings" -->
			<xsl:when test="$step='net'">
				<def>
					<xsl:if test="ips:pool-enabled()">
						<ips-pool-enabled/>
					</xsl:if>
				</def>
				<net>
					<xsl:call-template name="vzenv:env2net">
						<xsl:with-param name="env" select="$env"/>
						<xsl:with-param name="hn-platform" select="$hn-info/platform"/>
					</xsl:call-template>
				</net>
			</xsl:when>
			<!-- Load data for QoS -->
			<xsl:when test="$step='qos'">
				<xsl:variable name="vt-settings" select="envm:get-vt-settings($hn-eid)"/>	
				<def>
					<slm-mode>
						<xsl:value-of select="$config/slm_mode"/>
					</slm-mode>
					<xsl:if test="$vt-settings/parameter[id='slm']/value='yes'">
						<slm-hn-enabled/>
					</xsl:if>
				</def>					
				<!--|-->
				<qos>
					<slm-mode>
						<xsl:value-of select="$config/slm_mode"/>
					</slm-mode>
					<xsl:for-each select="$config/qos">
						<res>
							<xsl:copy-of select="node()"/>
							<soft_src>
								<xsl:value-of select="soft"/>
							</soft_src>
							<hard_src>
								<xsl:value-of select="hard"/>
							</hard_src>
						</res>
					</xsl:for-each>
				</qos>
			<!-- Disabled due to wrong Configure QoS buttons function,baza@ 
				<xsl:variable name="qos-mode" select="sw:sesget('ve-resource-mode')"/>
			-->
			<xsl:variable name="qos-mode" select="'all'"/>							
				<qos-mode>
					<xsl:value-of select="sw:if($qos-mode, $qos-mode, 'all')"/>
				</qos-mode>
				<qos-current>
					<xsl:variable name="ubcs-rtf">
						<xsl:call-template name="ubcs:get"/>
					</xsl:variable>
					<xsl:variable name="sysinfo-rtf">
						<xsl:call-template name="proc:sysinfo">
							<xsl:with-param name="eid" select="$eid"/>
						</xsl:call-template>
					</xsl:variable>
					<xsl:variable name="vequota" select="env:get-quota($eid)"/>

					<xsl:call-template name="sw:getQoSCurrentValues">
						<xsl:with-param name="eid" select="$eid"/>
						<xsl:with-param name="qos-limit" select="$config/qos"/>
						<xsl:with-param name="ubcs" select="exsl:node-set($ubcs-rtf)"/>
						<xsl:with-param name="sysinfo" select="exsl:node-set($sysinfo-rtf)"/>
						<xsl:with-param name="vequota" select="$vequota"/>
					</xsl:call-template>
				</qos-current>
			</xsl:when>
			<!-- /Load data for QoS Step -->
			<!-- Load data for 'Applications' screen-->
			<xsl:when test="$step='apps'">
				<xsl:variable name="os-id" select="$config/os_template/name"/>
				<xsl:variable name="installed-apps" select="vzapackagem:get-env-templates($env)"/>
				
				<!-- Load data  -->
				<xsl:variable name="type_os" select="$installed-apps[vzapackagem:is-os(.)]"/>
				<xsl:variable name="type_apps" select="$installed-apps[not(vzapackagem:is-os(.))]"/>
				
				<!--|-->
				<os_template>
					<xsl:for-each select="$type_os">
						<name>
							<xsl:value-of select="name"/>
						</name>
						<version>
							<xsl:value-of select="local:get-app-version(.)"/>
						</version>
					</xsl:for-each>
				</os_template>
				<apps>
					<xsl:for-each select="set:distinct($type_apps/name)">
						<xsl:variable name="name" select="."/>
						<xsl:variable name="versions" select="$type_apps[name=$name]"/>
						<xsl:variable name="app" select="$versions[not(version) or version=math:max($versions/version)]"/>
						<app>
							<name>
								<xsl:value-of select="."/>
							</name>
							<version>
								<xsl:value-of select="local:get-app-version($app)"/>
							</version>
						</app>
					</xsl:for-each>
				</apps>
				<apps_src>
					<xsl:for-each select="set:distinct($type_apps/name)">
						<xsl:variable name="name" select="."/>
						<xsl:variable name="app" select="$type_apps[name=$name]"/>
						<app>
							<name>
								<xsl:value-of select="."/>
							</name>
							<version>
								<xsl:value-of select="local:get-app-version($app[not(version) or version=math:max($app/version)])"/>
							</version>
							<xsl:for-each select="$app">
								<installed-version>
									<xsl:value-of select="local:get-app-version(.)"/>
								</installed-version>
							</xsl:for-each>
						</app>
					</xsl:for-each>
				</apps_src>
				<!-- /Load TEMPLATES data -->
			</xsl:when>
			<!-- /Load data for 'Applications' screen-->
		</xsl:choose>
		<eid>
			<xsl:value-of select="$eid"/>
		</eid>
		<hn-eid>
			<xsl:value-of select="$hn-eid"/>
		</hn-eid>
		<hn>
			<xsl:copy-of select="$hn-info"/>
		</hn>
		<ve-id>
			<xsl:value-of select="$env/virtual_config/veid"/>
		</ve-id>
	</xsl:template>
	
	<func:function name="local:get-app-version">
		<xsl:param name="app"/>
		
		<func:result select="sw:if(sw:is-ez-package($app/name), '00000001', string($app/version))"/>
	</func:function>

	<func:function name="vzenv:getFinalPacket">
		<xsl:param name="step"/>
		<xsl:param name="data"/>
		<!--prepare common data-->
		<xsl:variable name="os-changed"
			select="$step='gen' and $data/gen/os_version!=$data/os_template/version"/>
		<!--|-->
		<func:result>
			<xsl:choose>
				<!-- Save General Settings -->
				<xsl:when test="$step='gen'">
					<xsl:call-template name="action:make-packet">
						<xsl:with-param name="path" select="'actions/vzdir/infrman/envs/configure.xsl'"/>
						<xsl:with-param name="cookie">
							<msg>
								<sched>
									<sw:text>The update of the Container general settings has been scheduled.</sw:text>
								</sched>
								<error>
									<sw:text>Failed to update the Container general settings.</sw:text>
								</error>
							</msg>
							<operation>update_ve</operation>
							<redirect-prev/>
						</xsl:with-param>
						<xsl:with-param name="input">
							<data>
								<xsl:copy-of select="$data/eid"/>
								<xsl:copy-of select="$data/hn-eid"/>
								<vzaenvm>
									<xsl:copy-of select="$data/eid"/>
									<xsl:copy-of select="$data/ve-id"/>
									<xsl:copy-of select="$data/gen"/>
									<xsl:copy-of select="$data/capabilities"/>
								</vzaenvm>
								<xsl:if test="$os-changed">
									<xsl:variable name="os-rtf">
										<new-os>
											<name><xsl:value-of select="$data/os_template/name"/></name>
											<version><xsl:value-of select="$data/gen/os_version"/></version>
										</new-os>
										<os>
											<xsl:copy-of select="$data/os_template/*"/>
											<xsl:if test="string($data/os_template/version)!=''">
												<installed-version>
													<xsl:value-of select="$data/os_template/version"/>
												</installed-version>
											</xsl:if>
										</os>
									</xsl:variable>
									<xsl:variable name="os-info" select="exsl:node-set(exsl:node-set($os-rtf))"/>
									
									<xsl:variable name="apps" 
											select="local:prepare-app-ids($os-info/new-os, 
													$os-info/os, $data/hn/platform, $data/os_template/name, true())"/>
									
									<vzapackagem>
										<command><xsl:value-of select="sw:if($apps/remove, 'remove', 'install')"/></command>
										<app-id>
											<xsl:copy-of select="$apps/*"/>
										</app-id>
										<eid><xsl:value-of select="$data/eid"/></eid>
										<hn-eid><xsl:value-of select="$data/hn-eid"/></hn-eid>
									</vzapackagem>
								</xsl:if>
							</data>
						</xsl:with-param>
					</xsl:call-template>
				</xsl:when>
				<!-- /Save General Settings -->
				<!-- Save Network Settings -->
				<xsl:when test="$step='net'">
					<packet log="on" progress="on">
						<target>vzaenvm</target>
						<xsl:copy-of select="sw:hn-dst($data/eid)"/>
						<cookie>
							<msg>
								<ok>
									<sw:text>The Container network settings have been successfully updated.</sw:text>
								</ok>
								<sched>
									<sw:text>The update of the Container network settings has been scheduled.</sw:text>
								</sched>
								<error>
									<sw:text>Failed to update the Container network settings.</sw:text>
								</error>
							</msg>
							<operation>update_ve</operation>
							<redirect-prev/>
						</cookie>
						<data>
							<vzaenvm>
								<set>
									<eid>
										<xsl:value-of select="$data/eid"/>
									</eid>
									<config>
										<xsl:copy-of select="vzenv:net2config($data/net,$data/hn/platform,true())"/>
									</config>
								</set>
							</vzaenvm>
							<xsl:if test="$data/net-flags/restart-ve='true'">
								<vzaenvm>
									<restart>
										<eid>
											<xsl:value-of select="$data/eid"/>
										</eid>
									</restart>
								</vzaenvm>
							</xsl:if>
						</data>
					</packet>
				</xsl:when>
				<!-- /Save Network Settings -->
				<!-- Save QoS -->
				<xsl:when test="$step='qos'">
					<packet log="on" progress="on">
						<target>vzaenvm</target>
						<xsl:copy-of select="sw:hn-dst($data/eid)"/>
						<cookie>
							<msg>
								<sched>
									<sw:text>The update of the Container resource settings has been scheduled.</sw:text>
								</sched>
								<error>
									<sw:text>Failed to update the Container resources.</sw:text>
								</error>
							</msg>
							<operation>update_ve</operation>
							<redirect-prev/>
						</cookie>
						<data>
							<xsl:if test="$data/qos/res/restart-ve='1'">
								<vzaenvm>
									<stop>
										<eid>
											<xsl:value-of select="$data/eid"/>
										</eid>
									</stop>
								</vzaenvm>
							</xsl:if>
							<vzaenvm>
								<set>
									<eid>
										<xsl:value-of select="$data/eid"/>
									</eid>
									<config>
										<xsl:if test="$data/hn/linux">
											<slm_mode>
												<xsl:value-of select="$data/qos/slm-mode"/>
											</slm_mode>	
										</xsl:if>
										<xsl:for-each select="$data/qos/res">
											<qos>
												<xsl:copy-of select="id"/>
												<xsl:if test="soft!=''">
													<xsl:copy-of select="soft"/>
												</xsl:if>
												<xsl:copy-of select="hard"/>
											</qos>
										</xsl:for-each>
									</config>
								</set>
							</vzaenvm>
							<xsl:if test="$data/qos/res/restart-ve='1'">
								<vzaenvm>
									<start>
										<eid>
											<xsl:value-of select="$data/eid"/>
										</eid>
									</start>
								</vzaenvm>
							</xsl:if>
						</data>
					</packet>
				</xsl:when>
				<!-- /Save QoS Settings -->
				<!-- Save Applications -->
				<xsl:when test="$step='apps'">
					<xsl:copy-of select="vzenv:getFinalPacketApps($data)"/>
				</xsl:when>
				<!-- /Save Applications -->
				<!-- Save "Apply Template" -->
				<xsl:when test="$step='apply'">
					<packet log="on" progress="on">
						<target>vzaenvm</target>
						<xsl:copy-of select="sw:hn-dst($data/eid)"/>
						<cookie>
							<msg>
								<sched>
									<sw:text>The application of the Container sample has been scheduled.</sw:text>
								</sched>
								<error>
									<sw:text>Failed to apply the Container sample.</sw:text>
								</error>
							</msg>
							<operation>apply_ve_template</operation>
							<redirect>
								<xsl:value-of select="concat($baseurl,'/vzdir/infrman/envs/env?tab-force=default')"/>
							</redirect>
							<xsl:if test="$activeMode!='vzcc'">
								<redirect-prev/>
							</xsl:if>
						</cookie>
						<data>
							<vzaenvm>
								<set>
									<eid>
										<xsl:value-of select="$data/eid"/>
									</eid>
									<set_mode>
										<xsl:choose>
											<xsl:when test="$data/apply/restart='1'">restart</xsl:when>
											<xsl:otherwise>ignore</xsl:otherwise>
										</xsl:choose>
									</set_mode>
									<apply_config>
										<sample_conf>
											<xsl:value-of select="$data/ve-template/id"/>
										</sample_conf>
										<category>qos</category>
										<xsl:if test="$data/hn/linux">
											<parameter>slm_mode</parameter>
										</xsl:if>
										<config_customized>0</config_customized>
									</apply_config>
								</set>
							</vzaenvm>
						</data>
					</packet>
				</xsl:when>
				<!-- /Save "Apply Template"-->
			</xsl:choose>
		</func:result>
	</func:function>

	<func:function name="local:prepare-app-ids">
		<xsl:param name="apps"/>
		<xsl:param name="apps_src"/>
		<xsl:param name="vt-platform"/>
		<xsl:param name="os-name"/>
		<xsl:param name="is-os" select="false()"/>
		
		<xsl:variable name="platform" select="vt:platform2vza($vt-platform)"/>
		
		<xsl:variable name="res">
			<!-- removed apps -->
			<xsl:for-each select="$apps_src[not(string(name)=$apps/name)][not(name='')]">
				<remove><xsl:value-of select="vzapackagem:create-package-id(
					sw:if($is-os, 'os', 'app'),
					name,
					version,
					$platform,
					'',
					$os-name
				)"/></remove>
			</xsl:for-each>
			<xsl:for-each select="$apps[not(name='')]">
				<xsl:variable name="app" select="."/>
				<xsl:variable name="id" select="vzapackagem:create-package-id(
					sw:if($is-os, 'os', 'app'),
					name,
					version,
					$platform,
					'',
					$os-name
				)"/>
				
				<xsl:variable name="installed" select="$apps_src[string(name)=$app/name]"/>
				<!-- apps to install or upgrade -->
				<xsl:if test="not($installed) or ($installed/installed-version and 
										math:max($installed/installed-version) &lt; $app/version)">
					<add><xsl:value-of select="$id"/></add>
				</xsl:if>
			</xsl:for-each>
		</xsl:variable>
		<func:result select="exsl:node-set($res)"/>
	</func:function>
	
	<func:function name="vzenv:getFinalPacketApps">
		<xsl:param name="data"/>

		<!-- Prepare Packet -->
		<xsl:variable name="apps" 
			select="local:prepare-app-ids($data/apps/app, $data/apps_src/app, $data/hn/platform, $data/os_template/name)"/>
		<xsl:variable name="apps_deinstall" select="$apps/remove"/>
		<xsl:variable name="apps_install" select="$apps/add"/>
			
		<xsl:variable name="command-rtf">
			<xsl:if test="$apps_deinstall">
				<data>
					<command>remove</command>
					<app-id><xsl:copy-of select="$apps_deinstall"/></app-id>
				</data>
			</xsl:if>
			<xsl:if test="$apps_install">
				<data>
					<command>install</command>
					<app-id><xsl:copy-of select="$apps_install"/></app-id>
				</data>
			</xsl:if>
		</xsl:variable>

		<!-- Generate Full Packet -->
		<xsl:variable name="command" select="exsl:node-set($command-rtf)/data"/>
		
		<xsl:variable name="packet-id" select="sw:generate-id()"/>
		<xsl:if test="sw:sesput('ve-app-action-id', $packet-id)"/>
		
		<xsl:choose>
			<xsl:when test="$command">
				<func:result>
					<xsl:call-template name="vzapackagem:chain-packet">
						<xsl:with-param name="packet-id" select="$packet-id" />
						<xsl:with-param name="commands" select="$command"/>
						<xsl:with-param name="hn-eid" select="$data/hn-eid"/>
						<xsl:with-param name="target-eid" select="$data/eid" />
						<xsl:with-param name="progress" select="true()" />
						<xsl:with-param name="cookie">
							<cookie>
								<msg>
									<sched>
										<sw:text>The Container applications updating has been scheduled.</sw:text>
									</sched>
									<error>
										<sw:text>Failed to update the Container applications.</sw:text>
									</error>
								</msg>
								<operation>update_ve_apps</operation>
								<xsl:choose>
									<xsl:when test="$activeMode!='vzcc'">
										<redirect-prev/>
									</xsl:when>
									<xsl:otherwise>
										<redirect>
											<xsl:value-of select="concat($baseurl,'/vzdir/infrman/envs/apps?pid=', $packet-id)"/>
										</redirect>
									</xsl:otherwise>
								</xsl:choose>
							</cookie>	
						</xsl:with-param>
					</xsl:call-template>
				</func:result>
			</xsl:when>
			<xsl:otherwise>
				<func:result>
					<packet>
						<cookie>
							<xsl:choose>
								<xsl:when test="$activeMode!='vzcc'">
									<redirect-prev/>
								</xsl:when>
								<xsl:otherwise>
									<redirect>
										<xsl:value-of select="concat($baseurl,'/vzdir/infrman/envs/apps')"/>
									</redirect>
								</xsl:otherwise>
							</xsl:choose>
						</cookie>
					</packet>
				</func:result>
			</xsl:otherwise>
		</xsl:choose>

	</func:function>


	<!-- credentials -->
	<sw:include href="/lib/cred.xsl"/>

	<sw:include href="/lib/vt/env-private.xsl"/>
	<sw:include href="/lib/globals.xsl"/>
	<sw:include href="/lib/trace.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>

	<sw:include href="/lib/vz/vzhn-redirects.xsl"/>

	<sw:include href="/lib/vt/env-quota.xsl"/>
	<sw:include href="/lib/vz/ubcs.xsl"/>

</xsl:stylesheet>
