<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl vzenv cred voc vzapackagem local func"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" 
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:vzenv="http://www.swsoft.com/xsl/cp/vzenv" 
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred" 
	xmlns:voc="http://www.swsoft.com/xsl/cp/voc"
	xmlns:hwm="http://www.swsoft.com/xsl/cp/hwm" 
	xmlns:func="http://exslt.org/functions" 
	xmlns:vzapackagem="http://www.swsoft.com/xsl/cp/vzapackagem"
	xmlns:task="http://www.swsoft.com/xsl/cp/task"
	xmlns:local="http://www.swsoft.com/xsl/cp/local">

	<!-- Import required modules -->
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/swa/system.xsl" />
	<sw:include href="/lib/common.xsl" />
	<sw:include href="/lib/vt/env-core.xsl" />
	<sw:include href="/lib/vza/vzapackagem.xsl" />
	<sw:include href="/lib/swa/op_log.xsl" />

	<!-- Import required modules -->

	<xsl:output method="xml" />

	<xsl:template match="node()|@*">
		<!-- Step "General Settings" -->
		<xsl:variable name="eid" select="sw:ve-eid()"/>
		<sw:noauth-redirect select="not(cred:check-env('vzcp.env.manage.properties.application', $eid))"/>
		<xsl:variable name="oper-problem" select="voc:check-operation('vzapackagem','install')"/>
		<xsl:choose>
			<xsl:when test="$oper-problem">
				<xsl:if test="sw:sesput(concat('ve-update-action-report.', $eid), '')"/>
				<packet />
			</xsl:when>
			<xsl:otherwise>
				<packet>
					<xsl:if test="sw:param('list') or not(local:need-update())">
						<cookie>
							<list/>
							<xsl:variable name="task-id" select="sw:sesget(concat('ve-update-action-report.', $eid))"/>
							<xsl:variable name="type" select="sw:sesget(concat('ve-update-action-type.', $eid))"/>
							<xsl:if test="not(string($task-id)='')">
								<xsl:variable name="task" select="task:get($task-id)"/>
								<xsl:if test="sw:sesput(concat('ve-update-action-id.', $eid), '')"/>
								<xsl:if test="sw:sesput(concat('ve-update-action-report.', $eid), '')"/>
								<msg>
									<xsl:call-template name="local:describe-command">
										<xsl:with-param name="command" select="$type"/>
										<xsl:with-param name="error"
											select="sw:if(task:is-error($task), task:message($task[last()]), /..)"/>
									</xsl:call-template>
								</msg>
							</xsl:if>
						</cookie>
					</xsl:if>
				</packet>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="local:describe-command">
		<xsl:param name="command"/>
		<xsl:param name="error" select="/.."/>
		<xsl:choose>
			<xsl:when test="$command='update' and $error">
				<xsl:if test="error:put(sw:text('Failed to schedule the updating of the selected software packages.'), $error)"/>
			</xsl:when>
			<xsl:when test="$command='update'">
				<xsl:if test="sw:sesput('msg', sw:text('The software packages have been successfully updated.'))"/>
			</xsl:when>
			<xsl:when test="$command='remove' and $error">
				<xsl:if test="error:put(sw:text('Failed to remove the selected software packages.'), $error)"/>
			</xsl:when>
			<xsl:when test="$command='remove'">
				<xsl:if test="sw:sesput('msg', sw:text('The software packages have been successfully removed.'))"/>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<func:function name="local:need-update">
		<func:result
			select="not(vzapackagem:has-rpms-cache(sw:ve-eid()))" />
	</func:function>	
	
	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
