<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func cred voc vzapackagem local"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:func="http://exslt.org/functions" xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:voc="http://www.swsoft.com/xsl/cp/voc" 
	xmlns:vzapackagem="http://www.swsoft.com/xsl/cp/vzapackagem" 
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:task="http://www.swsoft.com/xsl/cp/task"
	>

	<!-- Import required modules -->
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/swa/system.xsl" />
	<sw:include href="/lib/common.xsl" />
	<sw:include href="/lib/vt/env-core.xsl" />
	<sw:include href="/lib/vza/vzapackagem.xsl" />
	<sw:include href="/lib/swa/op_log.xsl"/>

	<!-- Import required modules -->

	<xsl:output method="xml" />

	<xsl:template match="node()|@*">
		<xsl:variable name="eid" select="sw:ve-eid()"/>
		<sw:noauth-redirect select="not(cred:check-env('vzcp.env.manage.properties.application', $eid))"/>
		<!-- Step "General Settings" -->
		<xsl:variable name="oper-problem" select="voc:check-operation('vzapackagem','list')"/>
		<xsl:choose>
			<xsl:when test="$oper-problem">
				<xsl:if test="sw:sesput(concat('ve-update-action-report.', $eid), '')"/>
				<packet />
			</xsl:when>
			<xsl:when test="sw:param('install')">
				<xsl:if test="vzapackagem:clear-rpms-cache($eid)" />
				
				<xsl:variable name="rpms" select="sw:param('id')" />

				<xsl:variable name="packet-id" select="sw:generate-id()"/>

				<xsl:if test="sw:sesput(concat('ve-update-action-id.', $eid), $packet-id)"/>
				<xsl:if test="sw:sesput(concat('ve-update-action-report.', $eid), $packet-id)"/>
				<xsl:if test="sw:sesput(concat('ve-update-action-type.', $eid), 'install')"/>
				
				<xsl:variable name="msg">
					<sw:text>
						The selected software packages have been scheduled for installation.
					</sw:text>
				</xsl:variable>
				
				<xsl:if test="sw:sesput('sched', $msg)"/>
				<xsl:if test="sw:sesput('operation_id', $packet-id)"/>
				
				<xsl:variable name="data">
					<xsl:call-template name="vzapackagem:action-packet">
							<xsl:with-param name="packet-id" select="$packet-id"/>
							<xsl:with-param name="command" select="'install'"/>
							<xsl:with-param name="app-id" select="$rpms"/>
							<xsl:with-param name="hn-eid" select="sw:ve-parent($eid)"/>
							<xsl:with-param name="target-eid" select="$eid"/>
							<xsl:with-param name="progress" select="true()"/>
							<xsl:with-param name="cookie">
								<cookie>
									<msg>
										<sched>
											<sw:text>
												The selected software packages have been scheduled for installation.
											</sw:text>
										</sched>
										<error>
											<sw:text>Failed to install the selected software packages.</sw:text>
										</error>
									</msg>
								</cookie>
							</xsl:with-param>
						</xsl:call-template>
				</xsl:variable>
				
				<xsl:variable name="res" select="sw:send($data, $packet-id)"/>
				<packet/>
			</xsl:when>
			<xsl:otherwise>
				<packet>
					<xsl:if test="sw:param('list') or not(local:need-update())">
						<cookie>
							<list/>
							<xsl:variable name="task-id" select="sw:sesget(concat('ve-update-action-report.', $eid))"/>
							<xsl:variable name="type" select="sw:sesget(concat('ve-update-action-type.', $eid))"/>
							<xsl:if test="not(string($task-id)='')">
								<xsl:variable name="task" select="task:get($task-id)"/>
								<xsl:if test="sw:sesput(concat('ve-update-action-id.', $eid), '')"/>
								<xsl:if test="sw:sesput(concat('ve-update-action-report.', $eid), '')"/>
								<msg>
									<xsl:call-template name="local:describe-command">
										<xsl:with-param name="command" select="$type"/>
										<xsl:with-param name="error"
											select="sw:if(task:is-error($task), task:message($task[last()]), /..)"/>
									</xsl:call-template>
								</msg>
							</xsl:if>
						</cookie>
					</xsl:if>
				</packet>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<func:function name="local:need-update">
		<func:result
			select="not(vzapackagem:has-rpms-cache(sw:ve-eid(), true()))" />
	</func:function>
	
	<xsl:template name="local:describe-command">
		<xsl:param name="command"/>
		<xsl:param name="error" select="/.."/>
		<xsl:choose>
			<xsl:when test="$command='install' and $error">
				<xsl:if test="error:put(sw:text('Failed to install the selected software packages.'), $error)"/>
			</xsl:when>
			<xsl:when test="$command='install'">
				<xsl:if test="sw:sesput('msg', sw:text('The software packages have been successfully installed.'))"/>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
