<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
>

	<xsl:output method="xml"/>

	<xsl:variable name="eid" select="sw:ve-eid()"/>

	<xsl:template match="/">
		<sw:noauth-redirect select="not(cred:check-env('vzcp.env.manage.services_and_files', $eid))"/>
		<!-- complain in case of no processes selceted -->
		<xsl:if
			test="sw:param('kill') and not(sw:param('pid'))">
			<xsl:value-of select="error:put(sw:text('No processes selected'))"/>
		</xsl:if>

		<packet>
			<xsl:variable name="default-signal" select="sw:param('signal')"/>
			<xsl:if test="$default-signal != ''">
				<xsl:if test="sw:sesputstr('default-signal', number($default-signal))"/>
			</xsl:if>
			<!-- check premissions before execute request -->
			<xsl:if test="cred:check-env('vzcp.env.manage.services_and_files',$eid)">
				<target>vzaprocessm</target>
				<xsl:copy-of select="sw:hn-dst($eid)"/>
				<xsl:choose>
					<!-- send signal to processes -->
					<xsl:when
						test="sw:param('kill') and sw:param('pid')">
						<xsl:if test="error:is-empty()">
							<xsl:if test="cred:detail-check-env('vzcp.env.manage.services_and_files',$eid)"
							/>
						</xsl:if>
						<xsl:if test="error:is-empty()">
							<cookie>
								<msg>
									<ok>
										<sw:text>The signal has been sent to the process(es).</sw:text>
									</ok>
									<error>
										<sw:text>Failed to send the signal to the process(es).</sw:text>
									</error>
								</msg>
								<operation>send_signal</operation>
							</cookie>
							<data>
								<vzaprocessm>
									<kill>
										<eid>
											<xsl:value-of select="$eid"/>
										</eid>
										<signal>
											<xsl:value-of
												select="number(sw:param('signal'))"/>
										</signal>
										<xsl:for-each select="sw:param('pid')">
											<xsl:if test="number(.) &gt; 1">
												<pid>
													<xsl:value-of select="number(.)"/>
												</pid>
											</xsl:if>
										</xsl:for-each>
										<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
									</kill>
								</vzaprocessm>
							</data>
						</xsl:if>
					</xsl:when>
				</xsl:choose>
			</xsl:if>
		</packet>

	</xsl:template>
	<!-- credentials -->
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/common.xsl"/>


</xsl:stylesheet>
