<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred securitym"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:securitym="http://www.swsoft.com/xsl/cp/securitym"
>

	<xsl:output method="xml"/>

	<sw:include href="/lib/swa/securitym.xsl"/>

	<xsl:template match="/">
		<xsl:variable name="eid" select="sw:ve-eid()"/>
		<packet>
			<target>vzaenvm</target>
			<xsl:copy-of select="sw:hn-dst($eid)"/>

			<!-- check premissions before execute request -->
			<xsl:if test="securitym:check-operation('environment.interaction.setUserPassword',
				securitym:env-scope($eid))">
				<xsl:choose>
					<xsl:when test="not(sw:param('_submit'))">
						<!-- no form post - do nothing -->
					</xsl:when>

					<xsl:when
						test="not(string(sw:param('passwd'))) or not(string(sw:param('retype')))">
						<!-- check password presence -->
						<xsl:value-of select="error:put(sw:text('The password was not specified.'))"/>
					</xsl:when>

					<xsl:when
						test="sw:param('passwd') != sw:param('retype')">
						<!-- check passwords match -->
						<xsl:value-of select="error:put(sw:text('The passwords do not match.'))"/>
					</xsl:when>


					<xsl:when test="sw:param('passwd')">
						<xsl:if test="error:is-empty()">
							<cookie>
								<msg>
									<ok>
										<sw:text>The password has been successfully changed.</sw:text>
									</ok>
									<error>
										<sw:text>
											Failed to change the password of the administrative account.
										</sw:text>
									</error>
								</msg>
								<redirect-prev/>
							</cookie>
							<data>
								<vzaenvm>
									<set_user_password>
										<eid>
											<xsl:value-of select="sw:ve-eid()"/>
										</eid>
										<password>
											<xsl:value-of
												select="sw:base64-encode(sw:param('passwd'))"
											/>
										</password>
									</set_user_password>
								</vzaenvm>
							</data>
							<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
						</xsl:if>
					</xsl:when>

				</xsl:choose>
				<vzcpauth/>
			</xsl:if>
		</packet>
	</xsl:template>
	<!-- credentials -->

	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/globals.xsl"/>
	<sw:include href="/lib/common.xsl"/>


</xsl:stylesheet>
