<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz local cred action securitym"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:check="http://www.swsoft.com/xsl/cp/check"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:form="http://www.swsoft.com/xsl/cp/form"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:action="http://www.swsoft.com/xsl/cp/action"
	xmlns:securitym="http://www.swsoft.com/xsl/cp/securitym"
>

	<xsl:output method="xml"/>

	<sw:include href="/lib/utils/action.xsl"/>

	<xsl:variable name="ve-eid" select="sw:ve-eid()"/>

	<xsl:variable name="step" select="wiz:processing-step-id()"/>

	<xsl:param name="wiz_code" select="'env-reinstall'"/>

	<xsl:variable name="form" select="local:init-form()"/>

	<xsl:template match="node()|@*">
		<xsl:choose>
			<!-- Step "Introduction" -->
			<xsl:when
				test="$step='intro'">

				<!-- Restore form's data  -->
				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="name()='123'"/>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
				<!-- /Restore form's data  -->

				<xsl:if test="sw:param('back')">
					<!-- Move to back -->
					<xsl:if test="wiz:goBack()"/>
					<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
				</xsl:if>
				<xsl:if test="sw:param('next')">
					<!-- Check data -->
					<!-- Move to next step -->
					<xsl:choose>
						<xsl:when test="error:is-empty()">
							<xsl:call-template name="local:goNext">
								<xsl:with-param name="data" select="$new_form"/>
								<xsl:with-param name="ve-eid" select="$ve-eid"/>
							</xsl:call-template>
						</xsl:when>
					</xsl:choose>
				</xsl:if>

			</xsl:when>

			<!-- Step "Install Options" -->
			<xsl:when
				test="$step='setup'">

				<!-- Restore form's data  -->
				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="name()='setup'"/>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<setup>
						<data>
							<xsl:value-of select="sw:param('data')"/>
						</data>
						<passw>
							<xsl:value-of select="sw:param('passw')"/>
						</passw>
						<root_pwd>
							<xsl:value-of select="sw:param('root_pwd')"/>
						</root_pwd>
						<root_pwd_re>
							<xsl:value-of
								select="sw:param('root_pwd_re')"/>
						</root_pwd_re>
						<custom-scripts-selected>
							<xsl:for-each select="sw:param('custom_script')">
								<id>
									<xsl:value-of select="."/>
								</id>
							</xsl:for-each>
						</custom-scripts-selected>
					</setup>
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
				<!-- /Restore form's data  -->

				<xsl:if test="sw:param('back')">
					<!-- Move to back -->
					<xsl:if test="wiz:goBack()"/>
					<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
				</xsl:if>
				<xsl:if test="sw:param('next')">
					<!-- Check data -->
					<xsl:if test="$new_form/setup/passw='reset'">
						<xsl:choose>
							<xsl:when test="$new_form/setup/root_pwd!=$new_form/setup/root_pwd_re">
								<xsl:if
									test="error:put(sw:text('The password entries do not match.'),'','root_pwd')"/>
							</xsl:when>
							<xsl:when test="$new_form/setup/root_pwd=''">
								<xsl:if test="error:put(sw:text('You should enter the password'),'','root_pwd')"/>
							</xsl:when>
						</xsl:choose>
					</xsl:if>
					<!-- Move to next step -->
					<xsl:choose>
						<xsl:when test="error:is-empty()">
							<xsl:call-template name="local:goNext">
								<xsl:with-param name="data" select="$new_form"/>
								<xsl:with-param name="ve-eid" select="$ve-eid"/>
							</xsl:call-template>
						</xsl:when>
					</xsl:choose>
				</xsl:if>

			</xsl:when>

			<!-- Step "Confirmation" -->
			<xsl:when
				test="$step='final'">

				<!-- Restore form's data  -->
				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="name()='123'"/>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
				<!-- /Restore form's data  -->

				<xsl:if test="sw:param('back')">
					<!-- Move to back -->
					<xsl:if test="wiz:goBack()"/>
				</xsl:if>
				<xsl:if test="sw:param('next')">
					<!-- Check data -->
					<!-- Move to next step -->
					<xsl:choose>
						<xsl:when test="error:is-empty()">
							<xsl:call-template name="local:goNext">
								<xsl:with-param name="data" select="$new_form"/>
								<xsl:with-param name="ve-eid" select="$ve-eid"/>
							</xsl:call-template>
						</xsl:when>
					</xsl:choose>
				</xsl:if>
			</xsl:when>
		</xsl:choose>

		<xsl:copy/>
	</xsl:template>

	<xsl:template name="local:goNext">
		<xsl:param name="data"/>
		<xsl:param name="ve-eid" select="$ve-eid"/>
		<!--|-->
		<xsl:choose>
			<xsl:when test="$step='intro'">
				<xsl:if test="sw:sesput($wiz_step, 'setup')"/>
				<xsl:if test="sw:sesput($wiz_data,exsl:node-set($data))"/>
			</xsl:when>
			<xsl:when test="wiz:isLastStep()">
				<xsl:if test="error:is-empty()">
					<xsl:if test="cred:check-env('vzcp.support.troubleshooting',$ve-eid)"/>
				</xsl:if>

				<xsl:choose>
					<xsl:when test="error:is-empty()">
						<xsl:if test="cred:detail-check-env('vzcp.support.troubleshooting',$ve-eid)"/>
						<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:call-template name="local:sendFinalPacket">
									<xsl:with-param name="data" select="$data"/>
									<xsl:with-param name="ve-eid" select="$ve-eid"/>
								</xsl:call-template>
							</xsl:when>
							<xsl:otherwise>
								<packet/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<packet/>
					</xsl:otherwise>
				</xsl:choose>

			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="wiz:goNext()"/>
				<xsl:if test="sw:sesput($wiz_data,exsl:node-set($data))"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<func:function name="local:init-form">
		<sw:noauth-redirect select="not(cred:check-env('vzcp.support.troubleshooting',$ve-eid))"/>
		<xsl:if test="($step = '') or ($step = 'intro')">
			<xsl:call-template name="local:init-new"/>				
 		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>
 	
	<xsl:template name="local:init-new">
		<xsl:param name="ve-eid" select="sw:ve-eid()"/>		
		<xsl:variable name="req-for-custom-scripts">
      <packet>
        <target>vzaenvm</target>
        <xsl:copy-of select="sw:hn-dst($ve-eid)"/>
        <data>
          <vzaenvm>
            <get_script>
							<eid><xsl:value-of select="$ve-eid"/></eid>
							<type>reinstall</type>
						</get_script>
          </vzaenvm>
        </data>
      </packet>
		</xsl:variable>
		<xsl:variable name="custom-scripts" select="sw:xchg($req-for-custom-scripts)/packet/data/vzaenvm"/>

		<xsl:choose>
			<xsl:when
				test="$step='intro'">
				<!-- Init steps -->
				<xsl:variable name="all_steps_">
					<step id="setup" screen-id="03.02.01.11.01"/>
					<step id="final" screen-id="03.02.01.11.02"/>
				</xsl:variable>

				<!-- Init Step -->
				<xsl:variable name="new_step">
					<xsl:choose>
						<xsl:when test="string(sw:param('tab'))!=''">
							<xsl:value-of select="string(sw:param('tab'))"/>
						</xsl:when>
						<xsl:otherwise>setup</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<xsl:variable name="new_steps"
					select="exsl:node-set($all_steps_)/step[(not(@cred) or cred:check(@cred)) ]"/>

				<!-- Check startup conditions -->
				<xsl:variable name="new_form">
					<setup>
						<data>preserve</data>
						<passw>preserve</passw>
						<custom-scripts-selected>
							<xsl:for-each select="$custom-scripts/script">
								<id>
									<xsl:value-of select="sw:base64-encode(name)"/>
								</id>
							</xsl:for-each>
						</custom-scripts-selected>
					</setup>
					<custom-scripts>
						<xsl:copy-of select="$custom-scripts/script"/>
					</custom-scripts>
				</xsl:variable>
				<!-- Save wizard initial settings -->
				<xsl:if test="error:is-empty()">
					<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
					<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
					<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
				</xsl:if>
			</xsl:when>
			<xsl:when
				test="$step = ''">

				<!-- Init steps -->
				<xsl:variable name="all_steps_">
					<step id="intro" screen-id="03.02.01.11.00"/>
				</xsl:variable>

				<!-- Init Step -->
				<xsl:variable name="new_step">intro</xsl:variable>
				<xsl:variable name="new_steps"
					select="exsl:node-set($all_steps_)/step[(not(@cred) or cred:check(@cred)) ]"/>

				<!-- Check startup conditions -->
				<xsl:variable name="new_form">
					<setup>
						<data>preserve</data>
						<passw>preserve</passw>
						<custom-scripts-selected>
							<xsl:for-each select="$custom-scripts/script">
								<id>
									<xsl:value-of select="sw:base64-encode(name)"/>
								</id>
							</xsl:for-each>
						</custom-scripts-selected>
					</setup>
					<custom-scripts>
						<xsl:copy-of select="$custom-scripts/script"/>
					</custom-scripts>
				</xsl:variable>
				<!-- Save wizard initial settings -->
				<xsl:if test="error:is-empty()">
					<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
					<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
					<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
				</xsl:if>
			</xsl:when>
		</xsl:choose>
	</xsl:template>


	<!-- *********************************************************** -->

	<xsl:template name="local:sendFinalPacket">
		<xsl:param name="data"/>
		<xsl:param name="ve-eid" select="sw:ve-eid()"/>
		<xsl:call-template name="action:make-packet">
			<xsl:with-param name="path" select="'actions/vzdir/infrman/envs/reinstall.xsl'"/>
			<xsl:with-param name="cookie">
				<msg>
					<sched>
						<sw:text>The Container reinstallation has beed scheduled.</sw:text>
					</sched>
					<error>
						<sw:text>Failed to reinstall the Container.</sw:text>
					</error>
				</msg>
				<operation>recover_template</operation>
				<redirect-prev/>
			</xsl:with-param>
			<xsl:with-param name="input">
				<data>
					<eid>
						<xsl:copy-of select="$ve-eid"/>
					</eid>
					<data-oper>
						<xsl:value-of select="$data/setup/data"/>
					</data-oper>
					<xsl:copy-of select="$data/setup/custom-scripts-selected"/>
									
					<xsl:if test="securitym:check-operation('environment.interaction.setUserPassword',
						securitym:env-scope($ve-eid))">
						<password-oper>
							<xsl:value-of select="$data/setup/passw"/>
						</password-oper>
						<xsl:if test="$data/setup/passw='reset'">
							<password>
								<xsl:value-of select="$data/setup/root_pwd"/>
							</password>
						</xsl:if>
					</xsl:if>
				</data>
			</xsl:with-param>
		</xsl:call-template>

		<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>

	</xsl:template>

	<!-- credentials -->
	<sw:include href="/lib/cred.xsl"/>

	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>


</xsl:stylesheet>
