<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred action"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:action="http://www.swsoft.com/xsl/cp/action"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
>

	<xsl:output method="xml"/>

	<sw:include href="/lib/utils/action.xsl"/>

	<xsl:template match="/">
		<xsl:variable name="eid" select="sw:ve-eid()"/>

		<xsl:variable name="action-repair"
			select="sw:param('repair_ve')"/>
		<xsl:variable name="action-stop-repair"
			select="sw:param('stop_repair_ve')"/>
		<xsl:choose>
			<xsl:when test="not(cred:check-env('vzcp.env.manage.maintenance.repair_mode',$eid))">
				<packet/>
			</xsl:when>
			<xsl:when test="$action-stop-repair">
				<xsl:if test="error:is-empty()">
					<xsl:if test="cred:detail-check-env('vzcp.env.manage.maintenance.repair_mode', $eid)"/>
				</xsl:if>
				<xsl:choose>
					<xsl:when test="error:is-empty()">
						<xsl:call-template name="action:make-packet">
							<xsl:with-param name="path" select="'actions/vzdir/infrman/envs/repair.xsl'"/>
							<xsl:with-param name="cookie">
								<msg>
									<ok>
										<sw:text>The Container has successfully exited the repair mode.</sw:text>
									</ok>
									<sched>
										<sw:text>The Container has been scheduled to exit the repair mode.</sw:text>
									</sched>
									<error>
										<sw:text>Failed to exit the Container repair mode.</sw:text>
									</error>
								</msg>
								<operation>stop_repair</operation>
							</xsl:with-param>
							<xsl:with-param name="input">
								<data>
									<eid>
										<xsl:copy-of select="$eid"/>
									</eid>
									<cmd>stop-repair</cmd>
								</data>
							</xsl:with-param>
						</xsl:call-template>
						<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
					</xsl:when>
					<xsl:otherwise>
						<packet/>
					</xsl:otherwise>
				</xsl:choose>
				<!--/-->
			</xsl:when>
			<xsl:when test="$action-repair">
				<xsl:if test="error:is-empty()">
					<xsl:if test="cred:detail-check-env('vzcp.env.manage.maintenance.repair_mode', $eid)"/>
				</xsl:if>
				<xsl:choose>
					<xsl:when test="error:is-empty()">
						<packet log="on" progress="on">
							<target>vzaenvm</target>
							<xsl:copy-of select="sw:hn-dst($eid)"/>
							<cookie>
								<msg>
									<ok>
										<sw:text>The Container is in the repair mode.</sw:text>
									</ok>
									<sched>
										<sw:text>The Container has been scheduled to start in the repair mode.</sw:text>
									</sched>
									<error>
										<sw:text>Failed to start the Container in the repair mode.</sw:text>
									</error>
								</msg>
								<operation>start_repair</operation>
							</cookie>
							<data>
								<vzaenvm>
									<repair>
										<eid>
											<xsl:value-of select="$eid"/>
										</eid>
									</repair>
								</vzaenvm>
							</data>
						</packet>
						<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
					</xsl:when>
					<xsl:otherwise>
						<packet/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<packet/>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

	<!-- credentials -->
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/common.xsl"/>

</xsl:stylesheet>
