<!--
		 Copyright (c) SWsoft, 1999-2007
		 All rights reserved.
	-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl math cred env proc networkm show-resource format"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl	="http://exslt.org/common"
	xmlns:math	="http://exslt.org/math"
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:vt		="http://www.swsoft.com/xsl/cp/vt"	
	xmlns:env		="http://www.swsoft.com/xsl/cp/env"
	xmlns:ve		="http://www.swsoft.com/xsl/cp/ve"
	xmlns:cred	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:proc	="http://www.swsoft.com/xsl/cp/proc"
	xmlns:vzenv	="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:networkm			="http://www.swsoft.com/xsl/cp/networkm"
	xmlns:vznet					="http://www.swsoft.com/xsl/cp/vznet"
	xmlns:show-resource ="http://www.swsoft.com/xsl/cp/show-resource"
	xmlns:format				="http://www.swsoft.com/xsl/cp/format"
>

	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/proc.xsl"/>
	<sw:include href="/lib/get_log.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/show-resource.xsl"/>

	<sw:include href="/lib/utils/format-resusage.xsl"/>

	<sw:include href="/lib/vt/core.xsl"/>
	<sw:include href="/lib/vt/ve-core.xsl"/>
	<sw:include href="/lib/vt/env-private.xsl"/>	

	<sw:include href="/lib/vz/vzenv-qos.xsl"/>
	<sw:include href="/lib/vt/env-mem.xsl"/>
	<sw:include href="/lib/vt/env-quota.xsl"/>
	<sw:include href="/lib/vz/vznet.xsl"/>

	<sw:include href="/lib/vza/networkm.xsl"/>

	<xsl:variable name="ve-eid" select="sw:ve-eid()"/>
	<xsl:variable name="cr-resource-extended"
		select="cred:check-env('vzcp.env.manage.resources',$ve-eid)"/>

	<xsl:output method="xml"/>

	<xsl:template match="/">
		<xsl:variable name="env" select="env:get-env($ve-eid)/env"/>
		<xsl:variable name="platform" select="env:env2platform($env)"/>

		<!-- cpu -->
		<xsl:variable name="sysinfo-rtf">
			<xsl:call-template name="proc:sysinfo">
				<xsl:with-param name="eid" select="$ve-eid"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="sysinfo" select="exsl:node-set($sysinfo-rtf)"/>
		<!-- cpu load value -->
		<xsl:variable name="cpu-load" select="proc:calc-cpu-load($sysinfo/system)"/>

		<!-- get all alerts -->
		<xsl:variable name="total-alerts" select="vzenv:get-all-alerts($sysinfo)"/>

		<xsl:variable name="load-avg-node" select="proc:calc-load-avg($sysinfo/system/load_avg)"/>
		<xsl:variable name="load-average"	select="$load-avg-node/value"/>
		<xsl:variable name="load-average-alert"	select="$load-avg-node/alert/level"/>
		<xsl:variable name="cpu-alert"	select="$total-alerts/alerts/alert[id = 'cpuunits']/type"/>

		<!-- memory -->
		<xsl:variable name="memory"	select="env:get-memory($ve-eid)"/>
		<xsl:variable name="memory-alert"	select="vzenv:get-memory-alert($ve-eid,$total-alerts)"/>
		
		<!-- disk -->
		<xsl:variable name="vequota" select="env:get-quota($ve-eid)"/>
		<xsl:variable name="disk-info-rtf">
			<xsl:for-each select="$vequota/ve_quota/diskspace">
				<resource>
					<id>diskspace</id>
					<fraction>
						<xsl:value-of select="cur div total"/>
					</fraction>					
					<values>
						<cur><xsl:value-of select="cur * 1024"/></cur>
						<total><xsl:value-of select="total * 1024"/></total>
						<free>
							<xsl:choose>
								<xsl:when test="(total - cur) &gt; 0">
									<xsl:value-of select="(total - cur) * 1024"/>
								</xsl:when>
								<xsl:otherwise>0</xsl:otherwise>
							</xsl:choose>    
						</free>
					</values>
				</resource>
			</xsl:for-each>
		</xsl:variable>	
		<xsl:variable name="disk-info" select="exsl:node-set($disk-info-rtf)"/>
		<xsl:variable name="diskspace-alert" select="show-resource:normalize-alert-type($total-alerts/alerts/alert[id = 'diskspace']/type,1)"/>
		<xsl:variable name="diskinodes-alert" select="show-resource:normalize-alert-type($total-alerts/alerts/alert[id = 'diskinodes']/type,1)"/>

		<packet>
			<!-- check premissions before execute request -->
			<xsl:if test="cred:check-env('vzcp.env.manage.resources',$ve-eid)">
				<cookie>
					<resources>
						<group>
							<id>cpu</id>
							<title>
								<sw:text>CPU Usage</sw:text>
							</title>
							<resource>
								<id>cpu</id>
								<gauge>cpu</gauge>
								<alert>
									<type><xsl:value-of select="$cpu-alert"/></type>
									<show-by-icon/>
								</alert>
								<name>
									<sw:text>CPU</sw:text>
								</name>
								<xsl:if test="$cr-resource-extended">
									<link>/vzdir/infrman/envs/resources-adv</link>
								</xsl:if>
								<fraction>
									<xsl:value-of select="$cpu-load"/>
								</fraction>
							</resource>
							<xsl:if test="vt:is-platform-linux($platform)">
								<resource>
									<name>
										<sw:text>Load Average</sw:text>
									</name>
									<alert>
										<type><xsl:value-of select="$load-average-alert"/></type>
										<show-by-icon/>
									</alert>
									<value>
										<xsl:value-of select="$load-average"/>
									</value>
								</resource>
							</xsl:if>
						</group>

						<!-- Memory -->
						<group>
							<id>system</id>
							<title>
								<sw:text>Memory Usage</sw:text>
							</title>
							<resource>
								<xsl:if test="$cr-resource-extended">
									<link>/vzdir/infrman/envs/resources-adv</link>
								</xsl:if>
								<id>memory</id>
								<gauge>system</gauge>
								<alert>
									<type><xsl:value-of select="$memory-alert"/></type>
									<show-by-icon/>
								</alert>
								<name>
									<sw:text>Memory</sw:text>
								</name>
								<fraction>
									<xsl:value-of select="$memory/fraction"/>
								</fraction>
								<values>
									<cur>
										<xsl:value-of select="format:int2bytes($memory/used,'', 'yes', '#,##0.#')"/>
									</cur>
									<total>
										<xsl:value-of select="format:int2bytes($memory/total,'', 'yes', '#,##0.#')"/>
									</total>
									<free>
										<xsl:value-of select="format:int2bytes($memory/free,'', 'yes', '#,##0.#')"/>
									</free>
								</values>
							</resource>
						</group>

						<!-- DiskSpace -->
						<group>
							<id>disk</id>
							<title>
								<sw:text>Disk Usage</sw:text>
							</title>
							<xsl:for-each select="$vequota/ve_quota/diskspace">
								<resource>
									<xsl:if test="$cr-resource-extended">
										<link>/vzdir/infrman/envs/resources-adv</link>
									</xsl:if>
									<id>diskspace</id>
									<gauge>diskspace</gauge>
									<alert>
										<type><xsl:value-of select="$diskspace-alert"/></type>
										<show-by-icon/>
									</alert>
									<name>
										<sw:text>Disk Space</sw:text>
									</name>
									<fraction>
										<xsl:value-of select="cur div total"/>
									</fraction>
									<values>
										<cur>
											<sizekb format="#0.00">
												<xsl:value-of select="cur"/>
											</sizekb>
										</cur>
										<total>
											<sizekb format="#0.00">
												<xsl:value-of select="total"/>
											</sizekb>
										</total>
										<free>
											<sizekb format="#0.00">
												<xsl:choose>
													<xsl:when test="(total - cur) &gt; 0">
														<xsl:value-of select="total - cur"/>
													</xsl:when>
													<xsl:otherwise>0</xsl:otherwise>
												</xsl:choose>
											</sizekb>
										</free>
										<units>
											<sw:text>1K blocks</sw:text>
										</units>
									</values>
								</resource>
							</xsl:for-each>

							<!-- DiskInodes -->
							<xsl:for-each select="$vequota/ve_quota/diskinodes[ hard &gt; 0 ]">
								<resource>
									<xsl:if test="$cr-resource-extended">
										<link>/vzdir/infrman/envs/resources-adv</link>
									</xsl:if>
									<id>diskinodes</id>
									<gauge>diskinodes</gauge>
									<alert>
										<type><xsl:value-of select="$diskinodes-alert"/></type>
										<show-by-icon/>
									</alert>
									<name>
										<sw:text>Disk Inodes</sw:text>
									</name>
									<fraction>
										<xsl:value-of select="cur div total"/>
									</fraction>
									<values>
										<cur>
											<xsl:value-of select="format-number(cur, '#,##0')"/>
										</cur>
										<total>
											<xsl:value-of select="format-number(total, '#,##0')"/>
										</total>
										<free>
											<xsl:choose>
												<xsl:when test="(total - cur) &gt; 0">
													<xsl:value-of select="format-number(total - cur, '#,##0')"/>
												</xsl:when>
												<xsl:otherwise>0</xsl:otherwise>
											</xsl:choose>
										</free>
									</values>
								</resource>
							</xsl:for-each>
						</group>
						
						<xsl:variable name="netconfig-raw" select="networkm:get-config(sw:hn-eid())"/>
						<!-- check shaping , accounting always on   -->
						<xsl:if test="$netconfig-raw/shaping">
							<!-- NetWork -->
							<xsl:variable name="netcounters" select="vznet:merge-network-class()"/>							
							<xsl:variable name="vetraffic-rtf">
								<xsl:call-template name="vznet:resource-network">
									<xsl:with-param name="ve-eid" select="$ve-eid"/>
									<xsl:with-param name="netcounters" select="$netcounters"/>									
								</xsl:call-template>
							</xsl:variable>
							<xsl:variable name="vetraffic" select="exsl:node-set($vetraffic-rtf)"/>
							<!-- if shaping on, but no class configure per VE - no need show bandwidth -->
							<xsl:if test="count($vetraffic/resources/resource[not(fraction = -1)]) &gt; 0"> 
								<group>
									<id>network</id>
									<gauge>bandwidth</gauge>
									<title>
										<sw:text>Network Usage</sw:text>
									</title>
									<xsl:for-each select="$vetraffic/resources/resource[not(fraction = -1)]">
										<xsl:variable name="current-class-id" select="class"/>
										<resource>
											<xsl:if test="$cr-resource-extended">
												<link>/vzdir/infrman/envs/resources-adv</link>
											</xsl:if>
											<id>network</id>
											<gauge>bandwidth</gauge>
											<xsl:variable name="current-class-alert" select="sw:get-fake-alerts(fraction,1)"/>
											<alert>
												<type><xsl:value-of select="exsl:node-set($current-class-alert)/level"/></type>
												<show-by-icon/>
											</alert>
											<name><xsl:value-of select="$netcounters/range[class_id = $current-class-id]/title"/></name>
											<xsl:copy-of select="fraction"/>
										</resource>
									</xsl:for-each>
								</group>
							</xsl:if>
						</xsl:if>
					</resources>
				</cookie>
			</xsl:if>
		</packet>
	</xsl:template>

</xsl:stylesheet>
