<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred func vzenv servicem"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:servicem="http://www.swsoft.com/xsl/cp/servicem"
	xmlns:func="http://exslt.org/functions"
	xmlns:vzenv="http://www.swsoft.com/xsl/cp/vzenv"
>

	<sw:include href="/lib/swa/servicem.xsl"/>
	<sw:include href="/lib/vz/vzenv-core.xsl"/>

	<xsl:output method="xml"/>

	<xsl:variable name="eid" select="sw:ve-eid()"/>
	<xsl:variable name="tab" select="sw:param('tab')"/>
	<xsl:variable name="returl" select="concat($requesturl,'?tab=',$tab)"/>

	<xsl:template match="/">

		<packet/>
		<!-- all action put in lib -->

		<xsl:variable name="id" select="sw:param('id')"/>
		<xsl:variable name="services-rtf">
			<xsl:for-each select="$id">
				<service>
					<name>
						<xsl:value-of select="."/>
					</name>
					<display-name>
						<xsl:value-of select="."/>
					</display-name>
				</service>
			</xsl:for-each>
		</xsl:variable>
		<xsl:variable name="services" select="exsl:node-set($services-rtf)"/>

		<xsl:choose>
			<xsl:when
				test="not(sw:param('start') or sw:param('stop') or sw:param('restart') or sw:param('fast_stop') or sw:param('enable') or sw:param('disable') )">
				<!-- no action specified -->
			</xsl:when>
			<xsl:when test="count($services/service) = 0">
				<xsl:if test="error:put(sw:text('Please select at least one service.'),'')"/>
			</xsl:when>

			<xsl:when test="sw:param('start')">
				<xsl:if test="error:is-empty()">
					<xsl:if test="cred:detail-check-env('vzcp.env.manage.services_and_files',$eid)"/>
				</xsl:if>
				<xsl:if test="error:is-empty()">
					<xsl:choose>
						<xsl:when test="$tab = 'xinetd-all' or $tab = 'xinetd-standart'">
							<xsl:copy-of select="servicem:xinetd-service-enable($eid,$services)"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:copy-of select="servicem:sysv-service-start($eid,$services)"/>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:if test="sw:response('lib/opredirect.xsl')"/>
				</xsl:if>
			</xsl:when>

			<xsl:when test="sw:param('restart')">
				<xsl:if test="error:is-empty()">
					<xsl:if test="cred:detail-check-env('vzcp.env.manage.services_and_files',$eid)"/>
				</xsl:if>
				<xsl:if test="error:is-empty()">
					<xsl:copy-of select="servicem:sysv-service-restart($eid,$services)"/>
					<xsl:if test="sw:response('lib/opredirect.xsl')"/>
				</xsl:if>
			</xsl:when>

			<xsl:when test="sw:param('stop')">
				<xsl:if test="error:is-empty()">
					<xsl:if test="cred:detail-check-env('vzcp.env.manage.services_and_files',$eid)"/>
				</xsl:if>
				<xsl:if test="error:is-empty()">
					<xsl:choose>
						<xsl:when test="$tab = 'xinetd-all' or $tab = 'xinetd-standart'">
							<xsl:copy-of select="servicem:xinetd-service-disable($eid,$services)"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:copy-of select="servicem:sysv-service-stop($eid,$services)"/>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:if test="sw:response('lib/opredirect.xsl')"/>
				</xsl:if>
			</xsl:when>

			<xsl:when test="sw:param('enable')">
				<xsl:if test="error:is-empty()">
					<xsl:if test="cred:detail-check-env('vzcp.env.manage.services_and_files',$eid)"/>
				</xsl:if>
				<xsl:if test="error:is-empty()">
					<xsl:copy-of select="servicem:sysv-service-autostart-enable($eid,$services)"/>
					<xsl:if test="sw:response('lib/opredirect.xsl')"/>
				</xsl:if>
			</xsl:when>

			<xsl:when test="sw:param('disable')">
				<xsl:if test="error:is-empty()">
					<xsl:if test="cred:detail-check-env('vzcp.env.manage.services_and_files',$eid)"/>
				</xsl:if>
				<xsl:if test="error:is-empty()">
					<xsl:copy-of select="servicem:sysv-service-autostart-disable($eid,$services)"/>
					<xsl:if test="sw:response('lib/opredirect.xsl')"/>
				</xsl:if>
			</xsl:when>

		</xsl:choose>
	</xsl:template>

	<!-- creds  -->
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/common.xsl"/>

</xsl:stylesheet>
