<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred error check local servicem vzenv"
	xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl			="http://exslt.org/common"
	xmlns:sw				="http://www.swsoft.com/xsl/cp"
	xmlns:error			="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz				="http://www.swsoft.com/xsl/cp/wiz"
  xmlns:func			="http://exslt.org/functions"	
	xmlns:cred			="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local     ="http://www.swsoft.com/xsl/cp/local"
	xmlns:check     ="http://www.swsoft.com/xsl/cp/check"
	xmlns:servicem   ="http://www.swsoft.com/xsl/cp/servicem"
	xmlns:vzenv		="http://www.swsoft.com/xsl/cp/vzenv"
>
	<sw:include href="/lib/swa/servicem.xsl"/>	
  <sw:include href="/lib/vz/vzenv-core.xsl"/>

 <xsl:output method="xml"/>

	<xsl:variable name="eid" select="sw:ve-eid()" />	
	<xsl:variable name="returl"	select="'redirect-prev'"/>

	<xsl:variable name="step" select="wiz:processing-step-id()"/>

	<xsl:param name="wiz_code" select="'service-management'"/>
 	<xsl:variable name="form" select="local:init-form()"/>

	<xsl:template match="node()|@*">
		<xsl:choose>
			<xsl:when test="$step='srv-detail'">
				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="name()='startup-type'"></xsl:when>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>

					<startup-type>
						<xsl:value-of select="sw:param('startup-type')"/>
					</startup-type>
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>

				<xsl:if test="sw:param('next')">
					<!-- CHECK DATA -->
					<!-- no possible error on form: only radio button present -->
				</xsl:if>

				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new_form"/>
				</xsl:call-template>
			</xsl:when>			
		</xsl:choose>
		
		<xsl:copy/>
	</xsl:template>
	
	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		
		<!--|-->		
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
						<xsl:if test="error:is-empty()">
							<xsl:if test="cred:detail-check-env('vzcp.env.manage.services_and_files',$eid)"/>
  		  		</xsl:if>
			    	<xsl:choose>
				    	<xsl:when test="error:is-empty()">
								<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
								<xsl:copy-of select="local:final($data)"/>
								<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>	
			      	</xsl:when>
							<xsl:otherwise>
								<packet/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>
					
	</xsl:template>
	
	<func:function name="local:init-form">
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:init-new"/>				
 		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>
 	
	<xsl:template name="local:init-new">
		<xsl:variable name="svc" select="sw:base64-decode(sw:param('name'))"/>	
		<xsl:variable name="name" select="substring-before($svc, '|')"/>	
		<!-- load service detail by name -->
		<xsl:variable name="service-details" select="servicem:get($eid,$name)/servicem/service"/>
		<xsl:variable name="new_form">
			<name>
				<xsl:value-of select="$name"/>
			</name>
			<display-name>
				<xsl:value-of select="sw:base64-decode($service-details/display_name)"/>
			</display-name>
			<startup-type>
				<xsl:value-of select="$service-details/startup_type"/>
			</startup-type>
			<status>
				<xsl:value-of select="$service-details/status"/>
			</status>
			<logon-as>
				<xsl:value-of select="$service-details/logon_as"/>
			</logon-as>

			<!-- prepare all deps services -->
			<xsl:variable name="dep-services-rtf">
				<service>
				<xsl:for-each select="$service-details/dependent|$service-details/depended_on">
					<name><xsl:value-of select="."/></name>
				</xsl:for-each>
				</service>
			</xsl:variable>
			<xsl:variable name="dep-services" select="exsl:node-set($dep-services-rtf)"/>
			
			<!-- get info about all deps services -->
			<xsl:variable name="dep-service-details" select="servicem:get($eid,$dep-services)/servicem/service"/>						
			
			<!-- fill answer structure with display name and short name -->
			<dependent>			
				<xsl:for-each select="$service-details/dependent">			
					<xsl:variable name="cur-dependent-name" select="."/>
					<service>
						<display-name>				
							<xsl:value-of select="sw:base64-decode($dep-service-details[name = $cur-dependent-name]/display_name)"/>
						</display-name>
						<name>				
							<xsl:value-of select="$cur-dependent-name"/>
						</name>
					</service>
				</xsl:for-each>					
			</dependent>

			<depended-on>			
				<xsl:for-each select="$service-details/depended_on">			
					<xsl:variable name="cur-depended-on-name" select="."/>
					<service>
						<display-name>				
							<xsl:value-of select="sw:base64-decode($dep-service-details[name = $cur-depended-on-name]/display_name)"/>
						</display-name>
						<name>				
							<xsl:value-of select="$cur-depended-on-name"/>
						</name>
					</service>
				</xsl:for-each>					
			</depended-on>
				
			<description>
				<xsl:value-of select="sw:base64-decode($service-details/description)"/>
			</description>
		</xsl:variable>
		<!-- Init steps -->
		<xsl:variable name="new_steps_">
			<step id="srv-detail" screen-id="03.02.01.07.08" 
					screen-title="{sw:text('Service Management')}" 
					cred="vzcp.env.manage.services_and_files"
					security-obj-type="ve.vz.vt"
			/>
		</xsl:variable>

		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:variable name="new_steps_filtered">
				<xsl:copy-of	select="exsl:node-set($new_steps_)/step[(not(@cred) or cred:check-env(@cred,$eid)) and (not(@platform) or (@platform = $platform))]"/>
			</xsl:variable>
			<xsl:variable name="new_steps" select="exsl:node-set($new_steps_filtered)"/>
			<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
			<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
			<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>
	</xsl:template>
	
	<!-- *********************************************************** -->
	<func:function name="local:final">
		<xsl:param name="data"/>
		<func:result select="servicem:win-startup-type($eid,$data)"/>
	</func:function>

  <!-- credentials -->	
  <sw:include href="/lib/cred.xsl"/>
	
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>
  
	<sw:include href="/lib/vocabulary.xsl"/>				
	
</xsl:stylesheet>
