<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred servicem vzenv"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl	="http://exslt.org/common"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
	xmlns:servicem  ="http://www.swsoft.com/xsl/cp/servicem"
	xmlns:vzenv		="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
>
  <sw:include href="/lib/swa/servicem.xsl"/>	
  <sw:include href="/lib/vz/vzenv-core.xsl"/>
  
  <xsl:output method="xml"/>

  <xsl:variable name="eid" select="sw:ve-eid()" />	
	<xsl:variable name="returl"	select="'redirect-last'"/>

  <xsl:variable name="service-name">
		<xsl:variable name="new-service-name"	select="sw:param('id')"/>
    <xsl:if test="$new-service-name">
      <xsl:value-of select="sw:sesput('svcname', $new-service-name)"/>
    </xsl:if>
    <xsl:value-of select="sw:sesget('svcname')"/>
  </xsl:variable>

  <xsl:template match="/">
	<sw:noauth-redirect select="not(cred:check-env('vzcp.env.manage.services_and_files', $eid))"/>
    <!-- get action -->
    <xsl:variable name="action">
      <xsl:choose>
        <xsl:when test="sw:param('restart_service')">restart</xsl:when>
        <xsl:when test="sw:param('start_service')">start</xsl:when>
        <xsl:when test="sw:param('stop_service')">stop</xsl:when>
        <xsl:when test="sw:param('enable_service')">enable</xsl:when>
        <xsl:when test="sw:param('disable_service')">disable</xsl:when>
        <xsl:when test="sw:param('autostart_service')">autostart_on</xsl:when>
        <xsl:when test="sw:param('noautostart_service')">autostart_off</xsl:when>
      </xsl:choose>
    </xsl:variable>

    <xsl:choose>
    	<xsl:when test="$service-name and not($action = '')">
				<xsl:choose>
					<xsl:when test="error:is-empty()">
						<xsl:call-template name="one-service-management">
							<xsl:with-param name="service-name" select="$service-name"/>
							<xsl:with-param name="action" select="$action"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="one-service-view">
							<xsl:with-param name="service-name" select="$service-name"/>
						</xsl:call-template>
					</xsl:otherwise>
				</xsl:choose> 
			</xsl:when>

      <!-- pass parameters for single service form -->
      <xsl:otherwise>
				<xsl:call-template name="one-service-view">
        	<xsl:with-param name="service-name" select="$service-name"/>
				</xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

	<xsl:template name="one-service-management">
		<xsl:param name="service-name"/>
		<xsl:param name="action"/>

		<packet/>
		<!-- all action in lib -->

    <xsl:choose>
    	<xsl:when test="$action = 'start'">
				<xsl:copy-of select="servicem:sysv-service-start($eid,$service-name)"/>
      </xsl:when>

      <xsl:when test="$action = 'restart'">
				<xsl:copy-of select="servicem:sysv-service-restart($eid,$service-name)"/>
      </xsl:when>

      <xsl:when test="$action = 'stop'">
				<xsl:copy-of select="servicem:sysv-service-stop($eid,$service-name)"/>
      </xsl:when>

      <xsl:when test="$action = 'autostart_on'">
				<xsl:copy-of select="servicem:sysv-service-autostart-enable($eid,$service-name)"/>
			</xsl:when>

      <xsl:when test="$action = 'autostart_off'">
				<xsl:copy-of select="servicem:sysv-service-autostart-disable($eid,$service-name)"/>
      </xsl:when>

      <xsl:when test="$action = 'enable'">
				<xsl:copy-of select="servicem:xinetd-service-enable($eid,$service-name)"/>
			</xsl:when>

      <xsl:when test="$action = 'disable'">
				<xsl:copy-of select="servicem:xinetd-service-disable($eid,$service-name)"/>
      </xsl:when>

    </xsl:choose>
    <xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
	</xsl:template>

	<xsl:template name="one-service-view">
		<xsl:param name="service-name"/>
		<xsl:variable name="service-detail" select="servicem:get($eid,$service-name)"/>
		<packet>
			<cookie>
				<xsl:copy-of select="$service-detail/servicem"/>
				<xsl:if test="$service-detail/servicem/service/xinetd">
					<!-- make one addon request for xinetd states -->
					<xsl:variable name="xinetd-detail" select="servicem:get($eid,'xinetd')"/>
					<xinetd-autostart>
						<xsl:value-of  select="sw:if($xinetd-detail/servicem/service/level = 3,1,0)"/>
					</xinetd-autostart>
					<xinetd-state>
						<xsl:value-of select="sw:if($xinetd-detail/servicem/service/state = 1,1,0)"/>
					</xinetd-state>
				</xsl:if>
			</cookie>	
		</packet>
	</xsl:template>

  <!-- credentials -->
  <sw:include href="/lib/cred.xsl"/>
  <sw:include href="/lib/common.xsl"/>

</xsl:stylesheet>
