<!--
	Copyright (c) SWsoft, 1999-2007
	All rights reserved.
-->
<xsl:stylesheet version="1.0" extension-element-prefixes="exsl sw error check wiz local func cred networkm traffic env set ve"
	xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl			="http://exslt.org/common"
	xmlns:sw				="http://www.swsoft.com/xsl/cp"
	xmlns:error			="http://www.swsoft.com/xsl/cp/error"
	xmlns:check			="http://www.swsoft.com/xsl/cp/check"
	xmlns:wiz				="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local			="http://www.swsoft.com/xsl/cp/local"
	xmlns:func			="http://exslt.org/functions"
	xmlns:cred			="http://www.swsoft.com/xsl/cp/cred"
	xmlns:networkm	="http://www.swsoft.com/xsl/cp/networkm"
	xmlns:traffic		="http://www.swsoft.com/xsl/cp/traffic"
	xmlns:env				="http://www.swsoft.com/xsl/cp/env"
	xmlns:set				="http://exslt.org/sets"
	xmlns:ve				="http://www.swsoft.com/xsl/cp/ve"
	xmlns:vt				="http://www.swsoft.com/xsl/cp/vt"
	>

	<xsl:output method="xml"/>

	<xsl:variable name="ve-eid" select="sw:ve-eid()"/>
	
	<xsl:variable name="step" select="wiz:processing-step-id()"/>
	<xsl:param name="wiz_code" select="'ve_shaping'"/>
	<xsl:variable name="form" select="local:init-form()"/>

	<xsl:template match="node()|@*">
		<xsl:variable name="new_form_">
			<xsl:choose>
				<xsl:when test="$step='edit'">
					<xsl:variable name="rate-type"	select="sw:param('rate_type')"/>
					<xsl:variable name="rate-bound"	select="sw:param('rate_bound')"/>
					<ve>
						<xsl:if test="$rate-type = 'custom'">
							<xsl:for-each select="sw:param('class')">
								<xsl:variable name="class-id" select="string(.)"/>
								<interface_rate>
									<class_id>
										<xsl:value-of select="$class-id"/>
									</class_id>
									<rate>
										<xsl:value-of select="sw:param(concat('rate_',$class-id))"/>
									</rate>
									<factor_rate>
										<xsl:value-of select="sw:param(concat('factor_rate_',$class-id))"/>
									</factor_rate>								
								</interface_rate>
							</xsl:for-each>	
						</xsl:if>
						<rate_bound>
							<xsl:value-of select="$rate-bound"/>
						</rate_bound>
						<xsl:copy-of select="$form/ve/linux"/>
					</ve>
					<rate-type>
						<xsl:value-of select="$rate-type"/>
					</rate-type>
					<xsl:copy-of select="$form/hn"/>					
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="$form/hn"/>
					<xsl:copy-of select="$form/ve"/>
					<xsl:copy-of select="$form/rate-type"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
		<xsl:if test="sw:sesputtree($wiz_data,$new_form)"/>
		<xsl:call-template name="local:completeFormHandling">
			<xsl:with-param name="data"		select="$new_form"/>
			<xsl:with-param name="ve-eid"	select="$ve-eid"/>
		</xsl:call-template>
		<xsl:copy/>
	</xsl:template>

	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<xsl:param name="ve-eid" select="sw:ve-eid()"/>
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
						<xsl:if test="$data/rate-type = 'custom'">
							<xsl:if test="traffic:check-env-shaping($data/ve)"/>
						</xsl:if>
						<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:copy-of select="local:getFinalPacket($data,$ve-eid)"/>
								<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
							</xsl:when>
							<xsl:otherwise>
								<packet/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<func:function name="local:init-form">
		<sw:noauth-redirect select="not(cred:check-env('vzcp.env.manage.properties.preferences',$ve-eid))"/>
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:init-new"/>				
 		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>
 	
	<xsl:template name="local:init-new">
		<xsl:param name="ve-eid" select="sw:ve-eid()"/>
		<xsl:variable name="init-mode" select="sw:if(sw:param('mode') = 'edit','edit','view')"/>
		<!-- Init steps -->
		<xsl:variable name="new_steps_">
			<xsl:choose>
				<xsl:when test="$init-mode='edit'">
					<step id="edit" screen-id="03.02.01.03.10" screen-title="{sw:text('Configure Traffic Shaping')}"
						screen-icon="traffic_shape"/>
				</xsl:when>
				<xsl:when test="$init-mode='view'">
					<step id="view" screen-id="03.02.01.03.05" screen-title="{sw:text('View Traffic Shaping')}"
						screen-icon="traffic_shape"/>
				</xsl:when>
			</xsl:choose>	
		</xsl:variable>
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:variable name="saved_form" select="sw:sesputtree($wiz_data, local:initData($ve-eid))"/>
			<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
			<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
			<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>
	</xsl:template>

	<func:function name="local:initData">
		<xsl:param name="ve-eid" select="sw:ve-eid()"/>
		<xsl:variable name="hn-eid"	select="sw:ve-parent($ve-eid)"/>
		<xsl:variable name="env"		select="env:get-env($ve-eid)/env"/>
		<xsl:variable name="netconfig-raw" select="networkm:get-config($hn-eid)"/>
		<xsl:variable name="netconfig-ve"	select="$env/virtual_config"/>
		<xsl:variable name="platform-is-linux" select="vt:is-platform-linux(ve:ve2platform($env))"/>
		

		<func:result>
			<hn>
				<xsl:copy-of select="$netconfig-raw/shaping"/>
				<xsl:copy-of select="$netconfig-raw/interface"/>
				<xsl:copy-of select="set:distinct($netconfig-raw/range/class_id)/.."/>
				<xsl:copy-of select="$netconfig-raw/class"/>
			</hn>
			<ve>
				<xsl:copy-of select="$netconfig-ve/interface_rate"/>
				<xsl:copy-of select="$netconfig-ve/rate_bound"/>
				<xsl:if test="$platform-is-linux">
					<linux/>  
				</xsl:if>				
			</ve>
			<rate-type>
				<xsl:value-of select="sw:if(not($platform-is-linux) or count($netconfig-ve/interface_rate) &gt; 0,'custom','default')"/>
			</rate-type>
		</func:result>
	</func:function>

	<func:function name="local:getFinalPacket">
		<xsl:param name="data"/>
		<xsl:param name="ve-eid" select="sw:ve-eid()"/>		
		<func:result>
			<packet log="on" progress="on">		
				<target>vzaenvm</target>
				<xsl:copy-of select="sw:hn-dst($ve-eid)"/>
				<cookie>
					<msg>
						<sched>
							<sw:text>The changing of the traffic shaping settings has been scheduled.</sw:text>
						</sched>
						<ok>
							<sw:text>The traffic shaping settings have been successfully changed.</sw:text>
						</ok>					
						<error>
							<sw:text>Failed to update the traffic shaping settings.</sw:text>
						</error>
					</msg>
					<redirect-prev/>
					<operation>env_config_shaping</operation>
				</cookie>
				<data>
					<vzaenvm>
						<set>
							<eid>
								<xsl:value-of select="$ve-eid"/>
							</eid>
							<config>
								<xsl:if test="$data/rate-type = 'custom'">
									<xsl:choose>
										<xsl:when test="count($data/ve/interface_rate/rate) &gt; 0">
											<xsl:for-each select="$data/ve/interface_rate">
												<interface_rate>											
													<rate>
														<xsl:value-of select="format-number((rate * factor_rate) div 1000,'#')"/>
													</rate>
													<class_id>
														<xsl:value-of select="class_id"/>
													</class_id>
												</interface_rate>
											</xsl:for-each>
										</xsl:when>
										<xsl:otherwise>
											<interface_rate>
												<rate/>
											</interface_rate>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:if>
								<xsl:copy-of select="$data/ve/rate_bound"/>
							</config>
							<xsl:if test="$data/rate-type = 'default'">
              	<default>interface_rate</default>
							</xsl:if>             							
						</set>
					</vzaenvm>
				</data>
			</packet>
		</func:result>
	</func:function>

	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/vza/networkm.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>	
	<sw:include href="/lib/traffic.xsl"/>

</xsl:stylesheet>
