<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func voc cred local check wiz dev"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:voc="http://www.swsoft.com/xsl/cp/voc"
	xmlns:check="http://www.swsoft.com/xsl/cp/check"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"	
	xmlns:vz="http://www.swsoft.com/xsl/cp/vz"
	xmlns:dev="http://www.swsoft.com/xsl/cp/dev"
>

	<sw:include href="/lib/vt/env-core.xsl"/>


	<xsl:output method="xml"/>
	<xsl:param name="wiz_code" select="'ve-create-volume'"/>
	<xsl:variable name="step" select="wiz:processing-step-id()"/>
	<xsl:variable name="form" select="local:init-form()"/>

	<xsl:template match="node()|@*">
		<!-- /Init Form Data -->

		<xsl:choose>
			<!-- Step "General Settings" -->
			<xsl:when
				test="$step='gen'">

				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="name()=$step"/>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<gen>
						<point>
							<xsl:value-of select="sw:param('point')"/>
						</point>
						<size>
							<xsl:value-of select="sw:param('size')"/>
						</size>
						<size-unit>
							<xsl:value-of select="sw:param('size_unit')"/>
						</size-unit>
					</gen>
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>

				<xsl:if test="sw:param('back')">
					<!-- Move to back -->
					<xsl:if test="wiz:goBack()"/>
				</xsl:if>
				<xsl:if test="sw:param('next')">
					<!-- Check data -->
					<!-- check point -->
					<xsl:choose>
						<!-- check point presence -->
						<xsl:when test="string($new_form/gen/point)=''">
							<xsl:if test="error:put(sw:text('You should specify the mount point.'),'','point')"/>
						</xsl:when>
					</xsl:choose>
					<!-- check size -->
					<xsl:choose>
						<!-- check size presence -->
						<xsl:when test="string($new_form/gen/size)=''">
							<xsl:if test="error:put(sw:text('You should specify a volume size.'),'','size')"/>
						</xsl:when>
						<!-- check size format -->
						<xsl:when test="not(check:num($new_form/gen/size))">
							<xsl:if
								test="error:put(sw:text('You should specify the volume size as an integer value.'),'','size')"
							/>
						</xsl:when>
						<!-- check size for low limit -->
						<xsl:when
							test="($new_form/gen/size * $new_form/gen/size-unit) &lt; $new_form/def/min-size">
							<xsl:variable name="error">
								<sw:text>
									<xsl:with-param name="value" select="round($new_form/def/min-size div 1024)"
									/>
				      				The volume size should be equal to or greater than %{value} KB.				      		
				      		</sw:text>
							</xsl:variable>
							<xsl:if test="error:put($error,'','size')"/>
						</xsl:when>
					</xsl:choose>
					<!-- Move to next step -->
					<xsl:choose>
						<xsl:when test="error:is-empty()">
							<xsl:copy-of select="local:final($new_form)"/>
							<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
						</xsl:when>
					</xsl:choose>
				</xsl:if>

				<!-- Store form values-->
				<xsl:variable name="res">
					<xsl:value-of select="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
				</xsl:variable>

			</xsl:when>

		</xsl:choose>

	</xsl:template>

	<func:function name="local:init-form">
		<sw:noauth-redirect select="not(cred:check-env('vzcp.env.manage.properties.hardware',sw:ve-eid()))"/>
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:init-new"/>				
 		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>
 	
	<xsl:template name="local:init-new">
			<!-- Init default data -->
			<xsl:variable name="voc-args">
				<category>vz_dev</category>
			</xsl:variable>
			<xsl:variable name="voc" select="voc:get($voc-args, env:make-platform-ref(sw:ve-parent()))"/>
			<!-- /Init default data -->
			<xsl:variable name="new_form">
				<eid><xsl:value-of select="sw:ve-eid()"/></eid>
				<def>
					<min-size>
						<xsl:value-of select="$voc[id='drive_size']/min"/>
					</min-size>
				</def>
				<gen>
					<size-unit>1048576</size-unit>
				</gen>
			</xsl:variable>
			<!-- Init steps -->
			<xsl:variable name="new_steps_">
				<step id="gen" screenid="03.02.01.08.03"/>
			</xsl:variable>
			<!-- Save wizard initial settings -->
			<xsl:if test="error:is-empty()">
				<xsl:variable name="new_steps_filtered">
					<xsl:copy-of
						select="exsl:node-set($new_steps_)/step"
					/>
				</xsl:variable>
				<xsl:variable name="new_steps" select="exsl:node-set($new_steps_filtered)"/>
				<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
				<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
				<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
				<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
			</xsl:if>
	</xsl:template>

	<!-- *********************************************************** -->
	<func:function name="local:final">
		<xsl:param name="data"/>
		<!--|-->
		<func:result>
			<packet log="on" progress="on">
				<target>vzadevm</target>
				<xsl:copy-of select="sw:hn-dst($data/eid)"/>
				<cookie>
					<msg>
						<ok>
							<sw:text>The volume has been created.</sw:text>
						</ok>
						<error>
							<sw:text>Failed to create the volume.</sw:text>
						</error>
					</msg>
					<operation>ve_mount_device</operation>
					<redirect-prev/>
				</cookie>
				<data>
					<vzadevm>
						<create_drive>
							<eid>
								<xsl:value-of select="$data/eid"/>
							</eid>
							<point>
								<xsl:value-of select="$data/gen/point"/>
							</point>
							<size>
								<xsl:value-of select="format-number($data/gen/size * $data/gen/size-unit,'#')"/>
							</size>
						</create_drive>
					</vzadevm>
				</data>
				<vzcpauth/>
			</packet>
		</func:result>
	</func:function>


	<!-- UI modules -->
	<sw:include href="/lib/wizard.xsl"/>

	<!-- System modules -->
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/globals.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>

	<!-- VZA functionality modules -->
	<sw:include href="/lib/vza/dev.xsl"/>

</xsl:stylesheet>
