<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl sw func local dev cred"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:dev="http://www.swsoft.com/xsl/cp/dev"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
>

	<xsl:output method="xml"/>

	<xsl:template match="/">
		<!-- check permissions to this page -->
		<xsl:variable name="cr-manage"
			select="cred:check-env('vzcp.env.manage.properties.hardware',sw:ve-eid())"/>

		<xsl:choose>

			<xsl:when test="sw:param('delete') and not($cr-manage)">
				<!-- no delete cred -->
				<packet/>
			</xsl:when>
			<xsl:when test="sw:param('unmount') and not($cr-manage)">
				<!-- no delete cred -->
				<packet/>
			</xsl:when>

			<!-- there is no post -->
			<xsl:when test="not(/http_request/*[self::post or self::get]/parameter)">
				<packet/>
			</xsl:when>

			<!-- Check selected templates -->
			<xsl:when test="not(sw:param('volume-point'))">
				<xsl:if test="error:put(sw:text('Please select at least one volume.'),'')"/>
				<packet/>
			</xsl:when>

			<!-- Delete volume -->
			<xsl:when test="sw:param('delete')">
				<xsl:choose>
					<xsl:when test="error:is-empty()">
						<xsl:copy-of
							select="local:get-packet-delete(sw:param('volume-point'))"/>
						<xsl:if test="sw:response('lib/opredirect.xsl')"/>
					</xsl:when>
					<xsl:otherwise>
						<packet/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>

			<!-- Unmount template-->
			<xsl:when test="sw:param('unmount')">
				<xsl:choose>
					<xsl:when test="error:is-empty()">
						<xsl:copy-of
							select="local:get-packet-unmount(sw:param('volume-point'))"/>
						<xsl:if test="sw:response('lib/opredirect.xsl')"/>
					</xsl:when>
					<xsl:otherwise>
						<packet/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>

			<!-- Unknown post -->
			<xsl:otherwise>
				<packet/>
			</xsl:otherwise>

		</xsl:choose>
	</xsl:template>


	<func:function name="local:get-packet-delete">
		<xsl:param name="vol_ids"/>
		<xsl:variable name="eid" select="sw:ve-eid()"/>
		<func:result>
			<packet log="on">
				<target>vzadevm</target>
				<xsl:copy-of select="sw:hn-dst($eid)"/>
				<cookie>
					<msg>
						<ok>
							<sw:text>The volume(s) has/have been deleted.</sw:text>
						</ok>
						<error>
							<sw:text>Failed to delete the volume(s).</sw:text>
						</error>
					</msg>
					<operation>delete_ve_volume</operation>
					<redirect-last/>
				</cookie>
				<data>
					<xsl:for-each select="$vol_ids">
						<vzadevm>
							<delete_drive>
								<point>
									<xsl:value-of select="."/>
								</point>
								<eid>
									<xsl:value-of select="$eid"/>
								</eid>
							</delete_drive>
						</vzadevm>
					</xsl:for-each>
				</data>
				<vzcpauth/>
			</packet>
		</func:result>
	</func:function>

	<func:function name="local:get-packet-unmount">
		<xsl:param name="vol_ids"/>
		<xsl:variable name="eid" select="sw:ve-eid()"/>
		<func:result>
			<packet log="on">
				<target>vzadevm</target>
				<xsl:copy-of select="sw:hn-dst($eid)"/>
				<cookie>
					<msg>
						<ok>
							<sw:text>The volume(s) has/have been unmounted.</sw:text>
						</ok>
						<error>
							<sw:text>Failed to unmount the volume(s).</sw:text>
						</error>
					</msg>
					<operation>unmount_ve_volume</operation>
					<redirect-last/>
				</cookie>
				<data>
					<xsl:for-each select="$vol_ids">
						<vzadevm>
							<umount>
								<point>
									<xsl:value-of select="."/>
								</point>
								<eid>
									<xsl:value-of select="$eid"/>
								</eid>
							</umount>
						</vzadevm>
					</xsl:for-each>
				</data>
				<vzcpauth/>
			</packet>
		</func:result>
	</func:function>

	<!-- credentials -->
	<sw:include href="/lib/cred.xsl"/>

	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/vza/dev.xsl"/>

</xsl:stylesheet>
