<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func voc cred local check wiz dev"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl	="http://exslt.org/common"
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:error	="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz		="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local	="http://www.swsoft.com/xsl/cp/local"
  xmlns:func	="http://exslt.org/functions"	
	xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
	xmlns:voc		="http://www.swsoft.com/xsl/cp/voc"
	xmlns:check	="http://www.swsoft.com/xsl/cp/check"
	xmlns:dev	="http://www.swsoft.com/xsl/cp/dev"
>
	<xsl:output method="xml"/>
	<xsl:param name="wiz_code" select="'ve-mount-device'"/>
	<xsl:variable name="step" select="wiz:processing-step-id()"/>
	<xsl:variable name="form" select="local:init-form()"/>

	<xsl:template match="node()|@*">
		<!-- /Init Form Data -->
	
		<xsl:choose>
			<!-- Step "General Settings" -->
			<xsl:when test="$step='gen'">
			
					<xsl:variable name="new_form_">
						<xsl:for-each select="$form/*">
							<xsl:choose>
								<xsl:when test="name()=$step"></xsl:when>
								<xsl:otherwise>
									<xsl:copy-of select="."/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
						<gen>
							<point><xsl:value-of select="sw:param('point')"/></point>
							<device><xsl:value-of select="sw:param('device')"/></device>
						</gen>
					</xsl:variable>
					<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
										
					<xsl:if test="sw:param('back')">
						 <!-- Move to back -->
						<xsl:if test="wiz:goBack()"/>
					</xsl:if>
					<xsl:if test="sw:param('next')">
						<!-- Check data -->
			      <!-- check point -->
			      <xsl:choose>
			      	<!-- check point presence -->
				      <xsl:when test="string($new_form/gen/point)=''">
				      	<xsl:if test="error:put(sw:text('You should specify the mount point.'),'','point')"/>
				      </xsl:when>				      
						</xsl:choose>
						<!-- check device name -->
			      <xsl:choose>
			      	<!-- check device presence -->
				      <xsl:when test="string($new_form/gen/device)=''">
				      	<xsl:if test="error:put(sw:text('You should specify the device name.'),'','device')"/>
				      </xsl:when>				      
						</xsl:choose>
			      <!-- Move to next step -->
			      <xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:copy-of select="local:final($new_form)"/>
								<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>		
							</xsl:when>
						</xsl:choose>
					</xsl:if>
					
					<!-- Store form values-->
					<xsl:variable name="res">
						<xsl:value-of select="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
					</xsl:variable>
					
			</xsl:when>
				
		</xsl:choose>
		
	</xsl:template>
	
	<func:function name="local:init-form">
		<sw:noauth-redirect select="not(cred:check-env('vzcp.env.manage.properties.hardware', sw:ve-eid()))"/>
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:init-new"/>				
 		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>
 	
	<xsl:template name="local:init-new">
			<!-- Init default data -->
			<!-- /Init default data -->
			<xsl:variable name="new_form">
				<gen/>
				<eid><xsl:value-of select="sw:ve-eid()"/></eid>
			</xsl:variable>
			<!-- Init steps -->
			<xsl:variable name="new_steps_">
				<step id="gen" screenid="03.02.01.08.01" cred="vzcp.env.manage.properties.hardware" security-obj-type="ve.vz.vt"/>
			</xsl:variable>
			<!-- Save wizard initial settings -->
			<xsl:if test="error:is-empty()">
				<xsl:variable name="new_steps_filtered">
					<xsl:copy-of	select="exsl:node-set($new_steps_)/step"/>
				</xsl:variable>
				<xsl:variable name="new_steps"	select="exsl:node-set($new_steps_filtered)"/>
				<xsl:variable name="new_step"		select="string($new_steps/step[1]/@id)"/>
				<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
				<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
				<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
			</xsl:if>
	</xsl:template>
	
	<!-- *********************************************************** -->
	<func:function name="local:final">
		<xsl:param name="data"/>
		<!--|-->
		<func:result>
 			<packet log="on" progress="on">
				<target>vzadevm</target>
				<xsl:copy-of select="sw:hn-dst($data/eid)"/>
        <cookie>
          <msg>
            <sched><sw:text>The device has been scheduled for mounting.</sw:text></sched>
            <error><sw:text>Failed to mount the device.</sw:text></error>
          </msg>
          <operation>ve_mount_device</operation>
          <redirect-prev/>
        </cookie>			
				<data>
					<vzadevm>
						<new_mount>
							<eid><xsl:value-of select="$data/eid"/></eid>								
							<device><xsl:value-of select="$data/gen/device"/></device>
							<point><xsl:value-of select="$data/gen/point"/></point>
						</new_mount>
					</vzadevm>
				</data>
				<vzcpauth/>
			</packet>
 		</func:result>
	</func:function>
	
	
	<!-- UI modules -->
	<sw:include href="/lib/wizard.xsl"/>
	
	<!-- System modules -->
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/globals.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>		

	<!-- VZA functionality modules -->	
	<sw:include href="/lib/vza/dev.xsl"/>			
	
</xsl:stylesheet>
