<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl sw func env-samplem local cred dirm vz xsi"
  xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl		="http://exslt.org/common"
  xmlns:sw			="http://www.swsoft.com/xsl/cp"
  xmlns:error		="http://www.swsoft.com/xsl/cp/error"
	xmlns:sample	="http://www.swsoft.com/xsl/cp/sample"  
  xmlns:env-samplem	="http://www.swsoft.com/xsl/cp/env-samplem"
  xmlns:func		="http://exslt.org/functions"
	xmlns:cred		="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"
	xmlns:dirm		="http://www.swsoft.com/xsl/cp/dirm"
	xmlns:vz			="http://www.swsoft.com/xsl/cp/vz"
	xmlns:vt			="http://www.swsoft.com/xsl/cp/vt"	
	xmlns:sys			="http://www.swsoft.com/xsl/cp/sys"
	xmlns:xsi			="http://www.w3.org/2001/XMLSchema-instance"
>
	<sw:include href="/lib/core/sys-attrs.xsl"/>	
	<sw:include href="/lib/swa/dirm.xsl"/>	
  <sw:include href="/lib/swa/env-samplem.xsl"/>	
  <sw:include href="/lib/vt/core.xsl"/>	  
  <sw:include href="/lib/vz/core.xsl"/>	
  
  <xsl:output method="xml"/>

	<xsl:template match="/">
		<xsl:variable name="samples" select="sw:param('id')"/>
		<xsl:choose>
				<xsl:when test="not(cred:check('vzcp.envsamples'))">	
					<!-- no cred -->
					<packet/>
				</xsl:when>

        <!-- Check selected templates -->
        <xsl:when test="not($samples)">
          <xsl:if test="error:put(sw:text('Please select at least one Container sample.'),'')"/>
          <packet/>
        </xsl:when>

        <!-- Delete template-->
        <xsl:when test="sw:param('delete')">
    			<xsl:choose>
	          <xsl:when test="error:is-empty()">
	          	<xsl:copy-of select="local:getPacketDelete($samples)"/>
  	        	<xsl:if test="sw:response('lib/opredirect.xsl')"/>
	          </xsl:when>
  	        <xsl:otherwise>
    	        <packet/>
      	    </xsl:otherwise>
        	</xsl:choose>
        </xsl:when>
        
        <!-- Clone template-->
        <xsl:when test="sw:param('clone')">
          <xsl:choose>
            <xsl:when test="error:is-empty()">
		          <xsl:copy-of select="local:getPacketClone($samples)"/>
    		      <xsl:if test="sw:response('lib/opredirect.xsl')"/>	
            </xsl:when>
            <xsl:otherwise>
              <packet/>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:when>
        
        <!-- Change default template-->
        <xsl:when test="sw:param('setdef')">
          <xsl:choose>
            <xsl:when test="error:is-empty()">
		          <xsl:copy-of select="local:getPacketSetDef(string($samples[1]))"/>
    		      <xsl:if test="sw:response('lib/opredirect.xsl')"/>	
            </xsl:when>
            <xsl:otherwise>
              <packet/>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:when>

        <!-- Unknown post -->
        <xsl:otherwise>
          <packet/>
        </xsl:otherwise>

      </xsl:choose>
  </xsl:template>
  

  <func:function name="local:getPacketDelete">
  	<xsl:param name="tmpl_ids"/>
 		<func:result>
 			<packet log="on">
				<target>env_samplem</target>
	        <cookie>
	          <msg>
	            <ok><sw:text>The Container sample(s) has/have been deleted.</sw:text></ok>
	            <error><sw:text>Failed to delete the Container sample(s).</sw:text></error>
	          </msg>
	          <operation>delete_envsample</operation>
	          <redirect-last/>
	        </cookie>			
				<data>
					<xsl:for-each select="$tmpl_ids">
						<env_samplem>
            	<del_sample_conf>
            		<id>
            			<xsl:value-of select="."/>
            		</id>
            	</del_sample_conf>
						</env_samplem>
					</xsl:for-each>
				</data>
				<vzcpauth/>
			</packet>
 		</func:result>
  </func:function>
  
  <func:function name="local:getPacketClone">
  	<xsl:param name="tmpl_ids"/>
  	<!--|Load source templates|-->
  	<xsl:variable name="tmpls" select="env-samplem:list-samples('virtuozzo')"/>
  	<!--|Make packet to cloine|-->
 		<func:result>
 			<packet log="on">
				<target>env_samplem</target>
	        <cookie>
	          <msg>
	            <ok><sw:text>The Container sample(s) has/have been cloned. The new Container sample name(s) will start with "Copy-of-..".</sw:text></ok>
	            <error><sw:text>Failed to clone the Container sample(s).</sw:text></error>
	          </msg>
	          <operation>clone_envsample</operation>
	          <redirect-last/>
	        </cookie>			
				<data>
					<xsl:for-each select="$tmpls[id=$tmpl_ids/text()]">
						<xsl:variable name="id" select="id"/>
						<xsl:variable name="new_name">
							<sw:text>
	      				<xsl:with-param name="name" select="name"/>	      				
	      				Copy-of-%{name}
	      			</sw:text>
	      		</xsl:variable>
						<env_samplem>
            	<set_sample_conf>
            		<sample_conf>
            			<xsl:copy-of select="env_config"/>
            			
		            	<xsl:copy-of select="node()[not(self::name or self::id or self::env_config)]"/>
	            		<name>
	        			    <xsl:choose>
	        						<xsl:when test="$tmpls[name=$new_name]">
												<xsl:value-of select="local:getNewName($new_name,1,$tmpls)"/>  
	        						</xsl:when>
	        						<xsl:otherwise>
	        							<xsl:value-of select="$new_name"/>
	        						</xsl:otherwise>
	        					</xsl:choose>
	            		</name>
	            	</sample_conf>
            	</set_sample_conf>
						</env_samplem>
					</xsl:for-each>
				</data>
				<vzcpauth/>
			</packet>
 		</func:result>
  </func:function>
  
  <func:function name="local:getNewName">
  	<xsl:param name="name"/>
  	<xsl:param name="number"/>
  	<xsl:param name="tmpls"/>
  	
  	<xsl:variable name="new_name">
			<sw:text>
				<xsl:with-param name="name" select="name"/>
				<xsl:with-param name="number" select="$number"/>
				Copy-%{number}-of-%{name}
			</sw:text>        							
		</xsl:variable>
		
		<xsl:choose>
			<xsl:when test="not($tmpls[name=$new_name])">
				<func:result select="$new_name"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="local:getNewName($name,number($number)+1,$tmpls)"/>
			</xsl:otherwise>
		</xsl:choose>
  	<!--|-->
  </func:function>
  
  <func:function name="local:getPacketSetDef">
  	<xsl:param name="sample-id"/> 
  	
  	<xsl:variable name="sample" 			select="env-samplem:get-sample($sample-id)"/>  	  	
 		<xsl:variable name="sample-platform" 		select="sample:sample2platform($sample)"/>  	  	
	  <xsl:variable name="def-samples" 	select="vz:default-samples()"/>
	  <xsl:variable name="def-exists" 	select="$def-samples[platform=$sample-platform]"/>
 		
 		<xsl:variable name="packet-data-rtf">
 			<obj>
 				<cookie>
 					<msg>
						<ok>
							<sw:text>The default Container sample has been changed.</sw:text>
						</ok>
						<error>
 							<sw:text>Failed to change the default Container sample.</sw:text>
						</error>
          			</msg>
          			<redirect-last/>          
 				</cookie>
 				<ref>
 					<dn>platform=<xsl:value-of select="$sample-platform"/>,<xsl:value-of select="vz:defenvsamples-dn()"/></dn>
 					<objectClass>VZCPEnvDefaultSample</objectClass>
 				</ref>
 				<data>
 					<xsl:if test="not($def-exists)">
 						<platform><xsl:value-of select="$sample-platform"/></platform>
 					</xsl:if>
 					<objectId><xsl:value-of select="$sample-id"/></objectId>
 				</data>
 			</obj>
 		</xsl:variable>  	  	 		 		
 		
 		<!-- Post packet -->  	
		<xsl:choose>
			<xsl:when test="$def-exists">
				<func:result select="dirm:packet-modify(exsl:node-set($packet-data-rtf)/obj)"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="dirm:packet-add(exsl:node-set($packet-data-rtf)/obj)"/>
			</xsl:otherwise>
		</xsl:choose>
		<!-- /Post packet -->
  </func:function>

  <!-- credentials -->
  <sw:include href="/lib/cred.xsl"/>
  <sw:include href="/lib/common.xsl"/>
 
</xsl:stylesheet>
