<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred check local env-samplem error"
	xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl			="http://exslt.org/common"
	xmlns:sw				="http://www.swsoft.com/xsl/cp"
	xmlns:error			="http://www.swsoft.com/xsl/cp/error"
	xmlns:check			="http://www.swsoft.com/xsl/cp/check"
	xmlns:wiz				="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local			="http://www.swsoft.com/xsl/cp/local"
	xmlns:env-samplem		="http://www.swsoft.com/xsl/cp/env-samplem"
  xmlns:func			="http://exslt.org/functions"	
	xmlns:cred			="http://www.swsoft.com/xsl/cp/cred"
  xmlns:vt				="http://www.swsoft.com/xsl/cp/vt"
	xmlns:env				="http://www.swsoft.com/xsl/cp/env"
  xmlns:hn				="http://www.swsoft.com/xsl/cp/hn"
>
	<sw:include href="/lib/core/check-funcs.xsl"/>
 	<sw:include href="/lib/vt/core.xsl"/>
 	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vt/hn-core.xsl"/>
	<sw:include href="/lib/swa/env-samplem.xsl"/>

	<xsl:output method="xml"/>
			
	<xsl:param name="wiz_code" select="'envsample_split'"/>

  <xsl:variable name="step" select="wiz:processing-step-id()"/>	
  <xsl:variable name="form" select="local:init-form()"/>

	<xsl:template match="node()|@*">
		<xsl:choose>
			<!-- Step "General Settings" -->
			<xsl:when test="$step='gen'">
			
					<!-- try to cache -->
					<xsl:variable name="sample_configs" select="env-samplem:list-samples('virtuozzo')"/>					
			
					<!-- Read HN Selection -->
					<xsl:variable name="hn-rtf">
						<xsl:variable name="hn-eid" select="sw:param('hn')"/>
						<xsl:if test="$hn-eid!=''">
							<xsl:variable name="hn-env" select="env:get-env($hn-eid)/env"/>
							<xsl:copy-of select="$hn-env/eid"/>
							<xsl:copy-of select="$hn-env/config/hostname"/>
							<platform>								
								<xsl:value-of select="hn:hn2platform($hn-env)"/> 
							</platform>
							<tech>vz.vt</tech>
						</xsl:if>
					</xsl:variable>
					<xsl:variable name="hn" select="exsl:node-set($hn-rtf)"/>	
			
					<xsl:variable name="new_form_">
						<xsl:for-each select="$form/*">
							<xsl:choose>
								<xsl:when test="name()=$step or self::hn	"></xsl:when>
								<xsl:otherwise>
									<xsl:copy-of select="."/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
						<gen>
							<name><xsl:value-of select="sw:param('name')"/></name>
							<descr><xsl:value-of select="sw:param('descr')"/></descr>
							<count><xsl:value-of select="sw:param('count')"/></count>
						</gen>
						<hn>
							<xsl:copy-of select="$hn-rtf"/>
						</hn>
						<!-- /Select HN  -->
					</xsl:variable>
					<xsl:variable name="new-form" select="exsl:node-set($new_form_)"/>
					
					<xsl:if test="sw:param('next')">
						<!-- Check data -->
						<!-- Check HN -->
						<xsl:if test="not($new-form/hn/eid!='')">
							<xsl:if test="error:put(sw:text('You should select the Hardware Node.'),'','hn')"/>
						</xsl:if>
						<!-- /Check HN -->
						<!-- check name -->
			      <xsl:choose>
 				      <!-- check name presence -->
				      <xsl:when test="string($new-form/gen/name)=''">
				      	<xsl:value-of select="error:put(sw:text('You should specify a name.'),'','name')"/>
				      </xsl:when>
				      <!-- check name for max.length -->
				      <xsl:when test="string-length($new-form/gen/name)>255">
				      	<xsl:value-of select="error:put(sw:text('The specified name cannot be longer than 255 characters.'),'','name')"/>
				      </xsl:when>
				      <!-- check name for valid chars -->
				      <xsl:when test="not(check:fileName($new-form/gen/name))">
				      	<xsl:value-of select="error:put(sw:text('The specified name contains a space or other invalid characters.'),'','name')"/>
				      </xsl:when>
				      <!-- check name for uniq -->
				      <xsl:when test="$sample_configs[name = $new-form/gen/name] and not($new-form/gen/name = $new-form/name_src)">
				      	<xsl:if test="error:put(sw:text('The submitted name is already used by another sample. Please specify another name.'),'','name')"/>
				      </xsl:when>
						</xsl:choose>
						<!-- check descr-->
			      <xsl:choose>
 				      <!-- check name presence -->
				      <xsl:when test="string($new-form/gen/descr)=''">
				      </xsl:when>
				      <!-- check name for max.length -->
				      <xsl:when test="string-length($new-form/gen/descr)>65535">
				      	<xsl:value-of select="error:put(sw:text('The specified name cannot be longer than 65535 characters.'),'','descr')"/>
				      </xsl:when>
						</xsl:choose>
						<!-- check count-->
			      <xsl:choose>
 				      <!-- check count presence -->
				      <xsl:when test="string($new-form/gen/count)=''">
				      	<xsl:value-of select="error:put(sw:text('You should specify the number of Containers.'),'','count')"/>
				      </xsl:when>
				      <!-- check count as unsigned unzero int -->
				      <xsl:when test="not(check:num($new-form/gen/count)) or (number($new-form/gen/count)&lt;=0)">
				      	<xsl:value-of select="error:put(sw:text('The number of Containers should be a valid positive integer.'),'','count')"/>
				      </xsl:when>
						</xsl:choose>
					</xsl:if>
					
					<!-- Try to calc splitting VE Sample configuration -->
					<xsl:variable name="new_data">
						<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:variable name="split-conf" select="local:split-hn($hn/eid,$new-form/gen/count)"/>
								<xsl:copy-of select="$new-form/*[name()!='env_config']"/>
								<xsl:choose>
									<xsl:when test="$split-conf/error">
										<xsl:if test="error:put(sw:text('Failed to split the Hardware Node.'),$split-conf/error/message,'count')"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:copy-of select="$split-conf/env_config"/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
							<xsl:otherwise>
								<xsl:copy-of select="$new-form"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
					
					<xsl:call-template name="local:completeFormHandling">
						<xsl:with-param name="data" select="exsl:node-set($new_data)"/>
					</xsl:call-template>
					
			</xsl:when>
			
			<!-- Step "Final" -->
			<xsl:when test="$step='final'">
			
					<!-- try to cache -->
					<xsl:variable name="sample_configs" select="env-samplem:list-samples('virtuozzo')"/>					
			
					<xsl:variable name="new_form_">
						<xsl:for-each select="$form/*">
							<xsl:choose>
								<xsl:when test="name()=$step"></xsl:when>
								<xsl:otherwise>
									<xsl:copy-of select="."/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
					</xsl:variable>
					<xsl:variable name="new-form" select="exsl:node-set($new_form_)"/>
					
					<xsl:if test="sw:param('next')">
						<!-- Check data -->
					</xsl:if>
					
					<xsl:call-template name="local:completeFormHandling">
						<xsl:with-param name="data" select="$new-form"/>
					</xsl:call-template>
					
			</xsl:when>
		</xsl:choose>
		
		<xsl:copy/>
	</xsl:template>
	
	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->		
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
    				<xsl:choose>
							<xsl:when test="error:is-empty()">
					    	<xsl:if test="cred:detail-check('vzcp.envsamples')"/>
						    <xsl:choose>
		    					<xsl:when test="error:is-empty()">
										<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
										<xsl:copy-of select="local:getFinalPacket($data)"/>
										<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>					
	      					</xsl:when>
									<xsl:otherwise>
										<packet/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
		          <xsl:otherwise>
              	<packet/>
            	</xsl:otherwise>
          	</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>
					
	</xsl:template>
	
	<func:function name="local:init-form">
		<sw:noauth-redirect select="not(cred:check('vzcp.envsamples'))"/>
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:init-form-data"/>
		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>

	
	<xsl:template name="local:init-form-data">
		<!-- Init default data -->
		<xsl:variable name="new-form">
			<gen>
				<name/>
				<descr/>
				<count/>
			</gen>
			<hn>
				<eid>
					<!-- We can split only Linux node -->
					<xsl:variable name="master-info" select="env:eid2info(sw:master-eid())"/>
					<xsl:if test="$master-info/linux">
						<xsl:value-of select="$master-info/eid"/>
					</xsl:if>
				</eid>
			</hn>
		</xsl:variable>
		<!-- Init steps -->
		<xsl:variable name="new_steps_">
			<step id="gen" screenid="03.02.01.26.02" screen-title="{sw:text('Split Hardware Node: Specify Parameters')}" icon="env_sample_split"/>
			<step id="final" screenid="03.02.01.26.03"  screen-title="{sw:text('Split Hardware Node: Final')}" icon="env_sample_split"/>
		</xsl:variable>
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
			<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
			<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new-form))"/>
			<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>
	</xsl:template>
	
	<!-- *********************************************************** -->
	<func:function name="local:getFinalPacket">
		<xsl:param name="data"/>
		<!--|-->
		<func:result>
			<packet log="on"
				xmlns:xsi		="http://www.w3.org/2001/XMLSchema-instance"
				xmlns:vzat	="http://www.swsoft.com/webservices/vza/4.0.0/vzatypes"
			>
				<target>env_samplem</target>
	        <cookie>
	          <msg>
	            <ok><sw:text>
	            	<xsl:with-param name="id" select="$data/gen/name"/>
	            	The "%id" Container sample has been successfully created.
	            </sw:text></ok>
	            <error><sw:text>Failed to create the Container sample.</sw:text></error>
	          </msg>
	          <operation>split_envsample</operation>
	          <redirect-prev/>
	        </cookie>			
				<data>				
					<!-- Create/Update -->
					<env_samplem>
						<set_sample_conf>
							<sample_conf>
								<name><xsl:value-of select="$data/gen/name"/></name>
								<comment><xsl:value-of select="sw:base64-encode($data/gen/descr)"/></comment>
								<env_config>
									<xsl:copy-of select="$data/env_config/*"/>
									<os xsi:type="vzat:osType">
										<platform><xsl:value-of select="vt:platform2vza($data/hn/platform)"/></platform>
										<name/>
									</os>								
								</env_config>
								<vt_version>
									<platform><xsl:value-of select="vt:platform2vza($data/hn/platform)"/></platform>
									<architecture><xsl:value-of select="vt:platform2vza-architecture($data/hn/platform)"/></architecture>									
									<vt_technology>virtuozzo</vt_technology>
								</vt_version>
							</sample_conf>
						</set_sample_conf>
					</env_samplem>
				</data>
				<vzcpauth/>
			</packet>
		</func:result>
	</func:function>
	
	<!-- Ask VZA about Split QoS-->
	<func:function name="local:split-hn">
		<xsl:param name="hn-eid"/>
		<xsl:param name="count"/>
		
		<xsl:variable name="req">
			<packet>
				<target>vzaenvm</target>
				<xsl:copy-of select="sw:hn-dst($hn-eid)"/>
				<data>
					<vzaenvm>
						<get_split_conf>
							<number><xsl:value-of select="$count"/></number>
						</get_split_conf>
					</vzaenvm>
				</data>
				<vzcpauth/>
			</packet>
		</xsl:variable>
		<func:result select="sw:xchg($req)/packet/data/vzaenvm"/>
		
	</func:function>

  <!-- credentials -->	
  <sw:include href="/lib/cred.xsl"/>
	
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>

	<sw:include href="/lib/vocabulary.xsl"/>				
	
</xsl:stylesheet>
