<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred check local env-samplem error"
	xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl			="http://exslt.org/common"
	xmlns:sw				="http://www.swsoft.com/xsl/cp"
	xmlns:error			="http://www.swsoft.com/xsl/cp/error"
	xmlns:check			="http://www.swsoft.com/xsl/cp/check"
	xmlns:wiz				="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local			="http://www.swsoft.com/xsl/cp/local"
	xmlns:env				="http://www.swsoft.com/xsl/cp/env"
	xmlns:sample		="http://www.swsoft.com/xsl/cp/sample"	
	xmlns:env-samplem ="http://www.swsoft.com/xsl/cp/env-samplem"
	xmlns:func			="http://exslt.org/functions"	
	xmlns:cred			="http://www.swsoft.com/xsl/cp/cred"
	xmlns:voc				="http://www.swsoft.com/xsl/cp/voc"
	xmlns:envm			="http://www.swsoft.com/xsl/cp/envm"			
	xmlns:filem			="http://www.swsoft.com/xsl/cp/filem"		
	xmlns:vzenv			="http://www.swsoft.com/xsl/cp/vzenv"	
>
	<sw:include href="/lib/core/check-funcs.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/swa/env-samplem.xsl"/>
	<sw:include href="/lib/swa/envm.xsl"/>		
	<sw:include href="/lib/vza/filem.xsl"/>		
	<sw:include href="/lib/vz/vzenv-core.xsl"/>			

	<xsl:output method="xml"/>
	
	<xsl:param name="wiz_code" select="'envsample_upload'"/>		

  <xsl:variable name="step" select="wiz:processing-step-id()"/>	
  <xsl:variable name="form" select="local:init-form()"/>

	<xsl:template match="node()|@*">
		<xsl:choose>
			<!-- Step "General Settings" -->
			<xsl:when test="$step='gen'">
					<!-- try to cache -->
					<xsl:variable name="sample_configs" select="env-samplem:list-samples('virtuozzo')"/>					

					<xsl:variable name="new_form_">
						<xsl:for-each select="$form/*">
							<xsl:choose>
								<xsl:when test="name()=$step"></xsl:when>
								<xsl:otherwise>
									<xsl:copy-of select="."/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
						<gen>
							<name><xsl:value-of select="sw:param('name')"/></name>
							<xsl:copy-of select="/http_request/files/file[input_name = 'upload']"/>
							<xsl:if test="/http_request/files/file[input_name = 'upload']">
								
								<xsl:variable name="file-path" select="/http_request/files/file[input_name = 'upload']/local_path"/>							
								<xsl:variable name="config-name" select="string(sw:param('name'))"/>
								
								<!-- Impersonated call to filer used -->
								<xsl:variable name="file-res" select="filem:get($file-path, vzenv:veid-to-eid(1,sw:local-hn-eid()), true(), true())"/>

								<xsl:choose>
									<xsl:when test="exsl:object-type($file-res)='node-set'">
										<xsl:if test="error:put(sw:text('Error uploading the sample.'),$file-res/message,'file')"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:variable name="sample-virtual-config" select="envm:config-native2virtual($file-res)"/>
										<!-- Handle converted config -->
										<xsl:choose>
											<xsl:when test="$sample-virtual-config[self::error]">
												<xsl:if test="error:put(sw:text('Error processing the sample.'),$sample-virtual-config/message,'file')"/>											
											</xsl:when>
											<xsl:otherwise>
												<xsl:if test="$sample-virtual-config">
													<sample_conf>				
														<env_config>
															<xsl:copy-of select="$sample-virtual-config/*"/>
														</env_config>
														<name><xsl:value-of select="$config-name"/></name>
													</sample_conf>
													<xsl:variable name="sample-platform" select="sample:sample2platform($sample-virtual-config)"/>									
													<platform>
														<xsl:value-of select="$sample-platform"/>
													</platform>	
												</xsl:if>
											</xsl:otherwise>
										</xsl:choose>
										<!-- /Handle converted config -->										
									</xsl:otherwise>
								</xsl:choose>
								
							</xsl:if>
						</gen>
					</xsl:variable>
					<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
					
					<xsl:if test="sw:param('next')">
						<!-- Check data -->
						
						<!-- check file -->
			      <xsl:choose>
 				      <!-- check file presence -->
				      <xsl:when test="not($new_form/gen/file)">
				      	<xsl:value-of select="error:put(sw:text('You should select some file to upload.'),'','upload')"/>
				      </xsl:when>
				      <!-- check file parsing result -->
				      <xsl:when test="not($new_form/gen/sample_conf/*)">
				      	<xsl:value-of select="error:put(sw:text('The file you are trying to upload is not a valid Container sample configuration file.'),'','upload')"/>
				      </xsl:when>				       
						</xsl:choose>

						<!-- check name -->			
						<xsl:if test="error:is-empty()">
							<xsl:variable name="name-pattern" select="voc:get-pattern(
								env:make-platform-ref('',$new_form/gen/platform)
								,'pattern.vesampleconfig')" 
							/>
							<xsl:variable name="name-error" select="check:get-voc-pattern-match-error(
								env:make-platform-ref('',$new_form/gen/platform),$new_form/gen/name, 'pattern.vesampleconfig'
							)" />
							
							<xsl:choose>
								<!-- check name presence -->
								<xsl:when test="$name-error and $name-error[name()='short']">
									<xsl:value-of select="error:put(sw:text('You should specify a name.'),'','name')"/>
								</xsl:when>
								<!-- check name for max.length -->
								<xsl:when test="$name-error and $name-error[name()='long']">
									<xsl:variable name="err-msg">
										<sw:text>
											<xsl:with-param name="max" select="$name-pattern/max" />
											A Container sample name cannot be longer than %max characters.
										</sw:text>
									</xsl:variable>
									<xsl:value-of select="error:put($err-msg,'','name')"/>
								</xsl:when>
								<!-- check name for valid chars -->
								<xsl:when test="$name-error">
									<xsl:value-of select="error:put(sw:text('The specifed name contains a white space or other invalid characters.'),'','name')"/>
								</xsl:when>
								<!-- check name for uniq -->
								<xsl:when test="$sample_configs[name = $new_form/gen/name] and not($new_form/gen/name = $new_form/name_src)">
									<xsl:if test="error:put(sw:text('The submitted name is already used by another sample. Please specify another name.'),'','name')"/>
								</xsl:when>
								<xsl:when test="$new_form/gen/offline_type = 'custom' and count($new_form/gen/selected_offline_service/value) = 0">
									<xsl:if test="error:put(sw:text('Select at least one service for custom offline management.'),'','selected_offline_service')"/>
								</xsl:when>
							</xsl:choose>
						</xsl:if>

					</xsl:if>
					
					<xsl:call-template name="local:completeFormHandling">
						<xsl:with-param name="data" select="$new_form"/>
					</xsl:call-template>
					
			</xsl:when>
		</xsl:choose>
		
		<xsl:copy/>
	</xsl:template>
	
	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->		
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
    				<xsl:choose>
							<xsl:when test="error:is-empty()">
						    <xsl:choose>
		    					<xsl:when test="error:is-empty()">
										<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
										<xsl:copy-of select="local:getFinalPacket($data)"/>
										<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>	
	      					</xsl:when>
									<xsl:otherwise>
										<packet/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
		          <xsl:otherwise>
              	<packet/>
            	</xsl:otherwise>
          	</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>
					
	</xsl:template>
	
	<func:function name="local:init-form">
		<sw:noauth-redirect select="not(cred:check('vzcp.envsamples'))"/>
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:initCreate"/>
		</xsl:if>
		<func:result select="wiz:init-data()"/>		
	</func:function>
	
	<xsl:template name="local:initCreate">
		<!-- Init default data -->
		<xsl:variable name="new_form">
			<gen>
				<name/>
			</gen>
		</xsl:variable>
		<!-- Init steps -->
		<xsl:variable name="new_steps_">
			<step id="gen" screenid="03.02.01.26.01"/>
		</xsl:variable>
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
			<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
			<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
			<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>
	</xsl:template>
	
	<!-- *********************************************************** -->
	<func:function name="local:getFinalPacket">
		<xsl:param name="data"/>
		<!--|-->
		<func:result>
			<packet log="on">
				<target>env_samplem</target>
	        <cookie>
	          <msg>
	            <ok><sw:text>
	            	<xsl:with-param name="id" select="$data/gen/name"/>
	            	The "%id" Container sample has been successfully uploaded.
	            </sw:text></ok>
	            <error><sw:text>Failed to upload the Container sample.</sw:text></error>
	          </msg>
	          <operation>upload_envsample</operation>
	          <redirect-prev/>
	        </cookie>			
				<data>				
					<!-- Create/Update -->
					<env_samplem>
						<set_sample_conf>
							<xsl:copy-of select="$data/gen/sample_conf"/>
						</set_sample_conf>
					</env_samplem>
				</data>
				<vzcpauth/>
			</packet>
		</func:result>
	</func:function>

  <!-- credentials -->	
<sw:include href="/lib/cred.xsl"/>
<sw:include href="/lib/wizard.xsl"/>
<sw:include href="/lib/common.xsl"/>
<sw:include href="/lib/vocabulary.xsl"/>				

</xsl:stylesheet>
