<!--
	Copyright (c) SWsoft, 1999-2007
	All rights reserved.
-->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred check local"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:check="http://www.swsoft.com/xsl/cp/check"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:networkm="http://www.swsoft.com/xsl/cp/networkm"
	xmlns:traffic="http://www.swsoft.com/xsl/cp/traffic"
	>

	<xsl:output method="xml"/>

	<!-- check permissions to show this page -->
	<xsl:variable name="hn-eid" select="sw:hn-eid()"/>

	<xsl:variable name="step" select="wiz:processing-step-id()"/>
	<xsl:param name="wiz_code" select="'vznet_accounting'"/>
	<xsl:variable name="form" select="local:init-form()"/>

	<xsl:template match="node()|@*">
		<xsl:choose>
			<xsl:when test="$step='config' and sw:param('ranges')">
				<xsl:variable name="new_form_">
					<xsl:copy-of select="$form/*[not(self::config)]"/>
					<config>
						<xsl:copy-of select="traffic:restore-hw-interface-ranges()"/>
						<xsl:copy-of select="$form/config/shaping"/>
						<xsl:copy-of select="$form/config/interface"/>
						<xsl:copy-of select="$form/config/class"/>
					</config>
				</xsl:variable>	
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
				<xsl:if test="sw:sesputtree($wiz_data,$new_form)"/>
				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data"		select="$new_form"/>
					<xsl:with-param name="hn-eid"	select="$hn-eid"/>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>
		<xsl:copy/>
	</xsl:template>

	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<xsl:param name="hn-eid"/> 
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
						<xsl:if test="traffic:check-hw-interface-ranges($hn-eid, $data)"/>
						<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:copy-of select="local:getFinalPacket($data,$hn-eid)"/>
								<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
							</xsl:when>
							<xsl:otherwise>
								<packet/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<func:function name="local:init-form">
		<sw:noauth-redirect select="not(cred:check-hw('vzcp.hn.manage.config.network',$hn-eid))"/>
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:init-new"/>
		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>

	<xsl:template name="local:init-new">
			<xsl:param name="hn-eid" select="sw:hn-eid()"/>
			<!-- Init steps -->
			<xsl:variable name="new_steps_">
				<step id="config" screen-id="03.02.01.32.04"
					screen-title="{sw:text('Configure Accounting')}" screen-icon="traffic_shape"/>
			</xsl:variable>
			<!-- Save wizard initial settings -->
			<xsl:if test="error:is-empty()">
				<xsl:variable name="saved_form" select="sw:sesputtree($wiz_data, local:initData($hn-eid))"/>
				<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
				<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
				<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
				<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
			</xsl:if>
	</xsl:template>

	<func:function name="local:initData">
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>
		<xsl:variable name="netconfig-raw" select="networkm:get-config($hn-eid)"/>
		<func:result>
			<config>
				<xsl:copy-of select="$netconfig-raw/shaping"/>
				<xsl:copy-of select="$netconfig-raw/range"/>
				<xsl:copy-of select="$netconfig-raw/class"/>				
				<xsl:copy-of select="$netconfig-raw/interface"/>
			</config>
		</func:result>
	</func:function>

	<func:function name="local:getFinalPacket">
		<xsl:param name="data"/>
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>
		<xsl:variable name="cookie-rtf">
			<cookie>
				<msg>
					<sched>
						<sw:text>The changing of the traffic accounting settings has been scheduled.</sw:text>
					</sched>
					<ok>
						<sw:text>The traffic accounting settings have been successfully changed.</sw:text>
					</ok>
					<error>
						<sw:text>Failed to update the traffic accounting settings.</sw:text>
					</error>
				</msg>
				<operation>hw_config_vznet_accounting</operation>
				<redirect-prev/>
			</cookie>
		</xsl:variable>

		<xsl:variable name="filtered-data-rtf">
			<config>
				<xsl:copy-of select="$data/config/range"/>
				<xsl:copy-of select="$data/config/class[id=$data/config/range/class_id]"/>
			</config>
		</xsl:variable>
		<xsl:variable name="filtered-data" select="exsl:node-set($filtered-data-rtf)"/>
		<func:result select="networkm:set-config-packet($hn-eid,$filtered-data,exsl:node-set($cookie-rtf))"/>
	</func:function>

	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/vza/networkm.xsl"/>
	<sw:include href="/lib/traffic.xsl"/>

</xsl:stylesheet>
