<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred check local"
	xmlns:xsl					="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl				="http://exslt.org/common"
	xmlns:sw					="http://www.swsoft.com/xsl/cp"
	xmlns:error				="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz					="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local				="http://www.swsoft.com/xsl/cp/local"	
	xmlns:request			="http://www.swsoft.com/xsl/cp/request"		
  xmlns:func				="http://exslt.org/functions"	
	xmlns:cred				="http://www.swsoft.com/xsl/cp/cred"
	xmlns:env					="http://www.swsoft.com/xsl/cp/env"	
	xmlns:check				="http://www.swsoft.com/xsl/cp/check"
	xmlns:backups			="http://www.swsoft.com/xsl/cp/backups"
>

	<!-- Functionality  modules -->
	<sw:include href="/lib/vt/env-core.xsl"/>	
	<sw:include href="/lib/vt/backups-core.xsl"/>
  <sw:include href="/lib/vt/backups-forms.xsl"/>  	

	<xsl:output method="xml"/>
	
	<xsl:variable name="step" select="wiz:processing-step-id()"/>

	<xsl:param name="wiz_code" select="'vz-hn-setup-backups'"/>
 	<xsl:variable name="form" select="local:init-form()"/>

	<xsl:template match="node()|@*">
		<xsl:choose>
			<!-- Step "General Settings" -->
			<xsl:when test="$step='gen'">
			
				<xsl:variable name="use-global-settings" select="not($form/def/hn/master) and sw:param('usage_mode')='global'"/>
			
				<xsl:variable name="new-form-rtf">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="self::storage-config or self::core-options or self::gen"></xsl:when>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<gen>
						<xsl:if test="$use-global-settings">
							<use-global-settings/>
						</xsl:if>
					</gen>
					<storage-config>							
						<location>
							<type>
								<xsl:choose>
									<xsl:when test="$form/def/hn/windows">
										<xsl:value-of select="sw:param('storage_type')"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="'local'"/>
									</xsl:otherwise>	
								</xsl:choose>
							</type>
							<local>
								<path>
									<xsl:value-of select="sw:param('local_path')"/>
								</path>							
							</local>
							<share>
								<path><xsl:value-of select="sw:param('share_path')"/></path>
								<login>
									<name><xsl:value-of select="sw:param('share_login_name')"/></name>
									<domain><xsl:value-of select="sw:param('share_login_domain')"/></domain>
									<password><xsl:value-of select="sw:param('share_login_password')"/></password>
								</login>
							</share>
						</location>
					</storage-config>
					<xsl:choose>
						<xsl:when test="$use-global-settings">
							<xsl:copy-of select="$form/core-options"/>
						</xsl:when>
						<xsl:otherwise>
							<core-options>
								<xsl:call-template name="backups:restore-core-options">
									<xsl:with-param name="old-options" select="$form/core-options"/>
								</xsl:call-template>
							</core-options>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<xsl:variable name="new-form" select="exsl:node-set($new-form-rtf)"/>
				
				<xsl:if test="sw:param('next')">
					<!-- check data -->			
					<!-- check store config -->	
					<xsl:variable name="location" select="$new-form/storage-config/location"/>
					<xsl:choose>
						<xsl:when test="$location/type='local'">
							<xsl:if test="$location/local/path=''">
								<xsl:if test="error:put(
									sw:text('The Location Path field cannot be empty.'),'','local_path'
								)"/>								
							</xsl:if>
						</xsl:when>
						<xsl:when test="$location/type='share'">
							<xsl:if test="$location/share/path=''">
								<xsl:if test="error:put(
									sw:text('The Location Path field cannot be empty.'),'','share_path'
								)"/>								
							</xsl:if>
							<xsl:if test="$location/share/login/name=''">
								<xsl:if test="error:put(
									sw:text('The User Name field should contain a valid user name for a Windows network share. '),'','share_login_name'
								)"/>								
							</xsl:if>
						</xsl:when>						
					</xsl:choose>
					<!-- check core options -->
					<xsl:if test="not($use-global-settings)">
						<xsl:if test="backups:check-core-options($new-form/core-options)"/>
					</xsl:if>
				</xsl:if>
				
				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new-form"/>
				</xsl:call-template>
					
			</xsl:when>
				
		</xsl:choose>
		
		<xsl:copy/>
	</xsl:template>
	
	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->		
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
    				<xsl:choose>
							<xsl:when test="error:is-empty()">
					    	<xsl:choose>
		    					<xsl:when test="error:is-empty()">
										<xsl:copy-of select="local:getFinalPacket($data)"/>
										<xsl:if test="sw:response('lib/opredirect.xsl')"/>
					      	</xsl:when>
									<xsl:otherwise>
										<packet/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
		          <xsl:otherwise>
              	<packet/>
            	</xsl:otherwise>
          	</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>
					
	</xsl:template>
	
	<func:function name="local:init-form">
		<sw:noauth-redirect select="not(cred:check-hw('vzcp.hn.backups.configure',sw:hn-eid()))"/>
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:init-new"/>
		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>
	
	<xsl:template name="local:init-new">
			<xsl:variable name="hn-eid" select="sw:hn-eid()"/>
			<sw:die test="not($hn-eid!='')">
				HN EID is uknown
			</sw:die>
			<!-- Get data -->			
			<xsl:variable name="storage-config" select="backups:get-storage-config($hn-eid)"/>
			<xsl:variable name="core-options" select="backups:get-core-options($hn-eid)"/>
			<!-- Init form data -->
			<xsl:variable name="new_form">	
				<def>
					<hn>
						<xsl:copy-of select="env:env2info(env:get-env($hn-eid)/env)"/>
						<xsl:if test="sw:master-eid()=$hn-eid">
							<master/>
						</xsl:if>						
					</hn>
				</def>
				<gen>			
					<xsl:if test="$core-options/global">
						<use-global-settings/>
					</xsl:if>
				</gen>
				<storage-config>
					<xsl:copy-of select="$storage-config"/>
				</storage-config>
				<core-options>
					<xsl:copy-of select="$core-options"/>
				</core-options>
			</xsl:variable>
			<!-- Init steps -->
			<xsl:variable name="new_steps_">
				<step id="gen" screen-id="03.02.01.32.07"/>
			</xsl:variable>
			<!-- Save wizard initial settings -->
			<xsl:if test="error:is-empty()">
				<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
				<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
				<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
				<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
				<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
			</xsl:if>
	</xsl:template>
	
	<!-- *********************************************************** -->
	<func:function name="local:getFinalPacket">
		<xsl:param name="data"/>
		
		<!-- Save new data -->				
		<xsl:variable name="error-storage" select="backups:set-storage-config($data/def/hn/eid,$data/storage-config)"/>
		
		<xsl:variable name="error">
			<xsl:choose>
				<xsl:when test="not($error-storage)">
					<xsl:copy-of select="backups:set-core-options($data/def/hn/eid,
						sw:if($data/gen/use-global-settings,/..,$data/core-options)
					)"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="$error-storage"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<xsl:choose>
			<!-- Saved -->
			<xsl:when	test="$error=''">
				<!-- Return back -->
				<func:result>
		 			<packet>
		        <cookie>
		          <msg>
		            <set-ok><sw:text>The settings have been changed.</sw:text></set-ok>
		          </msg>
		          <redirect-prev/>
		        </cookie>						
					</packet>
				</func:result>
			</xsl:when>
			<!-- /Saved -->
			<xsl:otherwise>
				<!-- Error occure  -->
				<func:result>
		 			<packet>
		        <cookie>
		          <msg>
		            <set-error>
		            	<short-desc>
		            		<sw:text>Error saving the backups configuration.</sw:text>
		            	</short-desc>
		            	<detail>
		            		<xsl:value-of select="$error"/>
		            	</detail>
		            </set-error>
		          </msg>
		        </cookie>						
					</packet>		
				</func:result>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

  <!-- credentials -->	
	<sw:include href="/lib/cred.xsl"/>  
	
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>

	<sw:include href="/lib/vocabulary.xsl"/>					
	
</xsl:stylesheet>
