<!--
	Copyright (c) SWsoft, 1999-2007
	All rights reserved.
-->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred check local"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:check="http://www.swsoft.com/xsl/cp/check"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:networkm="http://www.swsoft.com/xsl/cp/networkm"
	xmlns:traffic="http://www.swsoft.com/xsl/cp/traffic"
	xmlns:computerm="http://www.swsoft.com/xsl/cp/computerm"
	xmlns:vznet="http://www.swsoft.com/xsl/cp/vznet"
	>

	<xsl:output method="xml"/>

	<xsl:variable name="hn-eid" select="sw:hn-eid()"/>

	<xsl:variable name="step" select="wiz:processing-step-id()"/>
	<xsl:param name="wiz_code" select="'vznet_interfaces'"/>
	<xsl:variable name="form" select="local:init-form()"/>

	<xsl:template match="node()|@*">
		<xsl:variable name="new_form_">
			<xsl:choose>
				<xsl:when test="$step='config'">
					<config>
						<xsl:for-each select="$form/interfaces/interface">
							<xsl:variable name="iface" 			select="name"/>
							<xsl:variable name="bandwidth"	select="string( sw:param(concat($iface,'_bandwidth')) )"/>
							<xsl:variable name="bandwidth-factor"	select="string( sw:param(concat($iface,'_factor')) )"/>
							<xsl:if test="sw:param($iface)">
								<interface>
									<!-- reget info about defined interface -->
									<xsl:variable name="defined-iface"	select="networkm:get-config($hn-eid)/interface"/>
									<xsl:choose>
										<xsl:when test="$defined-iface/net_device_id = $iface">
											<!-- interface already defined, copy all exclude bandwidth -->
											<xsl:copy-of select="$form/config/interface[net_device_id=$iface]/*[name() = 'net_device_id']"/>
										</xsl:when>
										<xsl:otherwise>
											<!-- realy new inetrface -->
											<net_device_id>
												<xsl:value-of select="sw:param($iface)"/>
											</net_device_id>
										</xsl:otherwise>
									</xsl:choose>
									<bandwidth>
										<xsl:value-of select="$bandwidth"/>
									</bandwidth>
									<bandwidth-factor>
										<xsl:value-of select="$bandwidth-factor"/>
									</bandwidth-factor>									
								</interface>
							</xsl:if>
						</xsl:for-each>
						<xsl:copy-of select="$form/config/shaping"/>  
						<xsl:copy-of select="$form/config/range"/>
						<xsl:copy-of select="$form/config/class"/>
					</config>
					<xsl:copy-of select="$form/interfaces"/>					
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="$form/config"/>
					<xsl:copy-of select="$form/interfaces"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
		<xsl:if test="sw:sesputtree($wiz_data,$new_form)"/>
		<xsl:call-template name="local:completeFormHandling">
			<xsl:with-param name="data" select="$new_form"/>
			<xsl:with-param name="hn-eid" select="$hn-eid"/>			
		</xsl:call-template>
		<xsl:copy/>
	</xsl:template>

	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
						<xsl:for-each select="$data/config/interface">
							<xsl:if test="traffic:check-interface-bandwith(.)"/>
						</xsl:for-each>
						<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:copy-of select="local:getFinalPacket($data,$hn-eid)"/>
								<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
							</xsl:when>
							<xsl:otherwise>
								<packet/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<func:function name="local:init-form">
		<sw:noauth-redirect select="not(cred:check-hw('vzcp.hn.manage.config.network',$hn-eid))"/>
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:init-new"/>
		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>

	<xsl:template name="local:init-new">
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>
			<!-- Init steps -->
			<xsl:variable name="new_steps_">
				<step id="config" screen-id="03.02.01.32.06"
					screen-title="{sw:text('Configure Interfaces')}" screen-icon="networkadapter"/>
			</xsl:variable>
			<!-- Save wizard initial settings -->
			<xsl:if test="error:is-empty()">
				<xsl:variable name="saved_form" select="sw:sesputtree($wiz_data, local:initData())"/>
				<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
				<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
				<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
				<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
			</xsl:if>
	</xsl:template>

	<func:function name="local:initData">
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>
		<xsl:variable name="netconfig-raw"	select="networkm:get-config($hn-eid)"/>
		<xsl:variable name="netinfo-raw"		select="vznet:remove-loopback-and-down-iface($hn-eid,computerm:get-network($hn-eid))"/>
		<func:result>
			<config>
				<xsl:copy-of select="$netconfig-raw/shaping"/>
				<xsl:copy-of select="$netconfig-raw/interface"/>
				<xsl:copy-of select="$netconfig-raw/range"/>
				<xsl:copy-of select="$netconfig-raw/class"/>
			</config>
			<interfaces>
				<xsl:copy-of select="$netinfo-raw"/>
			</interfaces>
		</func:result>
	</func:function>

	<!-- *********************************************************** -->
	<func:function name="local:getFinalPacket">
		<xsl:param name="data"/>
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>
		<xsl:variable name="cookie-rtf">
			<cookie>
				<msg>
					<sched>
						<sw:text>The changing of the Virtuozzo interfaces settings has been scheduled.</sw:text>
					</sched>
					<ok>
						<sw:text>The Virtuozzo interfaces settings have been successfully changed.</sw:text>
					</ok>					
					<error>
						<sw:text>Failed to update the Virtuozzo interfaces settings.</sw:text>
					</error>
				</msg>
				<redirect-prev/>
				<operation>hw_config_vznet_interfaces</operation>
			</cookie>
		</xsl:variable>
		<xsl:variable name="data-norm-rtf"> 
			<config>
				<xsl:copy-of select="$data/config/shaping"/>		
				<xsl:copy-of select="$data/config/range"/>
				<xsl:copy-of select="$data/config/class"/>
				<xsl:for-each select="$data/config/interface">
					<interface>
						<xsl:copy-of select="net_device_id"/>
						<bandwidth>
							<xsl:value-of select="format-number((bandwidth * bandwidth-factor) div 1000,'#')"/>
						</bandwidth>
					</interface>
				</xsl:for-each>
			</config>
			<xsl:copy-of select="$data/interfaces"/>
		</xsl:variable>
		<func:result select="networkm:set-config-packet($hn-eid,exsl:node-set($data-norm-rtf),exsl:node-set($cookie-rtf))"/>
	</func:function>

	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/traffic.xsl"/>
	<sw:include href="/lib/vza/networkm.xsl"/>
	<sw:include href="/lib/swa/computerm.xsl"/>
	<sw:include href="/lib/vz/vznet-core.xsl"/> 	
	
</xsl:stylesheet>
