<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred check local"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:check="http://www.swsoft.com/xsl/cp/check"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:networkm="http://www.swsoft.com/xsl/cp/networkm"	
	xmlns:traffic="http://www.swsoft.com/xsl/cp/traffic"
	>

	<xsl:output method="xml"/>

	<!-- check permissions to show this page -->
	<xsl:variable name="hn-eid"				select="sw:hn-eid()"/> 
	<xsl:variable name="cred"					select="cred:check-hw('vzcp.hn.manage.config.network',$hn-eid)"/>
	<xsl:variable name="cred-acc"			select="$cred"/>
	<xsl:variable name="cred-shaping"	select="$cred"/>

	<xsl:template match="/">
		<xsl:variable name="new_form" select="local:initData($hn-eid)"/>
		<!-- Step "General Settings" -->
		<xsl:if test="not($cred-acc) and $new_form/manage/accounting">
			<xsl:if test="error:put(sw:text('You are not allowed to change the traffic accounting settings.'), '', '')"/>
		</xsl:if>
		<xsl:if test="not($cred-shaping) and $new_form/manage/shaping">
			<xsl:if test="error:put(sw:text('You are not allowed to change the traffic shaping settings.'), '', '')"/>
		</xsl:if>
		<xsl:if test="count($new_form/manage/*) != 0">
			<xsl:call-template name="local:completeFormHandling">
				<xsl:with-param name="hn-eid" select="$hn-eid"/>
				<xsl:with-param name="data" 	select="$new_form"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:copy/>
	</xsl:template>

	<func:function name="local:initData">
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>
		<!-- get account/shaper config for hnode -->
		<xsl:variable name="netconfig-raw"	select="networkm:get-config($hn-eid)"/>
		<xsl:variable name="config-rtf">
			<config>
				<xsl:copy-of select="$netconfig-raw/class"/>			
				<xsl:copy-of select="$netconfig-raw/shaping"/>
				<xsl:copy-of select="$netconfig-raw/interface"/>
        <xsl:copy-of select="$netconfig-raw/range"/>
			</config>
			<manage>
				<xsl:choose>
					<xsl:when test="sw:param('enable_shaping')">
						<shaping>yes</shaping>
					</xsl:when>
					<xsl:when test="sw:param('disable_shaping')">
						<shaping>no</shaping>
					</xsl:when>
				</xsl:choose>
			</manage>
		</xsl:variable>
		<func:result select="exsl:node-set($config-rtf)"/>
	</func:function>

	<xsl:template name="local:completeFormHandling">
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>
		<xsl:param name="data"/>
		<xsl:if test="error:is-empty()">
			<xsl:copy-of select="local:getFinalPacket($hn-eid,$data)"/>
			<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
		</xsl:if>
	</xsl:template>

	<func:function name="local:getFinalPacket">
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>
		<xsl:param name="data"/>
		<xsl:variable name="cookie-rtf">
			<cookie>
				<xsl:choose>
					<xsl:when test="$data/manage/shaping='yes'">
						<msg>
							<sched>
								<sw:text>The enabling of the traffic shaping has been scheduled.</sw:text>
							</sched>
							<ok>
								<sw:text>The traffic shaping has been successfully enabled.</sw:text>
							</ok>
							<error>
								<sw:text>Failed to enable the traffic shaping.</sw:text>
							</error>
		    		</msg>
		    	</xsl:when>
		    	<xsl:otherwise>
						<msg>
							<sched>
								<sw:text>The disabling of the traffic shaping has been scheduled.</sw:text>
							</sched>
							<ok>
								<sw:text>The traffic shaping has been successfully disabled.</sw:text>
							</ok>
							<error>
								<sw:text>Failed to disable the traffic shaping.</sw:text>
							</error>
		    		</msg>		    		
		    	</xsl:otherwise>
				</xsl:choose>	
				<operation>hw_config_vznet</operation>
			</cookie>
		</xsl:variable>
		<xsl:variable name="new-config-rtf">
			<config>
				<xsl:copy-of select="$data/config/interface"/>
				<xsl:copy-of select="$data/config/class"/>
				<xsl:copy-of select="$data/config/range"/>
				<xsl:if test="$data/manage/shaping='yes'">
					<shaping/>
				</xsl:if>
			</config>
		</xsl:variable>
		<func:result select="networkm:set-config-packet($hn-eid,exsl:node-set($new-config-rtf),exsl:node-set($cookie-rtf))"/>
	</func:function>

	<!-- credentials -->
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/vz/vznet.xsl"/>
	<sw:include href="/lib/traffic.xsl"/>
	<sw:include href="/lib/vza/networkm.xsl"/>

</xsl:stylesheet>
