<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred check local envm"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:check="http://www.swsoft.com/xsl/cp/check" 
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:swa-mailer="http://www.swsoft.com/xsl/cp/swa-mailer"	
	xmlns:envm="http://www.swsoft.com/xsl/cp/envm"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:env="http://www.swsoft.com/xsl/cp/env" 		
	xmlns:hn="http://www.swsoft.com/xsl/cp/hn" 	
>

	<sw:include href="/lib/core/check-funcs.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vt/hn-core.xsl"/>
	<sw:include href="/lib/swa/swa-mailer.xsl"/>
	<sw:include href="/lib/swa/envm.xsl"/>

	<xsl:output method="xml"/>

	<xsl:variable name="curr-hwid" select="sw:hn-eid()"/>

	<xsl:variable name="step" select="wiz:processing-step-id()"/>
	<xsl:param name="wiz_code" select="'hw-config-network'"/>
	<xsl:variable name="form" select="local:init-form()"/>

	<xsl:template match="node()|@*">

		<xsl:choose>
			<xsl:when test="not(cred:check-hw('vzcp.hn.manage.config.email',$curr-hwid))">
				<!-- no crerd for proxy, redirect to traffic screen -->
				<packet>
					<cookie>
						<redirect>
							<xsl:value-of select="concat($baseurl,'/vzdir/infrman/hns/config/traffic')"/>
						</redirect>
					</cookie>
				</packet>
				<xsl:if test="sw:response('lib/opredirect.xsl')"/>
			</xsl:when>
			<!-- Step "General Settings" -->
			<xsl:when
				test="$step='gen'">

				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="self::proxy or self::mailer"/>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<mailer>
						<relay>
							<xsl:value-of select="sw:param('relay')"/>
						</relay>
					</mailer>
					<xsl:if test="$form/hn/linux 
						and cred:check-hw('vzcp.hn.manage.config.network',sw:hn-eid())">
						<proxy>
							<proxy_address>
								<xsl:value-of select="sw:param('proxy_address')"/>
							</proxy_address>
						</proxy>
					</xsl:if>
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>

				<xsl:if test="sw:param('next')">
					<!-- check relay -->
					<xsl:choose>
						<!-- check name for valid chars -->
						<xsl:when test="$new_form/mailer/relay!='' and not( check:ip($new_form/mailer/relay))">
							<xsl:value-of
								select="error:put(sw:text('The specified relay server IP address is invalid. Please correct it.'),'','relay')"
							/>
						</xsl:when>
					</xsl:choose>
				</xsl:if>

				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new_form"/>
				</xsl:call-template>

			</xsl:when>

		</xsl:choose>

		<xsl:copy/>
	</xsl:template>

	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
						<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:if
									test="cred:detail-check-hw('vzcp.hn.manage.config.email',sw:hn-eid())"/>
								<xsl:choose>
									<xsl:when test="error:is-empty()">
										<xsl:copy-of select="local:getFinalPacket($data)"/>
										<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
									</xsl:when>
									<xsl:otherwise>
										<packet/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
							<xsl:otherwise>
								<packet/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

	<func:function name="local:init-form">
		<sw:noauth-redirect select="not(cred:check-hw('vzcp.hn.manage.config.email', $curr-hwid))"/>
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:init-new"/>
		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>

	<xsl:template name="local:init-new">
		<xsl:variable name="hn-eid" select="sw:hn-eid()"/>
			<!-- Get VZA data -->
			<xsl:variable name="vzconfig" select="envm:get-vt-settings($hn-eid)"/>
			<xsl:variable name="mailer" select="swa-mailer:get-relay($hn-eid)"/>
				
			<!-- Init form data -->
			<xsl:variable name="new_form">
				<proxy>
					<proxy_address>
						<xsl:value-of select="$vzconfig/parameter[id='http_proxy']/value"/>
					</proxy_address>
				</proxy>
				<mailer>
					<relay>
						<xsl:value-of select="$mailer/relay"/>
					</relay>
				</mailer>
				<hn>
					<xsl:copy-of select="env:eid2info($hn-eid)"/>
				</hn>
			</xsl:variable>
			<!-- Init steps -->
			<xsl:variable name="new_steps_">
				<step id="gen" screen-id="03.02.01.32.02"/>
			</xsl:variable>
			<!-- Save wizard initial settings -->
			<xsl:if test="error:is-empty()">
				<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
				<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
				<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
				<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
				<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
			</xsl:if>
	</xsl:template>

	<!-- *********************************************************** -->
	<func:function name="local:getFinalPacket">
		<xsl:param name="data"/>
		<!--|-->
		<func:result>
			<packet log="on">
				<xsl:if test="$data/hn/linux">
					<target>vzaenvm</target>
				</xsl:if>
				<target>mailer</target>
				<xsl:copy-of select="sw:hn-dst($data/hn/eid)"/>
				<cookie>
					<msg>
						<ok>
							<sw:text>The proxy settings have been successfully updated.</sw:text>
						</ok>
						<error>
							<sw:text>Failed to update the proxy settings.</sw:text>
						</error>
					</msg>
					<operation>hw_config_network</operation>
					<redirect-prev/>
				</cookie>
				<data>
					<xsl:if test="$data/hn/linux">
						<vzaenvm>
							<set_vt_settings>
								<vt_settings>
									<parameter>
										<id>http_proxy</id>
										<value>
											<xsl:value-of select="$data/proxy/proxy_address"/>
										</value>
									</parameter>
								</vt_settings>
							</set_vt_settings>
						</vzaenvm>
					</xsl:if>
					<mailer>
						<set_relay>
							<relay>
								<xsl:value-of select="$data/mailer/relay"/>
							</relay>
						</set_relay>
					</mailer>
				</data>
				<vzcpauth/>
			</packet>
		</func:result>
	</func:function>

	<!-- credentials -->
	<sw:include href="/lib/cred.xsl"/>

	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>

	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
