<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred local reb"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl	="http://exslt.org/common"
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:wiz		="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local			="http://www.swsoft.com/xsl/cp/local"
  xmlns:func	="http://exslt.org/functions"
  xmlns:reb		="http://www.swsoft.com/xsl/cp/reb"
  xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
>
	<xsl:output method="xml"/>
	<xsl:param name="wiz_code" select="'reboot-hw'"/>

	<xsl:variable name="backurl" select="concat($baseurl,'/vzdir/infrman/hns/hn')"/>

	<xsl:variable name="step" select="wiz:processing-step-id()"/>
	<xsl:variable name="form" select="local:init-form()"/>

	<xsl:template match="node()|@*">
		<xsl:choose>
			<xsl:when test="$step='reboot'">

					<xsl:variable name="new_form_">
						<xsl:for-each select="$form/*">
							<xsl:choose>
								<xsl:when test="name()=$step"></xsl:when>
								<xsl:otherwise>
									<xsl:copy-of select="."/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
					</xsl:variable>
					<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
					<xsl:if test="sw:param('back')">
						 <!-- Move to back -->
						<xsl:if test="wiz:goBack()"/>
					</xsl:if>
					<xsl:if test="sw:param('next')">
						<!-- no need check data -->
			      <!-- Move to next step -->

			      <xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:copy-of select="reb:getFinalPacket($step,$new_form)"/>
								<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>		
							</xsl:when>
						</xsl:choose>
					</xsl:if>
					
					<!-- Store form values-->
					<xsl:variable name="res">
						<xsl:value-of select="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
					</xsl:variable>
			</xsl:when>
		</xsl:choose>
		
		<xsl:copy/>
	</xsl:template>
	
	<func:function name="local:init-form">
		<sw:noauth-redirect select="not(cred:check-context('vzcp.hn.reboot','hn.vz.vt'))"/>
		<xsl:if test="$step = ''">
			<xsl:call-template name="init-data"/>
		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>
	
	<xsl:template name="init-data">
			<!-- Init Step -->
      <xsl:variable name="new_step">
        <xsl:choose>
          <xsl:when test="string(sw:param('tab'))!=''">
              <xsl:value-of select="sw:param('tab')"/>
          </xsl:when>
          <xsl:otherwise>reboot</xsl:otherwise>
        </xsl:choose>
      </xsl:variable>

			<!-- Init steps -->
			<xsl:variable name="new_steps_">
				<xsl:choose>
					<xsl:when test="$new_step = 'reboot'">
						<step id="reboot"	screenid="03.02.01.30.00"/>
					</xsl:when>
				</xsl:choose>
			</xsl:variable>

			<xsl:variable name="new_steps">
				<xsl:copy-of	select="exsl:node-set($new_steps_)/step[(not(@cred) or cred:check-context(@cred,'hn.vz.vt'))]"/>
			</xsl:variable>

			<!-- Check startup conditions -->
			<xsl:variable name="new_form">
				<xsl:choose>
					<xsl:when test="count($new_steps)=0">
						<xsl:message terminate="yes">
							Requested tab '<xsl:value-of select="$new_step"/>' is unknown for HW node reboot code.
						</xsl:message>
					</xsl:when>
					<xsl:otherwise>
							<!-- all ok, no need any prepare on init -->
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
			<!-- Save wizard initial settings -->
			<xsl:if test="error:is-empty()">
				<xsl:variable name="saved_form" select="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
				<xsl:variable name="saved_steps" select="sw:sesput($wiz_steps,$new_steps)"/>
				<xsl:variable name="saved_step" select="sw:sesput($wiz_step,$new_step)"/>
			</xsl:if>
	</xsl:template>
	
	<func:function name="reb:getFinalPacket">
		<xsl:param name="step"/>
		<xsl:param name="data"/>
		<!--|-->
		<func:result>
			<xsl:choose>
				<!-- reboot hw node -->
				<xsl:when test="$step='reboot'">

					<xsl:if test="error:is-empty()">
						<xsl:if test="cred:detail-check-hw('vzcp.hn.reboot',sw:hn-eid())"/>
					</xsl:if>
					<xsl:choose>
						<xsl:when test="error:is-empty()">

					<packet log="on" progress="on">
						<target>computerm</target>
						<xsl:copy-of select="sw:hn-dst(sw:hn-eid())"/>
						<cookie>
							<msg>
								<ok><sw:text>The Hardware Node rebooting has been scheduled.</sw:text></ok>
								<error><sw:text>Failed to reboot the Hardware Node.</sw:text></error>
							</msg>
							<operation>reboot-hw</operation>
							<redirect><xsl:value-of select="$backurl"/></redirect>
						</cookie>
						<data>
							<computerm>
								<reboot/>
							</computerm>
						</data>
						<vzcpauth/>
					</packet>
						</xsl:when>
						<xsl:otherwise>
							<packet/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<!-- /reboot hw node -->
			</xsl:choose>
		</func:result>
	</func:function>
	
 <!-- credentials -->
	<sw:include href="/lib/cred.xsl"/>
	
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>

</xsl:stylesheet>
