<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl func wiz cred error local check"
	xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:sw			="http://www.swsoft.com/xsl/cp"
	xmlns:error		="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz			="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:func		="http://exslt.org/functions"
	xmlns:cred		="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"
	xmlns:check		="http://www.swsoft.com/xsl/cp/check"
	xmlns:redirect="http://www.swsoft.com/xsl/cp/redirect"
	xmlns:vzenv   ="http://www.swsoft.com/xsl/cp/vzenv"
>

	<sw:include href="/lib/vz/vzenv-core.xsl"/>
	<sw:include href="/lib/core/check-funcs.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>

	<xsl:output method="xml"/>
	<xsl:variable name="hn-eid" select="sw:hn-eid()"/>

	<!-- Load data -->
	<xsl:variable name="action" select="sw:if(sw:param('cmd') = 'v','edit','new')"/>
	<xsl:variable name="step" select="wiz:processing-step-id()"/>

	<xsl:variable name="redirect-id">
		<xsl:choose>
			<xsl:when test="($action = 'edit') or ($step = 'edit')">
				<xsl:value-of select="sw:base64-decode(sw:param('id'))"/>
			</xsl:when>
			<xsl:when test="($action = 'new') or ($step = 'new')">
				<xsl:value-of select="sw:param('id')"/>
			</xsl:when>
		</xsl:choose>
 	</xsl:variable>


	<xsl:param name="wiz_code" select="'hn-redirect'"/>
	<xsl:variable name="form" select="local:init-form()"/>

	<xsl:template match="node()|@*">
		<xsl:choose>
			<!-- Step "Add" and "New" -->
			<xsl:when test="$step='edit' or $step='new'">
				<xsl:variable name="new_form_">
					<service>
						<id>
							<xsl:value-of select="$redirect-id"/>
						</id>
						<dst>
							<xsl:value-of select="sw:param('dst')"/>
						</dst>
						<port>
							<xsl:value-of select="sw:param('port')"/>
						</port>
						<default>
							<xsl:value-of select="sw:if(sw:param('default')=1,1,0)"/>
						</default>
					</service>
				</xsl:variable>

				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
				<xsl:if test="sw:param('next')">
					<!-- CHECK DATA -->
					<xsl:choose>
						<xsl:when test="not($new_form/service/id != '')">
							<xsl:if test="error:put(sw:text('You should specify a name.'),'','id')"/>
						</xsl:when>
						<xsl:when test="not($new_form/service/dst != '')">
							<xsl:if test="error:put(sw:text('You should specify a destination Container ID.'),'','dst')"/>
						</xsl:when>						
						<xsl:when test="not($new_form/service/port != '')">
							<xsl:if test="error:put(sw:text('You should specify a redirected port.'),'','port')"/>
						</xsl:when>												
						<xsl:when test="not(check:num($new_form/service/dst))">
							<xsl:if test="error:put(sw:text('The destination Container ID must be a number.'),'','dst')"/>							
						</xsl:when>
						<xsl:when test="not(check:port($new_form/service/port))">
							<xsl:if test="error:put(sw:text('The redirected port must be a number in the 1-65535 range.'),'','port')"/>
						</xsl:when>
						<xsl:when test="not(vzenv:veid-to-eid($new_form/service/dst,$hn-eid) != '')">
							<xsl:if test="error:put(sw:text('You should specify an existing destination Container ID.'),'','dst')"/>
						</xsl:when>						
					</xsl:choose>
					<!-- /CHECK DATA -->
				</xsl:if>

				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new_form"/>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>

		<xsl:copy/>
	</xsl:template>

	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
						<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
								<xsl:copy-of select="local:final($data)"/>
								<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
							</xsl:when>
							<xsl:otherwise>
								<packet/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

	<func:function name="local:init-form">
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:init-new"/>				
 		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>
 	
	<xsl:template name="local:init-new">
		<xsl:variable name="new_form">
			<xsl:choose>
				<xsl:when test="$action = 'new'">
					<service>
						<id/>
						<port/>
						<dst>1</dst>
						<default>0</default>
					</service>
				</xsl:when>
				<xsl:otherwise>
					<!-- it's edit rule, load data -->
					<xsl:copy-of select="redirect:load($hn-eid,$redirect-id)"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<!-- Init steps -->
		<xsl:variable name="new_steps_">
			<xsl:choose>
				<xsl:when test="$action = 'new'">
					<step id="new" screen-id="03.02.01.32.31"
						cred="vzcp.hn.manage.config.network"
						security-obj-type="hn.vz.vt"
						screen-title="{sw:text('New Offline Service')}"/>
				</xsl:when>
				<xsl:when test="$action = 'edit'">
					<xsl:variable name="title">
						<sw:text>
							<xsl:with-param name="service" select="exsl:node-set($new_form)/service/id"/>
							Configure %{service}
						</sw:text>
					</xsl:variable>
					<step id="edit" screen-id="03.02.01.32.32"
						cred="vzcp.hn.manage.config.network"
						security-obj-type="hn.vz.vt"
						screen-title="{$title}"/>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:variable name="new_steps_filtered">
				<xsl:copy-of
					select="exsl:node-set($new_steps_)/step[(not(@cred) or cred:check-context(@cred,@security-obj-type)) and (not(@platform) or (@platform = $platform))]"
				/>
			</xsl:variable>
			<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
			<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
			<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
			<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>
	</xsl:template>

	<!-- *********************************************************** -->
	<func:function name="local:final">
		<xsl:param name="data"/>
		<func:result>
			<xsl:choose>
				<xsl:when test="$step = 'new'">
					<xsl:if test="error:is-empty()">
						<xsl:if test="cred:check-hw('vzcp.hn.manage.config.network',$hn-eid)"/>
					</xsl:if>
					<xsl:choose>
						<xsl:when test="error:is-empty()">
							<xsl:copy-of select="redirect:add($hn-eid,$data)"/>
						</xsl:when>
						<xsl:otherwise>
							<packet/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="$step = 'edit'">
					<xsl:if test="error:is-empty()">
						<xsl:if test="cred:check-hw('vzcp.hn.manage.config.network',$hn-eid)"/>
					</xsl:if>
					<xsl:choose>
						<xsl:when test="error:is-empty()">
							<xsl:copy-of select="redirect:edit($hn-eid,$data)"/>
						</xsl:when>
						<xsl:otherwise>
							<packet/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
			</xsl:choose>
		</func:result>
	</func:function>


	<!-- credentials -->
	<sw:include href="/lib/cred.xsl"/>

	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/vz/vzhn-redirects.xsl"/>	
	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
