<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred local vzhn"
	xmlns:xsl			="http://www.w3.org/1999/XSL/Transform" 
	xmlns:exsl		="http://exslt.org/common"
	xmlns:sw			="http://www.swsoft.com/xsl/cp" 
	xmlns:error		="http://www.swsoft.com/xsl/cp/error" 
	xmlns:wiz			="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:func		="http://exslt.org/functions" 
	xmlns:cred		="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local		="http://www.swsoft.com/xsl/cp/local" 
	xmlns:vzhn		="http://www.swsoft.com/xsl/cp/vzhn" 
	xmlns:request	="http://www.swsoft.com/xsl/cp/request" 
	xmlns:top			="http://www.swsoft.com/xsl/cp/top" 
	xmlns:voc			="http://www.swsoft.com/xsl/cp/voc" 
	xmlns:user		="http://www.swsoft.com/xsl/cp/user" 
	xmlns:date			="http://exslt.org/dates-and-times"
	>

	<sw:include href="/lib/vz/vzhn-core.xsl"/>
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/get_top.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/core/user-attrs.xsl"/>

	<xsl:output method="xml"/>
	<xsl:param name="wiz_code" select="'get-top'"/>
	<!-- top resource usage counters, from agent -->
	<xsl:variable name="counters" select="top:get-counters()"/>
	<!-- parameter from internal, per user, storage -->
	<xsl:variable name="saved-params" select="user:get-attrs('resourceLogSettings')"/>
	<xsl:variable name="top-structure" select="exsl:node-set(top:return-init-structure())"/>

	<xsl:variable name="initializer">
		<!-- get current step, step define all behavior -->
		<xsl:variable name="step-raw">
			<xsl:variable name="tab-from-get" 			select="sw:param('tab')"/>
			<xsl:variable name="step-from-post"			select="sw:param('step')"/>
			<xsl:choose>
				<xsl:when test="$step-from-post != ''">
					<!-- from post -->
					<xsl:value-of select="$step-from-post"/>
				</xsl:when>
				<xsl:when test="$tab-from-get != ''">
					<!-- calc step by tab -->
					<xsl:value-of select="$top-structure/top[tab = $tab-from-get]/step"/>
				</xsl:when>
				<xsl:otherwise>
					<!-- no get , no post.  Try get from persistence storage -->
					<xsl:value-of select="local:get-top-param('step', '')"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<!-- describe step for wizard  -->
		<xsl:variable name="new_steps_">
			<step id="cpu" 			screenid="03.02.03.03.01"/>
			<step id="memtotal" screenid="03.02.03.03.02"/>
			<step id="disk" 		screenid="03.02.03.03.04"/>
			<step id="fs" 			screenid="03.02.03.03.05"/>
			<step id="netin" 		screenid="03.02.03.03.06"/>
			<step id="netout" 	screenid="03.02.03.03.07"/>
		</xsl:variable>	
		<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)/step"/>
		<!-- refine and normalize step-raw -->
		<xsl:variable name="step" select="local:process-param(string($new_steps[@id = $step-raw]/@id),$new_steps[1]/@id)"/>
		
		<!-- initial screens setup -->
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:variable name="saved_step" select="sw:sesput($wiz_step, $step)"/>
			<xsl:variable name="saved_steps" select="sw:sesput($wiz_steps, $new_steps)"/>
			<xsl:variable name="saved_form"
				select="sw:sesput($wiz_data, local:form-data($step,
				local:get-top-param('interval', 3600), local:get-top-param('records', 10), 
				local:get-top-param('mode', 'relative')))"/>
		</xsl:if>
		<!-- calculate minimal interval -->
	</xsl:variable>
	
	<!-- main handler -->
	<xsl:template match="/">
		<xsl:variable name="step" select="wiz:processing-step-id()"/>
		<xsl:variable name="form" 		select="sw:sesget($wiz_data)"/>
		<xsl:choose>
			<!-- Move back -->
			<xsl:when test="sw:param('back')">
				<xsl:if test="wiz:goBack()"/>
				<packet />
			</xsl:when>
			<!-- handle steps -->
			<xsl:when test="$step != ''">
				<xsl:variable name="interval" select="local:process-param(sw:param('interval'), $form/top:query/interval)"/>
				<xsl:variable name="records" 	select="local:process-param(sw:param('records'), $form/top:query/records)"/>
				<xsl:variable name="mode" 		select="local:process-param(sw:param('mode'), $form/top:view/mode)"/>
				<xsl:variable name="new-form-rtf" select="local:form-data($step, $interval, $records, $mode)"/>
				<xsl:variable name="new-form" 		select="exsl:node-set($new-form-rtf)"/>
				<xsl:choose>
					<xsl:when test="error:is-empty()">
						<!-- Store form values-->
						<xsl:variable name="res">
							<xsl:value-of select="sw:sesput($wiz_data, $new-form)"/>
							<xsl:if test="sw:sesput($wiz_step,$step)"/>
						</xsl:variable>
						<xsl:choose>
							<xsl:when test="$new-form/top:query[id='counter_memory_used' and interval=0]"> 
								<xsl:call-template name="top:get-mem-instant-packet">
					        <xsl:with-param name="data" select="$new-form/top:query"/>
					      </xsl:call-template>
							</xsl:when>							
							<xsl:when test="$new-form/top:query[(id='counter_disk_used') and interval=0]"> 
								<xsl:call-template name="top:get-disk-instant-packet">
					        <xsl:with-param name="data" select="$new-form/top:query"/>
					      </xsl:call-template>
							</xsl:when>							
							<xsl:otherwise>
								<xsl:call-template name="top:get-top-packet">
					        <xsl:with-param name="data" select="$new-form/top:query"/>
					      </xsl:call-template>
							</xsl:otherwise>
						</xsl:choose>	
						<xsl:if test="local:save-params($new-form)"/>
					</xsl:when>
					<xsl:otherwise>
						<packet/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<!-- first load page -->
			<xsl:when test="$step = ''">
				<xsl:choose>
					<xsl:when test="$form/top:query[id='counter_memory_used' and interval=0]"> 
						<xsl:call-template name="top:get-mem-instant-packet">
							<xsl:with-param name="data" select="$form/top:query"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:when test="$form/top:query[(id='counter_disk_used') and interval=0]"> 
						<xsl:call-template name="top:get-disk-instant-packet">
							<xsl:with-param name="data" select="$form/top:query"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="top:get-top-packet">
							<xsl:with-param name="data" select="$form/top:query"/>
						</xsl:call-template>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>			
			<xsl:otherwise>
				<!-- fallback -->
				<packet/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- Local functions -->
	<func:function name="local:form-data">
		<xsl:param name="step"/>
		<xsl:param name="interval"/>
		<xsl:param name="records"/>
		<xsl:param name="mode"/>
		<xsl:variable name="counter" select="$counters[id=local:step-to-counter-id($step)]"/>
		<xsl:variable name="min-interval" select="$counter/period"/>
		<xsl:variable name="ret-rtf">
			<xsl:copy-of select="$counter"/>
			<top:query>
				<id><xsl:value-of select="$counter/id"/></id>
				<interval>
					<xsl:value-of
						select="sw:if(number($interval) != 'NaN' 
								and (number($interval) &gt;= $min-interval or ($interval=0 and $counter/instant)), 
								$interval, $min-interval)"/>
				</interval>
				<records>
					<xsl:value-of select="$records"/>
				</records>
			</top:query>
			<top:view>
				<xsl:copy-of select="$counter/measure"/>
				<mode>
					<xsl:value-of select="$mode"/>
				</mode>
				<min-interval>
					<xsl:value-of select="$min-interval"/>
				</min-interval>
			</top:view>
		</xsl:variable>
		<func:result>
			<xsl:copy-of select="exsl:node-set($ret-rtf)"/>
		</func:result>
	</func:function>

	<!-- input:  wizard step name, 
			 output: agent counter id 	-->
	<func:function name="local:step-to-counter-id">
		<xsl:param name="step"/>
		<func:result select="$top-structure/top[step=$step]/id"/>
	</func:function>

	<func:function name="local:save-params">
		<xsl:param name="form"/>
		<func:result select="user:set-attrs('resourceLogSettings', ($form/top:query|$form/top:view)/*)"/>
	</func:function>

	<func:function name="local:process-param">
		<xsl:param name="value"/>
		<xsl:param name="default"/>
		<func:result select="sw:if(string($value)='', $default, $value)"/>
	</func:function>

	<!-- restore from preferences or fallback to hardcoded default-->
	<func:function name="local:get-top-param">
		<xsl:param name="key"/>
		<xsl:param name="default"/>
		<xsl:variable name="rc" select="$saved-params/*[name()=$key]"/>
		<func:result select="sw:if(string($rc)='', $default, $rc)"/>
	</func:function>

</xsl:stylesheet>
