<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func date wiz vzasupport cred"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:func="http://exslt.org/functions"
	xmlns:date="http://exslt.org/dates-and-times"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:filem="http://www.swsoft.com/xsl/cp/filem"
	xmlns:vzasupport="http://www.swsoft.com/xsl/cp/vzasupport"
	xmlns:vzenv="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
>

	<sw:include href="/lib/vza/vzasupport.xsl"/>
	<sw:include href="/lib/vz/vzenv-core.xsl"/>		

	<xsl:output method="xml"/>
	<xsl:param name="wiz_code" select="'support_key'"/>

  <xsl:variable name="step" select="wiz:processing-step-id()"/>	
  <xsl:variable name="form" select="local:init-form()"/>

	<xsl:template match="node()|@*">
		<xsl:choose>
			<xsl:when	test="$step='install'">
				<xsl:variable name="file-size"
					select="$request/http_request/env/parameter[name = 'CONTENT_LENGTH']/value"/>
				<xsl:variable name="size-limit"
					select="$config/vzcpcon/defines/support/channel/key-size-limit"/>
				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="name()=$step"/>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<xsl:variable name="key-file"
						select="$request/http_request/files/file[input_name = 'key_file']"/>
					<install>
						<file>
							<xsl:copy-of select="$key-file"/>
						</file>
						<size>
							<xsl:value-of select="$file-size"/>
						</size>
						<xsl:choose>
							<xsl:when test="not($size-limit) or ($file-size &gt; ($size-limit*1024))">
								<size-limit>
									<xsl:value-of select="$size-limit"/>
								</size-limit>
							</xsl:when>
							<xsl:otherwise>
								<content>
									<xsl:variable name="key-content" select="filem:get($key-file/local_path, vzenv:veid-to-eid(1,sw:local-hn-eid()))"/>
									<xsl:choose>
										<xsl:when test="name($key-content)='error'">
											<xsl:if test="error:put(sw:text('An error occurred during the uploading of the file.'),$key-content/message,'key_file')"/>											
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="$key-content"/>											
										</xsl:otherwise>
									</xsl:choose>
								</content>
							</xsl:otherwise>
						</xsl:choose>
					</install>
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
				<xsl:if test="wiz:clicked-back()">
					<xsl:if test="wiz:goBack()"/>
				</xsl:if>
				<xsl:if test="wiz:clicked-next()">
					<!-- Check data -->
					<xsl:choose>
						<xsl:when
							test="not(string($new_form/install/file) != '') and cred:detail-check('vzcp.support.troubleshooting')">
							<!-- User provided both sources -->
							<xsl:if test="error:put(sw:text('Please select the certificate file.'),'','key_file')"/>
						</xsl:when>
						<!-- Key too big -->
						<xsl:when test="$new_form/install/size-limit">
							<xsl:variable name="error">
								<sw:text>
									<xsl:with-param name="limit" select="$new_form/install/size-limit"
									/>
										Your certificate size is too big. The maximal size is %{limit} KB.
									</sw:text>
							</xsl:variable>
							<xsl:if test="error:put($error,'','key_file')"/>
						</xsl:when>
					</xsl:choose>
					<!-- Move to next step -->
					<xsl:choose>
						<xsl:when test="error:is-empty()">
							<xsl:copy-of select="local:get-final-packet($step,$new_form)"/>
							<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
						</xsl:when>
					</xsl:choose>
				</xsl:if>

				<!-- Store form values-->
				<xsl:variable name="res">
					<xsl:value-of select="sw:sesput($wiz_data,$new_form)"/>
				</xsl:variable>
			</xsl:when>

		</xsl:choose>

		<xsl:copy/>
	</xsl:template>

	<func:function name="local:init-form">
		<xsl:if test="$step = ''">
		
			<!-- Init Step -->
			<xsl:variable name="new_step" select="'install'"/>

			<!-- Init steps -->
			<xsl:variable name="new_steps_">
				<step id="install" screen-id="03.02.01.29.01" cred="vzcp.support.troubleshooting" security-obj-type="hn.vz.vt"/>
			</xsl:variable>

			<xsl:variable name="new_steps">
				<xsl:copy-of
					select="exsl:node-set($new_steps_)/step[(not(@cred) or cred:check-hw(@cred,sw:hn-eid()))]"
				/>
			</xsl:variable>
			<!-- Check startup conditions -->
			<xsl:variable name="new_form">
				<xsl:choose>
					<xsl:when test="count($new_steps)=0">
						<xsl:message terminate="yes">
							Requested tab '<xsl:value-of select="$new_step"
							/>' is unknown for support certificate content.
						</xsl:message>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="local:init-data($new_step)"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
			<!-- Save wizard initial settings -->
			<xsl:if test="error:is-empty()">
				<xsl:variable name="saved_form" select="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
				<xsl:variable name="saved_steps" select="sw:sesput($wiz_steps,$new_steps)"/>
				<xsl:variable name="saved_step" select="sw:sesput($wiz_step,$new_step)"/>
			</xsl:if>
		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>
	
	<func:function name="local:init-data">
		<xsl:param name="step"/>
		<func:result>
			<xsl:choose>
				<xsl:when test="$step='install'">
					<!-- Load data for Install Step -->
					<!-- /Load data for Install Step -->
				</xsl:when>
			</xsl:choose>
		</func:result>
	</func:function>

	<func:function name="local:get-final-packet">
		<xsl:param name="step"/>
		<xsl:param name="data"/>
		<!--|-->
		<func:result>
			<packet>
				<target>vzasupport</target>
				<xsl:copy-of select="sw:hn-dst(sw:hn-eid())"/>
				<cookie>
					<msg>
						<ok>
							<sw:text>
								The new certificate has been successfully installed.
							</sw:text>
						</ok>
						<error>
							<sw:text>Failed to install the new certificate.</sw:text>
						</error>
					</msg>
					<operation>install-support-key</operation>
					<redirect-prev/>
				</cookie>
				<data>
					<vzasupport>
						<set_key>
							<key>
								<xsl:value-of select="$data/install/content"/>
							</key>
						</set_key>
					</vzasupport>
				</data>
				<vzcpauth/>
			</packet>
		</func:result>
	</func:function>


	<!-- credentials -->
	<sw:include href="/lib/cred.xsl"/>

	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/vza/filem.xsl"/>

</xsl:stylesheet>
