<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
	extension-element-prefixes="sw exsl func wiz cred local vznet"
	xmlns:exsl="http://exslt.org/common" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz" xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:func="http://exslt.org/functions" xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:vznet="http://www.swsoft.com/xsl/cp/vznet" xmlns:request="http://www.swsoft.com/xsl/cp/request"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
>
	<sw:include href="/lib/vz/vznet-vn.xsl"/>
	<sw:include href="/lib/vz/vznet-core.xsl"/>
	<sw:include href="/lib/vz/vznet-adaptor.xsl"/>
	<sw:include href="/lib/vz/vznet-switch.xsl"/>
	<sw:include href="/lib/vz/vznet-ui.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>

	<xsl:output method="xml"/>
	<xsl:variable name="hn-eid" select="sw:hn-eid()"/>

	<xsl:variable name="step" select="wiz:processing-step-id()"/>

	<xsl:param name="wiz_code" select="'netadaptor-config'"/>
	<xsl:variable name="form" select="local:init-form()"/>

	<xsl:template match="node()|@*">
		<xsl:choose>
			<!-- Step "General Settings" -->
			<xsl:when
				test="$step='gen'">

				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="name()='gen'"/>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<gen>
						<net_device>
							<id>
								<xsl:value-of select="$form/static/id"/>
							</id>
							<xsl:copy-of select="vznet:restore-virtual-network()"/>
						</net_device>
					</gen>
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>

				<xsl:if test="sw:param('next')">
					<!-- check data -->
					<xsl:if test="vznet:check-virtual-network($new_form)"/>							
				</xsl:if>

				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new_form"/>
					<xsl:with-param name="hn-eid" select="$hn-eid"/>
				</xsl:call-template>

			</xsl:when>
		</xsl:choose>
		<xsl:copy/>
	</xsl:template>

	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>
		<!--|-->
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
						<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:choose>
									<xsl:when test="$data/gen/net_device/network_id=''">
										<xsl:copy-of select="local:processEthUpdate($data,$hn-eid)"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:copy-of select="local:processEthUpdateConnected($data,$hn-eid)"/>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
							</xsl:when>
							<xsl:otherwise>
								<packet/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<func:function name="local:init-form">
		<sw:noauth-redirect select="not(cred:check-hw('vzcp.hn.manage.config.network', $hn-eid))"/>
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:init-new"/>				
 		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>
 	
	<xsl:template name="local:init-new">
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>
			<xsl:variable name="curr-adaptor-id" select="sw:sesget('adaptor-id')"/>
			<xsl:variable name="get-adaptor-id"
				select="sw:base64-decode(sw:param('id'))"/>
			<xsl:variable name="adaptor-id"
				select="sw:if(string-length($get-adaptor-id) > 0,$get-adaptor-id,$curr-adaptor-id)"/>
			<xsl:if test="sw:sesput('vznet-adaptor-id', $adaptor-id)"/>
			<xsl:variable name="data" select="vznet:get-adaptor($hn-eid,$adaptor-id)"/>
			<xsl:variable name="network-id" select="sw:base64-decode($data/network_id)"/>
			
			<xsl:variable name="new_form">
				<gen>
					<net_device>
						<id>
							<xsl:value-of select="$data/id"/>
						</id>
						<network_id>
							<xsl:value-of select="$network-id"/>
						</network_id>
						<xsl:copy-of select="$data/ip_address"/>
					</net_device>
					<new_network>
						<network_id/>
						<description/>
					</new_network>
				</gen>
				<static>
					<xsl:call-template name="vznet:init-networks">
						<xsl:with-param name="current-adapter-id" select="$adaptor-id"/>
					</xsl:call-template>				
					<id>
						<xsl:value-of select="$data/id"/>
					</id>
				</static>
				<hn>
					<xsl:copy-of select="env:eid2info($hn-eid)"/>
				</hn>
			</xsl:variable>
			<!-- Init steps -->
			<xsl:variable name="new_steps_">
				<step id="gen" screen-id="03.02.01.32.19"/>
			</xsl:variable>
			<!-- Save wizard initial settings -->
			<xsl:if test="error:is-empty()">
				<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
				<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
				<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
				<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
				<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
			</xsl:if>
	</xsl:template>

	<func:function name="local:processEthUpdate">
		<xsl:param name="data"/>
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>
		<xsl:variable name="result" select="vznet:save-adaptor($hn-eid,$data/gen/net_device)"/>

		<func:result select="local:postResult($result)"/>
	</func:function>

	<func:function name="local:processEthUpdateConnected">
		<xsl:param name="data"/>
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>
		<xsl:variable name="br-result-rtf">
			<xsl:choose>
				<xsl:when test="$data/hn/linux and not(vznet:is-vn-bridged($hn-eid,$data/gen/net_device/network_id))">
					<xsl:copy-of select="vznet:set-vn-bridged($hn-eid,$data/gen/net_device)"/>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="br-result" select="exsl:node-set($br-result-rtf)"/>
		<xsl:variable name="result-rtf">
			<xsl:choose>
				<xsl:when test="not($br-result/error)">
					<xsl:copy-of select="vznet:save-adaptor($hn-eid,$data/gen/net_device)"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="$br-result"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="result" select="exsl:node-set($result-rtf)"/>
		<func:result select="local:postResult($result)"/>
	</func:function>

	<func:function name="local:postResult">
		<xsl:param name="result"/>
		<xsl:choose>
			<!-- Saved -->
			<xsl:when test="not($result/error)">
				<!-- Return back -->
				<func:result>
					<packet>
						<cookie>
							<msg>
								<set-ok>
									<sw:text>The network adapter configuration has been saved successfully.</sw:text>
								</set-ok>
							</msg>
							<redirect-prev/>
						</cookie>
					</packet>
				</func:result>
			</xsl:when>
			<!-- /Saved -->
			<xsl:otherwise>
				<!-- Error occure  -->
				<func:result>
					<packet>
						<cookie>
							<msg>
								<set-error>
									<short-desc>
										<sw:text>Error configuring the network adapter.</sw:text>
									</short-desc>
									<detail>
										<xsl:value-of select="$result/error"/>
									</detail>
								</set-error>
							</msg>
						</cookie>
					</packet>
				</func:result>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<!-- credentials -->
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>
</xsl:stylesheet>
