<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl func wiz cred local vznet error server_group"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz" xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:func="http://exslt.org/functions" xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:vznet="http://www.swsoft.com/xsl/cp/vznet"
	xmlns:server_group="http://www.swsoft.com/xsl/cp/server_group">

	<!-- Functionality  modules -->
	<sw:include href="/lib/vz/vznet-switch.xsl"/>
	<sw:include href="/lib/swa/server-group.xsl"/>

	<xsl:output method="xml"/>

	<xsl:variable name="step" select="wiz:processing-step-id()"/>

	<xsl:param name="wiz_code" select="'netbridge-add'"/>
	<xsl:variable name="form" select="local:init-form()"/>

	<xsl:template match="node()|@*">
		<xsl:choose>
			<!-- Step "General Settings" -->
			<xsl:when
				test="not(sw:param('step') != ''">
				<xsl:if test="error:has-errors()">
					<packet>
						<xsl:if test="sw:response('lib/opredirect.xsl')"/>
						<cookie>
							<redirect-last/>
						</cookie>
					</packet>
				</xsl:if>
			</xsl:when>
			<xsl:when
				test="$step='gen'">

				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="name()='gen'"/>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<gen>
						<id/>
						<network_id>
							<xsl:value-of select="sw:param('network_id')"/>
						</network_id>
					</gen>
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>

				<xsl:if test="sw:param('next')">
					<!-- check data -->
				</xsl:if>

				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new_form"/>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>
		<xsl:copy/>
	</xsl:template>

	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
						<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:choose>
									<xsl:when test="error:is-empty()">
										<xsl:copy-of select="local:getFinalPacket($data)"/>
										<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
									</xsl:when>
									<xsl:otherwise>
										<packet/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
							<xsl:otherwise>
								<packet/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<func:function name="local:init-form">
		<sw:noauth-redirect select="not(cred:check-hw('vzcp.hn.manage.config.network', sw:hn-eid()))"/>
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:init-new"/>				
 		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>
 	
	<xsl:template name="local:init-new">
			<!-- Init form data -->
			<xsl:variable name="cluster_config" select="server_group:get-config()"/>
			<xsl:variable name="ex-switches" select="vznet:list-switches(sw:hn-eid())"/>
			<xsl:variable name="rfc-free-networks">
				<xsl:for-each select="$cluster_config/networks/network">
					<xsl:variable name="network_id" select="sw:base64-decode(id)"/>
					<xsl:if test="count($ex-switches/net_device[string(network_id) = $network_id]) = 0">
						<xsl:copy-of select="."/>
					</xsl:if>
				</xsl:for-each>
			</xsl:variable>
			<xsl:variable name="free-networks" select="exsl:node-set($rfc-free-networks)"/>
			<xsl:choose>
				<xsl:when test="count($cluster_config/networks/network) = 0">
					<xsl:if
						test="error:put(sw:text('Cannot add a new switch.'),sw:text('No virtual networks found.'))"
					/>
				</xsl:when>
				<xsl:when test="count($free-networks/network) = 0">
					<xsl:if
						test="error:put(sw:text('Cannot add a new switch.'),sw:text('All virtual networks are already assigned to other switches.'))"
					/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:variable name="new_form">
						<gen>
							<network_id/>
						</gen>
						<static>
							<networks>
								<xsl:for-each select="$free-networks/network">
									<xsl:copy>
										<id>
											<xsl:value-of select="sw:base64-decode(id)"/>
										</id>
									</xsl:copy>
								</xsl:for-each>
							</networks>
						</static>
					</xsl:variable>
					<!-- Init steps -->
					<xsl:variable name="new_steps_">
						<step id="gen" screen-id="03.02.01.32.13"/>
					</xsl:variable>
					<!-- Save wizard initial settings -->
					<xsl:if test="error:is-empty()">
						<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
						<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
						<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
						<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
						<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
					</xsl:if>
				</xsl:otherwise>
			</xsl:choose>
	</xsl:template>

	<func:function name="local:getFinalPacket">
		<xsl:param name="data"/>
		<xsl:variable name="error" select="vznet:add-switch(sw:sesget('hn-eid'),$data/gen)"/>
		<xsl:choose>
			<!-- Saved -->
			<xsl:when test="not($error/error)">
				<!-- Return back -->
				<func:result>
					<packet>
						<cookie>
							<msg>
								<set-ok>
									<sw:text>The network switch configuration has been saved successfully.</sw:text>
								</set-ok>
							</msg>
							<redirect-prev/>
						</cookie>
					</packet>
				</func:result>
			</xsl:when>
			<!-- /Saved -->
			<xsl:otherwise>
				<!-- Error occure  -->
				<func:result>
					<packet>
						<cookie>
							<msg>
								<set-error>
									<short-desc>
										<sw:text>Error configuring the network switch.</sw:text>
									</short-desc>
									<detail>
										<xsl:value-of select="$error/error"/>
									</detail>
								</set-error>
							</msg>
							<redirect-prev/>
						</cookie>
					</packet>
				</func:result>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<!-- credentials -->
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
