<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred local vznet check"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz" xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:func="http://exslt.org/functions" xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:vznet="http://www.swsoft.com/xsl/cp/vznet"
	xmlns:check	="http://www.swsoft.com/xsl/cp/check"	
>
	<!-- Functionality  modules -->
	<sw:include href="/lib/vz/vznet-core.xsl"/>
	<sw:include href="/lib/vz/vznet-switch.xsl"/>
	<sw:include href="/lib/vz/vznet-vlan.xsl"/>
	<sw:include href="/lib/vz/vznet-adaptor.xsl"/>
	<sw:include href="/lib/vz/vznet-ui.xsl"/>
	<sw:include href="/lib/vz/vznet-vn.xsl"/>

	<xsl:output method="xml"/>

	<xsl:variable name="step" select="wiz:processing-step-id()"/>

	<xsl:param name="wiz_code" select="'vlan-add'"/>
	<xsl:variable name="form" select="local:init-form()"/>

	<xsl:variable name="base_device_id">
		<xsl:choose>
			<xsl:when test="sw:param('adaptor-id')">
				<xsl:value-of
					select="sw:base64-decode(sw:param('adaptor-id'))"
				/>
			</xsl:when>
			<xsl:when test="sw:param('base_device_id')">
				<xsl:value-of select="sw:param('base_device_id')"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="sw:sesget('vznet-adaptor-id')"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>

	<xsl:template match="node()|@*">
		<xsl:choose>
			<!-- Step "General Settings" -->
			<xsl:when
				test="$step='gen'">

				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="name()='gen'"/>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<gen>
						<net_device>
							<base_device_id>
								<xsl:value-of select="sw:param('base_device_id')"/>
							</base_device_id>
							<id/>
							<vlan_id>
								<xsl:value-of select="sw:param('vlan_id')"/>
							</vlan_id>
							<xsl:copy-of select="vznet:restore-virtual-network()"/>
						</net_device>
					</gen>
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>

				<xsl:if test="sw:param('next')">
					<!-- check data -->
					<xsl:if test="not(check:num($new_form/gen/net_device/vlan_id))">
						<xsl:if test="error:put(sw:text('The VLAN Tag field should contain a valid integer number.'))"/>
					</xsl:if>					
					<xsl:if test="vznet:check-virtual-network($new_form)"/>
					<!-- /check data -->					
				</xsl:if>

				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new_form"/>
				</xsl:call-template>

			</xsl:when>
		</xsl:choose>
		<xsl:copy/>
	</xsl:template>

	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
						<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:choose>
									<xsl:when test="error:is-empty()">
										<xsl:choose>
											<xsl:when test="$data/gen/net_device/network_id!=''">
												<xsl:copy-of select="local:processVLANAddConnected($data)"/>											
											</xsl:when>
											<xsl:otherwise>
												<xsl:copy-of select="local:processVLANAdd($data)"/>											
											</xsl:otherwise>
										</xsl:choose>
										<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
									</xsl:when>
									<xsl:otherwise>
										<packet/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
							<xsl:otherwise>
								<packet/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<func:function name="local:init-form">
		<sw:noauth-redirect select="not(cred:check-hw('vzcp.hn.manage.config.network', sw:hn-eid()))"/>
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:init-new"/>				
 		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>
 	
	<xsl:template name="local:init-new">
			<!-- Init form data -->
			<xsl:variable name="new_form">
				<gen>
					<net_device>
						<base_device_id>
							<xsl:value-of select="$base_device_id"/>
						</base_device_id>
						<vlan_id/>
						<network_id/>
					</net_device>
				</gen>
				<static>
					<xsl:call-template name="vznet:init-networks"/>
					<adaptors>
						<xsl:copy-of select="vznet:list-adaptors(sw:hn-eid())/net_device"/>
					</adaptors>
				</static>
			</xsl:variable>
			<!-- Init steps -->
			<xsl:variable name="new_steps_">
				<step id="gen" screen-id="03.02.01.32.18"/>
			</xsl:variable>
			<!-- Save wizard initial settings -->
			<xsl:if test="error:is-empty()">
				<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
				<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
				<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
				<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
				<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
			</xsl:if>
	</xsl:template>

	<func:function name="local:processVLANAdd">
		<xsl:param name="data"/>
		<xsl:variable name="result" select="vznet:add-vlan(sw:hn-eid(),$data/gen/net_device)"/>

		<func:result select="local:postResult($result)"/>
	</func:function>

	<func:function name="local:processVLANAddConnected">
		<xsl:param name="data"/>
		<xsl:variable name="hw_id" select="sw:hn-eid()"/>
		<xsl:variable name="br-result-rtf">
			<xsl:choose>
				<xsl:when test="not(vznet:is-vn-bridged($hw_id,$data/gen/net_device/network_id))">
					<xsl:copy-of select="vznet:set-vn-bridged($hw_id,$data/gen/net_device)"/>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="br-result" select="exsl:node-set($br-result-rtf)"/>
		<xsl:variable name="result-rtf">
			<xsl:choose>
				<xsl:when test="not($br-result/error)">
					<xsl:copy-of select="vznet:add-vlan($hw_id,$data/gen/net_device)"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="$br-result"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="result" select="exsl:node-set($result-rtf)"/>
		<func:result select="local:postResult($result)"/>
	</func:function>

	<func:function name="local:postResult">
		<xsl:param name="result"/>
		<xsl:choose>
			<!-- Saved -->
			<xsl:when test="not($result/error)">
				<!-- Return back -->
				<func:result>
					<packet>
						<cookie>
							<msg>
								<set-ok>
									<sw:text>The VLAN configuration has been saved successfully.</sw:text>
								</set-ok>
							</msg>
							<redirect-prev/>
						</cookie>
					</packet>
				</func:result>
			</xsl:when>
			<!-- /Saved -->
			<xsl:otherwise>
				<!-- Error occure  -->
				<func:result>
					<packet>
						<cookie>
							<msg>
								<set-error>
									<short-desc>
										<sw:text>Error configuring the VLAN.</sw:text>
									</short-desc>
									<detail>
										<xsl:value-of select="$result/error"/>
									</detail>
								</set-error>
							</msg>
						</cookie>
					</packet>
				</func:result>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	<!-- credentials -->
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>
</xsl:stylesheet>
