<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl func wiz cred local server_group vznet"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz" xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:func="http://exslt.org/functions" xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:server_group="http://www.swsoft.com/xsl/cp/server_group"
	xmlns:networkm="http://www.swsoft.com/xsl/cp/networkm"
	xmlns:vznet="http://www.swsoft.com/xsl/cp/vznet"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	>

	<sw:include href="/lib/swa/server-group.xsl"/>
	<sw:include href="/lib/vz/vznet-core.xsl"/>
	<sw:include href="/lib/vz/vznet-switch.xsl"/>
	<sw:include href="/lib/vz/vznet-vn.xsl"/>
	<sw:include href="/lib/vz/vznet-ui.xsl"/>
	<sw:include href="/lib/vza/networkm.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>

	<xsl:output method="xml"/>
	<xsl:variable name="hn-eid"	select="sw:hn-eid()"/>

	<xsl:variable name="step" select="wiz:processing-step-id()"/>

	<xsl:param name="wiz_code" select="'vn-connect'"/>
	<xsl:variable name="form" select="local:init-form()"/>

	<xsl:template match="node()|@*">
		<xsl:choose>
			<!-- Step "General Settings" -->
			<xsl:when
				test="$step='gen'">

				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="name()='gen'"/>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<gen>
						<network_id>
							<xsl:value-of select="$form/static/network/network_id"/>
						</network_id>
						<xsl:copy-of select="vznet:ui-restore-vn-connection()"/>
					</gen>
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>

				<xsl:if test="sw:param('next')">
					<!-- check data -->
				</xsl:if>

				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new_form"/>
					<xsl:with-param name="hn-eid" select="$hn-eid"/>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>
		<xsl:copy/>
	</xsl:template>

	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>
		<!--|-->
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
						<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:variable name="current-device-name" select="string(sw:param('current_device_name'))"/>
								<xsl:choose>
									<xsl:when test="$data/gen/conn_type = $vznet:not-connected">
										<xsl:copy-of select="vznet:action-vns-disconnect($hn-eid,$data/static/network/network_id,$data/gen/network_type = 'local')"/>
									</xsl:when>
									<xsl:when test="$data/gen/conn_type = $vznet:connected-iface">
										<xsl:copy-of select="local:processConnectInterface($data,$hn-eid,$current-device-name)"/>
									</xsl:when>
									<xsl:when test="$data/gen/conn_type = $vznet:connected-switch">
										<xsl:copy-of select="local:processConnectSwitch($data,$hn-eid,$current-device-name)"/>
									</xsl:when>
									<xsl:otherwise/>
								</xsl:choose>
								<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
							</xsl:when>
							<xsl:otherwise>
								<packet/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<func:function name="local:init-form">
		<sw:noauth-redirect select="not(cred:check-hw('vzcp.hn.manage.config.network', $hn-eid))"/>
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:init-new"/>				
 		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>
 	
	<xsl:template name="local:init-new">
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>
			<!-- Init form data -->
			<xsl:variable name="devices" select="vznet:list-devices($hn-eid,/..)"/>
			<xsl:variable name="network_id" select="sw:sesget('vn-id')"/>
			<xsl:variable name="network-id-coded" select="sw:base64-encode($network_id)"/>			
			<xsl:variable name="is_bridged"
				select="sw:if(count($devices[sw:split(@xsi:type,':')[last()] = 'net_bridgeType' and network_id = $network-id-coded]) &gt; 0,true(),false())"/>
			<xsl:variable name="interface"
				select="$devices[( sw:split(@xsi:type,':')[last()] = 'net_nicType' or sw:split(@xsi:type,':')[last()] = 'net_vlanType' ) and network_id = $network-id-coded]"/>
			<xsl:variable name="new_form">
				<gen>
					<network_id><xsl:value-of select="$network_id"/></network_id>
					<conn_type>
						<xsl:choose>
							<xsl:when test="$interface/id">
								<xsl:value-of select="$vznet:connected-iface"/>
							</xsl:when>
							<xsl:when test="$is_bridged">
								<xsl:value-of select="$vznet:connected-switch"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="$vznet:not-connected"/>
							</xsl:otherwise>
						</xsl:choose>
					</conn_type>
					<interface>
						<xsl:value-of select="sw:if($interface/id,$interface/id,'')"/>
					</interface>
				</gen>
				<static>
					<network>
						<network_id>
							<xsl:value-of select="$network_id"/>
						</network_id>
					</network>
				</static>
				<hn>
					<xsl:copy-of select="env:eid2info($hn-eid)"/>
				</hn>
			</xsl:variable>
			<!-- Init steps -->
			<xsl:variable name="new_steps_">
				<step id="gen" screen-id="03.02.01.32.25"/>
			</xsl:variable>
			<!-- Save wizard initial settings -->
			<xsl:if test="error:is-empty()">
				<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
				<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
				<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
				<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
				<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
			</xsl:if>
	</xsl:template>

	<func:function name="local:processConnectInterface">
		<xsl:param name="data"/>
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>
		<xsl:param name="current-device-name"/>
		<xsl:variable name="device" select="vznet:get-device($hn-eid,$data/gen/interface)"/>
		<xsl:variable name="current-device" select="vznet:get-device($hn-eid,$current-device-name)"/>
		<xsl:variable name="br-result-rtf">
			<xsl:choose>
				<xsl:when test="$data/hn/linux and not(vznet:is-vn-bridged($hn-eid,$data/static/network/network_id))">
					<xsl:copy-of select="vznet:set-vn-bridged($hn-eid,$data/static/network)"/>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="br-result" select="exsl:node-set($br-result-rtf)"/>
		<xsl:variable name="result-rtf">
			<xsl:if test="not($br-result/error)">
				<xsl:copy-of select="networkm:disconnect($hn-eid,$current-device)"/>
				<xsl:copy-of select="networkm:connect($hn-eid,$device,$data/static/network/network_id)/*"/>
			</xsl:if>
		</xsl:variable>
		<xsl:variable name="result" select="exsl:node-set($result-rtf)"/>
		<func:result>
			<xsl:choose>
				<xsl:when test="$br-result/error">
					<packet>
						<cookie>
							<msg>
								<set-error>
									<short-desc>
										<sw:text>Failed to update the virtual network information.</sw:text>
									</short-desc>
									<detail>
										<xsl:value-of select="$br-result/error"/>
									</detail>
								</set-error>
							</msg>
							<redirect-prev/>
						</cookie>
					</packet>
				</xsl:when>
				<xsl:when test="$result/error">
					<packet>
						<cookie>
							<msg>
								<set-error>
									<short-desc>
										<sw:text>Failed to update the virtual network information.</sw:text>
									</short-desc>
									<detail>
										<xsl:value-of select="$result/error/message"/>
									</detail>
								</set-error>
							</msg>
							<redirect-prev/>
						</cookie>
					</packet>
				</xsl:when>
				<xsl:otherwise>
					<packet>
						<cookie>
							<msg>
								<set-ok>
									<sw:text>The virtual network information has been successfully updated.</sw:text>
								</set-ok>
							</msg>
							<redirect-prev/>
						</cookie>
					</packet>
				</xsl:otherwise>
			</xsl:choose>
		</func:result>
	</func:function>

	<func:function name="local:processConnectSwitch">
		<xsl:param name="data"/>
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>
		<xsl:param name="current-device-name"/>
		<xsl:variable name="result-rtf">
			<xsl:if test="$data/hn/linux and not(vznet:is-vn-bridged($hn-eid,$data/static/network/network_id))">
				<xsl:copy-of select="vznet:set-vn-bridged($hn-eid,$data/static/network)"/>
			</xsl:if>
			<xsl:if test="$current-device-name != ''">
				<xsl:variable name="current-device" select="vznet:get-device($hn-eid,$current-device-name)"/>
				<xsl:copy-of select="networkm:disconnect($hn-eid,$current-device)"/>
			</xsl:if>				
		</xsl:variable>
		<xsl:variable name="result" select="exsl:node-set($result-rtf)"/>
		<func:result>
			<xsl:choose>
				<xsl:when test="not($result/error)">
					<packet>
						<cookie>
							<msg>
								<set-ok>
									<sw:text>The virtual network information has been successfully updated.</sw:text>
								</set-ok>
							</msg>
							<redirect-prev/>
						</cookie>
					</packet>
				</xsl:when>
				<xsl:otherwise>
					<packet>
						<cookie>
							<msg>
								<set-error>
									<short-desc>
										<sw:text>Failed to update the virtual network information.</sw:text>
									</short-desc>
									<detail>
										<xsl:value-of select="$result/error"/>
									</detail>
								</set-error>
							</msg>
							<redirect-prev/>
						</cookie>
					</packet>
				</xsl:otherwise>
			</xsl:choose>
		</func:result>
	</func:function>

	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>
</xsl:stylesheet>
