<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl sw func cred"
  xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl		="http://exslt.org/common"
  xmlns:sw			="http://www.swsoft.com/xsl/cp"
  xmlns:error			="http://www.swsoft.com/xsl/cp/error"
  xmlns:func		="http://exslt.org/functions"
	xmlns:cred 		="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local	="http://www.swsoft.com/xsl/cp/local"
>
  <sw:include href="/lib/common.xsl"/>
  <sw:include href="/lib/cred.xsl"/>

  <xsl:output method="xml"/>

  <!-- check permissions to this page -->
	<xsl:variable name="cr-pool-delete"	select="cred:check('vzcp.virtuozzo_group.network.ippools')"/>
  
	<xsl:template match="/">
		<xsl:choose>

				<xsl:when test="sw:param('delete') and not($cr-pool-delete)">	
					<!-- no delete cred -->
					<packet/>
				</xsl:when>
				
        <!-- Check selected templates -->
        <xsl:when test="not(sw:param('id'))">
          <xsl:if test="error:put(sw:text('Please select at least one IP addresses range.'),'')"/>
          <packet/>
        </xsl:when>

        <!-- Delete template-->
        <xsl:when test="sw:param('delete')">
        	<xsl:copy-of select="local:get-packet-delete(sw:param('id'))"/>
        	<xsl:if test="sw:response('lib/opredirect.xsl')"/>	
        </xsl:when>
        
        <!-- Unknown post -->
        <xsl:otherwise>
          <packet/>
        </xsl:otherwise>

      </xsl:choose>
  </xsl:template>
  

  <func:function name="local:get-packet-delete">
  	<xsl:param name="ids"/>
 		<func:result>
			<packet log="on"	xmlns:resource="http://www.swsoft.com/webservices/vzl/4.0.0/resourcem"
												xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
				<target>resourcem</target>
	        <cookie>
	          <msg>
	            <ok><sw:text>The IP address range(s) has/have been deleted.</sw:text></ok>
	            <error><sw:text>Failed to delete the IP address range(s).</sw:text></error>
	          </msg>
	          <operation>delete_ip_range</operation>
	          <redirect-last/>
	        </cookie>			
				<data>
					<resourcem>
						<remove_resource>
							<resource_pool xsi:type="resource:resource_ip_poolType">
								<type>resource_ip</type>
								<xsl:for-each select="$ids">
									<xsl:variable name="ips" select="sw:split(.,'-','ip')"/>
									<xsl:choose>	
										<!-- IP Range -->
										<xsl:when test="$ips[1]!=$ips[2]">
											<ip_range>
												<start_ip>
													<xsl:value-of select="$ips[1]"/>
												</start_ip>
												<end_ip>
													<xsl:value-of select="$ips[2]"/>
												</end_ip>
											</ip_range>
										</xsl:when>
										<!-- IP Address -->
										<xsl:otherwise>
											<ip>
												<xsl:value-of select="$ips[1]"/>
											</ip>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:for-each>
							</resource_pool>
						</remove_resource>
					</resourcem>
				</data>
			</packet>
 		</func:result>
  </func:function> 
 
</xsl:stylesheet>
