<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred check local"
	xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl			="http://exslt.org/common"
	xmlns:sw				="http://www.swsoft.com/xsl/cp"
	xmlns:error				="http://www.swsoft.com/xsl/cp/error"
	xmlns:check			="http://www.swsoft.com/xsl/cp/check"
	xmlns:wiz				="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local			="http://www.swsoft.com/xsl/cp/local"
  xmlns:func			="http://exslt.org/functions"	
	xmlns:cred			="http://www.swsoft.com/xsl/cp/cred"
>
	<sw:include href="/lib/cred.xsl"/>

	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/core/check-funcs.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>				

	<xsl:output method="xml"/>

	<!-- RESTORE FORM VALUES -->
	<xsl:variable name="step" select="wiz:processing-step-id()"/>	
	<xsl:variable name="form" select="local:init-form()"/>

	<xsl:param		name="wiz_code" 	select="'ip-range'"/>
	<xsl:variable	name="edit-mode"	select="$form/range_id"/>

	<xsl:template match="node()|@*">
		<xsl:choose>
			<!-- Step "General Settings" -->
			<xsl:when test="$step='gen'">
			
					<xsl:variable name="new_form_">
						<xsl:for-each select="$form/*">
							<xsl:choose>
								<xsl:when test="name()=$step"></xsl:when>
								<xsl:otherwise>
									<xsl:copy-of select="."/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
						<gen>
							<first>
								<xsl:value-of select="sw:param('first')"/>
							</first>
							<last>
								<xsl:value-of select="sw:param('last')"/>
							</last>
							<count>
								<xsl:value-of select="sw:param('count')"/>
							</count>
							<count_first>
								<xsl:value-of select="sw:param('count_first')"/>
							</count_first>
							<choice>
								<xsl:value-of select="sw:param('choice')"/>
							</choice>
						</gen>
					</xsl:variable>
					<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
					
					<xsl:if test="sw:param('next')">
						<!-- Check data -->
						<!-- Check Range -->
						<xsl:if test="$new_form/gen/choice='range'">
							<!-- Check first -->
							<xsl:choose>
	 				      <!-- check value presence -->
					      <xsl:when test="string($new_form/gen/first)=''">
					      	<xsl:value-of select="error:put(sw:text('You should specify the first IP address.'),'','first')"/>
					      </xsl:when>
					      <!-- check name for valid chars -->
					      <xsl:when test="not(check:ip($new_form/gen/first))">
					      	<xsl:value-of select="error:put('Specified first IP Addres contains invalid characters.','','first')"/>
					      </xsl:when>
							</xsl:choose>
							<!-- Check Last for Range -->
				      <xsl:choose>
	 				      <!-- check value presence -->
					      <xsl:when test="string($new_form/gen/last)=''">
					      	<xsl:value-of select="error:put(sw:text('You should specify the last IP address.'),'','last')"/>
					      </xsl:when>
					      <!-- check name for valid chars -->
					      <xsl:when test="not(check:ip($new_form/gen/last))">
					      	<xsl:value-of select="error:put('Specified last IP Address contains invalid characters.','','last')"/>
					      </xsl:when>
							</xsl:choose>
						</xsl:if>
						<!-- Check count -->
						<xsl:if test="$new_form/gen/choice='count'">
							<!-- Check first -->
							<xsl:choose>
	 				      <!-- check value presence -->
					      <xsl:when test="string($new_form/gen/count_first)=''">
					      	<xsl:value-of select="error:put(sw:text('You should specify the first IP address.'),'','count_first')"/>
					      </xsl:when>
					      <!-- check name for valid chars -->
					      <xsl:when test="not(check:ip($new_form/gen/count_first))">
					      	<xsl:value-of select="error:put('Specified first IP Address contains invalid characters.','','count_first')"/>
					      </xsl:when>
							</xsl:choose>
							<!-- check count-->
				      <xsl:choose>
	 				      <!-- check count presence -->
					      <xsl:when test="string($new_form/gen/count)=''">
					      	<xsl:value-of select="error:put(sw:text('You should specify the number of IP addresses.'),'','count')"/>
					      </xsl:when>
					      <!-- check count for valid chars -->
					      <xsl:when test="not(check:num($new_form/gen/count))">
					      	<xsl:value-of select="error:put('Specified last IP Addres contains invalid characters.','','count')"/>
					      </xsl:when>
							</xsl:choose>
						</xsl:if>
					</xsl:if>
					
					<xsl:call-template name="local:completeFormHandling">
						<xsl:with-param name="data" select="$new_form"/>
					</xsl:call-template>
					
			</xsl:when>
				
		</xsl:choose>
		
		<xsl:copy/>
	</xsl:template>
	
	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->		
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
						<xsl:copy-of select="local:getFinalPacket($data)"/>
						<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>	
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<func:function name="local:init-form">
		<sw:noauth-redirect select="not(cred:check('vzcp.virtuozzo_group.network.ippools'))"/>
		<xsl:if test="$step = ''">
			<xsl:choose>
				<xsl:when test="sw:param('mode')='edit' and sw:param('id') != ''">
						<xsl:call-template name="local:initEdit">
							<xsl:with-param name="id" select="sw:base64-decode(sw:param('id'))"/>
							<xsl:with-param name="step" select="string(sw:param('tab'))"/>
						</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="local:initCreate"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>
	
	<xsl:template name="local:initCreate">
		<!-- Init default data -->
		<xsl:variable name="new_form">
			<gen>
				<choice>range</choice>
			</gen>
		</xsl:variable>
		<!-- Init steps -->
		<xsl:variable name="new_steps_">
			<step id="gen" screenid="03.02.01.37.01"/>
		</xsl:variable>
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
			<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
			<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
			<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="local:initEdit">
		<xsl:param name="step"/>
		<xsl:param name="id"/>
		<!-- Init steps -->
		<xsl:variable name="all_steps_">
			<step id="gen" screenid="03.02.01.37.02"/>
		</xsl:variable>
		<!-- Init Step -->
		<xsl:variable name="new_step">
			<xsl:choose>
				<xsl:when test="string(sw:param('tab')) != ''"><xsl:value-of select="string(sw:param('tab'))"/></xsl:when>
				<xsl:otherwise>gen</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="new_steps" select="exsl:node-set($all_steps_)/step[@id=$new_step]"/>
		<!-- Check startup conditions -->
		<xsl:variable name="new_form">
			<xsl:choose>
				<xsl:when test="count($new_steps)=0">
					<xsl:message terminate="yes">
						Requested tab '<xsl:value-of select="$new_step"/>' is unknown for IP Range wizard code.
					</xsl:message>
				</xsl:when>
				<xsl:when test="not($id)">
					<xsl:message terminate="yes">
						IP Range ID should be specified.
					</xsl:message>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="local:initEditData">
						<xsl:with-param name="step" select="$step"/>
						<xsl:with-param name="id" select="$id"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
			<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>
	</xsl:template>	
	
	<xsl:template name="local:initEditData">
		<xsl:param name="step"/>
		<xsl:param name="id"/>
		<!--|-->
		<xsl:variable name="ips" select="sw:split($id,'-','ip')"/>
		<!--|-->
		<gen>
			<first><xsl:value-of select="$ips[1]"/></first>
			<last><xsl:value-of select="$ips[2]"/></last>
			<choice>range</choice>
			<count_first><xsl:value-of select="$ips[1]"/></count_first>
			<count><xsl:value-of select="sw:ip2number($ips[2]) - sw:ip2number($ips[1]) + 1"/></count>
		</gen>
		<range_first><xsl:value-of select="$ips[1]"/></range_first>
		<range_last><xsl:value-of select="$ips[2]"/></range_last>
		<range_id><xsl:value-of select="$id"/></range_id>		
	</xsl:template>
	
	<!-- *********************************************************** -->
	<func:function name="local:getFinalPacket">
		<xsl:param name="data"/>
		<!--|-->
		<func:result>
			<packet log="on"	xmlns:resource="http://www.swsoft.com/webservices/vzl/4.0.0/resourcem"
												xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
				<target>resourcem</target>
	        <cookie>
	        	<xsl:if test="not($data/range_id)">
		          <msg>
		            <ok><sw:text>The IP address range has been successfully created.</sw:text></ok>
		            <error><sw:text>Failed to create the IP address range.</sw:text></error>
		          </msg>
		          <operation>add_ip_range</operation>
		          <redirect-prev/>
	          </xsl:if>
	          <xsl:if test="$data/range_id">
	          	<msg>
		            <ok><sw:text>The IP address range has been successfully updated.</sw:text></ok>
		            <error><sw:text>Failed to update the IP address range.</sw:text></error>
		          </msg>
		          <operation>update_ip_range</operation>
		          <redirect-prev/>
	          </xsl:if>
	        </cookie>			
				<data>				
					<!-- Create/Update -->
					<resourcem>
						<!-- Remove Old -->
						<xsl:if test="$data/range_id">
							<remove_resource>
								<resource_pool xsi:type="resource:resource_ip_poolType">
									<type>resource_ip</type>
									<xsl:choose>
										<xsl:when test="$data/range_first!=$data/range_last">
											<ip_range>
												<start_ip><xsl:value-of select="$data/range_first"/></start_ip>
												<end_ip><xsl:value-of select="$data/range_last"/></end_ip>
											</ip_range>
										</xsl:when>
										<xsl:otherwise>
											<ip><xsl:value-of select="$data/range_first"/></ip>
										</xsl:otherwise>
									</xsl:choose>
								</resource_pool>
							</remove_resource>
						</xsl:if>
						<add_resource>
							<!-- Add New -->
							<resource_pool	xsi:type="resource:resource_ip_poolType">
								<type>resource_ip</type>
								<xsl:choose>
									<xsl:when test="$data/gen/choice='count'">
										<ip_range>
											<start_ip><xsl:value-of select="$data/gen/count_first"/></start_ip>
											<end_ip><xsl:value-of select="sw:number2ip( sw:ip2number($data/gen/count_first)+ $data/gen/count - 1  )"/></end_ip>
										</ip_range>
									</xsl:when>
									<xsl:when test="$data/gen/first!=$data/gen/last">
										<ip_range>
											<start_ip><xsl:value-of select="$data/gen/first"/></start_ip>
											<end_ip><xsl:value-of select="$data/gen/last"/></end_ip>
										</ip_range>
									</xsl:when>
									<xsl:otherwise>
										<ip><xsl:value-of select="$data/gen/first"/></ip>
									</xsl:otherwise>
								</xsl:choose>
							</resource_pool>	
						</add_resource>
					</resourcem>
				</data>
			</packet>
		</func:result>
	</func:function>
	
</xsl:stylesheet>
