<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl sw func cred server_group"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:server_group="http://www.swsoft.com/xsl/cp/server_group">

	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/swa/server-group.xsl"/>

	<xsl:output method="xml"/>

	<xsl:template match="/">
		<xsl:variable name="nids" select="sw:param('id')"/>
		<xsl:choose>
			<xsl:when test="not(cred:check('vzcp.virtuozzo_group.network.vnets'))">
				<packet/>
			</xsl:when>
			<xsl:when test="not($nids)">
				<xsl:if test="error:put(sw:text('Please select at least one virtual network.'),'')"/>
				<packet/>
			</xsl:when>
			<xsl:when test="sw:param('delete')">
				<xsl:variable name="master-eid" select="sw:master-eid()"/>
				<xsl:variable name="config" select="server_group:get-config()"/>
				<xsl:choose>
					<xsl:when test="not($config)">
						<packet>
							<cookie>
								<msg>
									<set-error>
										<short-desc>
											<sw:text>Error deleting the virtual networks.</sw:text>
										</short-desc>
										<detail/>
									</set-error>
								</msg>
							</cookie>
						</packet>
					</xsl:when>
					<xsl:otherwise>
						<packet log="on">
							<target>server_group</target>
							<xsl:copy-of select="sw:hn-dst($master-eid)"/>
							<cookie>
								<msg>
									<ok>
										<sw:text>The virtual networks have been successfully deleted.</sw:text>
									</ok>
									<error>
										<sw:text>Failed to delete the virtual networks.</sw:text>
									</error>
								</msg>
								<operation>network_delete</operation>
							</cookie>
							<data>
								<server_group>
									<set_config>
										<config>
											<xsl:copy-of select="$config/*[local-name() != 'networks']"/>
											<networks>
												<xsl:for-each select="$config/networks/network">
													<xsl:variable name="id" select="id"/>
													<xsl:if test="not(sw:base64-decode($id) = $nids)">
														<xsl:copy-of select="."/>
													</xsl:if>
												</xsl:for-each>
											</networks>
										</config>
									</set_config>
								</server_group>
							</data>
						</packet>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:if test="sw:response('lib/opredirect.xsl')"/>
			</xsl:when>
			<xsl:otherwise>
				<packet/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>
