<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl func wiz cred local server_group vznet"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz" xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:func="http://exslt.org/functions" xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:server_group="http://www.swsoft.com/xsl/cp/server_group"
	xmlns:vznet="http://www.swsoft.com/xsl/cp/vznet">

	<sw:include href="/lib/swa/server-group.xsl"/>
	<sw:include href="/lib/vz/vznet-vn.xsl"/>

	<xsl:output method="xml"/>


	<!-- RESTORE FORM VALUES -->
	<xsl:variable name="step" select="wiz:processing-step-id()"/>	
	<xsl:variable name="form" select="local:init-form()"/>

	<xsl:param name="wiz_code" select="'network-manage'"/>

	<xsl:template match="node()|@*">
		<xsl:choose>
			<!-- Step "General Settings" -->
			<xsl:when
				test="$step='gen'">

				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="name()='gen'"/>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<gen>
						<description>
							<xsl:value-of select="sw:param('description')"/>
						</description>
					</gen>
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>

				<xsl:if test="sw:param('next')">
					<!-- check data -->
				</xsl:if>

				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new_form"/>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>
		<xsl:copy/>
	</xsl:template>

	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
						<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:choose>
									<xsl:when test="error:is-empty()">
										<xsl:copy-of select="local:getFinalPacket($data)"/>
										<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
									</xsl:when>
									<xsl:otherwise>
										<packet/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
							<xsl:otherwise>
								<packet/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<func:function name="local:init-form">
		<sw:noauth-redirect select="not(cred:check('vzcp.virtuozzo_group.network.vnets'))"/>
		<xsl:if test="$step = ''">
			<!-- Init form data -->
			<xsl:variable name="config" select="server_group:get-config()"/>
			<xsl:variable name="network_id" select="sw:param('id')"/>
			<xsl:variable name="network" select="$config/networks/network[id = string($network_id)]"/>
			<xsl:variable name="new_form">
				<gen>
					<description>
						<xsl:value-of select="sw:base64-decode($network/description)"/>
					</description>
				</gen>
				<static>
					<network_id>
						<xsl:value-of select="sw:base64-decode($network_id)"/>
					</network_id>
				</static>
			</xsl:variable>
			<!-- Init steps -->
			<xsl:variable name="new_steps_">
				<step id="gen" screen-id="03.02.01.38.02"/>
			</xsl:variable>
			<!-- Save wizard initial settings -->
			<xsl:if test="error:is-empty()">
				<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
				<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
				<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
				<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
				<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
			</xsl:if>
		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>

	<func:function name="local:getFinalPacket">
		<xsl:param name="data"/>
		<xsl:variable name="error"
			select="vznet:update-vn($data/static/network_id,$data/gen)"/>

		<func:result>
			<xsl:choose>
				<xsl:when test="not($error/error)">
					<packet>
						<cookie>
							<msg>
								<set-ok>
									<sw:text>The virtual network information has been successfully updated.</sw:text>
								</set-ok>
							</msg>
							<redirect-prev/>
						</cookie>
					</packet>
				</xsl:when>
				<xsl:otherwise>
					<packet>
						<cookie>
							<msg>
								<set-error>
									<short-desc>
										<sw:text>Failed to update the virtual network information.</sw:text>
									</short-desc>
									<detail>
										<xsl:value-of select="$error/error"/>
									</detail>
								</set-error>
							</msg>
							<redirect-prev/>
						</cookie>
					</packet>
				</xsl:otherwise>
			</xsl:choose>
		</func:result>
	</func:function>

	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>
</xsl:stylesheet>
