<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet
	version="1.0"
	extension-element-prefixes="sw exsl sw func cred local"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:vzhn="http://www.swsoft.com/xsl/cp/vzhn"
	xmlns:vzapackagem="http://www.swsoft.com/xsl/cp/vzapackagem"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:func="http://exslt.org/functions">
	
	<xsl:output method="xml"/>
	
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/globals.xsl"/>
	<sw:include href="/lib/vz/vzhn-core.xsl"/>
	<sw:include href="/lib/vza/vzapackagem.xsl"/>

	<xsl:template match="/">
		<!-- set new type from GET -->
		<xsl:variable name="get-type" select="sw:param('type')"/>
		<xsl:if test="$get-type">
			<xsl:if test="sw:sesput('app-list-type', $get-type)"/>
		</xsl:if>
		<!-- /set new type from GET -->

		<xsl:variable name="app-list-type" select="sw:sesget('app-list-type')"/>
		<!-- cred checks -->
		<xsl:variable name="cr-template" select="cred:check-context('vzcp.template','hn.vz.vt')"/>

		<xsl:choose>
			<!-- minimal condition for show screen -->
			<xsl:when test="($app-list-type = 'os' or $app-list-type = 'app') and $cr-template">
				<xsl:variable name="app-id" select="local:get('app-id', sw:sesget('app-id'))"/> 
				
				<xsl:choose>
					<xsl:when test="$app-id=''">
						<!-- refreshing page, get info from session -->
						<packet>
							<error>
								<message>
									<sw:text>Cannot retrieve the template information as the template name has not been specified.</sw:text>
								</message>
							</error>
						</packet>
					</xsl:when>
					<xsl:otherwise>
						<xsl:variable name="hn-eid" select="local:get('hn-eid',sw:hn-eid())"/>
						<xsl:if test="sw:sesput('app-id', $app-id)"/>
						<xsl:if test="sw:sesput('app-hn-eid', $hn-eid)"/>
						
						<xsl:if test="sw:sesput('app-name', vzapackagem:app-title($app-id))" />
						<xsl:if test="sw:sesput('raw-app-name', vzapackagem:id2package($app-id)/name)" />
						
						<xsl:variable name="pkg-packet"
							select="vzapackagem:get($app-id, $hn-eid)/packet/data"/>
		
						<xsl:variable name="pkg" select="$pkg-packet/vzapackagem/packages/package"/>
						
						<xsl:if test="sw:sesput('app-os-cached', string(vzapackagem:is-os($pkg) and $pkg/cached='1'))"/>
						
						<packet>
							<errors>
								<xsl:copy-of select="$pkg-packet//error"/>
							</errors>
							<xsl:copy-of select="$pkg"/>
						</packet>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<packet>
					<error>
						<message>
							<sw:text>Cannot manage the templates.</sw:text>
						</message>
					</error>
				</packet>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<func:function name="local:get">
		<xsl:param name="name"/>
		<xsl:param name="default" select="''"/>
		<func:result
			select="sw:if(not(string(sw:param($name))=''), sw:base64-decode(sw:param($name)), $default)"/>
	</func:function>
</xsl:stylesheet>
