<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl sw func vzapackagem cred local wiz vzenv"
	exclude-result-prefixes="sw exsl sw func cred local wiz vzenv vz set vzhn"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" 
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred" 
	xmlns:vzapackagem="http://www.swsoft.com/xsl/cp/vzapackagem" 
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz" 
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:vzenv="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:vzhn="http://www.swsoft.com/xsl/cp/vzhn"
	xmlns:action="http://www.swsoft.com/xsl/cp/action"
	xmlns:set="http://exslt.org/sets" 
	xmlns:templates="http://www.swsoft.com/xsl/cp/templates"
	xmlns:vz="http://www.swsoft.com/xsl/cp/vz">
	
	<sw:include href="/lib/common.xsl" />
	<sw:include href="/lib/vzdir/infrman/templates/group-actions.xsl" />
	
	<xsl:output method="xml" />

	<!-- Init wizard data -->
	<xsl:template match="node()|@*">
		<xsl:apply-templates select="local:get-action()" mode="templates:req" />
	</xsl:template>
	
	<func:function name="local:get-action">
		<func:result select="exsl:node-set($actions)/action[@id=local:action-id()]" />
	</func:function>
	
	<func:function name="local:action-id">
		<xsl:choose>
			<xsl:when test="sw:param('install')">
				<func:result>install</func:result>
			</xsl:when>
			<xsl:when test="sw:param('install-app')">
				<func:result>install-app</func:result>
			</xsl:when>
			<xsl:when test="sw:param('deinstall')">
				<func:result>deinstall</func:result>
			</xsl:when>
			<xsl:when test="sw:param('fetch')">
				<func:result>fetch</func:result>
			</xsl:when>
			<xsl:when test="sw:param('cache')">
				<func:result>cache</func:result>
			</xsl:when>
		</xsl:choose>
	</func:function>
	
	<!-- Screen template reference-->
	<xsl:variable name="actions">
		
		<action id="install">
			<envs type="hn">
				<sw:text>Select Hardware Nodes</sw:text>
			</envs>
			<xsl:call-template name="local:action-mode"/>
			<screen id="{sw:if(sw:sesget('app-list-type')='os','03.02.01.39.09','03.02.01.39.10')}">
				<description>
					<sw:text>On this screen you can define a list of HNs where the selected templates are to be installed.</sw:text>
				</description>

				<apps>
					<sw:text>Templates to Install</sw:text>
				</apps>
				<submit>
					<sw:text>Install</sw:text>
				</submit>
			</screen>

			<message>
				<sw:text>The templates installation has been scheduled.</sw:text>
			</message>

			<error>
				<sw:text>Failed to schedule the templates installation.</sw:text>
			</error>
		</action>

		<action id="install-app">
			<envs type="ve">
				<sw:text>Select Containers</sw:text>
			</envs>
			<xsl:call-template name="local:action-mode"/>
			<screen id="03.02.01.39.11">
				<description>
					<sw:text>
						On this screen you can define a list of Containers where the selected application templates are to be added.
					</sw:text>
				</description>
				<apps>
					<sw:text>Templates to Install</sw:text>
				</apps>
				<submit>
					<sw:text>Install</sw:text>
				</submit>
			</screen>
			<message>
				<sw:text>The templates installation has been scheduled.</sw:text>
			</message>
			<error>
				<sw:text>Failed to schedule the templates installation.</sw:text>
			</error>
		</action>

		<action id="deinstall">
			<envs type="hn">
				<sw:text>Select Hardware Nodes</sw:text>
			</envs>
			<xsl:call-template name="local:action-mode"/>
			<screen id="03.02.01.39.12">
				<description>
					<sw:text>
						On this screen you can define a list of HNs to uninstall the selected templates from.
					</sw:text>
				</description>
				<apps>
					<sw:text>Templates to Uninstall</sw:text>
				</apps>
				<submit>
					<sw:text>Uninstall</sw:text>
				</submit>
			</screen>
			<message>
				<sw:text>The templates uninstallation has been scheduled.</sw:text>
			</message>
			<error>
				<sw:text>Failed to schedule the templates uninstallation.</sw:text>
			</error>
		</action>

		<action id="cache">
			<envs type="hn">
				<sw:text>Select Hardware Nodes</sw:text>
			</envs>
			<xsl:call-template name="local:action-mode"/>
			<screen id="03.02.01.39.13">
				<description>
					<sw:text>
						On this screen you can define a list of HNs where the cache for the selected templates is to be updated.
					</sw:text>
				</description>
				<apps>
					<sw:text>Templates to Cache</sw:text>
				</apps>
				<submit>
					<sw:text>Cache</sw:text>
				</submit>
			</screen>
			<message>
				<sw:text>The templates cache has been scheduled for updating.</sw:text>
			</message>
			<error>
				<sw:text>Failed to schedule the updating of the templates cache.</sw:text>
			</error>
		</action>

		<action id="fetch">
			<envs type="hn">
				<sw:text>Select Hardware Nodes</sw:text>
			</envs>
			<xsl:call-template name="local:action-mode"/>
			<screen id="03.02.01.39.14">
				<description>
					<sw:text>
						On this screen you can define a list of HNs where the packages of the selected templates are to be downloaded.
					</sw:text>
				</description>
				<apps>
					<sw:text>Download Packages for Templates</sw:text>
				</apps>
				<submit>
					<sw:text>Download</sw:text>
				</submit>
			</screen>
			<message>
				<sw:text>The template packages have been scheduled for caching.</sw:text>
			</message>
			<error>
				<sw:text>Failed to schedule the caching of the template packages.</sw:text>
			</error>
		</action>
	</xsl:variable>
	
	<xsl:template name="local:action-mode">
		<xsl:variable name="mode" select="sw:param('mode')"/>
		<xsl:if test="$mode='single'">
			<single-mode>template</single-mode>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>
