<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet
	version="1.0"
	extension-element-prefixes="sw exsl func wiz local action cred"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:check="http://www.swsoft.com/xsl/cp/check"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:form="http://www.swsoft.com/xsl/cp/form"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:action="http://www.swsoft.com/xsl/cp/action"
	xmlns:trace			="http://www.swsoft.com/xsl/cp/trace"	
>

	<sw:include href="/lib/trace.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/utils/action.xsl"/>

	<xsl:output method="xml"/>
	

	<xsl:variable name="install-cred" select="'vzcp.template'"/>
	<xsl:param name="wiz_code" select="'app-install'"/>

	<!-- calc cred in wizard step case -->
	<xsl:variable name="step" select="wiz:processing-step-id()" />
	<xsl:variable name="form" select="local:init-form()"/>   
	
	<func:function name="local:init-form">
        <xsl:if test="$step=''">
            <xsl:call-template name="local:initForm"/>               
        </xsl:if>
        <func:result select="wiz:init-data()"/>
    </func:function>

	<xsl:variable name="edit-mode" select="$form/app_id"/>

	<xsl:template match="node()|@*">
		<xsl:choose>
			<!-- Step "General Settings" -->
			<xsl:when test="$step='gen'">
				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="name()=$step"/>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<gen>
						<type><xsl:value-of select="sw:param('tmplt_type')"/></type>
						<xsl:copy-of select="/http_request/files/file[input_name = 'upload']"/>
						<hn><xsl:value-of select="sw:param('hn')"/></hn>
						<xsl:if test="sw:param('force')">
							<force/>
						</xsl:if>
					</gen>
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>

				<xsl:if test="sw:param('back')">
					<!-- Move to back -->
					<xsl:if test="wiz:goBack()"/>
				</xsl:if>
				<xsl:if test="sw:param('next')">
					<!-- Check data -->
					<!-- check name -->
					<xsl:choose>
						<!-- check name presence -->
						<xsl:when test="not($new_form/gen/file)">
							<xsl:value-of
								select="error:put(sw:text('You should select some file to upload.'),'','upload')"/>
						</xsl:when>
						<xsl:when test="string($new_form/gen/hn)=''">
							<xsl:value-of select="error:put(sw:text('You should select the HN where to upload the file.'),'','hn')"/>
						</xsl:when>
						<xsl:when test="not(cred:check-hw('vzcp.template',$new_form/gen/hn))">
							<xsl:value-of 
								select="error:put(sw:text('You are not authorized to manage templates on the selected Hardware Node. Please select another Hardware Node and try again.'),'','hn')"/>
						</xsl:when>
						<xsl:when test="($new_form/gen/type='ez' 
									or ($new_form/gen/type='auto' and contains($new_form/gen/file/remote_path, '-ez-'))) 
								and env:eid2info($new_form/gen/hn)/windows">
							<xsl:value-of select="error:put(sw:text('Installing EZ templates on Windows Hardware Nodes is not supported.'),'','hn')"/>
						</xsl:when>
					</xsl:choose>
					<!-- Move to next step -->
					<xsl:choose>
						<xsl:when test="error:is-empty()">
							<xsl:call-template name="local:goNext">
								<xsl:with-param name="data" select="$new_form"/>
							</xsl:call-template>
						</xsl:when>
					</xsl:choose>
				</xsl:if>

				<!-- Store form values-->
				<xsl:variable name="res">
					<xsl:value-of select="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
				</xsl:variable>

			</xsl:when>
		</xsl:choose>

		<xsl:copy/>
	</xsl:template>

	<xsl:template name="local:goNext">
		<xsl:param name="data"/>
		<!--|-->
		<xsl:choose>
			<xsl:when test="wiz:isLastStep()">
				<xsl:choose>
					<xsl:when test="error:is-empty()">
						<xsl:call-template name="local:sendFinalPacket">
							<xsl:with-param name="data" select="$data"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<packet/>
					</xsl:otherwise>
				</xsl:choose>

			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="wiz:goNext()"/>
				<xsl:if test="sw:sesput($wiz_data,exsl:node-set($data))"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="local:initForm">
		<xsl:if test="$step=''">
			<xsl:variable name="all_steps_">
				<step id="gen" screenid="03.02.01.35.10" title="{sw:text('Install New Template')}"/>
			</xsl:variable>
			<!-- Init Step -->
			<xsl:variable name="new_step" select="'gen'"/>
			<xsl:variable name="new_steps" select="exsl:node-set($all_steps_)/step"/>
			<!-- Check startup conditions -->
		<!-- Prepare current HN -->		
		<xsl:variable name="in-hn" select="trace:check-branch('vz-templates','hnoses') or trace:check-branch('vz-templates','hnapps')"/>		<!-- Do we inside HN/Templates? -->
		<xsl:variable name="get-hn-eid" select="sw:param('id')"/>
		<xsl:variable name="hn-eid" select="sw:if($in-hn,sw:if($get-hn-eid!='',$get-hn-eid,sw:hn-eid()),sw:master-eid())"/>
		<!-- /Prepare current HN -->				
			
			<xsl:variable name="new_form">
				<gen>
					<hn><xsl:value-of select="$hn-eid"/></hn>
				</gen>
			</xsl:variable>
			<!-- Save wizard initial settings -->
			<xsl:if test="error:is-empty()">
				<xsl:variable name="saved_form" select="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
				<xsl:variable name="saved_steps" select="sw:sesput($wiz_steps,$new_steps)"/>
				<xsl:variable name="saved_step" select="sw:sesput($wiz_step,$new_step)"/>
			</xsl:if>
		</xsl:if>
	</xsl:template>

	<xsl:template name="local:sendFinalPacket">
		<xsl:param name="data"/>

		<xsl:choose>
			<xsl:when test="$data/gen/file/remote_path">
				<!-- Upload From Client -->
				<xsl:copy-of select="local:getSetPacket($data)"/>
				<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
			</xsl:when>
			<xsl:otherwise>
				<!-- Upload From HN -->
				<packet/>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

	<func:function name="local:getSetPacket">
		<xsl:param name="data"/>
		<!--|-->
		<func:result>
			<xsl:call-template name="action:make-packet">
				<xsl:with-param name="path" select="'actions/vzdir/infrman/templates/install-new.xsl'"/>
				<xsl:with-param name="cookie">
					<msg>
						<sched>
							<sw:text>The template installation has been scheduled.</sw:text>
						</sched>
						<error>
							<sw:text>Failed to install the template.</sw:text>
						</error>
					</msg>
					<redirect-prev/>
				</xsl:with-param>
				<xsl:with-param name="input">
					<data>
						<xsl:copy-of select="$data/gen/force"/>
						<hn><xsl:value-of select="$data/gen/hn"/></hn>
						<type><xsl:value-of select="$data/gen/type"/></type>
						<local_path><xsl:value-of select="$data/gen/file/local_path"/></local_path>
						<remote_path><xsl:value-of select="$data/gen/file/remote_path"/></remote_path>
					</data>
				</xsl:with-param>
			</xsl:call-template>
		</func:result>
	</func:function>


	<!-- credentials -->
	<sw:include href="/lib/cred.xsl"/>

	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>

	<sw:include href="/lib/vza/tem.xsl"/>

</xsl:stylesheet>
