<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl sw cred update local action"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:hwm="http://www.swsoft.com/xsl/cp/hwm"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred" xmlns:update="http://www.swsoft.com/xsl/cp/update"
	xmlns:action="http://www.swsoft.com/xsl/cp/action"
	xmlns:local="http://www.swsoft.com/xsl/cp/local">
	<xsl:output method="xml" />

	<sw:include href="/lib/utils/action.xsl"/>

	<xsl:template match="/">
		<xsl:variable name="updates-cache" select="update:get-cached-update-list(sw:hn-eid())" />
		<xsl:choose>
			<xsl:when
				test="not($updates-cache/error) and sw:param('update') and string(update:get-task()/id)=''">
				<xsl:call-template name="local:handle-update" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="local:handle-init" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="local:handle-update">
		<xsl:variable name="update-config" select="update:get-config()" />
		<xsl:variable name="app-list-type" select="sw:sesget('app-list-type')" />
		<xsl:if test="update:clear-cached-template-update-list()" />

		<xsl:choose>
			<xsl:when test="$activeMode = 'vzcc'">
				<xsl:variable name="app-id" select="sw:sesget('app-id')" />
				
				<xsl:call-template name="action:make-packet">
					<xsl:with-param name="path" select="'actions/vzdir/maintman/updates/install-templates.xsl'" />
					<xsl:with-param name="cookie">
						<msg>
							<ok>
								<sw:text>The template has been successfully updated.</sw:text>
							</ok>
							<error>
								<sw:text>Failed to update the template.</sw:text>
							</error>
						</msg>
						<redirect-prev />
					</xsl:with-param>

					<xsl:with-param name="input">
						<data>
							<hw>
								<xsl:value-of select="sw:hn-eid()" />
							</hw>
							<xsl:choose>
								<xsl:when test="$app-list-type='app'">
									<application>
										<app>
											<uid>
												<xsl:value-of select="$app-id" />
											</uid>
										</app>
									</application>
								</xsl:when>
								<xsl:otherwise>
									<os>
										<uid>
											<xsl:value-of select="$app-id" />
										</uid>
									</os>
								</xsl:otherwise>
							</xsl:choose>
						</data>
					</xsl:with-param>
				</xsl:call-template>
				<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
				<xsl:if test="update:clear-cached-template-update-list()" />
			</xsl:when>
			<xsl:otherwise>
				<packet />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="local:handle-init">
		<!-- Handle listing type definition-->
		<xsl:if test="sw:param('type')">
			<xsl:variable name="get-var" select="sw:param('type')" />
			<xsl:if test="sw:sesput('app-list-type',sw:if($get-var='os',string($get-var),'app'))" />
		</xsl:if>

		<xsl:variable name="app-list-type" select="sw:sesget('app-list-type')" />

		<xsl:if
			test="$activeMode = 'vzcc'">
			<xsl:variable name="app-id"
				select="sw:if(string(sw:param('id'))!='', sw:base64-decode(string(sw:param('id'))), sw:sesget('app-id'))" />
			<xsl:if
				test="string(sw:param('id'))!='' and not($app-id=sw:sesget('app-id'))">
				<xsl:if test="sw:sesput('app-id',$app-id)" />
			</xsl:if>
		</xsl:if>

		<packet />

	</xsl:template>

	<sw:include href="/lib/update.xsl" />
	<sw:include href="/lib/common.xsl" />
	<sw:include href="/lib/cred.xsl" />
	<sw:include href="/lib/globals.xsl" />

</xsl:stylesheet>
