<!--
	Copyright (c) SWsoft, 1999-2007
	All rights reserved.
-->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred check local update"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:check="http://www.swsoft.com/xsl/cp/check"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:update="http://www.swsoft.com/xsl/cp/update"
>

	<xsl:output method="xml"/>

	<xsl:param name="wiz_code" select="'hw-config-update'"/>

	<xsl:variable name="step" select="wiz:processing-step-id()"/>   
	<xsl:variable name="form" select="local:init-form()"/>    

	<xsl:template match="node()|@*">
		<xsl:choose>
			<!-- Step "General Settings" -->
			<xsl:when test="$step='gen'">

				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="name()=$step"/>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<gen>
						<config>
							<xsl:if test="$form/gen/config/connection[$form/hn/linux]">
								<connection>
									<server>
										<xsl:value-of select="normalize-space(sw:param('up_url'))"/>
									</server>
									<user>
										<xsl:value-of select="sw:base64-encode(normalize-space(sw:param('up_user')))"/>
									</user>
									<password>
										<xsl:value-of select="sw:base64-encode(sw:param('up_passwd'))"/>
									</password>
									<proxy>
										<server>
											<xsl:value-of select="normalize-space(sw:param('pr_url'))"/>
										</server>
										<user>
											<xsl:value-of select="sw:base64-encode(normalize-space(sw:param('pr_user')))"/>
										</user>
										<password>
											<xsl:value-of select="sw:base64-encode(sw:param('pr_passwd'))"/>
										</password>
									</proxy>
								</connection>
							</xsl:if>
							
							<xsl:if test="$form/gen/config/connection[$form/hn/windows]">
								<connection>
									<proxy>
										<type>
											<xsl:element name="{sw:param('proxy_mode')}"/>
										</type>
										<server>
											<xsl:value-of select="normalize-space(sw:param('pr_url'))"/>
										</server>
										<user>
											<xsl:value-of select="sw:base64-encode(normalize-space(sw:param('pr_user')))"/>
										</user>
										<password>
											<xsl:value-of select="sw:base64-encode(sw:param('pr_passwd'))"/>
										</password>
									</proxy>
								</connection>
							</xsl:if>
							
							<xsl:if test="sw:param('enable_updates')='1'">
								<xsl:for-each select="$form/gen/config/product">
									<xsl:variable name="suffix" select="concat('.', $form/gen/map/product[id=current()/id]/pid)"/>
									
									<product>
										<xsl:copy-of select="id|name"/>
										<install>
											<xsl:element name="{string(sw:param(concat('mode', $suffix)))}"/>
										</install>
										<source>
											<xsl:choose>
												<xsl:when test="sw:param(concat('repo_mode', $suffix))='default'">
													<value><xsl:value-of select="source/standard"/></value>
												</xsl:when>
												<xsl:otherwise>
													<value><xsl:value-of 
															select="sw:base64-encode(
																		normalize-space(
																			sw:param(concat('url',$suffix))))"/></value>		
												</xsl:otherwise>
											</xsl:choose>
										</source>
										<destination><xsl:value-of select="sw:base64-encode(
																				normalize-space(
																					sw:param(concat('path', $suffix))))"/></destination>
									</product>					
								</xsl:for-each>
							</xsl:if>
							
							<xsl:if test="$form/gen/config/service">
								<service>
									<xsl:if test="sw:param('enable_reboot')='1'">
										<autoreboot/>
									</xsl:if>
									<xsl:if test="sw:param('days')!='everyday'">
										<check_period><xsl:element name="{sw:param('days')}"/></check_period>
									</xsl:if>
									<hour><xsl:value-of select="sw:param('hour')"/></hour>
									<xsl:if test="not(sw:param('enable_updates')='1')">
										<disabled/>
									</xsl:if>
								</service>
							</xsl:if>
						</config>
					</gen>
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>

				<!-- Turn Apps step On/Off -->
				<xsl:for-each select="$new_form/gen/config/connection[$form/hn/linux]">
					<xsl:if test="proxy/server='' and (proxy/password!='' or proxy/user!='')">
						<xsl:value-of select="error:put(sw:text('Please enter a valid proxy server URL.'),'','pr_url')"/>
					</xsl:if>
					<xsl:if test="server=''">
						<xsl:value-of select="error:put(sw:text('Please enter a valid repository URL.'),'','up_url')"/>
					</xsl:if>
					<xsl:if test="user='' and password!=''">
						<xsl:value-of
							select="error:put(sw:text('Please enter a valid repository user name.'),'','up_user')"/>
					</xsl:if>
					<xsl:if test="proxy/user='' and proxy/password!=''">
						<xsl:value-of
							select="error:put(sw:text('Please enter a valid proxy server user name.'),'','pr_user')"/>
					</xsl:if>
				</xsl:for-each>
				
				<xsl:variable name="proxy-types" select="update:proxy-types()"/>
				
				<xsl:for-each select="$new_form/gen/config/connection/proxy[type]">
					<xsl:variable name="type" select="$proxy-types[@id=name(current()/type/*[1])]"/>
					<xsl:if test="$type/@url and server=''">
						<xsl:value-of select="error:put(sw:text('Please enter a valid proxy server URL.'),'','pr_url')"/>
					</xsl:if>
					<xsl:if test="$type/@url and not(local:has-proxy-port(server))">
						<xsl:value-of select="error:put(sw:text('Please enter a valid port in the proxy server URL.'),'','pr_url')"/>
					</xsl:if>
					<xsl:if test="$type/@auth and user='' and password!=''">
						<xsl:value-of
							select="error:put(sw:text('Please enter a valid repository user name.'),'','up_user')"/>
					</xsl:if>
				</xsl:for-each>
				
				<xsl:for-each select="$new_form/gen/config/product">
					<xsl:variable name="suffix" select="concat('.', $form/gen/map/product[id=current()/id]/pid)"/>
					<xsl:if test="not(source/standard) and (source/value='' or sw:base64-decode(source/value)='')">
						<xsl:value-of select="error:put(sw:text('Please enter a valid update server URL.'),'',concat('url',$suffix))"/>						
					</xsl:if>
					<xsl:if test="destination='' or sw:base64-decode(destination)=''">
						<xsl:value-of select="error:put(sw:text('Please enter a valid update download location.'),'',concat('path', $suffix))"/>						
					</xsl:if>
				</xsl:for-each>

				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new_form"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<!-- Get VZA data -->
				<xsl:variable name="data" select="update:get-config()"/>

				<!-- Init form data -->
				<xsl:variable name="new_form_">
					<hn>
						<xsl:copy-of select="env:eid2info(sw:hn-eid())"/>
					</hn>
					<gen>
						<xsl:copy-of select="$data"/>
						<xsl:if test="$data/product">
							<map>
								<xsl:for-each select="$data/product">
									<product>
										<id><xsl:value-of select="id"/></id>
										<pid><xsl:value-of select="position()"/></pid>
									</product>
								</xsl:for-each>
							</map>
						</xsl:if>
					</gen>
				</xsl:variable>

				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="exsl:node-set($new_form_)"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>

		<xsl:copy/>
	</xsl:template>
	
	<func:function name="local:has-proxy-port">
		<xsl:param name="url"/>
		<xsl:variable name="parts" select="sw:split($url, ':')"/>
		
		<func:result select="string(number($parts[position()=last()]))!='NaN'"/>
	</func:function>

	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty() and wiz:isLastStep()">
				<xsl:if test="update:clear-cached-major-update-list()"/>
				<xsl:if test="update:clear-cached-template-update-list()"/>
				<xsl:copy-of select="local:getFinalPacket($data)"/>
				<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="sw:sesput($wiz_data,$data)"/>
				<packet/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<func:function name="local:init-form">
		<sw:noauth-redirect select="not(cred:check-hw('vzcp.hn.manage.update',sw:hn-eid()))"/>
        <xsl:if test="$step=''">
            <xsl:call-template name="local:init-new"/>               
        </xsl:if>
        <func:result select="wiz:init-data()"/>
    </func:function>

	<xsl:template name="local:init-new">
		<!-- Init steps -->
		<xsl:variable name="new_steps_">
			<step id="gen" screen-id="03.02.02.01.03" screen-title="{sw:text('Configure')}"
				screen-icon="vz_update"/>
		</xsl:variable>
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
			<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
			<xsl:if test="sw:sesput($wiz_data,exsl:node-set(''))"/>
			<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>
	</xsl:template>

	<func:function name="local:packet-header">
		<xsl:variable name="rtf">
			<cookie>
				<msg>
					<ok>
						<sw:text>The repository settings have been successfully updated.</sw:text>
					</ok>
					<error>
						<sw:text>Failed to update the repository settings.</sw:text>
					</error>
				</msg>
				<operation>hw_config_update</operation>
				<redirect-prev/>
			</cookie>
		</xsl:variable>
		<func:result select="exsl:node-set($rtf)"/>
	</func:function>

	<func:function name="local:getFinalPacket">
		<xsl:param name="data"/>
		<func:result>
			<xsl:copy-of select="update:packet(sw:hn-eid(), 'set_config', $data/gen/config, local:packet-header())"/>
		</func:result>
	</func:function>

	<!-- credentials -->
	<sw:include href="/lib/cred.xsl"/>

	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>

	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/update.xsl"/>

</xsl:stylesheet>
