<!--
	Copyright (c) SWsoft, 1999-2007
	All rights reserved.
-->
<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl func wiz cred check local update voc"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:check="http://www.swsoft.com/xsl/cp/check" xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:update="http://www.swsoft.com/xsl/cp/update" xmlns:voc="http://www.swsoft.com/xsl/cp/voc"
	xmlns:func="http://exslt.org/functions" xmlns:cred="http://www.swsoft.com/xsl/cp/cred">

	<xsl:output method="xml"/>

	<xsl:param name="wiz_code" select="'install-update'"/>
	
	<xsl:variable name="step" select="wiz:processing-step-id()" />
	<xsl:variable name="form" select="local:init-form()"/>   
	
	<func:function name="local:init-form">
		<sw:noauth-redirect select="not(cred:check-hw('vzcp.hn.manage.update',sw:hn-eid()))"/>
        <xsl:if test="$step=''">
            <xsl:call-template name="local:initForm"/>               
        </xsl:if>
        <func:result select="wiz:init-data()"/>
    </func:function>


	<xsl:template match="node()|@*">
		<xsl:if test="$step!=''">
			<xsl:variable name="new-form-rtf">
				<xsl:for-each select="$form/*">
					<xsl:choose>
						<xsl:when test="name()=$step"/>
						<xsl:otherwise>
							<xsl:copy-of select="."/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:for-each>
				<xsl:choose>
					<xsl:when
						test="$step='summary'">
						<summary>
							<system/>
							<self/>
							<xsl:if test="sw:param('no_reboot')">
								<no_reboot/>
							</xsl:if>
							<xsl:if test="sw:param('no_boot_loader')">
								<no_boot_loader/>
							</xsl:if>
							<selected>
								<xsl:copy-of
									select="$form/summary/selected/update[category='virtuozzo' and update:is-update(.)]"
								/>
							</selected>
						</summary>
					</xsl:when>
				</xsl:choose>
			</xsl:variable>
	
			<xsl:variable name="new-form" select="exsl:node-set($new-form-rtf)"/>
	
			<xsl:call-template name="local:completeFormHandling">
				<xsl:with-param name="data" select="$new-form"/>
			</xsl:call-template>
		</xsl:if>

		<xsl:copy/>
	</xsl:template>

	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->
		<xsl:choose>
			<xsl:when test="local:next-button() and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="local:start()">
						<xsl:if test="not(wiz:isLastStep())">
							<xsl:if test="wiz:goNext()"/>
						</xsl:if>
						<xsl:if test="sw:sesput($wiz_data, $data)"/>

						<xsl:variable name="packet-id" select="sw:generate-id()"/>

						<xsl:variable name="res"
							select="sw:send(update:action-update($data/summary),$packet-id)"/>

						<xsl:if test="sw:sesput('vzaup2date_op_id', $packet-id)"/>
						<xsl:if test="sw:sesput('vzaup2date_op_status', 2)"/>
						<xsl:if test="update:clear-cached-major-update-list()"/>
					</xsl:when>
					<xsl:when
						test="$step='progress' and sw:param('status') and not(sw:param('ok'))">

						<xsl:if
							test="sw:sesput('vzaup2date_op_status', sw:param('status'))"/>

						<packet/>
					</xsl:when>
					<xsl:otherwise>
						<packet>
							<cookie>
								<redirect-prev/>
							</cookie>
						</packet>
						<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesput($wiz_data, $data)"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<func:function name="local:start">
		<func:result
			select="$step='summary' or sw:param('retry')"/>
	</func:function>
	<func:function name="local:next-button">
		<func:result
			select="sw:param('next') or sw:param('retry') or sw:param('status') or sw:param('ok')"
		/>
	</func:function>

	<xsl:template name="local:initForm">
		<xsl:if
			test="$step=''">

			<xsl:variable name="data" select="update:get-cached-update-list(sw:hn-eid())"/>

			<xsl:variable name="new_form_">
				<xsl:copy-of select="$data/update[category='virtuozzo' and update:is-update(.)]"/>
				<summary>
					<selected>
						<xsl:copy-of
							select="$data/update[category='virtuozzo' and update:is-update(.)]"/>
					</selected>
				</summary>
			</xsl:variable>

			<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>

			<!-- Init steps -->
			<xsl:variable name="new_steps_">
				<xsl:choose>
					<xsl:when test="$new_form/summary/selected/update">
						<step id="summary" screen-id="03.02.02.02.01"
							screen-title="{sw:text('Install New Version: Review')}" screen-icon="vz_update"/>
						<step id="progress" screen-id="03.02.02.02.02"
							screen-title="{sw:text('Install New Version: Progress')}" screen-icon="vz_update"/>
					</xsl:when>
					<xsl:otherwise>
						<step id="no-updates" screen-id="03.02.02.02.03"
							screen-title="{sw:text('Install New Version')}" screen-icon="vz_update"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
			<!-- Save wizard initial settings -->
			<xsl:variable name="tab" select="sw:param('tab')"/>

			<xsl:if test="error:is-empty()">
				<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
				<xsl:variable name="new_step"
					select="sw:if($tab='progress', $tab, string($new_steps/step[1]/@id))"/>
				<xsl:if test="sw:sesput($wiz_data, $new_form)"/>
				<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
				<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
			</xsl:if>
		</xsl:if>
	</xsl:template>

	<!-- credentials -->
	<sw:include href="/lib/cred.xsl"/>

	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>

	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/update.xsl"/>
</xsl:stylesheet>
