<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func local update cred wiz action"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:dyn="http://exslt.org/dynamic" xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:local="http://www.swsoft.com/xsl/cp/local" xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:action="http://www.swsoft.com/xsl/cp/action"
	xmlns:vzapackagem="http://www.swsoft.com/xsl/cp/vzapackagem"
	xmlns:set="http://exslt.org/sets" 
	xmlns:update="http://www.swsoft.com/xsl/cp/update">
	
	<sw:include href="/lib/cred.xsl" />
	<sw:include href="/lib/wizard.xsl" />
	<sw:include href="/lib/utils/action.xsl"/>
	<sw:include href="/lib/common.xsl" />

	<sw:include href="/lib/vocabulary.xsl" />
	<sw:include href="/lib/update.xsl" />
	<sw:include href="/lib/vza/vzapackagem.xsl" />
	
	<xsl:param name="wiz_code" select="'install-templates'" />
	<xsl:variable name="step" select="wiz:processing-step-id()" />
	<xsl:variable name="form" select="local:init-form()"/>   
	
	<xsl:template match="node()|@*">
		<xsl:choose>
			<xsl:when test="$step='choose'">
				<xsl:call-template name="local:summary" />
			</xsl:when>
			<xsl:when test="$step='summary'">
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()" />
						<packet />
					</xsl:when>
					<xsl:when test="sw:param('next')">
						<xsl:call-template name="local:do-update" />
					</xsl:when>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<packet />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<func:function name="local:init-form">
		<sw:noauth-redirect select="not(cred:check-hw('vzcp.hn.manage.update',sw:hn-eid()))"/>
        <xsl:if test="$step=''">
            <xsl:call-template name="local:init-new"/>               
        </xsl:if>
        <func:result select="wiz:init-data()"/>
    </func:function>
	
	<!-- Initial step -->
	<xsl:template name="local:init-new">
		<xsl:variable name="data" select="update:get-cached-update-list(sw:hn-eid())" />
		
		<xsl:variable name="new_steps_">
			<step id="choose" screen-id="03.02.02.02.07" screen-icon="vz_update"/>
			<step id="summary" screen-id="03.02.02.02.08" screen-icon="vz_update"/>
		</xsl:variable>
		
		<xsl:variable name="new_form_">
			<xsl:choose>
				<xsl:when test="sw:param('filter')">
					<!-- filter updates by app-id provided in request or in session -->
					<xsl:variable name="ids">
						<xsl:choose>
							<xsl:when test="sw:param('app-id')">
								<xsl:for-each select="sw:param('app-id')">
									<app-id>
										<xsl:value-of select="sw:if(contains(., '|'), substring-before(., '|'), .)"/>
									</app-id>
								</xsl:for-each>
							</xsl:when>
							<xsl:otherwise>
								<xsl:copy-of select="sw:sesget('update-app-ids')"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
					<xsl:variable name="app-ids" select="exsl:node-set($ids)/app-id"/>
					<xsl:variable name="templates" select="vzapackagem:vztemplate-packages($app-ids)"/>
					
					<xsl:copy-of select="update:filter-template-updates($data/update, $templates)"/>
				</xsl:when>
				<xsl:when test="$data//id">
					<all/>
				</xsl:when>
				<xsl:otherwise>
					<nothing/>
				</xsl:otherwise>
			</xsl:choose>
			<selected/>
		</xsl:variable>

		<xsl:variable name="new_form" select="exsl:node-set($new_form_)" />
		<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)" />
		
		<xsl:if test="sw:sesput($wiz_data, $new_form)" />
		<xsl:if test="sw:sesput($wiz_steps,$new_steps)" />
		<xsl:if test="sw:sesput($wiz_step,'choose')" />
	</xsl:template>
	
	<!-- After Choose updates step (came from init)-->
	<xsl:template name="local:summary">
		<xsl:variable name="form" select="sw:sesget($wiz_data)" />
		<xsl:variable name="ids" select="sw:param('id')" />
		
		<xsl:variable name="data" select="update:get-cached-update-list(sw:hn-eid())"/>
		
		<xsl:variable name="new_form_">
			<xsl:copy-of select="$form/*[name()!='selected' and name()!='install']" />
			<selected>
				<xsl:copy-of select="$ids" />
			</selected>
			<install>
				<xsl:call-template name="local:parse-request">
					<xsl:with-param name="ids" select="$ids"/>
					<xsl:with-param name="updates" select="$data/update"/>
					<xsl:with-param name="ignore-os-version" select="true()" />
				</xsl:call-template>
			</install>
		</xsl:variable>
		
		<xsl:variable name="new_form" select="exsl:node-set($new_form_)" />
		<xsl:if test="sw:sesput($wiz_data, $new_form)" />
		
		<xsl:if test="wiz:goNext()" />
		<packet />
	</xsl:template>
	
	<xsl:template match="post" mode="local:parse">
		<xsl:variable name="split" select="sw:split(string(.), '/')"/>
		<update>
			<uid><xsl:value-of select="concat($split[2], '/', $split[3])"/></uid>
			<id><xsl:value-of select="$split[2]"/></id>
			<version><xsl:value-of select="$split[3]"/></version>
			<xsl:if test="contains($split[4], '|')">
				<app_template>
					<uid><xsl:value-of select="$split[4]"/></uid>
					<id><xsl:value-of select="substring-before($split[4], '|')"/></id>
					<version><xsl:value-of select="substring-after($split[4], '|')"/></version>
				</app_template>
			</xsl:if>
		</update>
	</xsl:template>
		
	<xsl:template name="local:parse-request">
		<xsl:param name="ids"/>
		<xsl:param name="updates" />
		<xsl:param name="ignore-os-version" select="false()" />

		<xsl:variable name="records-rtf">
			<xsl:apply-templates select="$ids" mode="local:parse"/>
		</xsl:variable>
		
		<xsl:variable name="records" select="exsl:node-set($records-rtf)/update"/>
		
		<xsl:for-each select="set:distinct($records/uid)">
			<xsl:variable name="uid" select="string(.)"/>
			<xsl:variable name="group" select="$records[uid=$uid]"/>
			
			<xsl:variable name="id" select="$group[1]/id"/>
			<xsl:variable name="version" select="$group[1]/version"/>
			
			<xsl:variable name="update" select="$updates[id=$id and version=$version]"/>
			
			<xsl:if test="$update">
				<xsl:call-template name="update:generate-update">
					<xsl:with-param name="type" select="update:type($update)"/>
					<xsl:with-param name="id" select="$id"/>
					<xsl:with-param name="content">
						<xsl:copy-of select="$update/*[not(self::id or self::app_template or self::description)]"/>
						<xsl:copy-of select="$update/app_template[id=$group/app_template/id]"/>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="local:do-update">
		<xsl:variable name="form" select="sw:sesget($wiz_data)" />
		<xsl:if test="update:clear-cached-template-update-list()" />
		
		<xsl:call-template name="action:make-packet">
			<xsl:with-param name="path" select="'actions/vzdir/maintman/updates/update/install-templates.xsl'" />
			<xsl:with-param name="cookie">
				<msg>
					<sched>
						<sw:text>The templates have been successfully scheduled for updating.</sw:text>
					</sched>
					<ok>
						<sw:text>The templates have been successfully updated.</sw:text>
					</ok>
					<error>
						<sw:text>Failed to update the templates.</sw:text>
					</error>
				</msg>
				<redirect-prev />
			</xsl:with-param>
			
			<xsl:with-param name="input">
				<data>
					<hw>
						<xsl:value-of select="sw:hn-eid()" />
					</hw>
					<templates>
						<xsl:copy-of select="$form/install/update"/>
					</templates>
				</data>
			</xsl:with-param>
		</xsl:call-template>
		<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
	</xsl:template>
</xsl:stylesheet>
