<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred local browse date"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl	="http://exslt.org/common"
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:error		="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz		="http://www.swsoft.com/xsl/cp/wiz"
  xmlns:func	="http://exslt.org/functions"	
  xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local	="http://www.swsoft.com/xsl/cp/local"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:date	="http://exslt.org/dates-and-times"
	xmlns:user	="http://www.swsoft.com/xsl/cp/user" 
	xmlns:time  ="http://www.swsoft.com/xsl/cp/time"
	xmlns:vznet	="http://www.swsoft.com/xsl/cp/vznet"
>
	<xsl:output method="xml"/>
	<xsl:param name="wiz_code" select="'get-traffic'"/>

  <xsl:variable name="netcounters" select="vznet:merge-network-class()"/>
  
	<!-- RESTORE FORM VALUES -->
	<xsl:variable name="step" select="wiz:processing-step-id()"/>	
	<xsl:variable name="form" select="local:init-form()"/>

	<xsl:template match="node()|@*">
		<xsl:variable name="period-selector" select="sw:param('period-selector')"/>
		<xsl:choose>
			<xsl:when test="$step='traffic'"> 
					<xsl:variable name="new_form_">
						<xsl:for-each select="$form/*">
							<xsl:choose>
								<xsl:when test="name()=$step"></xsl:when>
								<xsl:otherwise>
									<xsl:copy-of select="."/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
						<traffic>
							<netcounters><xsl:copy-of select="$netcounters"/></netcounters>								
							<unit><xsl:value-of select="sw:param('unit')"/></unit>
							<class><xsl:value-of select="sw:param('class')"/></class>
							<selected-class-node>
								<xsl:for-each select="$netcounters/range">
									<xsl:if test="class_id = sw:param('class')">
										<xsl:copy-of select="class_id"/>
									</xsl:if>
								</xsl:for-each>
							</selected-class-node>
							<period><xsl:value-of select="$period-selector"/></period>
							<one-date>
								<xsl:value-of select="sw:param('period-day')"/>
							</one-date>
							<start-date>
								<xsl:choose>
  		            <xsl:when test="$period-selector = 'month'">
										<xsl:value-of select="sw:param('period-month')"/>
									</xsl:when>
  		            <xsl:when test="$period-selector = 'year'">
										<xsl:value-of select="sw:param('period-year')"/>
									</xsl:when>
									<xsl:otherwise>
										<!-- it's from-to period, no start-date -->
									</xsl:otherwise>
								</xsl:choose>
							</start-date>
							<from-date>
								<xsl:value-of select="sw:param('period-from-date')"/>
							</from-date>
							<to-date>
								<xsl:value-of select="sw:param('period-to-date')"/>
							</to-date>
            </traffic>
					</xsl:variable>

					<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
					<xsl:if test="sw:param('back')">
						 <!-- Move to back -->
						<xsl:if test="wiz:goBack()"/>
					</xsl:if>
						<!-- Check data -->
						<xsl:choose>
							<xsl:when test="$period-selector = 'day'">
								<xsl:variable name="day-time-valid-rc" select="time:web-validate($new_form/traffic/one-date,'short-format')"/>
								<xsl:choose>
						      <xsl:when test="string($new_form/traffic/one-date) = ''">
										<xsl:value-of select="error:put(sw:text('Empty date entered'),'','period-selector')"/>
				    		  </xsl:when>
						      <xsl:when test="$day-time-valid-rc != ''">
										<xsl:value-of select="error:put($day-time-valid-rc,'','period-selector')"/>
				    		  </xsl:when>				    		  
								</xsl:choose>
							</xsl:when>
							<xsl:when test="$period-selector = 'month' or $period-selector = 'year'">
								<xsl:variable name="month-time-valid-rc" select="time:web-validate($new_form/traffic/start-date,'short-format')"/>
								<xsl:choose>
						      <xsl:when test="string($new_form/traffic/start-date) = ''">
										<xsl:value-of select="error:put(sw:text('Empty date entered'),'','period-selector')"/>
				    		  </xsl:when>								
						    	<xsl:when test="$month-time-valid-rc != ''">
										<xsl:value-of select="error:put($month-time-valid-rc,'','period-selector')"/>
									</xsl:when>
				    		</xsl:choose>
							</xsl:when>
							<xsl:when test="$period-selector = 'from-to'">
								<xsl:variable name="from-time-valid-rc" select="time:web-validate($new_form/traffic/from-date,'short-format')"/>
								<xsl:variable name="to-time-valid-rc"		select="time:web-validate($new_form/traffic/to-date,'short-format')"/>
								<xsl:choose>
						      <xsl:when test="string($new_form/traffic/from-date) = ''">
										<xsl:value-of select="error:put(sw:text('The start date is empty'),'','period-selector')"/>
				    		  </xsl:when>								
						    	<xsl:when test="$from-time-valid-rc != ''">
										<xsl:value-of select="error:put($from-time-valid-rc,'','period-selector')"/>
									</xsl:when>
						      <xsl:when test="string($new_form/traffic/to-date) = ''">
										<xsl:value-of select="error:put(sw:text('The end date is empty'),'','period-selector')"/>
				    		  </xsl:when>								
						    	<xsl:when test="$to-time-valid-rc != ''">
										<xsl:value-of select="error:put($to-time-valid-rc,'','period-selector')"/>
									</xsl:when>
				    		</xsl:choose>
							</xsl:when>
						</xsl:choose>		
			      <!-- Move to next step -->
			      <xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:if test="local:save-private($step,$new_form)"/>
								<xsl:copy-of	select="local:getFinalPacket($step,$new_form)"/>
							</xsl:when>
						</xsl:choose>
					
					<!-- Store form values-->
					<xsl:variable name="res">
						<xsl:value-of select="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
					</xsl:variable>
			</xsl:when>
			<xsl:when test="$step=''">
				<!-- its' addon for stadart wizard sheme. It's traffic step without post step
						 called on first form load, in our case  must -->
						 <!-- $form stored in wizard by init engine -->
						<xsl:copy-of	select="local:getFinalPacket($step,$form)"/>
			</xsl:when>
		</xsl:choose>
		<xsl:copy/>
	</xsl:template>
	
	<func:function name="local:init-form">
		<xsl:if test="$step = ''">
			<!-- Init Step -->
			<xsl:variable name="new_step">
				<xsl:choose>
					<xsl:when test="string(sw:param('tab')) != ''">
							<xsl:value-of select="sw:param('tab')"/>
					</xsl:when>
					<xsl:otherwise>traffic</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>

			<!-- Init steps -->
			<xsl:variable name="new_steps">
				<xsl:if test="$new_step = 'traffic'">
					<step id="traffic"/>
				</xsl:if>
			</xsl:variable>
			<!-- Check startup conditions -->
			<xsl:variable name="new_form-rtf">
				<xsl:choose>
					<xsl:when test="count($new_steps)=0">
						<xsl:message terminate="yes">
							Requested tab '<xsl:value-of select="$new_step"/>' is unknown for traffic log code.
						</xsl:message>
					</xsl:when>
					<xsl:otherwise>
							<xsl:copy-of select="local:initData($new_step)"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
			<xsl:variable name="new_form" select="exsl:node-set($new_form-rtf)"/>	
			
			<!-- Save wizard initial settings -->
			<xsl:if test="error:is-empty()">
				<xsl:variable name="saved_form" select="sw:sesput($wiz_data,$new_form)"/>
				<xsl:variable name="saved_steps" select="sw:sesput($wiz_steps,$new_steps)"/>
				<xsl:variable name="saved_step" select="sw:sesput($wiz_step,$new_step)"/>
			</xsl:if>		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>

	
	<func:function name="local:initData">
		<xsl:param name="step"/>
		<func:result>
			<xsl:choose>
				<xsl:when test="$step='traffic'">
					<xsl:variable name="date-date" select="substring(date:date(),1,10)"/>
					<xsl:variable name="date-date-post"	select="time:time2web($date-date)"/>
					<xsl:variable name="traffic-default-set-rtf">
						<unit><xsl:value-of select="'kbyte'"/></unit>
						<class>-1</class>
						<period><xsl:value-of select="'month'"/></period>
						<start-date><xsl:value-of select="$date-date"/></start-date>
						<one-date><xsl:value-of select="$date-date-post"/></one-date>
						<from-date></from-date>
						<to-date><xsl:value-of select="$date-date-post"/></to-date>
					</xsl:variable>
					<xsl:variable name="traffic-default-set" select="exsl:node-set($traffic-default-set-rtf)"/>
					<xsl:variable name="traffic-settings" select="user:get-attrs('traffic-settings',$traffic-default-set)"/>
					<!-- Load data for traffic Step -->
						<traffic>
              <netcounters>
								<xsl:copy-of select="$netcounters"/>
							</netcounters>
              <unit>
              	<xsl:value-of select="$traffic-settings/unit"/>
              </unit>
 							<start-date>
								<xsl:value-of select="$traffic-settings/start-date"/>
							</start-date>
 							<one-date>
								<xsl:value-of select="$traffic-settings/one-date"/>
							</one-date>
 							<from-date>
								<xsl:value-of select="$traffic-settings/from-date"/>
							</from-date>
 							<to-date>
								<xsl:value-of select="$traffic-settings/to-date"/>
							</to-date>							
							<xsl:variable name="class" select="$traffic-settings/class"/>
							<class>
								<xsl:value-of select="$class"/>
							</class>
							<selected-class-node>
                <xsl:for-each select="$netcounters/range">
                  <xsl:if test="class_id = $class">
                    <xsl:copy-of select="class_id"/>
                  </xsl:if>
                </xsl:for-each>
              </selected-class-node>
              <period><xsl:value-of select="$traffic-settings/period"/></period>
            </traffic>
					<!-- /Load data for traffic Step -->
				</xsl:when>
			</xsl:choose>
		</func:result>
	</func:function>

	<func:function name="local:getFinalPacket">
		<xsl:param name="step"/>
		<xsl:param name="data"/>
		<!--|-->
		<func:result>
			<packet>
				<cookie>
					<msg>
						<error><sw:text>Failed to get the traffic information for the requested period.</sw:text></error>
					</msg>
					<operation>get-traffic</operation>
					<xsl:variable name="start-date-norm">
						<xsl:choose>
							<xsl:when test="$data/traffic/period = 'year'">
									<!-- notes: don't trust that input date would balanced by 01 day of month and 01 month in year -->
									<!-- if need calc traffic for year from random month and day, remove this wrapper -->	
									<xsl:value-of select="concat(date:year($data/traffic/start-date),'-01-01')"/>
							</xsl:when>
							<xsl:when test="$data/traffic/period = 'month'">
									<!-- notes: don't trust that input date would balanced by 01 day of month  -->
									<!-- if need calc traffic for month from random day, remove this wrapper -->	
									<xsl:value-of select="concat(date:year($data/traffic/start-date),'-',format-number(date:month-in-year($data/traffic/start-date),'00'),'-01')"/>
							</xsl:when>											
							<xsl:when test="$data/traffic/period = 'day'">
									<xsl:value-of select="time:web2time($data/traffic/one-date)"/>
							</xsl:when>											
						</xsl:choose>
					</xsl:variable>
					<xsl:call-template name="getlog-for-period">
						<xsl:with-param	name="class-name"	select="'counters_vz_net'"/>
						<xsl:with-param name="start-date" select="$start-date-norm"/>
						<xsl:with-param name="period" select="$data/traffic/period"/>
			    	<xsl:with-param name="from-date" select="time:web2time($data/traffic/from-date)"/>
			    	<xsl:with-param name="to-date" select="date:add(time:web2time($data/traffic/to-date),'P1D')"/>
					</xsl:call-template>
				</cookie>
			</packet>
		</func:result>
	</func:function>

	<func:function name="local:save-private">
		<xsl:param name="step"/>
		<xsl:param name="data"/>
		<!--|-->
		<func:result>
			<xsl:choose>
				<!-- update privtae area -->
				<xsl:when test="$step='traffic'">
					<xsl:variable name="for-save-in-private">
						<xsl:copy-of select="$data/traffic/*[self::class or self::unit or self::period or self::from-date or self::to-date]"/>
					</xsl:variable>
					<xsl:if test="user:set-attrs('traffic-settings',exsl:node-set($for-save-in-private))"/>
				</xsl:when>
			</xsl:choose> 
		</func:result>
	</func:function>


 <!-- credentials -->
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/vz/vznet.xsl"/>
	<sw:include href="/lib/get_log.xsl"/>
	<sw:include href="/lib/date-time.xsl"/>
	<sw:include href="/lib/vt/env-private.xsl"/>	
	<sw:include href="/lib/core/user-attrs.xsl"/>
	<sw:include href="/lib/vz/vznet.xsl"/>

</xsl:stylesheet>
