<!--
	Copyright (c) SWsoft, 1999-2007
	All rights reserved.
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" 
	extension-element-prefixes="sw exsl cred env vzenv local plesk sb func"		
	xmlns:exsl		="http://exslt.org/common"
	xmlns:sw			="http://www.swsoft.com/xsl/cp" 
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"
	xmlns:ui			="http://www.swsoft.com/xsl/cp/ui"
	xmlns:vt			="http://www.swsoft.com/xsl/cp/vt"
	xmlns:ve			="http://www.swsoft.com/xsl/cp/ve"
	xmlns:env			="http://www.swsoft.com/xsl/cp/env"
	xmlns:cred		="http://www.swsoft.com/xsl/cp/cred"
  xmlns:vzenv		="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:sb			="http://www.swsoft.com/xsl/cp/sb"
	xmlns:plesk		="http://www.swsoft.com/xsl/cp/plesk"    
	xmlns:func		="http://exslt.org/functions"
>

	<sw:include href="/lib/vt/core.xsl"/>
	<sw:include href="/lib/vt/ve-core.xsl"/>
	<sw:include href="/lib/vz/vzenv-net-core.xsl"/>
	<sw:include href="/lib/sitebuilder.xsl"/>
	<sw:include href="/lib/plesk/core.xsl"/>

	<!-- check permissions to show this page -->
	<xsl:variable name="ve-eid" select="sw:ve-eid()"/>
	<xsl:variable name="env" select="env:get-env($ve-eid)/env"/>
	<xsl:variable name="hn-platform" select="ve:ve2platform($env)"/>
  <xsl:variable name="platform-is-win"	 select="vt:is-platform-windows($hn-platform)"/>

	<!-- creds -->
	<xsl:variable name="access-map-rtf">
		<xsl:call-template name="cred:access-map">
			<xsl:with-param name="creds-rtf">
				<cred id="vzcp.env.manage.services.plesk_control_panel" security-obj-type="ve.vz.vt" security-obj-id="{$ve-eid}"/>
				<cred id="vzcp.env.manage.properties.application" security-obj-type="ve.vz.vt" security-obj-id="{$ve-eid}"/>
				<cred id="vzcp.env.manage.services.sb_login" security-obj-type="ve.vz.vt" security-obj-id="{$ve-eid}"/>
				<cred id="vzcp.env.manage.services.confixx_control_panel" security-obj-type="ve.vz.vt" security-obj-id="{$ve-eid}"/>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="access-map" select="exsl:node-set($access-map-rtf)/cred"/>
	
	<xsl:variable name="cr-plesk-manage"				select="cred:match-access($access-map,'vzcp.env.manage.services.plesk_control_panel','ve.vz.vt',$ve-eid)"/>
	<xsl:variable name="cr-plesk-install"				select="cred:match-access($access-map,'vzcp.env.manage.properties.application','ve.vz.vt',$ve-eid)"/>	
	<xsl:variable name="cr-sitebuilder"	select="cred:match-access($access-map,'vzcp.env.manage.services.sb_login','ve.vz.vt',$ve-eid)"/>
	<xsl:variable name="cr-confixx"			select="cred:match-access($access-map,'vzcp.env.manage.services.confixx_control_panel','ve.vz.vt',$ve-eid)"/>

	<xsl:template mode="screen" match="/">
		<ui:screen id="03.02.01.03.15" icon="control_panels">
			<ui:properties>
				<ui:description mandatory="yes" width="max">
					<sw:text>This screen allows you to manage those control panels that are either installed in the Container or can be installed in it.</sw:text>
				</ui:description>
				<ui:form-get/>
			</ui:properties>			
			<ui:tab-bar id="vzve" current-tab="soft" current-subtab="control_panels"/>

			<ui:content>
				<xsl:variable name="content-for-show">
					<ui:dashboard-compact>
						<xsl:call-template name="local:plesk-summary"/>
						<xsl:if test="$cr-sitebuilder">
							<xsl:call-template name="local:sitebuilder-shared-summary"/>
						</xsl:if>
						<xsl:if test="$cr-confixx">
							<xsl:call-template name="local:confixx-summary"/>
						</xsl:if>
					</ui:dashboard-compact>
				</xsl:variable>
					<!-- each template know about conditions, where it showed or not -->
					<xsl:choose>
						<xsl:when test="count(exsl:node-set($content-for-show)//ui:dashboard-item) &gt; 0">
							<xsl:copy-of select="$content-for-show"/>
						</xsl:when>
						<!-- xsl:otherwise>
							<ui:raw>No available control panels for manage.</ui:raw>
						</xsl:otherwise -->
					</xsl:choose>
			</ui:content>		
		</ui:screen>

	</xsl:template>
	
	<!-- show summary for Plesk Control Panel -->
	<xsl:template name="local:plesk-summary">
		<xsl:variable name="vzve-plesk-status" select="plesk:detect-plesk($ve-eid)"/>

		<xsl:variable name="psa-setup-rtf">
			<xsl:choose>
				<xsl:when test="$vzve-plesk-status/installed">
					<xsl:copy-of select="plesk:getPsaSetup()"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="/.."/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="psa-setup" select="exsl:node-set($psa-setup-rtf)"/>

		<ui:dashboard-item title="{sw:text('Plesk Control Panel')}" icon="plesk">
			<xsl:choose>
				<xsl:when test="$vzve-plesk-status/installed">
					<xsl:if test="$cr-plesk-manage">
						<ui:action-link href="{$baseurl}/panel/plesk" tip="plesk_screen">
							<sw:text>Manage</sw:text>
						</ui:action-link>
					</xsl:if>
				</xsl:when>
				<xsl:when test="$vzve-plesk-status/unknown">
					<ui:action-link disabled="true">
						<sw:text>Cannot check the status of the Plesk installation as the Container is not running.</sw:text>
					</ui:action-link>
				</xsl:when>				
				<xsl:otherwise>
					<!-- check for install availability, if not  - show diganostic -->				
					<xsl:if test="$cr-plesk-install">

						<ui:action-link href="{$baseurl}/panel/plesk/install" tip="plesk_install_screen">
							<sw:text>Install</sw:text>
						</ui:action-link>
					</xsl:if>
				</xsl:otherwise>
			</xsl:choose>
		</ui:dashboard-item>
	</xsl:template>

	<!-- show summary for SitebBilder Shared Control Panel -->
	<xsl:template name="local:sitebuilder-shared-summary">
		<xsl:variable name="vzve-sitebuilder-shared-status" select="sb:is-service-allowed($ve-eid)"/>
		<xsl:if test="(($vzve-sitebuilder-shared-status/rc = 0) or ($vzve-sitebuilder-shared-status/rc = 6)) and $platform-is-win">
			<ui:dashboard-item title="{sw:text('Sitebuilder')}" icon="login_to_sb">
				<ui:action-link href="{$baseurl}/panel/sb/login" tip="open_sb" target="_blank">
					<sw:text>Login</sw:text>
				</ui:action-link>			
			</ui:dashboard-item>
		</xsl:if>
	</xsl:template>

	<!-- show summary for Confixx Control Panel -->
	<xsl:template name="local:confixx-summary">
		<xsl:variable name="vzve-confixx-status" select="sw:sesgettree('templates')/template[starts-with(name,'confixx-pro') and (version &gt;= 20040227)]"/>
		<xsl:if test="($vzve-confixx-status/name != '') and not($platform-is-win)">
			<ui:dashboard-item title="{sw:text('Confixx')}" icon="confixx">
				<ui:action-link href="{$baseurl}/panel/confixx" tip="confixx_screen">
					<sw:text>Login</sw:text>
				</ui:action-link>
			</ui:dashboard-item>
		</xsl:if>
	</xsl:template>

	<func:function name="local:norm-plesk-version">
		<xsl:param name="version"/>
		<func:result select="sw:if(not($version != ''),sw:text('Unknown'),$version)"/>
	</func:function>
	
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/screen.xsl"/>
	
</xsl:stylesheet>
