<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred func"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl	="http://exslt.org/common"
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:func	="http://exslt.org/functions"
	xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:sb		="http://www.swsoft.com/xsl/cp/sb"
	xmlns:redirect="http://www.swsoft.com/xsl/cp/redirect"
	xmlns:reg32	="http://www.swsoft.com/xsl/cp/reg32"
	xmlns:vt		="http://www.swsoft.com/xsl/cp/vt"
	xmlns:env   ="http://www.swsoft.com/xsl/cp/env"
	xmlns:process ="http://www.swsoft.com/xsl/cp/process"
>

	<xsl:variable name="ve-eid" select="sw:ve-eid()"/>
	<xsl:variable name="hn-eid" select="sw:hn-eid()"/>

	<!-- check permissions to show this page -->
	<xsl:variable name="cr-sb-login" select="cred:check-env('vzcp.env.manage.services.sb_login',$ve-eid)"/>
		
	<xsl:param name="access-denied" select="not($cr-sb-login)"/>

	<xsl:template match="/">

		<!-- Check offline service configuration -->
		<!-- do it, becuase client can load dashboard, change condition from
    			cmd line or from other browser windows , and then click 
          on icon "Login to Sitebuilder" -->

		<xsl:variable name="login-result" select="sb:is-service-allowed()"/>

		<xsl:choose>
			<xsl:when test="$login-result/rc = 6">
				<!-- sitebuilder _almost_ ready for use, but no reseller keys present -->

				<!-- get path to base virtuozzo dir, from hnode -->
				<xsl:variable name="reg-path" select="'HKLM\Software\SWSoft\Virtuozzo'"/>
				<xsl:variable name="request-for-path">
					<path-to-vz>
						<pattern>VZINSTALL REG_SZ</pattern>
					</path-to-vz>
				</xsl:variable>
				<xsl:variable name="path-to-vz" select="reg32:get($reg-path,$request-for-path,$hn-eid)/output/path-to-vz"/>

				<!-- hardcode path to sbreseller inside virtuozzo -->
				<xsl:variable name="sbreseller-path-in-vz" select="'installInVe\SWSoft\sbreseller'"/>

				<!-- get veid where need add reseller -->
				<xsl:variable name="veid" select="env:get-env($ve-eid)/env/virtual_config/veid"/>

				<!-- get admin login and password for sitebuilder, in reg on hnode -->
				<xsl:variable name="reg-keys" select="'HKLM\Software\SWSoft\Virtuozzo\SiteBuilder'"/>
				<xsl:variable name="request-for-keys">
					<sb-admin-keys-pair>
						<pattern>Keys REG_SZ</pattern>
					</sb-admin-keys-pair>
				</xsl:variable>
				<xsl:variable name="sb-admin-keys-pair" select="reg32:get($reg-keys,$request-for-keys,$hn-eid)/output/sb-admin-keys-pair"/>
				<xsl:variable name="sb-admin-keys" select="sw:split($sb-admin-keys-pair,':')"/>
				<xsl:variable name="sb-admin-creds" select="concat(' -u ',$sb-admin-keys[1],' -p ',$sb-admin-keys[2])"/> 

				<!-- make full string to add reseller -->
				<xsl:variable name="sbreseller-full-path" select="concat($path-to-vz,$sbreseller-path-in-vz)"/>

				<!-- exec sbreseller and add reseller -->
				<xsl:variable name="exec-arg">
					<argv>
						<xsl:value-of select="sw:base64-encode($sbreseller-full-path)"/>
          </argv>
          <argv>
						<xsl:value-of select="sw:base64-encode('-u')"/>
          </argv>
          <argv>
						<xsl:value-of select="sw:base64-encode($sb-admin-keys[1])"/>
          </argv>
          <argv>
						<xsl:value-of select="sw:base64-encode('-p')"/>
          </argv>
          <argv>
						<xsl:value-of select="sw:base64-encode($sb-admin-keys[2])"/>
          </argv>
          <argv>
						<xsl:value-of select="sw:base64-encode('-v')"/>
          </argv>
          <argv>
						<xsl:value-of select="sw:base64-encode($veid)"/>
          </argv>          
					<stdio>
						<output/>
						<error/>
					</stdio>
				</xsl:variable>
				<xsl:variable name="run-sbreseller" select="process:exec($exec-arg,sw:hn-dst($ve-eid))"/>

				<!-- handle error here -->
				<xsl:choose>
					<xsl:when test="$run-sbreseller/process/error/code">
						<!-- Can not add reseller -->
						<xsl:call-template name="sw:login-error">
							<xsl:with-param name="rc-string" select="$run-sbreseller/process/error/message"/>
						</xsl:call-template>						
					</xsl:when>
					<xsl:otherwise>
						<!-- final step try login as just created reseller into sb -->
						<xsl:call-template name="sb:login"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			
			<xsl:when test="$login-result/rc != 0">
				<xsl:call-template name="sw:login-error">
					<xsl:with-param name="rc-string" select="$login-result/rc-string"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="sb:login"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="sw:login-error">
		<xsl:param name="rc-string"/>
		<ui:popup-screen id="07.04.07.02" title="{sw:text('Sitebuilder is unavailable.')}">
			<ui:properties/>
			<ui:content>
				<ui:raw>
					<xsl:value-of select="$rc-string"/>
						<br/>
					<sw:text>Cannot log in to Sitebuilder.</sw:text>
				</ui:raw>
			</ui:content>
		</ui:popup-screen>	
	</xsl:template>
	
	
	<xsl:template name="sb:login">
		<!-- get from registry reseller creds -->
		<xsl:variable name="reg-path" select="'Software\SWSoft\Virtuozzo\SiteBuilder'"/>
		<xsl:variable name="request-for-keys">
			<reseller-keys>
				<pattern>ResellerKeys REG_SZ</pattern>
			</reseller-keys>
		</xsl:variable>

		<xsl:variable name="sb-reseller" select="reg32:get($reg-path,$request-for-keys)"/>
		<xsl:variable name="reseller-keys" select="sw:split($sb-reseller/output/reseller-keys,':')"/>
		<xsl:variable name="env-config"	select="env:get-env($ve-eid)/env"/>
		<xsl:variable name="platform"		select="env:env2platform($env-config)"/>
		<xsl:variable name="sb-port" 		select="redirect:load($env-config/parent_eid,'vzpp-sb')/service/port"/>

		<xsl:variable name="sb-uri-rtf">
			<proto>http</proto>
			<host>
				<xsl:value-of select="sw:if(vt:is-platform-windows($platform), $env-config/virtual_config/address/ip[1], $env-config/virtual_config/hostname)"/>
			</host>
			<port>
				<xsl:value-of select="$sb-port"/>
			</port>
			<url>
				<xsl:value-of select="'/ExternalLogin.ashx'"/>
			</url>
			<param>
				<xsl:value-of
					select="concat('?Login=',$reseller-keys[1],'&amp;Password=',sw:base64-decode($reseller-keys[2]),'&amp;ShowAdmin=1')"
				/>
			</param>
		</xsl:variable>
		<xsl:variable name="sb-uri" select="exsl:node-set($sb-uri-rtf)"/>

		<!-- set lang for vzcp self -->
		<xsl:variable name="location" select="concat($sb-uri/proto,'://',$sb-uri/host,':',$sb-uri/port,$sb-uri/url,$sb-uri/param)"/>
		<ui:redirect location="{$location}"/>
	</xsl:template>

	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/globals.xsl"/>
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/sitebuilder.xsl"/>
	<sw:include href="/lib/reg32.xsl"/>
	<sw:include href="/lib/vz/vzhn-redirects.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/progm.xsl"/>
	    

</xsl:stylesheet>
