<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func vzenv"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl	="http://exslt.org/common"
	xmlns:func	="http://exslt.org/functions"
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:error	="http://www.swsoft.com/xsl/cp/error"
	xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:vzenv	="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:local	="http://www.swsoft.com/xsl/cp/local"
	xmlns:redirect="http://www.swsoft.com/xsl/cp/redirect"
	xmlns:env		="http://www.swsoft.com/xsl/cp/env"
>
	
	<xsl:template match="/">

		<!-- Reset error -->
		<xsl:if test="sw:sesput('ve-error','')"/>
		
		<!-- Detect VE ID -->
		<xsl:variable name="ve-eid">
			<xsl:choose>
				<xsl:when test="$request/http_request/post/parameter[name = 'id']">
					<xsl:value-of select="string($request/http_request/post/parameter[name = 'id']/value)"/>
				</xsl:when>
				<xsl:otherwise>
					<sw:die>
						VE ID is not specified.
					</sw:die>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<!-- Check access to VE -->    
    	<xsl:if test="cred:detail-check-env('vzcp.env.manage.services.vzpp',$ve-eid)"/>

		<xsl:variable name="env-config"	select="env:get-env($ve-eid)/env"/>
    <xsl:variable name="ve-title"   select="env:env2title($env-config)"/>

		<!-- Check offline service configuration -->
		<xsl:variable name="service-status" select="exsl:node-set(vzenv:ve-offline-status('vzpp',$ve-eid))"/>

		<xsl:choose>
			<xsl:when test="$service-status/service-global-present = 0">
				<!-- Disabled in VZ HW config, windows never put in such condition -->
				<xsl:variable name="error">
						<sw:text>
              The "vzpp" offline service is not configured on the Hardware Node.
            </sw:text><br/>
						<sw:text>Unable to log in to Parallels Power Panel.</sw:text>
				</xsl:variable>
				<xsl:if test="sw:sesput('ve-error',$error)"/>
			</xsl:when>
			<xsl:when test="$service-status/config-present = 0">
				<!-- No such VE -->			
				<xsl:variable name="error">
					<sw:text>The Container does not exist.</sw:text><br/>
					<sw:text>Unable to log in to Parallels Power Panel.</sw:text>
				</xsl:variable>
				<xsl:if test="sw:sesput('ve-error',$error)"/>
			</xsl:when>
			<xsl:when test="$service-status/service-present = 0">
				<!-- Disabled in VE config -->
				<xsl:variable name="error">
					<sw:text>
						<xsl:with-param name="id" select="$ve-title"/>
						Offline management is disabled for Container "%{id}".
					</sw:text><br/>
					<sw:text>Unable to log in to Parallels Power Panel.</sw:text>
				</xsl:variable>
				<xsl:if test="sw:sesput('ve-error',$error)"/>
			</xsl:when>
			<xsl:when test="not($service-status/ip-address != '')">
				<!-- no ip for VE assigned -->
				<xsl:variable name="error">
					<sw:text>
						<xsl:with-param name="id" select="$ve-titel"/>
						Container "%{id}" has no IP address assigned.
					</sw:text><br/>
					<sw:text>Unable to log in to Parallels Power Panel.</sw:text>
				</xsl:variable>
				<xsl:if test="sw:sesput('ve-error',$error)"/>
			</xsl:when>
		</xsl:choose>
				
		<xsl:choose>
			<xsl:when test="sw:sesget('ve-error')">
				<ui:popup-screen id="03.02.01.22.03" title="{sw:text('Parallels Power Panel Unavailable')}">
					<ui:properties>
					</ui:properties>
					<ui:content>
						<ui:raw>
							<xsl:copy-of select="sw:sesget('ve-error')"/>
						</ui:raw>
					</ui:content>
				</ui:popup-screen>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="new-ticket" select="sw:new-pp-session($ve-eid, $super-user)"/>

				<!-- redirect parameters depend from platform and demo mode -->
				<xsl:variable name="vzpp-url"  	select="'/vz/cp'"/>
				<xsl:variable name="env-config"	select="env:get-env($ve-eid)/env"/>
				<xsl:variable name="platform"		select="env:env2platform($env-config)"/>
				<xsl:variable name="vzpp-port" 	select="redirect:load($env-config/parent_eid,'vzpp')/service/port"/>
				<xsl:variable name="host" 			select="$service-status/ip-address"/>
				<xsl:variable name="location"		select="concat('https://',$host,':',$vzpp-port,$vzpp-url,'?LoginTicket=',$new-ticket,'&amp;active_lang=',$active_lang_id)"/>

				<xsl:choose>
					<xsl:when test="$new-ticket">
	    			<xsl:choose>
		          <xsl:when test="error:is-empty()">
								<ui:redirect location="{$location}"/>
	      	    </xsl:when>
  	      	  <xsl:otherwise>
								<ui:redirect>
        				  <xsl:attribute name="path">last</xsl:attribute>
				        </ui:redirect>
	      	    </xsl:otherwise>
  	      	</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<ui:redirect>
		          <xsl:attribute name="path">last</xsl:attribute>
    		    </ui:redirect>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<sw:include href="/lib/globals.xsl"/>
	<sw:include href="/lib/vz/vzhn-redirects.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>	
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/vz/vzenv-offline.xsl"/>
	<sw:include href="/lib/common.xsl"/>

</xsl:stylesheet>
