<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func vzenv"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl	="http://exslt.org/common"
	xmlns:func	="http://exslt.org/functions"
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:error	="http://www.swsoft.com/xsl/cp/error"
	xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:vzenv	="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:vt		="http://www.swsoft.com/xsl/cp/vt"	
	xmlns:local	="http://www.swsoft.com/xsl/cp/local"
	xmlns:redirect="http://www.swsoft.com/xsl/cp/redirect"
	xmlns:env   ="http://www.swsoft.com/xsl/cp/env"
>
	
	<xsl:template match="/">
		<!-- Reset error -->
		<xsl:if test="sw:sesput('ve-error','')"/>
		<xsl:variable name="ve-eid" select="sw:ve-eid()"/>
		<xsl:variable name="env-config"	select="env:get-env($ve-eid)/env"/>
		<xsl:variable name="ve-title"		select="env:env2title($env-config)"/>
		<xsl:variable name="platform"		select="env:env2platform($env-config)"/>
		<xsl:variable name="is-windows" select="vt:is-platform-windows($platform)"/>
		
		<!-- Check offline service configuration -->
		<!-- do it, becuase client can load dashboard, change condition from
				 cmd line or from other browser windows	, and then click 
				 on icon "Login to VZPP" -->
		<xsl:variable name="service-status" select="exsl:node-set(vzenv:ve-offline-status('vzpp',$ve-eid))"/>
		<xsl:variable name="my-ip" select="sw:if($is-windows, $request/http_request/env/parameter[name = 'LOCAL_ADDR']/value, $request/http_request/env/parameter[name = 'SERVER_ADDR']/value)"/>
		
		<xsl:choose>
			<xsl:when test="not(cred:check-env('vzcp.env.manage.services.vzpp',$ve-eid))">
				<xsl:if test="sw:sesput('ve-error',sw:text('You are not authorized to log in to Parallels Power Panel.'))"/>
			</xsl:when>
			<xsl:when test="$service-status/service-global-present = 0">
				<!-- Disabled in VZ HW config, windows never put in such condition -->
				<xsl:variable name="error">
						<sw:text>
              The "vzpp" offline service is not configured on the Hardware Node.
            </sw:text><br/>
						<sw:text>Unable to log in to Parallels Power Panel.</sw:text>
				</xsl:variable>
				<xsl:if test="sw:sesput('ve-error',$error)"/>
			</xsl:when>
			<xsl:when test="$service-status/config-present = 0">
				<!-- No such VE -->			
				<xsl:variable name="error">
					<sw:text>The Container does not exist.</sw:text><br/>
					<sw:text>Unable to log in to Parallels Power Panel.</sw:text>
				</xsl:variable>
				<xsl:if test="sw:sesput('ve-error',$error)"/>
			</xsl:when>
			<xsl:when test="$service-status/service-present = 0">
				<!-- Disabled in VE config -->
				<xsl:variable name="error">
					<sw:text>
						<xsl:with-param name="id" select="$ve-title"/>
						Offline management is disabled for Container "%{id}".
					</sw:text><br/>
					<sw:text>Unable to log in to Parallels Power Panel.</sw:text>
				</xsl:variable>
				<xsl:if test="sw:sesput('ve-error',$error)"/>
			</xsl:when>
			<xsl:when test="not($service-status/ip-address != '')">
				<!-- no ip for VE assigned -->
				<xsl:variable name="error">
					<sw:text>
						<xsl:with-param name="id" select="$ve-title"/>
						Container "#%{id}" has no IP address assigned.
					</sw:text><br/>
					<sw:text>Unable to log in to Parallels Power Panel.</sw:text>
				</xsl:variable>
				<xsl:if test="sw:sesput('ve-error',$error)"/>
			</xsl:when>
			<xsl:when test="$service-status/ip-address = $my-ip">
				<!-- login to vzcc, but used address current vzenv -->
				<xsl:variable name="error">
					<sw:text>
						<xsl:with-param name="my-ip" select="$my-ip"/>
            The IP address of the selected Container (%{my-ip}) is already used for a Parallels Infrastructure Manager session. Container #%{id} has no IP address assigned.
					</sw:text><br/>
					<sw:text>Unable to log in to Parallels Power Panel.</sw:text>
				</xsl:variable>
				<xsl:if test="sw:sesput('ve-error',$error)"/>
			</xsl:when>
		</xsl:choose>
				
		<xsl:choose>
			<xsl:when test="sw:sesget('ve-error')">
		
				<ui:popup-screen id="03.02.01.22.04" title="{sw:text('Parallels Power Panel is unavailable')}">
					<ui:properties>
					</ui:properties>
					<ui:content>
						<ui:raw>
							<xsl:copy-of select="sw:sesget('ve-error')"/>
						</ui:raw>
					</ui:content>
				</ui:popup-screen>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="new-ticket" select="sw:new-pp-session($ve-eid, $super-user)"/>

				<!-- redirect parameters depend from platform and demo mode -->
				<xsl:variable name="vzpp-url"  	select="'/vz/cp'"/>
				<xsl:variable name="vzpp-port" 	select="redirect:load($env-config/parent_eid,'vzpp')/service/port"/>
				<xsl:variable name="host" 			select="$service-status/ip-address"/>
				<xsl:variable name="location" select="concat('https://',$host,':',$vzpp-port,$vzpp-url,'?LoginTicket=',$new-ticket,'&amp;active_lang=',$active_lang_id)"/>

				<xsl:choose>
					<xsl:when test="$new-ticket">
	    			<xsl:choose>
		          <xsl:when test="error:is-empty()">
								<ui:redirect location="{$location}"/>
	      	    </xsl:when>
  	      	  <xsl:otherwise>
								<ui:redirect>
        				  <xsl:attribute name="path">last</xsl:attribute>
				        </ui:redirect>
	      	    </xsl:otherwise>
  	      	</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<ui:redirect>
		          <xsl:attribute name="path">last</xsl:attribute>
    		    </ui:redirect>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

	<sw:include href="/lib/globals.xsl"/>
	<sw:include href="/lib/vz/vzhn-redirects.xsl"/>
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/vz/vzenv-offline.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>
	
</xsl:stylesheet>
