<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl	="http://exslt.org/common"
	xmlns:func	="http://exslt.org/functions"
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local	="http://www.swsoft.com/xsl/cp/local"
	xmlns:hwm		="http://www.swsoft.com/xsl/cp/hwm"
	xmlns:vzenv	="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:vt		="http://www.swsoft.com/xsl/cp/vt"		
	xmlns:env   ="http://www.swsoft.com/xsl/cp/env"	
>

	<!-- Check creds -->
	<xsl:variable name="ve-eid" select="sw:ve-eid()"/>
	<xsl:variable name="cr-vzpp-login" select="cred:check-env('vzcp.env.manage.services.vzpp',$ve-eid)"/>
	<xsl:param name="access-denied" select="not($cr-vzpp-login)"/>

	<xsl:variable name="env-config"	select="env:get-env($ve-eid)/env"/>
	<xsl:variable name="platform"		select="env:env2platform($env-config)"/>
	<xsl:variable name="is-windows" select="vt:is-platform-windows($platform)"/>
	<xsl:variable name="is-linux" 	select="vt:is-platform-linux($platform)"/>	

	<!-- Check offline service configuration -->
	<xsl:variable name="service-status" select="exsl:node-set(vzenv:ve-offline-status('vzpp',$ve-eid))"/>
	<xsl:variable name="my-ip"
		select="sw:if($is-windows, $request/http_request/env/parameter[name = 'LOCAL_ADDR']/value, $request/http_request/env/parameter[name = 'SERVER_ADDR']/value)"/>

	<xsl:variable name="login-result">
		<xsl:choose>
			<xsl:when test="$service-status/service-global-present = 0">
				<xsl:variable name="oper-problem-rtf">
					<type>custom</type>
					<ui:reason>
						<sw:text>
							The "vzpp" offline service is not configured on the Hardware Node.
						</sw:text>
					</ui:reason>
					<ui:solution>
						<sw:text>Configure the vzpp offline service on the Hardware Node.</sw:text>
					</ui:solution>
				</xsl:variable>
				<ui:block>
					<ui:operation-problem>
						<xsl:copy-of select="exsl:node-set($oper-problem-rtf)"/>
						<ui:descr>
							<sw:text>Unable to log in to Parallels Power Panel.</sw:text>
						</ui:descr>
					</ui:operation-problem>
				</ui:block>
			</xsl:when>
			<xsl:when test="$service-status/service-present = 0">
				<ui:block>
					<ui:operation-problem>
						<ui:reason>
							<xsl:choose>
								<xsl:when test="$is-linux">
									<sw:text>Offline management for the vzpp service is disabled.</sw:text>
								</xsl:when>
								<xsl:otherwise>
									<sw:text>The default offline management is disabled.</sw:text>
								</xsl:otherwise>
							</xsl:choose>
						</ui:reason>
						<ui:solution>
							<xsl:choose>
								<xsl:when test="cred:check-env('vzcp.env.manage.properties.preferences',$ve-eid)">
									<xsl:choose>
										<xsl:when test="$is-linux">
											<ui:i18n-link href="{$baseurl}/vzdir/infrman/envs/manage?tab=gen"
												tip="vzve_configure_general_menu">
												<_>Please %{aopen}enable%{aclose} the offline management for the vzpp service and try again.</_>
											</ui:i18n-link>
										</xsl:when>
										<xsl:otherwise>
											<ui:i18n-link href="{$baseurl}/vzdir/infrman/envs/manage?tab=gen"
												tip="vzve_configure_general_menu">
												<_>Please %{aopen}enable%{aclose} the default offline management and try again.</_>
											</ui:i18n-link>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:when>
								<xsl:otherwise>
									<xsl:choose>
										<xsl:when test="$is-linux">
											<sw:text>Please enable the offline management for the vzpp service and try again.</sw:text>
										</xsl:when>
										<xsl:otherwise>
											<sw:text>Please enable the default offline management and try again.</sw:text>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:otherwise>
							</xsl:choose>
						</ui:solution>
						<ui:descr>
							<sw:text>Unable to log in to Parallels Power Panel.</sw:text>
						</ui:descr>
					</ui:operation-problem>
				</ui:block>
			</xsl:when>
			<xsl:when test="not($service-status/ip-address != '')">
				<ui:block>
					<ui:operation-problem>
						<ui:reason>
							<sw:text>The Container has no host-routed IP address assigned.</sw:text>
						</ui:reason>
						<ui:solution>
							<xsl:choose>
								<xsl:when test="cred:check-env('vzcp.env.manage.properties.preferences',$ve-eid)">
									<ui:i18n-link href="{$baseurl}/vzdir/infrman/envs/manage?tab=net"
										tip="03.02.01.03.02">
										<_>Please %{aopen}assign an IP address%{aclose} and try again.</_>
									</ui:i18n-link>
								</xsl:when>
								<xsl:otherwise>
									<sw:text>Please assign an IP address and try again.	</sw:text>
								</xsl:otherwise>
							</xsl:choose>
						</ui:solution>
						<ui:descr>
							<sw:text>Unable to log in to Parallels Power Panel.</sw:text>
						</ui:descr>
					</ui:operation-problem>
				</ui:block>
			</xsl:when>
			<xsl:when test="$service-status/ip-address = $my-ip">
				<ui:block>
					<ui:operation-problem>
						<ui:reason>
							<sw:text>
								<xsl:with-param name="my-ip" select="$my-ip"
								/>
            		The IP address of the selected Container (%{my-ip}) is already used for a Parallels Infrastructure Manager session.
            	</sw:text>
						</ui:reason>
						<ui:solution>
							<ui:i18n-link href="{$baseurl}/logout" tip="log_out_cc">
								<_>Please %{aopen}log out of Parallels Infrastructure Manager%{aclose} and log in again using another IP address.</_>
							</ui:i18n-link>
						</ui:solution>
						<ui:descr>
							<sw:text>Unable to log in to Parallels Power Panel.</sw:text>
						</ui:descr>
					</ui:operation-problem>
				</ui:block>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>

	<xsl:template mode="screen" match="/">
		<ui:screen id="03.02.01.22.06" icon="vzpp" bg="vzpp">
			<ui:properties>
				<ui:width value="fixed"/>
				<ui:no-default-form/>
			</ui:properties>
			<ui:content>
				<xsl:copy-of select="exsl:node-set($login-result)"/>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<!-- configure new session by current -->
	<func:function name="local:configure-session">
		<xsl:param name="ticket"/>
		<xsl:param name="ip"/>

		<xsl:variable name="keys-to-copy">
			<key>selected_tz</key>
			<key>active_tz</key>
			<key>js_mode</key>
			<key>java_mode</key>
		</xsl:variable>

		<xsl:variable name="sesion-config-pkt">
			<packet>
				<target>ticketm</target>
				<data>
					<ticketm>
						<put>
							<ticket>
								<xsl:value-of select="$ticket"/>
							</ticket>
							<ip>
								<xsl:value-of select="$ip"/>
							</ip>

							<!-- copy values from current session -->
							<xsl:for-each select="exsl:node-set($keys-to-copy)/key">
								<data>
									<key>
										<xsl:value-of select="."/>
									</key>
									<value>
										<xsl:value-of select="sw:base64-encode(sw:sesgetstr(.))"/>
									</value>
								</data>
							</xsl:for-each>

						</put>
					</ticketm>
				</data>
				<vzcpauth/>
			</packet>
		</xsl:variable>

		<func:result select="sw:xchg($sesion-config-pkt)"/>
	</func:function>

	<sw:include href="/lib/vza/hwm.xsl"/>
	<sw:include href="/lib/vz/vzenv-offline.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/screen.xsl"/>

</xsl:stylesheet>
