<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred licensem"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:error="http://www.swsoft.com/xsl/cp/error"
  xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
  xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
  xmlns:func="http://exslt.org/functions"
	xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
	xmlns:backups	="http://www.swsoft.com/xsl/cp/backups"
	xmlns:licensem="http://www.swsoft.com/xsl/cp/licensem"
 >
  	
  <sw:include href="/lib/vt/backups-core.xsl"/>
  <sw:include href="/lib/vt/backups-forms.xsl"/>  

	<xsl:param name="access-denied" select="not(cred:check('vzcp.hn.backups.configure'))"/>

  <xsl:param name="wiz_code" select="'backups-setup-global'"/>
  
	<xsl:variable name="step_data"			select="wiz:getStep()"/>
	<xsl:variable name="step"						select="$step_data/@id"/>
	<xsl:variable name="form" select="sw:sesget($wiz_data)"/>
  
  <!-- Wizard, General Step  -->
  <xsl:template name="step_gen">
  	  
  	<ui:screen  id="{$step_data/@screen-id}">
  	
	    <ui:properties>
	    	<ui:form-get/>
	    	<ui:refresh-type>none</ui:refresh-type>
				<ui:description mandatory="yes">
					<sw:text>Configure the default settings for backing up the Containers of all the registered Hardware Nodes.</sw:text>
				</ui:description>
			</ui:properties>
	    
	    <ui:tab-bar id="setup.backups" current-tab="vzsetup"/>
	    <ui:content>
	      <ui:hidden name="step" value="gen"/>    
	      <ui:block mode="edit">
	      	 	
					<xsl:call-template name="backups:edit-core-options">
						<xsl:with-param name="options" select="$form/core-options"/>
					</xsl:call-template>
	   				
	        <ui:buttons>
	        	<xsl:call-template name="wiz:showButtons"/>
	        </ui:buttons>
	        
	     	</ui:block>
	    </ui:content>   
    </ui:screen>
  </xsl:template>
  
   <!-- Wizard, Error screen -->
  <xsl:template name="show-error">
  	  
  	<ui:screen  id="{$step_data/@screen-id}">
  	
	    <ui:properties>
	    	<ui:refresh-type>none</ui:refresh-type>
		</ui:properties>
	    
	    <ui:tab-bar id="setup.backups" current-tab="vzsetup"/>
	    <ui:content>
	      <ui:block>

					<ui:operation-problem>
						<ui:type>vza-error</ui:type>
						<ui:descr>
							<sw:text>The backup settings are unavailable now.</sw:text>
						</ui:descr>
						<ui:vza-error>
							<xsl:copy-of select="$form/core-options/error/*"/>
						</ui:vza-error>
					</ui:operation-problem>
				
	     	</ui:block>
	    </ui:content>   
    </ui:screen>
  </xsl:template>
 
	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
	
		<xsl:choose>
			<xsl:when test="$form/core-options/error">
				<xsl:call-template name="show-error"/>
			</xsl:when>
			<xsl:when test="$step = 'gen'">
				<xsl:call-template name="step_gen"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="step_gen"/>
			</xsl:otherwise>
			
		</xsl:choose>
	
	</xsl:template>
	
	<!-- Includes -->	
	<!-- UI modules -->
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>

	<!-- System modules -->
	<sw:include href="/lib/vocabulary.xsl"/>			
	
	<!-- /Includes -->	
	
</xsl:stylesheet>
