<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl func wiz cred"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:voc="http://www.swsoft.com/xsl/cp/voc"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
>

	<!-- check permissions to show this page -->
	<xsl:variable name="cred"
		select="cred:check-hw('vzcp.hn.manage.config.network',sw:hn-eid())"/>

	<xsl:param name="wiz_code" select="'hw-config-logging'"/>

	<xsl:variable name="step_data" select="wiz:getStep()"/>
	<xsl:variable name="step" select="$step_data/@id"/>

	<xsl:param name="access-denied" select="not($cred)"/>

	<xsl:variable name="form" select="sw:sesget($wiz_data)"/>

	<!-- Wizard, General Step  -->
	<xsl:template name="step_gen">
		<xsl:variable name="voc-counters" select="voc:get('counters',env:make-platform-ref($form/def/hn-eid),'',true())"/>
	
		<ui:screen id="{$step_data/@screen-id}">
			<ui:properties>
				<ui:refresh-type>none</ui:refresh-type>
				<ui:form-get/>
			</ui:properties>
			<ui:content>
				<ui:hidden name="step" value="gen"/>
				<ui:block mode="edit" width="max:">
				
					<ui:rows title="{sw:text('Logging Periods')}">
						<xsl:for-each select="$form/periods/period">
							<xsl:variable name="voc-counter" select="$voc-counters[id=current()/id]"/>
							<ui:row>
								<ui:cell-text>
									<xsl:choose>
										<xsl:when test="$voc-counter/long!=''">
											<sw:text select="string($voc-counter/long)" domain="vzagent-vocabulary"/>
										</xsl:when>
										<xsl:when test="$voc-counter/short!=''">
											<sw:text select="string($voc-counter/short)" domain="vzagent-vocabulary"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="id"/>
										</xsl:otherwise>
									</xsl:choose>
								</ui:cell-text>
								<ui:cell-input id="value_{position()}" maxlength="10" value="{value}" required="true"/>
								<ui:cell-list id="factor_{position()}" value="{factor}">
									<ui:list-item id="1" title="{sw:text('Seconds')}"/>
									<ui:list-item id="60" title="{sw:text('Minutes')}"/>
									<ui:list-item id="3600" title="{sw:text('Hours')}"/>									
								</ui:cell-list>
							</ui:row>
						</xsl:for-each>
					</ui:rows>

					<ui:buttons>
						<xsl:call-template name="wiz:showButtons"/>
					</ui:buttons>

				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>


	<!-- main document handler -->
	<xsl:template mode="screen" match="/">

		<xsl:choose>
			<xsl:when test="$step = 'gen'">
				<xsl:call-template name="step_gen"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="step_gen"/>
			</xsl:otherwise>

		</xsl:choose>

	</xsl:template>

	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>

	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>

</xsl:stylesheet>
