<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred "
  xmlns:xsl					="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl				="http://exslt.org/common"
  xmlns:sw					="http://www.swsoft.com/xsl/cp"  
  xmlns:ui					="http://www.swsoft.com/xsl/cp/ui"   
  xmlns:cred 			 	="http://www.swsoft.com/xsl/cp/cred"
  xmlns:local				="http://www.swsoft.com/xsl/cp/local" 
 	xmlns:voc					="http://www.swsoft.com/xsl/cp/voc" 
  xmlns:backups			="http://www.swsoft.com/xsl/cp/backups"  	
  xmlns:browse			="http://www.swsoft.com/xsl/cp/browse" 
>
	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/vt/backups-list.xsl"/>

	<!-- Load the EID of deleted VE -->
	<xsl:variable name="ve-eid" >
		<xsl:variable name="get-id" select="string(sw:param('ve-eid'))"/>
		<xsl:choose>
	    <!-- set new ID from GET -->
	    <xsl:when test="$get-id">
				<xsl:if test="sw:sesputstr('vz-backup-eid',$get-id)"/>
				<xsl:value-of select="$get-id"/>
			</xsl:when>
			<!-- get from session -->
			<xsl:when test="sw:sesgetstr('vz-backup-eid')!=''">
				<xsl:value-of select="sw:sesgetstr('vz-backup-eid')"/>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>
	
	<xsl:template mode="screen" match="/">	
		
		<ui:screen id="03.02.01.13.02" bg="backup">
			<ui:properties>
				<ui:form-get/>			
				<ui:contains-date-control/>
				<ui:description mandatory="yes">
					<sw:text>
						On this screen you can see a list of available backups for the Container.
						<br/>A backup of the Container stores all of its data including system and user files.
					</sw:text>
				</ui:description>
			</ui:properties>
				
			<ui:content>    	    	    
				<ui:block width="full">		
			
					<!-- Init Filter -->
					<xsl:variable name="filter-rtf">
						<xsl:call-template name="browse:init-filter">
							<xsl:with-param name="browse">
								<ui:browse-setup id="deleted-backups" url="/vz/ves/backups/index-deleted?ve-eid={sw:escape($ve-eid)}" 
									item-url="/vt/backups/backup-deleted"
									item-url-tip="ve_backups" items-title="{sw:text('Backups')}"
								/>
								<ui:cols sorting-col="backuped" sorting-direction="desc">
									<xsl:call-template name="backups:get-single-ve-browse-cols">
									</xsl:call-template>
								</ui:cols>
							</xsl:with-param>
						</xsl:call-template>
					</xsl:variable>    
		
					<!-- Fill Filter -->
					<xsl:variable name="filter-data-rtf">
						<xsl:call-template name="backups:fill-filter">
							<xsl:with-param name="filter-rtf" select="$filter-rtf"/>
							<xsl:with-param name="filter-ve-eid" select="$ve-eid"/>
						</xsl:call-template>
					</xsl:variable>
					<xsl:variable name="filter" select="exsl:node-set($filter-data-rtf)"/>
				
				
					<!-- Show Browse -->	
					<xsl:call-template name="local:post-single-ve-browse">
						<xsl:with-param name="filter" select="$filter"/>		
						<xsl:with-param name="new-allowed" select="false()"/>	    
						<xsl:with-param name="renew-allowed"  select="false()"/>	
						<xsl:with-param name="restore-allowed"  select="true()"/>	  
						<xsl:with-param name="remove-allowed"  select="true()"/>	 
					</xsl:call-template>				
					
				</ui:block>
			</ui:content>          
		</ui:screen>
	
	</xsl:template>  

	<sw:include href="/lib/screen.xsl"/>
	  
</xsl:stylesheet>
