<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred"
  xmlns:xsl					="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl				="http://exslt.org/common"
  xmlns:sw					="http://www.swsoft.com/xsl/cp"  
  xmlns:ui					="http://www.swsoft.com/xsl/cp/ui"   
  xmlns:cred 			 	="http://www.swsoft.com/xsl/cp/cred"
  xmlns:local				="http://www.swsoft.com/xsl/cp/local" 
  xmlns:backups			="http://www.swsoft.com/xsl/cp/backups"
 	xmlns:voc					="http://www.swsoft.com/xsl/cp/voc" 
>	

	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/vt/backups-core.xsl"/>	
	<sw:include href="/lib/vt/backups-list.xsl"/>
	<sw:include href="/lib/vt/backups-forms.xsl"/>	
	
	<xsl:variable name="ve-eid" 				select="sw:ve-eid()"/>	
	<xsl:variable name="list-problem" 	select="voc:check-operation('vzabackupm','list','',$ve-eid)"/>
	<xsl:variable name="backups-limit"	select="backups:find-actual-ve-limit(sw:ve-parent($ve-eid))"/>
	<xsl:param name="access-denied" select="not(cred:check-env('vzcp.env.backups.list', $ve-eid))"/>	
	
	<xsl:template mode="screen" match="/">	
		<xsl:choose>

			<!-- Backup listing is unavailable now -->
			<xsl:when test="$list-problem!=''">
				<ui:screen id="03.02.01.13.01" bg="backup">
					<ui:tab-bar id="maintance" current-tab="backups"/>
					<ui:content>    	    	    
						<ui:block>
							<ui:operation-problem>
								<xsl:copy-of select="$list-problem"/>
								<ui:descr>
									<sw:text>Unable to list the Container backups.</sw:text>
								</ui:descr>
							</ui:operation-problem>
						</ui:block>
					</ui:content>
				</ui:screen>
			</xsl:when>
			<!-- /Backup listing is unavailable now -->
			
			<!-- Show backups -->
			<xsl:otherwise>
						
				<xsl:variable name="browse-rtf">
					<xsl:call-template name="backups:browse-single-ve">
						<xsl:with-param name="backups-limit" select="$backups-limit"/>	
						<xsl:with-param name="filter-ve-eid" select="$ve-eid"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:variable name="browse" select="exsl:node-set($browse-rtf)"/>
				
				<ui:screen id="03.02.01.13.01" bg="backup">
					<ui:properties>
						<ui:contains-date-control/>	
						<ui:form-get/>
						<ui:description mandatory="yes">
							<sw:text>
								On this screen you can see a list of available backups for the Container.
								<br/>A backup of the Container stores all of its data including system and user files.
							</sw:text>
							<xsl:if test="$list-problem=''">
								<br/>
								<xsl:copy-of select="backups:get-vzpp-limits-warning($backups-limit,$browse//ui:filter/ui:coords/@total)"/>
							</xsl:if>
						</ui:description>
					</ui:properties>
		
					<ui:tab-bar id="maintance" current-tab="backups"/>
					
					<ui:content>
						<ui:block width="full">		
							<xsl:copy-of select="$browse-rtf"/>
						</ui:block>
					</ui:content>
				</ui:screen>
			</xsl:otherwise>
			<!-- /Show backups -->
			
		</xsl:choose>
	</xsl:template>  

	<sw:include href="/lib/screen.xsl"/>
	  
</xsl:stylesheet>
