<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred "
  xmlns:xsl					="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl				="http://exslt.org/common"
  xmlns:sw					="http://www.swsoft.com/xsl/cp"  
  xmlns:ui					="http://www.swsoft.com/xsl/cp/ui"   
  xmlns:cred 			 	="http://www.swsoft.com/xsl/cp/cred"
  xmlns:local				="http://www.swsoft.com/xsl/cp/local" 
 	xmlns:voc					="http://www.swsoft.com/xsl/cp/voc" 
  xmlns:backups			="http://www.swsoft.com/xsl/cp/backups" 
  xmlns:trace       ="http://www.swsoft.com/xsl/cp/trace"  
>       

	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/trace.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/vt/backups-list.xsl"/>

	<xsl:variable name="ve-eid" 				select="sw:ve-eid()"/>	
	<xsl:variable name="backups-limit" 	select="backups:find-actual-ve-limit(sw:ve-parent($ve-eid))"/>
	<xsl:variable name="list-problem" 	select="voc:check-operation('vzabackupm','list','',$ve-eid)"/>
	<xsl:variable name="is-backup-branch" 			select="trace:check-branch('env-home','unit.backups') or trace:check-branch('env-home','hn.backups')"/>
	<xsl:param name="access-denied" select="not(cred:check-env('vzcp.env.backups.list', $ve-eid))"/>
	
	<xsl:template mode="screen" match="/">	
		
		<ui:screen id="03.02.01.13.01" bg="backup">
			<ui:properties>
				<ui:form-get/>			
				<ui:contains-date-control/>
				<ui:description mandatory="yes">
					<sw:text>
						On this screen you can see a list of available backups for the Container.
						<br/>A backup of the Container stores all of its data including system and user files.
					</sw:text>
					<xsl:if test="$list-problem=''">
						<br/>
						<xsl:call-template name="local:limits-descripton"/>
					</xsl:if>
				</ui:description>
			</ui:properties>

			<xsl:if test="not($is-backup-branch)">
				<ui:tab-bar id="vzve" current-tab="backups"/>
			</xsl:if>
				
			<ui:content>
				<xsl:choose>
					<!-- Backup listing is unavailable now -->
					<xsl:when test="$list-problem!=''">
						<ui:block>
							<ui:operation-problem>
								<xsl:copy-of select="$list-problem"/>
								<ui:descr>
									<sw:text>Unable to list the Container backups.</sw:text>
								</ui:descr>
							</ui:operation-problem>
						</ui:block>
					</xsl:when>
					<!-- Show backups -->
					<xsl:otherwise>
						<ui:block width="full">
							<xsl:call-template name="backups:browse-single-ve">
								<xsl:with-param name="backups-limit" select="$backups-limit"/>
								<xsl:with-param name="filter-ve-eid" select="$ve-eid"/>
							</xsl:call-template>
						</ui:block>
					</xsl:otherwise>
					<!-- /Show backups -->
				</xsl:choose>
			</ui:content>
		</ui:screen>
	
	</xsl:template>  

	<!-- Show current VE backups limits -->
	<xsl:template name="local:limits-descripton">
		
		<xsl:variable name="icon-warning">
			<br/>	
			<img src="/{$theme}/icons/alert_yellow.gif" width="16" height="16" border="0"
			/>&#160;
		</xsl:variable>
		
		<xsl:variable name="icon-problem">
			<br/>
			<img src="/{$theme}/icons/alert_red.gif" width="16" height="16" border="0"
			/>&#160;
		</xsl:variable>
		
		<xsl:choose>
			<!-- Uknown limits -->
			<xsl:when test="not($backups-limit) or $backups-limit[self::error]">
				<xsl:copy-of select="$icon-warning"/>			
				<sw:text>The limit of backups per Container is unknown due to system error cp1301</sw:text>
			</xsl:when>
			<!-- Unlimited -->
			<xsl:when test="$backups-limit=''">
				<sw:text>
					The user is allowed to create an unlimited number of backups.
				</sw:text>
			</xsl:when>
			<!-- Limited -->
			<xsl:otherwise>
				<sw:text>
					<xsl:with-param name="max" select="$backups-limit"/>
					The user is allowed to create up to %max backup(s).
				</sw:text>
			</xsl:otherwise>
		</xsl:choose>
		
	</xsl:template>

	<sw:include href="/lib/screen.xsl"/>
	
</xsl:stylesheet>
