<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred vzapackagem dynamic local func voc"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:exsl="http://exslt.org/common"
	xmlns:set="http://exslt.org/sets" 
	xmlns:func="http://exslt.org/functions" 
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui" 
	xmlns:dynamic="http://www.swsoft.com/xsl/cp/dynamic"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:voc="http://www.swsoft.com/xsl/cp/voc" 
	xmlns:local="http://www.swsoft.com/xsl/cp/local" 
	xmlns:error="http://www.swsoft.com/xsl/cp/error" 
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:vzenv="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:vzapackagem="http://www.swsoft.com/xsl/cp/vzapackagem"
	>

	<sw:include href="/lib/swa/system.xsl" />
	<sw:include href="/lib/common.xsl" />
	<sw:include href="/lib/vt/env-core.xsl" />
	<sw:include href="/lib/vz/vzenv-apps.xsl" />
	<sw:include href="/lib/vza/vzapackagem.xsl" />
	<sw:include href="/lib/dynamic.xsl" />
	<sw:include href="/lib/screen.xsl" />

	<!-- check permissions to show this page -->
	<xsl:param name="access-denied" select="not(cred:check-env('vzcp.env.manage.properties.application', sw:ve-eid()))" />
	<xsl:variable name="pid" select="sw:if(sw:param('pid'), string(sw:param('pid')), sw:sesget('ve-app-action-id'))"/>

	<xsl:template mode="screen" match="/">
		<xsl:if test="sw:sesput('ve-app-action-id', '')"/>
		
		<xsl:variable name="eid" select="sw:ve-eid()"/>
		<!-- Get summary info for templates in VE -->
		<xsl:variable name="summary" select="/packet/info/apps"/>
		
		<ui:screen id="03.02.01.03.03" icon="app_package">
			<ui:properties>
				<ui:description mandatory="yes" width="max">
					<sw:text>View and manage your Container applications.</sw:text>
				</ui:description>
				<ui:form-get/>
			</ui:properties>
			
			<ui:tab-bar id="vzve" current-tab="soft" current-subtab="apps"/>
			<xsl:variable name="oper-problem" select="voc:check-operation('vzapackagem','install')"/>
			<xsl:variable name="updating" select="vzenv:is-ve-updating($eid) or not(string($pid)='')"/>
			
			<ui:content>
				<!-- Check current transition -->
				<xsl:choose>
					<xsl:when test="string($oper-problem)='' and (not(/packet/cookie/list) or string($summary)='') and not($updating)">
						<xsl:call-template name="local:show-ve-state">
							<xsl:with-param name="summary" select="$summary"/>
							<xsl:with-param name="show-progress" select="true()"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:when test="string($oper-problem)='' or $updating">
						<!-- Show VE state -->
						<xsl:call-template name="local:show-ve-state">
							<xsl:with-param name="summary" select="$summary"/>
							<xsl:with-param name="show-progress" select="$updating"/>
						</xsl:call-template>
						
						<!-- Show installed templates list -->
						<ui:summary-block title="{sw:text('Installed Applications')}" width="max">
							<xsl:variable name="cred-manage-apps"
								select="cred:check-hw('vzcp.template', sw:hn-eid()) and $activeMode='vzcc'"/>
							<xsl:choose>
								<xsl:when test="$summary/installed/package">
									<ui:table>
										<xsl:for-each select="$summary/installed/package">
											<xsl:sort select="name"/>
											<row>
												<col>
													<xsl:call-template name="vzenv:get-app-tmpl-label">
														<xsl:with-param name="app" select="."/>
														<xsl:with-param name="enabled" select="$cred-manage-apps"/>
														<xsl:with-param name="hn-eid" select="sw:hn-eid()"/>
														<xsl:with-param name="global" select="false()"/>
													</xsl:call-template>
												</col>
												<col width="100%">
													<xsl:copy-of select="summary"/>
												</col>
											</row>
										</xsl:for-each>
									</ui:table>
								</xsl:when>
								<xsl:otherwise>
									<ui:simple-table>
										<row>
											<col>
												<span class="inactive">
													<span class="inactive"><sw:text>No applications installed</sw:text></span>
												</span>
											</col>
										</row>
									</ui:simple-table>
								</xsl:otherwise>
							</xsl:choose>	
						</ui:summary-block>
						
						<!-- Show control button -->
						<ui:block width="max">
							<ui:buttons>
								<ui:button type="ok" name="manage" id="manage" tip="configure_app_templates" sandclock="no"
									disabled="{$updating or not($summary//package)}">
									<sw:text>Manage</sw:text>
								</ui:button>
							</ui:buttons>
						</ui:block>
					</xsl:when>
					<xsl:otherwise>
					<!-- Show operation problem report -->
						<ui:block>
							<ui:operation-problem>
								<xsl:copy-of select="$oper-problem"/>
								<ui:descr>
									<sw:text>Unable to manage applications in this Container.</sw:text>
								</ui:descr>
							</ui:operation-problem>
						</ui:block>
					</xsl:otherwise>
				</xsl:choose>
			</ui:content>		
		</ui:screen>
	</xsl:template>
	
	<xsl:template name="local:show-ve-state">
		<xsl:param name="summary"/>
		<xsl:param name="show-progress" select="false()"/>
		
		<ui:summary-block title="{sw:text('Overall Status')}" width="max">
			<ui:simple-table>
				<row>
					<xsl:choose>
						<xsl:when test="$show-progress">
							<col valign="middle">
								<img id="refresh_img" width="16" border="0" height="16"
									src="/{$theme}/icons/indicator.gif"/>
							</col>
							<col width="100%" valign="middle">
								<xsl:call-template name="local:show-progress"/>
							</col>
						</xsl:when>
						<xsl:when test="not($summary//package)">
							<col valign="middle">
								<img src="/{$theme}/icons/yellow_16.gif" width="16" height="16"/>
							</col>
							<col width="100%" valign="middle">
								<sw:text>No application templates are available for this Container.</sw:text>
							</col>
						</xsl:when>
						<xsl:when test="not($summary/updates)">
							<col valign="middle">
								<img src="/{$theme}/icons/green_16.gif" width="16" height="16"/>
							</col>
							<col width="100%" valign="middle">
								<sw:text>The Container applications are up to date.</sw:text>
							</col>
						</xsl:when>
						<xsl:otherwise>
							<col valign="middle">
								<img src="/{$theme}/icons/yellow_16.gif" width="16" height="16"/>
							</col>
							<col width="100%" valign="middle">
								<xsl:choose>
									<xsl:when test="$summary/type='ez'">
										<sw:text>Updates are available for the Container application packages.</sw:text>
									</xsl:when>
									<xsl:otherwise>
										<sw:text>The Container applications are not up to date.</sw:text>
									</xsl:otherwise>
								</xsl:choose>
								
							</col>
						</xsl:otherwise>
					</xsl:choose>
				</row>
			</ui:simple-table>
		</ui:summary-block>
	</xsl:template>
	
	<xsl:template name="local:show-progress">
		<ui:raw>
			<div>
				<span id="list_result">
					<sw:text>Waiting for the Container software status...</sw:text>
				</span>
			</div>
			
			<xsl:variable name="send-ui-name" select="'get_rpms'" />
			<xsl:variable name="recv-ui-name" select="'list_rpms'" />
			<xsl:variable name="div-name" select="'list_result'" />
			
			<xsl:call-template name="dynamic:error-reporter-script" />

			<script>
				var timerID;
				function recv(content) {
					clearTimeout(timerID);
					<!-- replace progress with initial message -->
					var div_obj = document.getElementById('list_result');
					if (content.length &gt; 1) {
						if (content[0] != 'retry') {
							document.getElementById('list_result').innerHTML = content[1];
							doSubmit();
						} else if(content[0] =='retry') {
							document.getElementById('list_result').innerHTML = content[1];
							timerID = setTimeout("<xsl:value-of select="$send-ui-name"/>()", 1000);
						} 
					} 
				}
			</script>
			
			<xsl:call-template name="dynamic:ajax-sender-func">
				<xsl:with-param name="sender-func" select="$send-ui-name"/>
				<xsl:with-param name="reciever-func" select="$recv-ui-name" />
				<xsl:with-param name="request-url" select="concat('/vz/cp/vzdir/infrman/envs/apps-dynamic?pid=', $pid)"/>
			</xsl:call-template>
	
			<xsl:call-template name="dynamic:ajax-reciever-func">
				<xsl:with-param name="reciever-func" select="$recv-ui-name"/>
				<xsl:with-param name="ui-func" select="'recv'" />
			</xsl:call-template>
			
			<script>
				<xsl:value-of select="$send-ui-name"/>();
			</script>
		</ui:raw>
	</xsl:template>
	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
