<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred voc vzenv-files env licensem func"
  xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl			="http://exslt.org/common"
  xmlns:sw				="http://www.swsoft.com/xsl/cp"
  xmlns:ui				="http://www.swsoft.com/xsl/cp/ui"   
	xmlns:cred			="http://www.swsoft.com/xsl/cp/cred"
	xmlns:vzenv-files	="http://www.swsoft.com/xsl/cp/vzenv-files"
	xmlns:voc				="http://www.swsoft.com/xsl/cp/voc"	
	xmlns:env				="http://www.swsoft.com/xsl/cp/env"	
  xmlns:vzaconfig	="http://www.swsoft.com/xsl/cp/vzaconfig"
  xmlns:local			="http://www.swsoft.com/xsl/cp/local"  
  xmlns:backups		="http://www.swsoft.com/xsl/cp/backups"
  xmlns:licensem="http://www.swsoft.com/xsl/cp/licensem"
  xmlns:func			="http://exslt.org/functions"  
>

	<sw:include href="/lib/globals.xsl"/>  
	<sw:include href="/lib/vt/env-core.xsl"/>  
  <sw:include href="/lib/vt/backups-core.xsl"/>
	
	<xsl:variable name="backup-id"				 	select="sw:sesgetstr('vz-backup-id')"/>		
	<xsl:variable name="backup" 						select="backups:find-backup($backup-id)"/>		
	<xsl:variable name="backup-env" 				select="backups:find-env-info($backup)/env"/>	
	<xsl:variable name="env" 								select="env:get-env($backup/eid)/env"/>	
	<xsl:variable name="env-exists" 				select="$env and $env[status/state and status/state!=$env-state/unexist]"/>
  <xsl:variable name="backup-hn-eid"			select="$backup/storage_eid"/>

	<!-- check permissions to show this page -->
	<xsl:param name="access-denied"
		select="$env-exists and not(cred:check-env('vzcp.env.backups.list',$env/eid))"/>
	
  <xsl:template mode="screen" match="/">
  
		<xsl:variable name="env-platform" select="env:env2platform($backup-env)"/>	  

		<ui:screen id="03.02.01.13.04" title="{sw:text('Browse Backup')}" icon="browse_backup">
  	
			<xsl:variable name="path" select="vzenv-files:path('browse-backup-path','browse-backup')"/>
			<xsl:variable name="path-for-download" select="vzenv-files:path('ve-fm-path','browse-backup')"/>
			<xsl:variable name="path-prefix" select="concat('backup://',$backup-id)"/>
			
			<xsl:variable name="path-win-root" select="vzenv-files:check-win-root($path)"/>
			
			<xsl:variable name="oper-problem" select="local:check-operation()"/>
	
			<xsl:choose>
				<xsl:when test="$oper-problem!=''">
					<ui:properties/>
					<ui:content>
						<ui:block>
							<ui:operation-problem>
				    		<xsl:copy-of select="$oper-problem"/>
								<ui:descr><sw:text>Unable to list the files in this backup.</sw:text></ui:descr>
							</ui:operation-problem>
						</ui:block>
					</ui:content>
				</xsl:when>
				<xsl:otherwise>
			
			    <ui:properties>
			      <ui:no-default-form/>
			      <ui:form-get/>
			    </ui:properties>
		
		    	<ui:content>
		    
		    		<ui:block width="full">
					    <xsl:variable name="actions-rtf">
								<actions>
									<download/>
								</actions>
							</xsl:variable>
		    		
						  <xsl:call-template name="vzenv-files:browse">
								<xsl:with-param name="root-title" select="sw:text('Backup')"/>
								<xsl:with-param name="path" select="$path"/>
								<xsl:with-param name="cwd" select="$path-prefix"/>
								<xsl:with-param name="browse-session-key" select="'browse-backup'"/>
								<xsl:with-param name="browse-url" select="'/vzdir/infrman/envs/backups/browse'"/>
								<xsl:with-param name="show-actions" select="exsl:node-set($actions-rtf)"/>
								<xsl:with-param name="url-to-download" select="'/vzdir/infrman/envs/backups/browse-download'"/>
								<xsl:with-param name="backup-browser" select="true()"/>
								<xsl:with-param name="dst-eid" select="$backup/storage_eid"/>
								<xsl:with-param name="env-platform" select="$env-platform"/>
								<xsl:with-param name="browse-controls">
									<ui:browse-buttons type="list-selection">		      
						        <ui:button type="list-selection" tip="restore_files" icon="restore" 
						        	confirmation="{sw:text('Are you sure you want to restore the selected file(s)?')}" 
					          	script="if (!atLeastOne()) return false;" name="restore"
					          >
						        	<xsl:if test="not($env-exists) 
						        		or not(cred:check-env('vzcp.env.backups.restore',$env/eid))">
					          		<xsl:attribute name="disabled">true</xsl:attribute>
					          	</xsl:if>
					            <sw:text>Restore</sw:text>
						        </ui:button>		      
						      </ui:browse-buttons>        
						      <!-- form definition for other controls -->
						      <ui:form action="browse-control"/>
						  	</xsl:with-param>
							</xsl:call-template>
					  
		      	</ui:block>
		    	</ui:content>          
		    </xsl:otherwise>
	    </xsl:choose>
	    
		</ui:screen>
	</xsl:template>  

	<func:function name="local:check-operation">
		<xsl:choose>
			<xsl:when test="$env-exists">
				<func:result select="voc:check-operation('vzabackupm','list','',$backup/eid)"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="''"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

  <sw:include href="/lib/screen.xsl"/>
  <sw:include href="/lib/vocabulary.xsl"/>
  <sw:include href="/lib/vzaconfig.xsl"/>
  
  <sw:include href="/lib/vza/filem.xsl"/>  
  
  <sw:include href="/lib/vz/vzenv-files.xsl"/>  

</xsl:stylesheet>
