<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz vzenv local cred voc"
	 xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	 xmlns:exsl	="http://exslt.org/common"
	 xmlns:sw		="http://www.swsoft.com/xsl/cp"
	 xmlns:local	="http://www.swsoft.com/xsl/cp/local"
	 xmlns:error	="http://www.swsoft.com/xsl/cp/error"
	 xmlns:wiz		="http://www.swsoft.com/xsl/cp/wiz"
	 xmlns:vzenv	="http://www.swsoft.com/xsl/cp/vzenv"
	 xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
	 xmlns:func		="http://exslt.org/functions"
	 xmlns:cred		="http://www.swsoft.com/xsl/cp/cred"
	 xmlns:voc		="http://www.swsoft.com/xsl/cp/voc"
 >
  <sw:include href="/lib/vz/vzenv-net.xsl"/>
	<sw:include href="/lib/vz/vzenv-net-core.xsl"/>
	<sw:include href="/lib/vz/vzenv-net-ui.xsl"/>	
	<sw:include href="/lib/vz/vzenv-offline.xsl"/>
	<sw:include href="/lib/vz/vzenv-clone.xsl"/>

	<xsl:param		name="wiz_code"		select="'cloneve'"/>
	<xsl:variable	name="step_data"	select="wiz:getStep()"/>
	<xsl:variable	name="step"				select="$step_data/@id"/>
	<xsl:variable	name="screen-id"	select="$step_data/@screen-id"/>
	
	<xsl:variable name="form" select="sw:sesget($wiz_data)"/>
	<!-- check permissions to show this page -->
	<xsl:param name="access-denied" select="not(cred:check-context('vzcp.env.clone','ve.vz.vt'))"/>

	<!-- Reinstall Wizard, Step 'General Settings' -->
	<xsl:template name="step_gen">
		<xsl:variable name="oper-problem" select="voc:check-operation('vzarelocator','clone')"/>

	  <ui:screen id="{$screen-id}">
	  	<!-- Load some VZ data -->  	
	  	<!-- /Load some VZ data -->  	
  	
			<ui:properties>
				<ui:refresh-type>none</ui:refresh-type>
				<ui:description  mandatory="yes">
					<sw:text>
						Cloning allows you to create an exact copy of an existing Container. You should select a new name for the Container clone. You can also select a new hostname and Container ID and change the administrative password for the Container. Clicking the Customize button will allow you to set up the network settings of the Container clone.
					</sw:text>
				</ui:description>  
				<ui:form-get/>
			</ui:properties>
			
			<ui:content>
					<xsl:choose>
					<xsl:when test="$oper-problem">
							<ui:block>
								<ui:operation-problem>
									<xsl:copy-of select="$oper-problem"/>
									<ui:descr><sw:text>Unable to clone this Container.</sw:text></ui:descr>
								</ui:operation-problem>
							</ui:block>
					</xsl:when>
					<xsl:otherwise>        
		
						<ui:hidden name="step" value="gen"/>    
						<ui:block mode="edit">
		
							<ui:rows title="{sw:text('General Settings')}" separate-tables="true">
									<ui:row>
									<ui:cell-label>
										<sw:text>Name</sw:text>
									</ui:cell-label>
									<ui:cell-input id="name" maxlength="255" required="true">
										<xsl:attribute name="value"><xsl:value-of select="$form/gen/name"/></xsl:attribute>
									</ui:cell-input>
									</ui:row>
								</ui:rows>
			
								<ui:rows title="{sw:text('Network Settings')}">
									<ui:row>
									<ui:cell-label>
										<sw:text>Hostname</sw:text>
									</ui:cell-label>
									<ui:cell-input id="hostname" maxlength="256">
										<xsl:attribute name="value"><xsl:value-of select="$form/gen/hostname"/></xsl:attribute>
									</ui:cell-input>
									</ui:row>
								</ui:rows>
			
								<ui:rows title="{sw:text('New Password')}">
			
									<ui:row>
									<ui:cell colspan="2">
									<ui:text-disabled>
									<sw:text>You can enter a new password or leave the field empty to use your existing password for the cloned Container.</sw:text>
									</ui:text-disabled>
									</ui:cell>
									</ui:row>
			
									<ui:row>
									<ui:cell-label>
										<sw:text>
											Administrative password
										</sw:text>
									</ui:cell-label>
									<ui:cell-input mode-password="true" id="root_pwd" maxlength="64">
									<xsl:attribute name="value"><xsl:value-of select="$form/gen/root_pwd"/></xsl:attribute>
									</ui:cell-input>
									</ui:row>
			
									<ui:row>
										<ui:cell-label>
										<sw:text>Retype the password</sw:text>
										</ui:cell-label>
										<ui:cell-input mode-password="true" id="root_pwd_re" maxlength="64">
										<xsl:attribute name="value"><xsl:value-of select="$form/gen/root_pwd_re"/></xsl:attribute>
										</ui:cell-input>
									</ui:row>
								</ui:rows>
					
							<!-- Advanced -->
							<xsl:variable name="show_adv" select="$form/gen/show_adv"/>
					
							<ui:rows title="{sw:text('Advanced Settings')}" id="show_adv" 
								status-def="0" 
								status="{$form/gen/show_adv}" 
								closed-text="{sw:text('Click to show the advanced settings (Container ID, startup options, etc.)')}"
							>
					
							<ui:row>
								<ui:cell-check id="ask_veid" close="false">
									<xsl:if test="$form/gen/ask_veid=1">
										<xsl:attribute name="checked">true</xsl:attribute>
									</xsl:if>
									<ui:control-slave>ve_id</ui:control-slave>
								</ui:cell-check>
						
								<ui:cell open="false" close="false">
									<nobr><sw:text>Assign Container ID</sw:text>&#160;&#160;</nobr>
								</ui:cell>
								<ui:cell-input id="ve_id" maxlength="10" width="5" open="false">
									<xsl:attribute name="value"><xsl:value-of select="$form/gen/ve_id"/></xsl:attribute>
								</ui:cell-input>
							</ui:row>
					
							<ui:row>
								<ui:cell-check id="start_after_create" close="false">
									<xsl:if test="$form/gen/start_after_create=1">
										<xsl:attribute name="checked">true</xsl:attribute>
									</xsl:if>         
								</ui:cell-check>
								<ui:cell open="false">
									<sw:text>Start the Container after it has been cloned.</sw:text>
								</ui:cell>
							</ui:row>
					
							</ui:rows>
							<!-- /Advanced -->
									
							<!-- 0ffline management control -->
							<xsl:variable name="offline-warning">
								<xsl:if test="not(vzenv:are-offline-services-allowed(
									$form/net,$form/def/src-ve-net,$form/gen/offline_type,$form/gen/selected_offline_service,$form/def/all_offline_service
								))">
									<ui:row offset="1">
										<ui:cell-text cell-valign="top">
											<img src="/{$theme}/icons/alert_red.gif" width="16" height="16" border="0"/>&#160;
										</ui:cell-text>
										<ui:cell-text cell-style="border-bottom: 1px dashed #CCCCCC;" cell-width="100%">
											<sw:text>
												The Container cannot be cloned as its offline management is enabled and at least one IP address of the new Container is identical to that of the source Container.
												<br/>To be able to clone the Container, either disable its offline management or click Customize and change the IP addresses on the next step.
											</sw:text>
											<br/><br/>
										</ui:cell-text>
									</ui:row>
									<ui:row offset="1">
										<ui:cell-text>&#160;</ui:cell-text>
									</ui:row>
								</xsl:if>
							</xsl:variable>
							<xsl:copy-of select="vzenv:show-offline-selector($form,'',0,$offline-warning)"/>

							<ui:buttons>
								<xsl:call-template name="wiz:showButtons">
									<xsl:with-param name="force-show-submit" select="true()"/>	
									<xsl:with-param name="submit-title" select="sw:text('Clone')"/>
									<xsl:with-param name="submit-tip" select="'start_ve_clone'"/>
									<xsl:with-param name="next-title" select="sw:text('Customize')"/>
								</xsl:call-template>
							</ui:buttons>
						</ui:block>
		
					</xsl:otherwise>
				</xsl:choose>
			</ui:content>   
		</ui:screen>
	
	</xsl:template>

  
  <!-- Wizard, Step 'Network Interfaces' -->
  <xsl:template name="step_net">
  	<ui:screen id="{$screen-id}">
  	<!-- Load some VZ data -->
  	<!-- /Load some VZ data -->  	
    <ui:properties>
      <ui:refresh-type>none</ui:refresh-type>
      <ui:description  mandatory="yes" width="max">
        <sw:text>
					On this step you can configure the Container network interfaces.
        </sw:text>
      </ui:description>      
      <ui:form-get/>
    </ui:properties>
    
    <ui:content>
      <ui:hidden name="step" value="net"/>    
      <ui:block mode="edit">
      
				<xsl:call-template name="vzenv:edit-net">
					<xsl:with-param name="env-form" select="$form"/>
					<xsl:with-param name="options-rtf">
						<exclude-hostname/>
					</xsl:with-param>
				</xsl:call-template>
    		      
        <ui:buttons>
					<xsl:call-template name="wiz:showButtons">
						<xsl:with-param name="submit-title" select="sw:text('Clone')"/>
						<xsl:with-param name="submit-tip" select="'start_ve_clone'"/>
					</xsl:call-template>
				</ui:buttons>
     </ui:block>
    </ui:content>   
    </ui:screen>
  </xsl:template>  

		
	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
		
		<xsl:choose>
			<xsl:when test="$step = 'gen'">
				<xsl:call-template name="step_gen"/>
			</xsl:when>
			<xsl:when test="$step = 'net'">
				<xsl:call-template name="step_net"/>
			</xsl:when>			
			<xsl:otherwise>
				<xsl:call-template name="step_gen"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
		
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>		
	
</xsl:stylesheet>
