<!--
		 Copyright (c) SWsoft, 1999-2007
		 All rights reserved.
   -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred env local voc vzenv html licensem show-resource format"
exclude-result-prefixes="exsl html ui vt ve env vzenv cred local voc envm math date user summary proc check tem vzapackagem vz func jobs backups licensem show-resource format"
	xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl			="http://exslt.org/common"
	xmlns:sw				="http://www.swsoft.com/xsl/cp"
	xmlns:html			="http://www.swsoft.com/xsl/cp/html"
	xmlns:ui				="http://www.swsoft.com/xsl/cp/ui"
	xmlns:vt				="http://www.swsoft.com/xsl/cp/vt"
	xmlns:ve				="http://www.swsoft.com/xsl/cp/ve"
	xmlns:env				="http://www.swsoft.com/xsl/cp/env"
	xmlns:vzenv			="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:cred			="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local			="http://www.swsoft.com/xsl/cp/local"
	xmlns:voc				="http://www.swsoft.com/xsl/cp/voc"
	xmlns:envm	="http://www.swsoft.com/xsl/cp/envm"
	xmlns:math			="http://exslt.org/math"
	xmlns:date			="http://exslt.org/dates-and-times"
	xmlns:user			="http://www.swsoft.com/xsl/cp/user"
	xmlns:summary		="http://www.swsoft.com/xsl/cp/summary"
	xmlns:proc  		="http://www.swsoft.com/xsl/cp/proc"
	xmlns:check 		="http://www.swsoft.com/xsl/cp/check"
	xmlns:tem				="http://www.swsoft.com/xsl/cp/tem"
	xmlns:vzapackagem		="http://www.swsoft.com/xsl/cp/vzapackagem"
	xmlns:vz				="http://www.swsoft.com/xsl/cp/vz"
	xmlns:func			="http://exslt.org/functions"
	xmlns:jobs	 		="http://www.swsoft.com/xsl/cp/jobs"
	xmlns:backups		="http://www.swsoft.com/xsl/cp/backups"
	xmlns:licensem	="http://www.swsoft.com/xsl/cp/licensem"
	xmlns:show-resource ="http://www.swsoft.com/xsl/cp/show-resource"
	xmlns:format				="http://www.swsoft.com/xsl/cp/format"
>

	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/meter.xsl"/>
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/globals.xsl"/>
	<sw:include href="/lib/show-resource.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/summary.xsl"/>
	<sw:include href="/lib/proc.xsl"/>

	<sw:include href="/lib/core/user-attrs.xsl"/>
	<sw:include href="/lib/core/jobs/core.xsl"/>

	<sw:include href="/lib/vt/core.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vt/env-private.xsl"/>
	<sw:include href="/lib/vt/backups-core.xsl"/>

	<sw:include href="/lib/swa/envm.xsl"/>

	<sw:include href="/lib/vz/vzenv-qos.xsl"/>
	<sw:include href="/lib/vt/env-mem.xsl"/>	
	<sw:include href="/lib/vz/apps.xsl"/>
	<sw:include href="/lib/vz/vzenv-offline.xsl"/>
	<sw:include href="/lib/vz/vzenv-apps.xsl"/>
	<sw:include href="/lib/vt/env-quota.xsl"/>

	<sw:include href="/lib/vza/tem.xsl"/>
	<sw:include href="/lib/vza/vzapackagem.xsl"/>

	<sw:include href="/lib/utils/format-datetime.xsl"/>
	<sw:include href="/lib/utils/format-number.xsl"/>
	<sw:include href="/lib/utils/format-resusage.xsl"/>

	<xsl:variable name="eid" select="sw:ve-eid()"/>
	<xsl:param name="vzpp-allowed" select="sw:sesputstr('env-vzpp-allowed',boolean(vzenv:vzpp-service-allowed($eid)))"/>

	<xsl:variable name="env" 			select="env:get-env($eid)/env" />
	<xsl:variable name="ve-state"		select="$env/status/state"/>
	<xsl:variable name="ve-transition"	select="$env/status/transition"/>
	<xsl:variable name="ve-disabled"	select="$env/virtual_config/disabled"/>
	<xsl:variable name="ve-description"	select="sw:base64-decode($env/virtual_config/description)"/>
	<xsl:variable name="vzconfig" 		select="envm:get-vt-settings($env/parent_eid)"/>


	<xsl:variable name="is-sve" select="$env/virtual_config/veid=1"/>

	<xsl:template match="/">
		<xsl:choose>
			<xsl:when test="$eid!='' and $env and $env/status/state!=$env-state/unexist">
				<xsl:choose>
					<xsl:when test="cred:check-env('vzcp.env.view',$eid)">
						<xsl:call-template name="local:show-env"/>
					</xsl:when>
					<xsl:otherwise>
						<ui:redirect location="{concat($baseurl,'/access-denied')}"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="local:show-unexistent"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="local:show-unexistent">
		<ui:screen id="03.02.01.01.01" title="{sw:text('Unknown Container')}" icon="env">
 	    <ui:properties>
			<ui:form-get/>
 	    </ui:properties>
			<ui:content>
				<ui:block>
					<ui:operation-problem>
						<ui:type>custom</ui:type>
						<ui:descr>
							<sw:text>The requested Container was not found.</sw:text>
						</ui:descr>
						<ui:reason>
							<sw:text>The Container was removed.</sw:text>
						</ui:reason>
						<ui:reason>
							<sw:text>The Container was moved to another Hardware Node.</sw:text>
						</ui:reason>
						<ui:solution>
							<sw:text>Return to the Containers list and select another item.</sw:text>
						</ui:solution>
					</ui:operation-problem>
				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<xsl:template name="local:show-env">
		<xsl:variable name="platform" select="env:env2platform($env)"/>

		<!-- cpu -->
		<xsl:variable name="sysinfo-rtf">
			<xsl:call-template name="proc:sysinfo">
				<xsl:with-param name="eid" select="$eid"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="sysinfo" select="exsl:node-set($sysinfo-rtf)"/>
		<!-- cpu load value -->
		<xsl:variable name="cpu-load" 	select="proc:calc-cpu-load($sysinfo/system)"/>

		<!-- get all alerts -->
		<xsl:variable name="total-alerts" select="vzenv:get-all-alerts($sysinfo)"/>

		<xsl:variable name="load-avg-node" select="proc:calc-load-avg($sysinfo/system/load_avg)"/>
		<xsl:variable name="load-average"	select="$load-avg-node/value"/>
		<xsl:variable name="load-average-color"	select="$load-avg-node/alert/color"/>
		<xsl:variable name="cpu-color"	select="show-resource:get-color-by-alert($total-alerts/alerts/alert[id = 'cpuunits']/type)"/>

		<!-- uptime -->
		<xsl:variable name="uptime-node" select="proc:split-time($sysinfo/system/uptime)"/>
		<xsl:variable name="uptime" select="proc:uptime-string($uptime-node)"/>

		<!-- memory -->
		<xsl:variable name="memory"	select="env:get-memory($eid)"/>
		<xsl:variable name="memory-alert"	select="vzenv:get-memory-alert($eid,$total-alerts)"/>
		<xsl:variable name="memory-color"	select="show-resource:get-color-by-alert($memory-alert)"/>

		<!-- disk -->
		<xsl:variable name="vequota" select="env:get-quota($eid)"/>
		<xsl:variable name="disk-info-rtf">
			<xsl:for-each select="$vequota/ve_quota/diskspace">
				<resource>
					<id>diskspace</id>
					<fraction>
						<xsl:value-of select="cur div total"/>
					</fraction>
					<values>
						<cur><xsl:value-of select="cur * 1024"/></cur>
						<total><xsl:value-of select="total * 1024"/></total>
						<free>
							<xsl:choose>
								<xsl:when test="(total - cur) &gt; 0">
									<xsl:value-of select="(total - cur) * 1024"/>
								</xsl:when>
								<xsl:otherwise>0</xsl:otherwise>
							</xsl:choose>
						</free>
					</values>
				</resource>
			</xsl:for-each>
		</xsl:variable>
		<xsl:variable name="disk-info" select="exsl:node-set($disk-info-rtf)"/>
		<xsl:variable name="disk-color" select="show-resource:get-color-by-alert($total-alerts/alerts/alert[id = 'diskspace']/type)"/>

		<!-- last backup -->
		<xsl:variable name="last-backup" select="backups:find-last-for-ve($eid)"/>
		<!-- next backup -->
		<xsl:variable name="next-backup-job"	select="jobs:find-next-for-ve($eid,'vz.backup.ves')"/>

		<!-- hardware node -->
		<xsl:variable name="hn-eid" select="sw:ve-parent()"/>
		<xsl:variable name="hn" select="env:get-env($hn-eid)/env"/>

		<!-- creds -->
		<xsl:variable name="access-map-rtf">
			<xsl:call-template name="cred:access-map">
				<xsl:with-param name="creds-rtf">
					<cred id="vzcp.env.backups.backup" security-obj-type="ve.vz.vt" security-obj-id="{$eid}"/>
					<cred id="vzcp.env.migrate" security-obj-type="ve.vz.vt" security-obj-id="{$eid}"/>
					<cred id="vzcp.env.manage.properties.application" security-obj-type="ve.vz.vt" security-obj-id="{$eid}"/>
					<cred id="vzcp.env.manage.properties.preferences" security-obj-type="ve.vz.vt" security-obj-id="{$eid}"/>
					<cred id="vzcp.env.manage.resources" security-obj-type="ve.vz.vt" security-obj-id="{$eid}"/>
					<cred id="vzcp.log.list" security-obj-type="ve.vz.vt" security-obj-id="{$eid}"/>
					<cred id="vzcp.hn.view" security-obj-type="hn.vz.vt"/>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="access-map" select="exsl:node-set($access-map-rtf)/cred"/>

		<xsl:variable name="cr-migrate"
			select="cred:match-access($access-map,'vzcp.env.migrate','ve.vz.vt',$eid)"/>
		<xsl:variable name="cr-hn-view" select="cred:match-access($access-map,'vzcp.hn.view','hn.vz.vt')"/>
		<xsl:variable name="cr-backup"
			select="cred:match-access($access-map,'vzcp.env.backups.backup','ve.vz.vt',$eid)"/>
		<xsl:variable name="cr-applications"
			select="cred:match-access($access-map,'vzcp.env.manage.properties.application','ve.vz.vt',$eid)"/>
		<xsl:variable name="cr-configure"
			select="cred:match-access($access-map,'vzcp.env.manage.properties.preferences','ve.vz.vt',$eid)"/>
		<xsl:variable name="cr-network" select="$cr-configure"/>
		<xsl:variable name="cr-qos" select="$cr-configure"/>
		<xsl:variable name="cr-log"
			select="cred:match-access($access-map,'vzcp.log.list','ve.vz.vt',$eid)"/>

		<!-- sample -->
		<xsl:variable name="origin-sample" select="$env/virtual_config/origin_sample"/>
		<xsl:variable name="has-updates" select="vz:has-ve-updates($eid)"/>

		<ui:screen id="03.02.01.01.01" icon="env">
			<ui:properties>
				<ui:form-get/>
			</ui:properties>
			<ui:tab-bar id="vzve" current-tab="summary"/>
			<ui:content>
				<ui:block>
					<ui:summary-cols>
						<ui:summary-col>
							<ui:summary-block title="{sw:text('Container Status')}">
								<ui:summary-generic>
									<item label="{sw:text('Status')}" id="ve_summary_status" icon="{$ve:state[vza-value=$ve-state]/icon}">
										<value>
											<xsl:choose>
												<!-- VE in transition -->
												<xsl:when test="string($ve-transition) != ''">
													<sw:text select="sw:title(name($env-trans/*[.=$ve-transition]))" domain="vzagent-vocabulary"/>
												</xsl:when>

												<!-- VE in persisten state -->
												<xsl:otherwise>
													<xsl:value-of select="ve:state2info($ve-state)/text-capitalized"/>
												</xsl:otherwise>
											</xsl:choose>
											<span id="ve_summary_status_disabled">
											<xsl:if test="$ve-disabled = 1">
												(<sw:text>Disabled</sw:text>)
											</xsl:if>
											</span>
										</value>
									</item>
									<!-- resource alert -->
									<item icon-id="ve_summary_alert" label="{sw:text('Resource Alerts')}">
										<xsl:choose>
											<xsl:when test="$total-alerts/alerts/alert">
												<xsl:attribute name="icon">
													<xsl:choose>
														<xsl:when test="$total-alerts/alerts/alert/type = 3">red</xsl:when>
														<xsl:when test="$total-alerts/alerts/alert/type = 2">red</xsl:when>
														<xsl:when test="$total-alerts/alerts/alert/type = 1">yellow</xsl:when>
														<xsl:otherwise>green</xsl:otherwise>
													</xsl:choose>
												</xsl:attribute>
												<value>
													<xsl:if test="$cr-log">
														<a href="{$baseurl}/core/alerts"><sw:text>Show</sw:text></a>
													</xsl:if>
													<input id="current-summary-type" type="hidden" value="ve_summary"/>
												</value>
											</xsl:when>
											<xsl:otherwise>
												<xsl:attribute name="icon">green</xsl:attribute>
												<value>
													<sw:text>No Alerts</sw:text>
													<input id="current-summary-type" type="hidden" value="ve_summary"/>
												</value>
											</xsl:otherwise>
										</xsl:choose>
									</item>
									<!--  Software update -->
									<item id="ve_summary_software_icon-text" label="{sw:text('Software Status')}">
										<xsl:choose>
											<xsl:when test="$has-updates">
												<xsl:attribute name="icon">yellow</xsl:attribute>
												<value>
													<a href="{$baseurl}/vzdir/infrman/envs/upgrade"><sw:text>Update Software</sw:text></a>
												</value>
											</xsl:when>
											<xsl:otherwise>
												<xsl:attribute name="icon">green</xsl:attribute>
												<value>
													<sw:text>Up-to-date</sw:text>
												</value>
											</xsl:otherwise>
										</xsl:choose>
									</item>
									<xsl:if test="$cr-hn-view">
										<item label="{sw:text('Hardware Node')}" icon="green">
											<value>
												<span id="ve_summary_hn-link_icon-text">
													<a href="{$baseurl}/vzdir/infrman/hns/hn?id={sw:base64-encode($hn-eid)}"><xsl:value-of select="$hn/config/name"/></a>
												</span>
											</value>
											<xsl:if test="$cr-migrate and $env/virtual_config/veid!=1">
												<action-link href="{$baseurl}/vzdir/infrman/envs/list-migrate?env-src=context"><sw:text>Migrate</sw:text></action-link>
											</xsl:if>
										</item>
									</xsl:if>
									<xsl:if test="vt:is-platform-linux($platform)">
										<item id="ve_summary_average_icon-text" label="{sw:text('Load Avg')}" icon="{$load-average-color}">
											<value>
												<xsl:value-of select="$load-average"/>
											</value>
										</item>
									</xsl:if>
									<!-- backups -->
									<xsl:if test="$cr-backup">
										<item id="ve_summary_last-backup_icon-text" label="{sw:text('Last Backup')}">
											<xsl:choose>
												<xsl:when test="$last-backup/count &gt; 0">
													<xsl:attribute name="icon">green</xsl:attribute>
													<value>
														<sw:text>
															<xsl:with-param name="last-date" select="format:date-date(sw:vzatime2utime($last-backup/time))"/>
															<xsl:with-param name="last-size" select="format:int2bytes($last-backup/size)"/>
																%{last-date} (%{last-size})
														</sw:text>
													</value>
												</xsl:when>
												<xsl:otherwise>
													<xsl:attribute name="icon">yellow</xsl:attribute>
													<value>
														<sw:text>No backup</sw:text>
													</value>
												</xsl:otherwise>
											</xsl:choose>
											<action-link href="{$baseurl}/vt/backups/new?env-set=current">
												<xsl:if test="voc:check-operation('vzabackupm','backup_env')!=''">
													<xsl:attribute name="disabled">true</xsl:attribute>
												</xsl:if>
												<sw:text>Back Up</sw:text>
											</action-link>
										</item>

										<!-- next sceduled backup -->
										<item id="ve_summary_next-backup_icon-text" label="{sw:text('Next Backup')}">
											<xsl:choose>
												<xsl:when test="$next-backup-job">
													<xsl:attribute name="icon">green</xsl:attribute>
													<value>
														<xsl:value-of select="format:date-time(sw:vzatime2utime(sw:time2vzatime($next-backup-job/next-start)))"/>
													</value>
												</xsl:when>
												<xsl:otherwise>
													<xsl:attribute name="icon">yellow</xsl:attribute>
													<value>
														<sw:text>No backup scheduled</sw:text>
													</value>
												</xsl:otherwise>
											</xsl:choose>
											<action-link href="{$baseurl}/core/jobs/manage?mode=new&amp;unit-type=vz.backup.ves&amp;envs={$eid}">
												<xsl:if test="not(cred:check('vzcp.full_control'))">
													<xsl:attribute name="disabled">true</xsl:attribute>
												</xsl:if>
												<sw:text>Schedule Backup</sw:text>
											</action-link>
										</item>
									</xsl:if>

									<item label="{sw:text('Uptime')}">
										<value>
											<xsl:value-of select="$uptime"/>
											<xsl:if test="string($uptime) =''">
												<ui:text-disabled><sw:text>n/a</sw:text></ui:text-disabled>
											</xsl:if>
										</value>
									</item>
								</ui:summary-generic>
							</ui:summary-block>

							<ui:summary-block title="{sw:text('Container Configuration')}">
								<ui:summary-generic>
									<item id="ve_summary_name_text" label="{sw:text('Name')}">
										<value>
											<xsl:value-of select="$env/virtual_config/name"/>
										</value>
										<xsl:if test="$cr-configure">
											<action-link href="{$baseurl}/vzdir/infrman/envs/manage?tab=gen"><sw:text>Change</sw:text></action-link>
										</xsl:if>
									</item>
									<xsl:if test="not($ve-description = '')">
										<item id="ve_summary_description_text" label="{sw:text('Description')}">
											<value>
												<xsl:value-of select="$ve-description"/>
											</value>
										</item>
									</xsl:if>
									<item id="ve_summary_id_text" label="{sw:text('Container ID')}">
										<value>
											<xsl:value-of select="$env/virtual_config/veid"/>
										</value>
									</item>

									<!-- OS version -->
									<item id="ve_summary_os_text" label="{sw:text('OS')}">
										<value>
											<xsl:call-template name="vzenv:view-apps-simple">
												<xsl:with-param name="env" select="$env"/>
												<xsl:with-param name="is-os" select="true()"/>
											</xsl:call-template>
										</value>
										<xsl:variable name="need-link"
											select="$cr-applications
												and (sw:is-ez-package($env/virtual_config/os_template/name) or $has-updates)"/>

										<xsl:if test="$need-link">
											<action-link href="{$baseurl}/vzdir/infrman/envs/upgrade">
												<sw:text>Update</sw:text>
											</action-link>
										</xsl:if>
									</item>

									<item id="ve_summary_applications_text" label="{sw:text('Applications')}">
										<value>
											<xsl:call-template name="vzenv:view-apps-simple">
												<xsl:with-param name="env" select="$env"/>
											</xsl:call-template>
										</value>
										<xsl:if test="$cr-applications">
											<action-link href="{$baseurl}/vzdir/infrman/envs/apps"><sw:text>Add/Remove</sw:text></action-link>
										</xsl:if>
									</item>
									<item id="ve_summary_sample_text" label="{sw:text('Container Sample')}">
										<value>
											<xsl:choose>
												<xsl:when test="$origin-sample!=''">
													<xsl:value-of select="$origin-sample"/>
												</xsl:when>
												<xsl:otherwise>
													<span class="inactive">
														<sw:text>n/a</sw:text>
													</span>
												</xsl:otherwise>
											</xsl:choose>
										</value>
										<xsl:if test="$cr-qos">
											<action-link href="{$baseurl}/vzdir/infrman/envs/manage?tab=apply"><sw:text>Change</sw:text></action-link>
										</xsl:if>
									</item>
									<!-- HN in cluster -->
									<xsl:if test="$vzconfig/parameter[id='in_cluster']/value='yes'">
										<item id="ve_summary_cluster" label="{sw:text('Cluster Status')}">
											<value>
												<xsl:value-of select="sw:if($env/virtual_config/capability[id='not_cluster_managed']/value='1',sw:text('Independent'),sw:text('Managed'))"/>
											</value>
										</item>
									</xsl:if>
								</ui:summary-generic>
							</ui:summary-block>
							<ui:summary-block title="{sw:text('Container Network Configuration')}">
								<ui:summary-generic>
									<item id="ve_summary_host_text" label="{sw:text('Hostname')}">
										<value>
											<xsl:value-of select="$env/virtual_config/hostname"/>
										</value>
										<xsl:if test="$cr-network">
											<action-link href="{$baseurl}/vzdir/infrman/envs/manage?tab=net"><sw:text>Configure</sw:text></action-link>
										</xsl:if>
									</item>
									<xsl:for-each select="$env/virtual_config/net_device[
										not(host_routed) or ip_address
									]">
										<item label="{id}" id="ve_summary_ip-address_{id}_text" lines="{sw:if(count(ip_address/ip) &gt; 0, count(ip_address/ip), '1')}">
											<value>
												<xsl:for-each select="ip_address/ip">
													<xsl:value-of select="string(.)"/>
													<xsl:if test="position() != last()">
														<br/>
													</xsl:if>
												</xsl:for-each>
												<xsl:if test="count(ip_address/ip) = 0">
													<sw:text>No IP address</sw:text>
												</xsl:if>
											</value>
										</item>
									</xsl:for-each>
									</ui:summary-generic>
							</ui:summary-block>
						</ui:summary-col>
						<ui:summary-col>
							<ui:summary-block title="{sw:text('Tasks')}">
								<ui:summary-tasks/>
							</ui:summary-block>
							<xsl:if test="cred:match-access($access-map,'vzcp.env.manage.properties.preferences','ve.vz.vt',$eid)">
								<ui:summary-block title="{sw:text('Container Resources')}">
									<ui:table>
										<col-header align="left"><sw:text>Resource</sw:text></col-header>
										<col-header align="center"><sw:text>Used</sw:text></col-header>
										<col-header align="right"><sw:text>Free</sw:text></col-header>
										<col-header align="right"><sw:text>Total</sw:text></col-header>
										<row>
											<col icon="{$cpu-color}"><a href="{$baseurl}/vzdir/infrman/envs/resources-adv?tab=cpu&amp;tab-force=default"><sw:text>CPU</sw:text></a></col>
											<col>
												<xsl:variable name="tip" select="show-resource:get-tips-by-alert('cpu',$total-alerts/alerts/alert[id = 'cpuunits']/type)"/>
												<ui:meter-block before="" after="{format:percent($cpu-load)}" fraction="{$cpu-load}" tip="{$tip}"/>
											</col>
											<col>&#160;</col>
											<col>&#160;</col>
										</row>
										<row>
											<col icon="{$memory-color}"><a href="{$baseurl}/vzdir/infrman/envs/resources-adv?tab=memory&amp;tab-force=default"><sw:text>Memory</sw:text></a></col>
											<col>
												<xsl:variable name="tip" select="show-resource:get-tips-by-alert('memory',show-resource:normalize-alert-type($memory-alert,$memory))"/>
												<ui:meter-block before="{format:int2bytes($memory/used,'', 'yes', '#,##0.#')}" after="{format:percent($memory/fraction)}" fraction="{$memory/fraction}" 	tip="{$tip}"/>
											</col>
											<col><xsl:value-of select="format:int2bytes($memory/free,'', 'yes', '#,##0.#')"/></col>
											<col><xsl:value-of select="format:int2bytes($memory/total,'', 'yes', '#,##0.#')"/></col>
										</row>
										<row>
											<col icon="{$disk-color}"><a href="{$baseurl}/vzdir/infrman/envs/resources-adv?tab=disk&amp;tab-force=default"><sw:text>Disk</sw:text></a></col>
											<col>
												<xsl:variable name="tip" select="show-resource:get-tips-by-alert('diskspace',show-resource:normalize-alert-type($total-alerts/alerts/alert[id = 'diskspace']/type,1))"/>
												<ui:meter-block before="{format:int2bytes($disk-info/resource/values/cur,'', 'yes', '#,##0.#')}" after="{format:percent($disk-info/resource/fraction)}" fraction="{$disk-info/resource/fraction}" tip="{$tip}"/>
											</col>
											<col><xsl:value-of select="format:int2bytes($disk-info/resource/values/free,'', 'yes', '#,##0.#')"/></col>
											<col><xsl:value-of select="format:int2bytes($disk-info/resource/values/total,'', 'yes', '#,##0.#')"/></col>
										</row>
									</ui:table>
								</ui:summary-block>
							</xsl:if>
						</ui:summary-col>
					</ui:summary-cols>
				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>

</xsl:stylesheet>
