<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl cred voc vzenv-files"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:env		="http://www.swsoft.com/xsl/cp/env"	
	xmlns:vzenv-files="http://www.swsoft.com/xsl/cp/vzenv-files"
	xmlns:voc="http://www.swsoft.com/xsl/cp/voc"
>
	<sw:include href="/lib/vt/env-core.xsl"/>

	<xsl:variable name="eid" select="sw:ve-eid()"/>

	<!-- check permissions to show this page -->
	<xsl:variable name="cr-copy" select="cred:check-env('vzcp.env.manage.services_and_files',$eid)"/>
	<xsl:variable name="cr-move" select="$cr-copy"/>
	<xsl:variable name="cr-remove" select="$cr-copy"/>
	<xsl:param name="access-denied" select="not($cr-copy)"/>

	<xsl:template mode="screen" match="/">

		<ui:screen id="03.02.01.12.01">
			<xsl:variable name="env-platform" select="env:eid2info($eid)/platform"/>
			<xsl:variable name="path" select="vzenv-files:path('ve-fm-path','vefiles')"/>

			<xsl:variable name="path-win-root" select="vzenv-files:check-win-root($path,$env-platform)"/>

			<xsl:variable name="oper-problem" select="voc:check-operation('filer')"/>
			<xsl:choose>
				<xsl:when test="$oper-problem!=''">
					<ui:properties>
						<ui:description mandatory="yes" width="full">
							<sw:text>
								When the Container is running, on this screen you can navigate inside its directory structure and perform all essential file operations.
							</sw:text>
						</ui:description>
					</ui:properties>
					<ui:content>
						<ui:block>
							<ui:operation-problem>
								<xsl:copy-of select="$oper-problem"/>
								<ui:descr>
									<sw:text>Unable to list the files in this Container.</sw:text>
								</ui:descr>
							</ui:operation-problem>
						</ui:block>
					</ui:content>
				</xsl:when>
				<xsl:otherwise>

					<ui:properties>
						<ui:description mandatory="yes" width="full">
							<sw:text>
								On this screen you can navigate inside the directory structure of the Container and perform all essential file operations.
							</sw:text>
						</ui:description>
						<ui:form-get/>
						<ui:no-default-form/>
					</ui:properties>

					<ui:content>

						<ui:block width="full">
							<xsl:variable name="actions-rtf">
								<actions>
									<props/>
									<download/>
									<edit/>
								</actions>
							</xsl:variable>
							<xsl:call-template name="vzenv-files:browse">
								<xsl:with-param name="dst-eid" select="$eid"/>
								<xsl:with-param name="env-platform" select="$env-platform"/>
								<xsl:with-param name="path" select="$path"/>
								<xsl:with-param name="browse-session-key" select="'vefiles'"/>
								<xsl:with-param name="browse-url" select="'/vzdir/infrman/envs/files/index'"/>
								<xsl:with-param name="show-actions" select="exsl:node-set($actions-rtf)"/>
								<xsl:with-param name="browse-controls">

									<xsl:if test="$cr-copy or $cr-move or $cr-remove">
										<ui:browse-buttons type="list-selection">
											<ui:button cred="vzcp.env.manage.services_and_files"
												security-obj-type="ve.vz.vt"
												submit-href="create-file" 
												new-obj-title="{sw:text('File')}"
												sandclock="false" 
												auxiliary="true"												
												tip="create_file" 
												icon="file_new"
											>
												<xsl:if test="$path-win-root">
													<xsl:attribute name="disabled">true</xsl:attribute>
												</xsl:if>
												<sw:text>Create File</sw:text>
											</ui:button>
											<ui:button cred="vzcp.env.manage.services_and_files"
												security-obj-type="ve.vz.vt"
												submit-href="upload"
												sandclock="false" 
												tip="upload_files" 
												auxiliary="true"
												icon="file_upload"													
											>
												<xsl:if test="$path-win-root">
													<xsl:attribute name="disabled">true</xsl:attribute>
												</xsl:if>
												<sw:text>Upload Files</sw:text>
											</ui:button>											
											<ui:button cred="vzcp.env.manage.services_and_files"
												security-obj-type="ve.vz.vt"
												new-obj-title="{sw:text('Folder')}"											
												submit-href="create-folder" 
												sandclock="false" 
												tip="create_folder" 
												auxiliary="true"
												icon="folder_new"												
											>
												<xsl:if test="$path-win-root">
													<xsl:attribute name="disabled">true</xsl:attribute>
												</xsl:if>
												<sw:text>Create Folder</sw:text>
											</ui:button>											
											<xsl:if test="$cr-copy">
												<ui:button type="list-selection" tip="copy_files" 
													submit-href="copy" 
													cred="vzcp.env.manage.services_and_files"
													security-obj-type="ve.vz.vt"
													script="if (!atLeastOne()) return false;" 
													auxiliary="true"
													icon="file_copy"													
												>
													<xsl:if test="$path-win-root">
														<xsl:attribute name="disabled">true</xsl:attribute>
													</xsl:if>
													<sw:text>Copy</sw:text>
												</ui:button>
											</xsl:if>

											<xsl:if test="$cr-move">
												<ui:button type="list-selection" tip="move_files" 
													submit-href="move" 
													cred="vzcp.env.manage.services_and_files"
													security-obj-type="ve.vz.vt"
													script="if (!atLeastOne()) return false;" 
													name="move" 
													auxiliary="true"													
													icon="file_move"													
												>
													<xsl:if test="$path-win-root">
														<xsl:attribute name="disabled">true</xsl:attribute>
													</xsl:if>
													<sw:text>Move</sw:text>
												</ui:button>
											</xsl:if>

											<xsl:if test="$cr-remove">
												<ui:button type="list-selection" tip="delete_files" 
													confirmation="{sw:text('Are you sure you want to delete the selected file(s)?')}"
													cred="vzcp.env.manage.services_and_files" security-obj-type="ve.vz.vt" script="if (!atLeastOne()) return false;"
													name="delete" 
													auxiliary="true"
													icon="delete"												
												>
													<xsl:if test="$path-win-root">
														<xsl:attribute name="disabled">true</xsl:attribute>
													</xsl:if>
													<sw:text>Remove</sw:text>
												</ui:button>
											</xsl:if>
										</ui:browse-buttons>
									</xsl:if>

									<!-- form definition for other controls -->
									<ui:form action="list-control"/>
								</xsl:with-param>
							</xsl:call-template>

						</ui:block>
					</ui:content>
				</xsl:otherwise>
			</xsl:choose>

		</ui:screen>
	</xsl:template>

	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>

	<sw:include href="/lib/vza/filem.xsl"/>

	<sw:include href="/lib/vz/vzenv-files.xsl"/>

</xsl:stylesheet>
