<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl date func wiz vzenv local cred voc show file format"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:local="http://www.swsoft.com/xsl/cp/local"
  xmlns:error="http://www.swsoft.com/xsl/cp/error"
  xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
  xmlns:vzenv="http://www.swsoft.com/xsl/cp/vzenv"
  xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
  xmlns:func="http://exslt.org/functions"
  xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
  xmlns:voc		="http://www.swsoft.com/xsl/cp/voc"
  xmlns:show	="http://www.swsoft.com/xsl/cp/show"
  xmlns:date    ="http://exslt.org/dates-and-times"
  xmlns:file="http://www.swsoft.com/xsl/cp/file"
  xmlns:format="http://www.swsoft.com/xsl/cp/format"
>

	<sw:include href="/lib/utils/file.xsl"/>
	<sw:include href="/lib/utils/format-datetime.xsl"/>
	<sw:include href="/lib/utils/format-resusage.xsl"/>

	 <xsl:param 	name="wiz_code"		select="'ve-props'"/>
	<xsl:variable	name="step_data"	select="wiz:getStep()"/>
	<xsl:variable	name="step"			select="$step_data/@id"/>
	<xsl:variable	name="step-cred"	select="$step_data/@cred"/>
	<xsl:variable	name="screenid"		select="$step_data/@screenid"/>
	<xsl:variable	name="screen-title"	select="sw:text('Change Properties')"/>
	<xsl:variable	name="screen-icon"	select="'fm_props'"/>
	<xsl:variable	name="path-id"		select="string(wiz:getSteps()/step[1]/@screenid)"/>
	
  <xsl:variable name="form" select="sw:sesget($wiz_data)"/>
  <!-- check permissions to show this page -->
	<xsl:param name="access-denied" select="$step-cred!='' and  not(cred:check-context($step-cred,$step_data/@security-obj-type))"/>

  <!-- Reinstall Wizard, Step 'General Settings' -->
  <xsl:template name="step_gen">
  	<ui:screen path-id="{$path-id}" id="{$screenid}" title="{$screen-title}" icon="{$screen-icon}">
  	
  	<xsl:variable name="new" select="$form/gen/file"/>
  	<xsl:variable name="old" select="$form/file"/>
  	
    <ui:properties>
    	<ui:form-get/>
      <ui:refresh-type>none</ui:refresh-type>
      <ui:description  mandatory="yes">
        <sw:text>
        	<xsl:with-param name="name" select="$old/name"/>
        	On this screen you can change the properties of <b>%{name}</b>
        </sw:text>
      </ui:description>  
    </ui:properties>
    
	    <ui:content>
	      <xsl:copy-of select="wiz:post-form-step($form,'gen')"/>
	      <ui:block mode="edit">

 					<xsl:variable name="mode" select="$new/mode"/>
 					
 					<ui:rows title="{sw:text('General Information')}">
 						<ui:row>
 							<ui:cell-label><sw:text>Name</sw:text></ui:cell-label>
 							<ui:cell-input maxlength="255" width="40" id="name" value="{$new/name}" required="true"/>
 						</ui:row>
 						<ui:row>
 							<ui:cell-label><sw:text>Path</sw:text></ui:cell-label>
 							<ui:cell-value><xsl:value-of select="file:path4screen($form/fm-path)"/></ui:cell-value>
 						</ui:row>
 						<xsl:choose>
 							<!-- Show folder -->
 							<xsl:when test="$old/type='4'">
								<ui:row>
									<ui:cell-label><sw:text>Size</sw:text></ui:cell-label>
									<ui:cell-value>
										<a href="#" onclick="initSize()"><img id="img_size" width="16" border="0" height="16" src="/{$theme}/icons/refresh_16.gif"/></a>&#160;
										<span id="div_size">
											<a href="#" onclick="initSize()"><sw:text>Click to calculate</sw:text></a>
										</span>
										<script>
											function initSize(){
												document.getElementById('img_size').src='/<xsl:value-of select="$theme"/>/icons/indicator.gif';
												document.getElementById('div_size').innerHTML = 'Calculating...';
												requestContent(
													'/vz/cp/vzdir/infrman/envs/files/props-dynamic?func=size&amp;path=<xsl:value-of select="sw:base64-encode($form/fm-path)"/>&amp;name=<xsl:value-of select="sw:base64-encode($old/name)"/>'
													,receiveSize
													,'<xsl:value-of select="$ticket"/>','<xsl:value-of select="$ticketid"/>');
											}
											function receiveSize(req){
												var content = req.readyState==4?req.responseText:'';
												if(content!=''){
													document.getElementById('img_size').src="/<xsl:value-of select="$theme"/>/icons/refresh_16.gif";
													var div_size = document.getElementById('div_size');
													var content_nodes = content.split('|'); 
													div_size.innerHTML = content_nodes[1];
												}
											}
										</script>									
									</ui:cell-value>
								</ui:row>
							</xsl:when>
							<xsl:otherwise>
								<ui:row>
									<ui:cell-label><sw:text>Size</sw:text></ui:cell-label>
									<ui:cell-value>
										<xsl:value-of select="format:bytes2str($old/size,true(),'',false())"/>
										&#160;(<xsl:value-of select="format:bytes2str($old/size,true(),'bytes',true())"/>)
									</ui:cell-value>
								</ui:row>
							</xsl:otherwise>
						</xsl:choose>
 						<ui:row>
 							<ui:cell-label><sw:text>Modified</sw:text></ui:cell-label>
 							<ui:cell-value><xsl:value-of select="format:date-time(date:seconds(sw:vzatime2time($old/date)))"/></ui:cell-value>
 						</ui:row>
 						<xsl:if test="$old/file/link_name!=''">
 							<ui:row>
	 							<ui:cell-label><sw:text>Link to</sw:text></ui:cell-label>
	 							<ui:cell-value><xsl:value-of select="sw:base64-decode($old/file/link_name)"/></ui:cell-value>
	 						</ui:row>
 						</xsl:if>
 					</ui:rows>
 					 					
					<xsl:if test="$form/linux">
	 					<ui:hidden name="mode" value="{$mode/src}"/>  
	 					
	 					<xsl:variable name="rows-title">
	 						<sw:text>
	 							<xsl:with-param name="file" select="$old/name"/>
	 							File '%{file}'
	 						</sw:text>
	 					</xsl:variable>
	 					<ui:rows title="{sw:text('Permissions')}">
							<ui:row type="head">
		   					<ui:cell-label/>
		   					<ui:cell><sw:text>Read</sw:text></ui:cell>
		   					<ui:cell><sw:text>Write</sw:text></ui:cell>
		   					<ui:cell><sw:text>Execute</sw:text></ui:cell>
							</ui:row>
							<ui:row>
								<ui:cell-label><sw:text>Owner</sw:text></ui:cell-label>
		   					<ui:cell-check id="owner_read">
			   					<xsl:if test="$mode/owner/read=1">
	                  <xsl:attribute name="checked">true</xsl:attribute>
	                </xsl:if> 
	              </ui:cell-check>
	              <ui:cell-check id="owner_write">
			   					<xsl:if test="$mode/owner/write=1">
	                  <xsl:attribute name="checked">true</xsl:attribute>
	                </xsl:if> 
	              </ui:cell-check>
	              <ui:cell-check id="owner_exec">
			   					<xsl:if test="$mode/owner/exec=1">
	                  <xsl:attribute name="checked">true</xsl:attribute>
	                </xsl:if> 
	              </ui:cell-check>
							</ui:row>
							<ui:row>
								<ui:cell-label><sw:text>Group</sw:text></ui:cell-label>
		   					<ui:cell-check id="group_read">
			   					<xsl:if test="$mode/group/read=1">
	                  <xsl:attribute name="checked">true</xsl:attribute>
	                </xsl:if> 
	              </ui:cell-check>
	              <ui:cell-check id="group_write">
			   					<xsl:if test="$mode/group/write=1">
	                  <xsl:attribute name="checked">true</xsl:attribute>
	                </xsl:if> 
	              </ui:cell-check>
	              <ui:cell-check id="group_exec">
			   					<xsl:if test="$mode/group/exec=1">
	                  <xsl:attribute name="checked">true</xsl:attribute>
	                </xsl:if> 
	              </ui:cell-check>
							</ui:row>
							<ui:row>
								<ui:cell-label><sw:text>Others</sw:text></ui:cell-label>
		   					<ui:cell-check id="others_read">
			   					<xsl:if test="$mode/others/read=1">
	                  <xsl:attribute name="checked">true</xsl:attribute>
	                </xsl:if> 
	              </ui:cell-check>
	              <ui:cell-check id="others_write">
			   					<xsl:if test="$mode/others/write=1">
	                  <xsl:attribute name="checked">true</xsl:attribute>
	                </xsl:if> 
	              </ui:cell-check>
	              <ui:cell-check id="others_exec">
			   					<xsl:if test="$mode/others/exec=1">
	                  <xsl:attribute name="checked">true</xsl:attribute>
	                </xsl:if> 
	              </ui:cell-check>
							</ui:row>
						</ui:rows>
	
						<ui:rows title="{sw:text('Ownership')}">
							<xsl:variable name="users" select="local:get-users()"/>
							<xsl:variable name="groups" select="local:get-groups()"/>
							
							<sw:die test="$users[error|userm/error]">
								Can`t fetch users. <xsl:value-of select="$users/error/message|$users/userm/error/message"/>	
							</sw:die>
							<sw:die test="$groups[error|userm/error]">
								Can`t fetch groups. <xsl:value-of select="$groups/error/message|$groups/userm/error/message"/>	
							</sw:die>
												
							<ui:row>
								<ui:cell-label>User</ui:cell-label>
								<ui:cell-list id="uid" value="{$form/gen/file/uid}">
									<xsl:for-each select="$users/userm/user">
										<xsl:sort select="name"/>
										<ui:list-item id="{uid}" title="{name}"/>
									</xsl:for-each>
								</ui:cell-list>
							</ui:row>
							
							<ui:row>
								<ui:cell-label>Group</ui:cell-label>
								<ui:cell-list id="gid" value="{$form/gen/file/gid}">
									<xsl:for-each select="$groups/userm/group">
										<xsl:sort select="name"/>
										<ui:list-item id="{gid}" title="{name}"/>
									</xsl:for-each>
								</ui:cell-list>
							</ui:row>
							
						</ui:rows>
	
					</xsl:if>
					
	        <ui:buttons>
	          <xsl:call-template name="wiz:showButtons">
	          	<xsl:with-param name="submit-title" select="sw:text('Submit')"/>
	          	<xsl:with-param name="submit-tip" select="'submit_props_files'"/>
	          </xsl:call-template>
	        </ui:buttons>
	        
	     	</ui:block>
	    </ui:content>   
    </ui:screen>
  </xsl:template>
  
  <func:function name="local:get-users">
		<xsl:variable name="req">
			<packet>
				<target>userm</target>
				<xsl:copy-of select="sw:env-dst(sw:ve-eid())"/>
				<data>
					<userm>
						<get_user/>							
					</userm>
				</data>
			</packet>
		</xsl:variable>
		<func:result select="sw:xchg($req)/packet/data"/>
	</func:function>
	
	<func:function name="local:get-groups">
		<xsl:variable name="req">
			<packet>
				<target>userm</target>
				<xsl:copy-of select="sw:env-dst(sw:ve-eid())"/>
				<data>
					<userm>
						<get_group/>
					</userm>
				</data>
			</packet>
		</xsl:variable>
		<func:result select="sw:xchg($req)/packet/data"/>
	</func:function>
 
	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
	
			<xsl:choose>
				<xsl:when test="/ui:redirect">
					<xsl:copy-of select="/"/>					
				</xsl:when>
				<xsl:when test="$step = 'gen'">
					<xsl:call-template name="step_gen"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="step_gen"/>
				</xsl:otherwise>
				
			</xsl:choose>
		
	</xsl:template>
	
	
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>
	
	<sw:include href="/lib/vocabulary.xsl"/>		
	
</xsl:stylesheet>
