<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz vzenv local cred voc form file"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:local="http://www.swsoft.com/xsl/cp/local"
  xmlns:error="http://www.swsoft.com/xsl/cp/error"
  xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
  xmlns:vzenv="http://www.swsoft.com/xsl/cp/vzenv"
  xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
  xmlns:func="http://exslt.org/functions"
  xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
  xmlns:voc		="http://www.swsoft.com/xsl/cp/voc"
  xmlns:form	="http://www.swsoft.com/xsl/cp/form"
  xmlns:file="http://www.swsoft.com/xsl/cp/file"
>

	<sw:include href="/lib/utils/file.xsl"/>

	<xsl:param 		name="wiz_code"		select="'fm_upload'"/>
	<xsl:variable	name="step_data"	select="wiz:getStep()"/>
	<xsl:variable	name="step"			select="$step_data/@id"/>
	<xsl:variable	name="step-cred"	select="$step_data/@cred"/>
	<xsl:variable	name="screenid"		select="$step_data/@screenid"/>
	<xsl:variable	name="screen-title"	select="sw:text('Upload Files')"/>
	<xsl:variable	name="screen-icon"	select="'file_upload'"/>
	<xsl:variable	name="path-id"		select="string(wiz:getSteps()/step[1]/@screenid)"/>

	<xsl:variable	name="max-fields"	select="20"/>
	
	<xsl:variable name="form" select="sw:sesget($wiz_data)"/>
	<!-- check permissions to show this page -->
	<xsl:param name="access-denied" select="$step-cred!='' and  not(cred:check-context($step-cred,$step_data/@security-obj-type))"/>

	<!-- Reinstall Wizard, Step 'General Settings' -->
	<xsl:template name="step_gen">
  	<ui:screen path-id="{$path-id}" id="{$screenid}" title="{$screen-title}" icon="{$screen-icon}">
  	
  	<!-- Load some VZ data -->  	
  	<!-- /Load some VZ data -->  	
  	
    <ui:properties>
      <ui:refresh-type>none</ui:refresh-type>  
      <ui:form-post/>
      <ui:description  mandatory="yes">
        <sw:text>
        	<xsl:with-param name="path" select="file:path4screen($form/fm-path)"/>
        	Upload the new files to <b>%{path}</b>
        </sw:text>
      </ui:description>        
    </ui:properties>

    
	    <ui:content>
	      <xsl:copy-of select="wiz:post-form-step($form,'gen')"/> 
	      <ui:block mode="edit">

				<ui:rows title="{sw:text('Specify File')}" separate-tables="true">
					<xsl:copy-of select="local:add-cells(1)"/>
				</ui:rows>
	
	        <ui:buttons>
	          <xsl:call-template name="wiz:showButtons">
	          	<xsl:with-param name="submit-title" select="sw:text('Upload')"/>
	          	<xsl:with-param name="submit-script">
	          	var max_fields=<xsl:value-of select="$max-fields"/>+1;
	          	<![CDATA[
					for (var i=1;i<max_fields;i++)
					{
						if (document.getElementById('select'+i).style.display=='none') {
							document.getElementById('clear_select'+i).innerHTML='';
						}
					}
				]]>
	          	</xsl:with-param>
	          </xsl:call-template>
	        </ui:buttons>

	     	</ui:block>
	    </ui:content>   
    </ui:screen>
  </xsl:template>
  
	<func:function name="local:add-cells">
		<xsl:param name="sel-num" select="1"/>
		<func:result>
			<ui:row>
				<ui:cell>
					<div style="width:500px">
						<div style="float:left" id="clear_select{$sel-num}">
							<nobr>
								<input type="file" name="select{$sel-num}" id="select{$sel-num}" size="32" class="q0">
									<xsl:if test="$sel-num &gt; 1">
										<xsl:attribute name="style">display:none</xsl:attribute>
									</xsl:if>
								</input>
							</nobr>
						</div>
						<xsl:if test="$sel-num &lt; $max-fields">
							<xsl:variable name="add_tip"><sw:text>Add a file to upload.</sw:text></xsl:variable>
							<div style="float:left">
								<img id="a_select{$sel-num}" src="/{$theme}/icons/item_add.gif"
									onmouseover="callTip('{sw:html-escape($add_tip,'escape-all')}',event)"
									onmouseout="callTip('')"
									onclick="hideDIVGroup('a_select{$sel-num}','d_select{$sel-num}');
										showDIVGroup('select{$sel-num + 1}','a_select{$sel-num + 1}','d_select{$sel-num + 1}')"
									class="q0" style="cursor:pointer">
									<xsl:if test="$sel-num &gt; 1">
										<xsl:attribute name="style">cursor:pointer;display:none</xsl:attribute>
									</xsl:if>
								</img>
							</div>
						</xsl:if>
						<xsl:if test="$sel-num &gt; 1">
							<xsl:variable name="remove_tip"><sw:text>Do not upload this file.</sw:text></xsl:variable>
							<div style="float:left">
								<img id="d_select{$sel-num}" src="/{$theme}/icons/item_delete.gif"
									onmouseover="callTip('{sw:html-escape($remove_tip,'escape-all')}',event)"
									onmouseout="callTip('')"
									onclick="hideDIVGroup('select{$sel-num}','a_select{$sel-num}','d_select{$sel-num}');
										showDIVGroup('a_select{$sel-num - 1}','d_select{$sel-num - 1}')"
									class="q0" style="cursor:pointer;">
									<xsl:if test="$sel-num &gt; 1">
										<xsl:attribute name="style">cursor:pointer;display:none</xsl:attribute>
									</xsl:if>
								</img>
							</div>
						</xsl:if>
					</div>
				</ui:cell>
			</ui:row>
			<xsl:if test="$sel-num &lt; $max-fields">
				<xsl:copy-of select="local:add-cells($sel-num + 1)"/>
			</xsl:if>
		</func:result>
	</func:function>

	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
	
			<xsl:choose>

				<xsl:when test="/ui:redirect">
					<xsl:copy-of select="/"/>					
				</xsl:when>			
				<xsl:when test="$step = 'gen'">
					<xsl:call-template name="step_gen"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="step_gen"/>
				</xsl:otherwise>
				
			</xsl:choose>
		
	</xsl:template>
	
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>
	
	<sw:include href="/lib/vocabulary.xsl"/>		
	
	<sw:include href="../../../../../layout/forms-list.xsl"/>	
	
</xsl:stylesheet>
