<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl browse cred"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:fwm="http://www.swsoft.com/xsl/cp/fwm"
>

	<!-- check permissions to show this page -->
	<xsl:variable name="eid" select="sw:ve-eid()"/>
	<xsl:variable name="cr-fwm-simple"
		select="cred:check-env('vzcp.env.manage.services_and_files',$eid)"/>
	<xsl:variable name="cr-fwm-advanced"
		select="$cr-fwm-simple"/>
	<!-- setup allowed only of user has ability choose mode -->
	<xsl:variable name="cr-fwm-setup" select="$cr-fwm-simple and $cr-fwm-advanced"/>

	<xsl:variable name="cr-fwm-rule-edit"
		select="$cr-fwm-simple"/>
	<xsl:variable name="cr-fwm-rule-activate"
		select="$cr-fwm-simple"/>
	<xsl:variable name="cr-fwm-rule-add"
		select="$cr-fwm-simple"/>
	<xsl:variable name="cr-fwm-rule-delete"
		select="$cr-fwm-simple"/>
	<xsl:variable name="cr-fwm-order"
		select="$cr-fwm-simple"/>

	<xsl:param name="access-denied" select="not($cr-fwm-advanced)"/>

	<!-- restore or set tab -->
	<xsl:variable name="tab-pre">
		<xsl:choose>
			<xsl:when test="sw:param('tab')">
				<!-- in case GET present, it beat all -->
				<xsl:value-of select="string(sw:param('tab'))"/>
			</xsl:when>
			<xsl:otherwise>
				<!-- try use session -->
				<xsl:value-of select="sw:sesgetstr('cur-tab-for-fwm')"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>	
	
	<!-- main tab logic -->
	<xsl:variable name="tab">
		<xsl:choose>
			<xsl:when test="$tab-pre != ''">
				<xsl:value-of select="$tab-pre"/>
			</xsl:when>
			<!-- no get, no prev session, init -->
			<xsl:otherwise>
				<xsl:value-of select="'input'"/>
			</xsl:otherwise>
		</xsl:choose>	
	</xsl:variable>
	<!-- store in session -->
	<xsl:variable name="save-tab" select="sw:sesputstr('cur-tab-for-fwm',$tab)"/>

	<xsl:variable name="fwm-chain-name" select="$fwm-chain/chain[tab = $tab]/chain-name"/>

	<xsl:variable name="fwm-system-default-policy" select="fwm:get-default-policy()"/>

	<xsl:template mode="screen" match="/">
		<ui:screen id="{$fwm-chain/chain[tab = $tab]/list-screen-id}">
			<ui:properties>
				<ui:form-get/>
				<ui:description width="full" mandatory="yes">
					<sw:text>
						On this screen you can manage firewall rules in the advanced mode.
					</sw:text>
				</ui:description>
				<ui:form-get/>
			</ui:properties>

			<ui:tab-bar id="fwm.chains" current-tab="{$tab}"/>

			<ui:content>
				<ui:block width="full">
					<!-- filter init -->
					<xsl:variable name="filter_init_">
						<xsl:call-template name="browse:init-filter">
							<xsl:with-param name="browse">
								<ui:browse-setup id="fwm" url="/vzdir/infrman/envs/fwm/fwm?tab={$tab}"
									item-url="/vzdir/infrman/envs/fwm/rule?tab={$tab}" item-url-tip="fwm_rule_edit"
									select-column="fwm-rule-uniq-id"/>
								<ui:cols>
									<xsl:if test="$cr-fwm-rule-activate or $cr-fwm-rule-delete">
										<ui:column id="fwm-rule-uniq-id" for-select="yes" hidden="yes" sorting="no"
											for-url="yes" encode="no"/>
									</xsl:if>
									<ui:column id="fwm-name" align="left" title="{sw:text('Name')}" sorting="no">
										<xsl:if test="$cr-fwm-rule-edit">
											<xsl:attribute name="show-url">yes</xsl:attribute>
										</xsl:if>
									</ui:column>
									<ui:column id="fwm-policy" align="center" title="{sw:text('Policy')}"
										apply-templates="yes" filter="select" sorting="no">
										<xsl:for-each select="$fwm-policy/policy">
											<ui:filter-option value="{title}" title="{title}"/>
										</xsl:for-each>
									</ui:column>
									<ui:column id="fwm-protocol" align="center" title="{sw:text('Protocol')}"
										filter="select" sorting="no">
										<xsl:for-each select="$fwm-protocol/protocol">
											<ui:filter-option value="{value}" title="{title}"/>
										</xsl:for-each>
									</ui:column>
									<ui:column id="fwm-from-host" align="center" title="{sw:text('Source Address')}"
										sorting="no"/>
									<ui:column id="fwm-from-port" align="center" title="{sw:text('Source Port')}"
										sorting="no"/>
									<ui:column id="fwm-to-host" align="center"
										title="{sw:text('Destination Address')}" sorting="no"/>
									<ui:column id="fwm-to-port" align="center" title="{sw:text('Destination Port')}"
										sorting="no"/>
									<ui:column id="fwm-status" align="center" title="{sw:text('Enabled')}"
										apply-templates="yes" filter="select" sorting="no">
										<ui:filter-option value="1" title="{sw:text('Enabled')}"/>
										<ui:filter-option value="0" title="{sw:text('Disabled')}"/>
									</ui:column>
									<xsl:if test="$cr-fwm-order">
										<ui:column id="fwm-rule-move" align="center" title="{sw:text('Move')}"
											apply-templates="yes" sorting="no"> </ui:column>
									</xsl:if>
								</ui:cols>
							</xsl:with-param>
						</xsl:call-template>
					</xsl:variable>

					<xsl:variable name="fwm-rules" select="sw:sesget('fwm-rules')"/>

					<xsl:variable name="count-rule-in-chain"
						select="count($fwm-rules/chain[name = $fwm-chain-name]/rule)"/>

					<xsl:variable name="filter">
						<xsl:call-template name="browse:fill-filter">
							<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
							<xsl:with-param name="rows">
								<ui:browse-rows>
									<xsl:for-each select="$fwm-rules/chain[name = $fwm-chain-name]/rule">
										<ui:row>
											<fwm-rule-uniq-id>
												<xsl:value-of select="fwm-rule-uniq-id"/>
											</fwm-rule-uniq-id>
											<fwm-status>
												<xsl:value-of select="allowed"/>
											</fwm-status>
											<fwm-rule-move>
												<xsl:choose>
													<xsl:when test="(fwm-rule-id = 1) and ($count-rule-in-chain = 1)">
														<xsl:value-of select="'none'"/>
													</xsl:when>
													<xsl:when test="fwm-rule-id = 1">
														<xsl:value-of select="'first'"/>
													</xsl:when>
													<xsl:when test="fwm-rule-id = $count-rule-in-chain">
														<xsl:value-of select="'last'"/>
													</xsl:when>
												</xsl:choose>
											</fwm-rule-move>
											<fwm-name>
												<xsl:value-of select="name"/>
											</fwm-name>
											<!-- cal from/to -->
											<xsl:variable name="from-addr" select="src_addr/host"/>
											<xsl:variable name="from-mask" select="src_addr/mask"/>
											<xsl:variable name="from-first-port" select="src_ports/first_port"/>
											<xsl:variable name="from-last-port" select="src_ports/last_port"/>

											<xsl:variable name="to-addr" select="dst_addr/host"/>
											<xsl:variable name="to-mask" select="dst_addr/mask"/>
											<xsl:variable name="to-first-port" select="dst_ports/first_port"/>
											<xsl:variable name="to-last-port" select="dst_ports/last_port"/>
											<fwm-from-host>
												<xsl:choose>
													<xsl:when test="$from-addr != ''">
														<xsl:value-of select="$from-addr"/>
														<xsl:if test="$from-mask != ''">
															<xsl:value-of select="concat('/',$from-mask)"/>
														</xsl:if>
													</xsl:when>
													<xsl:otherwise>
														<xsl:value-of select="$all-addr"/>
													</xsl:otherwise>
												</xsl:choose>
											</fwm-from-host>

											<fwm-from-port>
												<xsl:choose>
													<xsl:when test="$from-first-port != '' and $from-last-port != ''">
														<xsl:value-of select="concat($from-first-port,'-',$from-last-port)"/>
													</xsl:when>
													<xsl:when test="$from-first-port != '' and not($from-last-port != '')">
														<xsl:value-of select="$from-first-port"/>
													</xsl:when>
													<xsl:otherwise>
														<xsl:value-of select="$all-port"/>
													</xsl:otherwise>
												</xsl:choose>
											</fwm-from-port>

											<fwm-to-host>
												<xsl:choose>
													<xsl:when test="$to-addr != ''">
														<xsl:value-of select="$to-addr"/>
														<xsl:if test="$to-mask != ''">
															<xsl:value-of select="concat('/',$to-mask)"/>
														</xsl:if>
													</xsl:when>
													<xsl:otherwise>
														<xsl:value-of select="$all-addr"/>
													</xsl:otherwise>
												</xsl:choose>
											</fwm-to-host>

											<fwm-to-port>
												<xsl:choose>
													<xsl:when test="$to-first-port != '' and $to-last-port != ''">
														<xsl:value-of select="concat($to-first-port,'-',$to-last-port)"/>
													</xsl:when>
													<xsl:when test="$to-first-port != '' and not($to-last-port != '')">
														<xsl:value-of select="$to-first-port"/>
													</xsl:when>
													<xsl:otherwise>
														<xsl:value-of select="$all-port"/>
													</xsl:otherwise>
												</xsl:choose>
											</fwm-to-port>

											<fwm-protocol>
												<xsl:value-of select="protocol"/>
											</fwm-protocol>
											<xsl:variable name="raw-policy" select="policy"/>
											<fwm-policy>
												<xsl:value-of select="$fwm-policy/policy[value = $raw-policy]/title"/>
											</fwm-policy>
										</ui:row>
									</xsl:for-each>
									<ui:row position="bottom" allow-filter="true" bottom="yes" disable-checkbox="yes">
										<fwm-rule-uniq-id/>
										<fwm-name>
											<sw:text>Default system policy</sw:text>
										</fwm-name>
										<fwm-policy>
											<xsl:value-of
												select="$fwm-policy/policy[value = $fwm-system-default-policy]/title"/>
										</fwm-policy>
										<fwm-protocol>
											<xsl:value-of select="$all-proto"/>
										</fwm-protocol>
										<fwm-from-host>
											<xsl:value-of select="$all-addr"/>
										</fwm-from-host>
										<fwm-from-port>
											<xsl:value-of select="$all-port"/>
										</fwm-from-port>
										<fwm-to-host>
											<xsl:value-of select="$all-addr"/>
										</fwm-to-host>
										<fwm-to-port>
											<xsl:value-of select="$all-port"/>
										</fwm-to-port>
										<fwm-status>1</fwm-status>
										<fwm-rule-move>
											<xsl:value-of select="'none'"/>
										</fwm-rule-move>
									</ui:row>
								</ui:browse-rows>
							</xsl:with-param>
							<xsl:with-param name="cookies">
								<tab>
									<xsl:value-of select="$tab"/>
								</tab>
							</xsl:with-param>
						</xsl:call-template>
					</xsl:variable>

					<ui:browse title="{sw:text('Rules')}">
						<ui:browse-buttons type="list-selection">
							<xsl:if test="$cr-fwm-rule-add">
								<ui:button name="fwm-rule-add" icon="new"
									new-obj-title="{sw:text('Rule')}"
									submit-href="{$baseurl}/vzdir/infrman/envs/fwm/rule?tab={$tab}" tip="fwm_rule_add" auxiliary="true">
									<sw:text>New Rule</sw:text>
								</ui:button>
							</xsl:if>
							<xsl:if test="$cr-fwm-rule-delete">
								<ui:button type="list-selection" tip="fwm_rule_delete" icon="delete"
									confirmation="{sw:text('Are you sure you want to delete the selected rule(s)?')}"
									script="if (!atLeastOne()) return false;" name="fwm-rule-delete" auxiliary="true">
									<sw:text>Delete</sw:text>
								</ui:button>
							</xsl:if>
							<xsl:if test="$cr-fwm-rule-activate">
								<ui:button type="list-selection" tip="fwm_rule_enable" icon="enable"
									script="if (!atLeastOne()) return false;" name="fwm-rule-enable" auxiliary="true">
									<sw:text>Enable</sw:text>
								</ui:button>
								<ui:button type="list-selection" tip="fwm_rule_disable" icon="disable"
									script="if (!atLeastOne()) return false;" name="fwm-rule-disable" auxiliary="true">
									<sw:text>Disable</sw:text>
								</ui:button>
							</xsl:if>
							<xsl:if test="$cr-fwm-setup">
								<ui:button name="fwm-setup" icon="fwm"
									submit-href="{$baseurl}/vzdir/infrman/envs/fwm/setup?mode-selector=1" tip="fwm_setup" auxiliary="true">	
									<sw:text>Firewall Setup</sw:text>
								</ui:button>						
							</xsl:if>
						</ui:browse-buttons>
						<ui:filter>
							<xsl:copy-of select="$filter"/>
						</ui:filter>

						<ui:browse-empty-msg>
							<sw:text>
			  				  	No firewall rules are defined for the current chain.
									</sw:text>
						</ui:browse-empty-msg>

						<ui:browse-js-many>
							<ui:warn>
								<sw:text>Select at least one rule!</sw:text>
							</ui:warn>
						</ui:browse-js-many>

					</ui:browse>
				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/core/browse-filter-raw.xsl" />
	<sw:include href="/lib/vza/fwm.xsl"/>

	<sw:include href="/lib/fwm.xsl"/>

</xsl:stylesheet>
