<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred fwm"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl	="http://exslt.org/common"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
  xmlns:error	="http://www.swsoft.com/xsl/cp/error"
  xmlns:wiz		="http://www.swsoft.com/xsl/cp/wiz"
  xmlns:ui	="http://www.swsoft.com/xsl/cp/ui"
  xmlns:func	="http://exslt.org/functions"
	xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
	xmlns:fwm   ="http://www.swsoft.com/xsl/cp/fwm"
 >

  <xsl:param name="wiz_code" 					select="'ve-fwm-rule'"/>
  
	<xsl:variable name="step_data"			select="wiz:getStep()"/>
	<xsl:variable name="step"						select="$step_data/@id"/>
	<xsl:variable name="screen-id"			select="$step_data/@screen-id"/>
	<xsl:variable name="screen-title"		select="$step_data/@screen-title"/>
	<xsl:variable name="path-id"				select="string(wiz:getSteps()/step[1]/@screen-id)"/>

  <xsl:variable name="form" 					select="sw:sesget($wiz_data)"/>

	<xsl:param name="access-denied" 
		select="not(cred:check-context($step_data/@cred,$step_data/@security-obj-type))"/>

  <xsl:variable name="screen-icon" select="'fwm-rule-add'"/>

	<!-- Wizard, Step 'New fwm rule' -->
  <xsl:template name="edit-one-rule">
  	<ui:screen path-id="{$path-id}" id="{$screen-id}" title="{$screen-title}" icon="{$screen-icon}">
  	
	    <ui:properties>
				<ui:refresh-type>none</ui:refresh-type>
	      <ui:description  mandatory="yes">
	        <sw:text>
						<xsl:with-param name="action" select="sw:if($step='add',sw:text('add'),sw:text('edit'))"/>
						On this screen you can %{action} firewall rules.
	        </sw:text>
	      </ui:description>      
	      <ui:form-get/>
	    </ui:properties>
	    
	    <ui:content>
	      <ui:hidden name="step" value="{$step}"/>
	      <ui:block mode="edit">
	      	
					<ui:rows title="{sw:text('General Settings')}" separate-tables="true">
		   			<ui:row>
		   				<ui:cell-label>
			        	<sw:text>Name</sw:text>
							</ui:cell-label>
							<ui:cell-input required="true" id="name" maxlength="256" width="32">
								<xsl:attribute name="value"><xsl:value-of select="$form/name"/></xsl:attribute>
							</ui:cell-input>
						</ui:row>

		   			<ui:row>
		   				<ui:cell-label>
			        	<sw:text>Policy</sw:text>
							</ui:cell-label>
			        <ui:cell-list id="policy" value="{$form/policy}">
								<xsl:for-each select="$fwm-policy/policy">
									<xsl:sort select="value"/>
									<ui:list-item id="{value}" title="{title}"/>
								</xsl:for-each>
							</ui:cell-list>
						</ui:row>

		   			<ui:row>
		   				<ui:cell-label>
			        	<sw:text>Protocol</sw:text>
							</ui:cell-label>
			        <ui:cell-list id="protocol" value="{$form/protocol}">
								<xsl:for-each select="$fwm-protocol/protocol">
									<xsl:sort select="value"/>
									<ui:list-item id="{value}" title="{title}"/>
								</xsl:for-each>
							</ui:cell-list>
						</ui:row>

						<!-- selected source ipddress and netmask -->
						<ui:row>
    	      	<ui:cell-label>
      	      	<sw:text>Source Address and Netmask</sw:text>
        	    </ui:cell-label>
          	  <ui:cell-input id="src-addr" maxlength="31" width="31">
            		<xsl:attribute name="value">
									<xsl:value-of select="$form/src_addr/host"/>
									<xsl:value-of select="sw:if($form/src_addr/mask,concat('/',$form/src_addr/mask),'')"/>
								</xsl:attribute>
	            </ui:cell-input>
						</ui:row>
						<!-- /sources ipaddress and netmask -->

						<!-- selected source port or ports -->
						<ui:row>
    	      	<ui:cell-label>
      	      	<sw:text>Source Port or Port Range</sw:text>
        	    </ui:cell-label>
          	  <ui:cell-input id="src-ports" maxlength="31" width="31">
            		<xsl:attribute name="value">
									<xsl:value-of select="$form/src_ports/first_port"/>
									<xsl:value-of select="sw:if($form/src_ports/last_port,concat('-',$form/src_ports/last_port),'')"/>
								</xsl:attribute>
	            </ui:cell-input>
						</ui:row>
						<!-- /sources port or ports -->

						<!-- selected destination ipddress and netmask -->
						<ui:row>
    	      	<ui:cell-label>
      	      	<sw:text>Destination Address and Netmask</sw:text>
        	    </ui:cell-label>
          	  <ui:cell-input id="dst-addr" maxlength="31" width="31">
            		<xsl:attribute name="value">
									<xsl:value-of select="$form/dst_addr/host"/>
									<xsl:value-of select="sw:if($form/dst_addr/mask,concat('/',$form/dst_addr/mask),'')"/>
								</xsl:attribute>
	            </ui:cell-input>
						</ui:row>
						<!-- /sources destination and netmask -->

						<!-- selected destination port or ports -->
						<ui:row>
    	      	<ui:cell-label>
      	      	<sw:text>Destination Port or Port Range</sw:text>
        	    </ui:cell-label>
          	  <ui:cell-input id="dst-ports" maxlength="31" width="31">
            		<xsl:attribute name="value">
									<xsl:value-of select="$form/dst_ports/first_port"/>
									<xsl:value-of select="sw:if($form/dst_ports/last_port,concat('-',$form/dst_ports/last_port),'')"/>
								</xsl:attribute>
	            </ui:cell-input>
						</ui:row>
						<!-- /sources destination port or ports -->

		   			<ui:row>
		   				<ui:cell-label>
			        	<sw:text>Enable</sw:text>
							</ui:cell-label>
							<ui:cell-check id="allowed" checked="{$form/allowed='1'}"/>
						</ui:row>
						<ui:hidden name="fwm-rule-uniq-id" value="{$form/fwm-rule-uniq-id}"/>

						<!-- XXX probably need be not editable (we preselect chain by tab ) -->
		   			<ui:row>
		   				<ui:cell-label>
			        	<sw:text>Chain</sw:text>
							</ui:cell-label>
			        <ui:cell-list id="chain" value="{$form/chain}">
								<xsl:for-each select="$fwm-chain/chain">
									<ui:list-item id="{chain-name}" title="{title}"/>
								</xsl:for-each>
							</ui:cell-list>
						</ui:row>
						<!-- XXX remove edit ability ? -->
						<xsl:if test="$step = 'add'">
		   			<ui:row>
		   				<ui:cell-label>
			        	<sw:text>The rule's position in the chain</sw:text>
							</ui:cell-label>
			        <ui:cell-list id="position" value="{$form/position}">
								<ui:list-item id="up" title="{sw:text('Top')}"/>
								<ui:list-item id="down" title="{sw:text('Bottom')}"/>								
							</ui:cell-list>
						</ui:row>
						</xsl:if>
						<!-- XXX need ? -->

					</ui:rows>
					<ui:buttons>
		    		<xsl:call-template name="wiz:showButtons"/>
		  	  </ui:buttons>
	    	</ui:block>
	  	</ui:content>   
	  </ui:screen>
	</xsl:template>

	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
		<xsl:call-template name="edit-one-rule"/>
	</xsl:template>
	
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>

	<sw:include href="/lib/vza/fwm.xsl"/>
	<sw:include href="/lib/fwm.xsl"/>
	
</xsl:stylesheet>
