<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl wiz cred fwm"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:fwm="http://www.swsoft.com/xsl/cp/fwm"
	xmlns:fwm-util="http://www.swsoft.com/xsl/cp/fwm-util"
	xmlns:voc="http://www.swsoft.com/xsl/cp/voc"
>

	<xsl:param name="wiz_code" select="'ve-fwm-setup'"/>
	<xsl:variable name="step_data" select="wiz:getStep()"/>
	<xsl:variable name="step" select="$step_data/@id"/>
	<xsl:variable name="screen-id" select="$step_data/@screen-id"/>
	<xsl:variable name="screen-title" select="$step_data/@screen-title"/>
	<xsl:variable name="path-id" select="$screen-id"/>
	<xsl:variable name="problem-path-id" select="'ve-fwm'"/>

	<xsl:variable name="form" select="sw:sesget($wiz_data)"/>
	<xsl:variable name="fwm-inited" select="sw:get-private()/vzcp/fwm-mode"/>

	<xsl:variable name="eid" select="sw:ve-eid()"/>
	<xsl:variable name="cr-simple"
		select="cred:check-env('vzcp.env.manage.services_and_files',$eid)"/>
	<xsl:variable name="cr-advanced"
		select="$cr-simple"/>
	<xsl:param name="access-denied" select="not($cr-simple)"/>
	
	<xsl:variable name="screen-icon" select="'fwm-setup'"/>

	<!-- Wizard, Step 'Setup firewall' -->
	<xsl:template name="fwm-setup-screen-ok">
		<xsl:param name="normal-reset" select="0"/>
		<ui:screen path-id="{sw:if(not($fwm-inited !=''), $problem-path-id, $path-id)}"
			id="{$screen-id}" title="{$screen-title}" icon="{$screen-icon}">
			<ui:properties>
				<ui:refresh-type>none</ui:refresh-type>
				<ui:description mandatory="yes">
					<xsl:choose>
						<xsl:when test="not($fwm-inited !='')">
							<xsl:choose>
								<xsl:when test="not($cr-advanced)">
									<sw:text>The firewall is not active now. To activate the firewall, click "Activate".</sw:text>
								</xsl:when>
								<xsl:otherwise>
									<!-- advanced cred present -->
									<sw:text>The firewall is not active now. To activate the firewall, choose one of the firewall operation modes.</sw:text>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:when>
						<xsl:otherwise>
							<sw:text>On this screen you can set up common firewall properties.</sw:text>
							<br/>
							<xsl:if test="$normal-reset = 1">
								<sw:text>
	      					The Normal firewall mode option can be selected only together with the Reset the firewall option.
	      				</sw:text>
							</xsl:if>
						</xsl:otherwise>
					</xsl:choose>
				</ui:description>
				<ui:form-get/>
			</ui:properties>

			<ui:content>
				<ui:hidden name="step" value="{$step}"/>
				<ui:block mode="edit">

					<xsl:choose>
						<xsl:when test="not($cr-advanced)">
							<ui:hidden name="fwm-mode" value="normal-DROP"/>
							<!-- reset only if needed -->
							<xsl:if test="$normal-reset = 1">
								<ui:hidden name="reset" value="reset"/>
							</xsl:if>
							<ui:buttons>
								<xsl:call-template name="wiz:showButtons">
									<xsl:with-param name="submit-title" select="sw:text('Activate')"/>
								</xsl:call-template>
							</ui:buttons>
						</xsl:when>

						<xsl:otherwise>

							<ui:rows separate-tables="true" title="{sw:text('Select firewall mode')}">
								<!-- normal firewall -->
								<ui:row>
									<ui:cell-radio name="fwm-mode" id="fwm-mode-simple" value="normal-DROP"
										close="false" colspan="2">
										<xsl:if
											test="($form/mode = 'normal' and $form/policy = 'DROP') or not($fwm-inited !='')">
											<xsl:attribute name="checked">true</xsl:attribute>
										</xsl:if>
										<xsl:if test="$fwm-inited !=''">
											<ui:control-slave>
												<xsl:value-of select="'normal-mode-reset'"/>
											</ui:control-slave>
										</xsl:if>
									</ui:cell-radio>
									<ui:cell open="false">
										<sw:text>Normal firewall mode</sw:text>
									</ui:cell>
								</ui:row>

								<xsl:if test="$normal-reset = 1">
									<ui:hidden name="need-reset" value="need-reset"/>
								</xsl:if>

								<xsl:if test="not($fwm-inited !='')">
									<ui:hidden name="reset" value="reset"/>
								</xsl:if>

								<!-- /normal firewall -->
								<!-- normal firewall warning about reset -->
								<xsl:if test="$fwm-inited !=''">
									<ui:row offset="2">
										<ui:cell-check name="reset" id="normal-mode-reset" value="reset" close="false"
											colspan="2">
											<xsl:if test="$form/reset = 'reset'">
												<xsl:attribute name="checked">true</xsl:attribute>
											</xsl:if>
										</ui:cell-check>
										<ui:cell open="false">
											<sw:text>Reset the firewall</sw:text>
										</ui:cell>
									</ui:row>
								</xsl:if>
								<!-- /normal firewall -->

								<!-- advanced firewall -->

								<xsl:for-each select="$fwm-default-policy/policy">
									<ui:row>
										<ui:cell-radio name="fwm-mode" id="fwm-mode-advanced-{value}"
											value="advanced-{value}-none" close="false" colspan="2">
											<xsl:if
												test="$form/policy = value and $form/mode = 'advanced' and $form/reset = 'none'">
												<xsl:attribute name="checked">true</xsl:attribute>
											</xsl:if>
											<xsl:if test="$fwm-inited !=''">
												<ui:control-slave inverse="true">
													<xsl:value-of select="'normal-mode-reset'"/>
												</ui:control-slave>
											</xsl:if>
										</ui:cell-radio>
										<ui:cell open="false">
											<sw:text>
												<xsl:with-param name="policy-name" select="title"
												/>
											Advanced firewall mode with default policy %{policy-name}
										</sw:text>
										</ui:cell>
									</ui:row>
								</xsl:for-each>
							</ui:rows>
							<!-- /advanced firewall -->
							<ui:buttons>
								<xsl:call-template name="wiz:showButtons"/>
							</ui:buttons>
						</xsl:otherwise>
					</xsl:choose>
				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<xsl:template name="fwm-setup-screen-fail">
		<xsl:param name="problem-body"/>

		<ui:screen path-id="{$problem-path-id}" id="{$screen-id}" title="{$screen-title}"
			icon="{$screen-icon}">
			<ui:properties>
				<ui:form-get/>
			</ui:properties>
			<ui:content>
				<ui:block mode="edit">
					<xsl:copy-of select="$problem-body"/>
				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<xsl:template name="fwm-setup-result">
		<xsl:variable name="oper-problem" select="voc:check-operation('firewallm')"/>
		<xsl:variable name="fmw-list" select="fwm:get()"/>

		<xsl:variable name="request-mode">
			<xsl:choose>
				<xsl:when test="sw:param('mode-selector') = 1">
					<!-- empty mode, show selector for modes -->
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="fwm-util:get-mode()"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<xsl:variable name="fwm-setup-result">
			<xsl:choose>
				<xsl:when test="$oper-problem != ''">
					<!-- VE has bad state -->
					<ui:block>
						<ui:operation-problem>
							<xsl:copy-of select="$oper-problem"/>
							<ui:descr>
								<sw:text>Unable to manage the firewall.</sw:text>
							</ui:descr>
						</ui:operation-problem>
					</ui:block>
				</xsl:when>
				<xsl:when test="$fmw-list/error">
					<!-- fwm return error, report low layer report  -->
					<ui:block>
						<ui:operation-problem>
							<ui:type>vza-error</ui:type>
							<ui:descr>
								<sw:text>Error managing the firewall.</sw:text>
							</ui:descr>
							<ui:reason>
								<sw:text>An internal error occurred.</sw:text>
							</ui:reason>
							<ui:solution>
								<sw:text>Read the technical details below.</sw:text>
							</ui:solution>
							<ui:vza-error>
								<xsl:copy-of select="$fmw-list/error/*"/>
							</ui:vza-error>
						</ui:operation-problem>
					</ui:block>
				</xsl:when>
				<xsl:when test="$request-mode = 'advanced'">
					<!-- redirect to advanced mode, default policy would be calculated in ve-fwm -->
					<ui:redirect location="{$baseurl}/vzdir/infrman/envs/fwm/fwm"/>
				</xsl:when>
				<xsl:otherwise>
					<!-- try reconstruct simple rules -->
					<xsl:variable name="fwm-simple-rules-raw">
						<xsl:call-template name="fwm-calc-simple-rules"/>
					</xsl:variable>

					<xsl:variable name="fwm-simple-rules" select="exsl:node-set($fwm-simple-rules-raw)"/>
					<!-- raw rules calc as side-effect for fwm-simple-rules. -->
					<xsl:variable name="fwm-rules" select="sw:sesget('fwm-rules')"/>

					<!-- calc that simple rule consistens -->
					<xsl:variable name="fwm-simple-consistens">
						<xsl:variable name="fwm-system-default-policy" select="fwm:get-default-policy()"/>
						<xsl:variable name="diff-between-rulesset-and-raw"
							select="count($fwm-simple-rules/set[selected]/rule) - count($fwm-rules/chain/rule)"/>
						<xsl:value-of
							select="sw:if($fwm-system-default-policy = 'DROP' and $diff-between-rulesset-and-raw = 0,1,0)"
						/>
					</xsl:variable>
					<xsl:choose>
						<xsl:when test="$fwm-simple-consistens = 1 and $request-mode = 'normal'">
							<!-- redirect to normal firewall screen -->
							<ui:redirect location="{$baseurl}/vzdir/infrman/envs/fwm/simple"/>
						</xsl:when>
						<xsl:when test="$fwm-simple-consistens = 1 and not($request-mode != '')">
							<!-- selector of mode: normal, advanced accept, advanced drop -->
							<!-- standart selector use -->
						</xsl:when>
						<xsl:when test="$fwm-simple-consistens = 0 and $request-mode = 'normal'">
							<!-- oper problem with 3 link: reset to 
							default normal, advanced drop, advaced accept -->
							<!-- check that firewall was inited -->
							<xsl:choose>
								<xsl:when test="not($fwm-inited !='')">
									<!-- firewall was just inited -->
									<normal-reset/>
								</xsl:when>
								<xsl:otherwise>
									<!-- firewall was already inited -->
									<ui:block>
										<ui:operation-problem>
											<ui:descr>
												<sw:text>The firewall cannot be managed.</sw:text>
											</ui:descr>
											<ui:reason>
												<sw:text>When managing the firewall, its rule(s) settings were changed in such a way that rendered your firewall unmanageable in the normal mode.</sw:text>
											</ui:reason>
											<ui:solution>
												<ui:i18n-link href="{$baseurl}/vzdir/infrman/envs/fwm/simple?reset=1"
													tip="apply_defaults">
													<_>%{aopen}Reset the firewall%{aclose} back to the normal mode. This will roll back the changes.</_>
												</ui:i18n-link>
											</ui:solution>
											<xsl:if
												test="cred:check-env('vzcp.env.manage.services_and_files',$eid)">
												<ui:solution>
													<ui:i18n-link href="{$baseurl}/vzdir/infrman/envs/fwm/fwm?reset=1"
														tip="03.02.01.18.01">
														<_>%{aopen}Select%{aclose} the advanced firewall mode. While being, effectively, advanced, it has no constraints as to changing the rules settings. Thus, the changes that have made the firewall rules incompatible with the normal mode will not be lost.</_>
													</ui:i18n-link>
												</ui:solution>
											</xsl:if>
										</ui:operation-problem>
									</ui:block>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:when>
						<xsl:when test="$fwm-simple-consistens = 0 and not($request-mode != '')">
							<!-- selector of mode: reset to default normal, advanced drop, advaced accept -->
							<!-- use special selector -->
							<normal-reset/>
						</xsl:when>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:copy-of select="$fwm-setup-result"/>
	</xsl:template>

	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
		<xsl:variable name="fwm-setup-result">
			<xsl:call-template name="fwm-setup-result"/>
		</xsl:variable>

		<xsl:choose>
			<xsl:when test="exsl:node-set($fwm-setup-result)/ui:redirect">
				<xsl:copy-of select="$fwm-setup-result"/>
			</xsl:when>
			<xsl:when test="exsl:node-set($fwm-setup-result)/ui:block">
				<xsl:call-template name="fwm-setup-screen-fail">
					<xsl:with-param name="problem-body" select="$fwm-setup-result"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="exsl:node-set($fwm-setup-result)/normal-reset">
				<xsl:call-template name="fwm-setup-screen-ok">
					<xsl:with-param name="normal-reset" select="1"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="fwm-setup-screen-ok"/>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>

	<sw:include href="/lib/vza/fwm.xsl"/>
	<sw:include href="/lib/fwm.xsl"/>

	<sw:include href="/lib/vt/env-private.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
