<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred fwm"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl	="http://exslt.org/common"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
  xmlns:error	="http://www.swsoft.com/xsl/cp/error"
  xmlns:wiz		="http://www.swsoft.com/xsl/cp/wiz"
  xmlns:ui	="http://www.swsoft.com/xsl/cp/ui"
  xmlns:func	="http://exslt.org/functions"
	xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
	xmlns:fwm   ="http://www.swsoft.com/xsl/cp/fwm"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:voc   ="http://www.swsoft.com/xsl/cp/voc"
 >

  <xsl:param name="wiz_code" 					select="'ve-fwm-simple-rule'"/>
  
	<xsl:variable name="step_data"			select="wiz:getStep()"/>
	<xsl:variable name="step"						select="$step_data/@id"/>
	<xsl:variable name="screen-id"			select="$step_data/@screen-id"/>
	<xsl:variable name="screen-title"		select="$step_data/@screen-title"/>
	<xsl:variable name="path-id"				select="string(wiz:getSteps()/step[1]/@screen-id)"/>

  <xsl:variable name="form" 					select="sw:sesget($wiz_data)"/>
	<xsl:param name="access-denied" 		select="not(cred:check-env($step_data/@cred,sw:ve-eid()))"/>
  <xsl:variable name="screen-icon" select="'fwm_simple_rule_edit'"/>

	<xsl:variable name="fwm-simple-rules" select="sw:sesget('fwm-simple-rules')"/>
	
	<!-- Wizard, Step 'New simple fwm rule' -->
  <xsl:template name="add-one-simple-rule">
		<xsl:variable name="oper-problem" select="voc:check-operation('firewallm')"/>

    <ui:screen path-id="ve-fwm-simple-rule" id="{$screen-id}" title="{sw:text('Add Access Rule')}" icon="fwm-rule-add">
	    <ui:properties>
    	  <ui:description width="full" mandatory="yes">
					<sw:text>
						On this screen you can add access rules from a list.
					</sw:text>
  	    </ui:description>      
  	    <ui:form-get/>
    	</ui:properties>

  	  <ui:content>
				<ui:hidden name="step" value="add"/>
		    <xsl:choose>
					<xsl:when test="$oper-problem=''">
            <ui:block width="full">
							<!-- filter init -->
							<xsl:variable name="filter_init_">
								<xsl:call-template name="browse:init-filter">
									<xsl:with-param name="browse">
										<ui:browse-setup id="fwm_simple_rule_edit"
											url="/vzdir/infrman/envs/fwm/simple-rule"
											item-url-tip="fwm_simple_rule_edit"
											select-column="fwm-rule-uniq-id"/>
									  <ui:cols>
							  			<ui:column id="fwm-simple-rule-uniq-id" for-select="yes"  hidden="yes" sorting="no" for-url="yes" encode="no"/>
						  				<ui:column id="fwm-simple-name"	 align="left" title="{sw:text('Name')}" sorting="yes"/>
						  				<ui:column id="fwm-simple-description"	 align="left" title="{sw:text('Description')}" sorting="yes"/>	
								  	</ui:cols>
									</xsl:with-param>
								</xsl:call-template>
							</xsl:variable>

							<xsl:variable name="filter">
								<xsl:call-template name="browse:fill-filter">
									<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
									<xsl:with-param name="rows">
										<ui:browse-rows>
									  	<xsl:for-each select="$fwm-simple-rules/set[not(selected)]">
												<ui:row>
													<fwm-simple-rule-uniq-id>
														<xsl:value-of select="fwm-simple-rule-uniq-id"/>
													</fwm-simple-rule-uniq-id>
													<fwm-simple-name>
														<xsl:value-of select="name"/>
													</fwm-simple-name>
													<fwm-simple-description>
														<xsl:value-of select="description"/>	
													</fwm-simple-description>
												</ui:row>
											</xsl:for-each>
										</ui:browse-rows>
									</xsl:with-param>
								</xsl:call-template>
							</xsl:variable>

							<ui:browse title="{sw:text('Access rules to be added')}">
								<ui:filter>
	      					<xsl:copy-of select="$filter"/>
					      </ui:filter>
				         
	      				<ui:browse-empty-msg>
							  	<sw:text>
									All access rules have been added already.
								</sw:text>
								</ui:browse-empty-msg>

								<ui:browse-js-many>
									<ui:warn><sw:text>Select at least one access rule!</sw:text></ui:warn>
								</ui:browse-js-many>
								                                  
							</ui:browse>
							<ui:buttons>
								<xsl:call-template name="wiz:showButtons">
									<xsl:with-param name="submit-script">
										if (!atLeastOne()) return false;
									</xsl:with-param>
									<xsl:with-param name="next-script">
										if (!atLeastOne()) return false;
									</xsl:with-param>
									<xsl:with-param name="show-submit" select="boolean(count($fwm-simple-rules/set[not(selected)]))"/>
								</xsl:call-template>
							</ui:buttons>							
						</ui:block>
					</xsl:when>
					<xsl:otherwise>
						<ui:block>
							<ui:operation-problem>
								<xsl:copy-of select="$oper-problem"/>
								<ui:descr><sw:text>Unable to manage the firewall in this Container.</sw:text></ui:descr>
							</ui:operation-problem>
						</ui:block>
					</xsl:otherwise>
				</xsl:choose>
    	</ui:content>          
    </ui:screen>
	</xsl:template>

	<!-- Wizard, Step 'Configure VE' -->
  <xsl:template name="edit-one-simple-rule">
  	<xsl:variable name="selected-ruleset" select="$fwm-simple-rules/set[fwm-simple-rule-uniq-id = $form/fwm-simple-rule-uniq-id]"/>
    <ui:screen path-id="ve-fwm-simple-rule" id="{$screen-id}" title="{sw:text('View Access Rule')}" icon="fwm_simple_rule_edit">
	    <ui:properties>
    	  <ui:description width="full" mandatory="yes">
					<sw:text>
						On this screen you can view the details of the access rule.
					</sw:text>
  	    </ui:description>      
  	    <ui:form-get/>
    	</ui:properties>

  	  <ui:content>
				<ui:hidden name="step" value="edit"/>
				<ui:block>
					<ui:rows title="{sw:text('Access Rule')}">
			    	<ui:row>
      		  	<ui:cell-label>  
          			<sw:text>Name</sw:text>
				      </ui:cell-label>
  	    		 	<ui:cell-value>
    	  		 		<xsl:value-of select="$selected-ruleset/name"/>
		 		      </ui:cell-value>
      			</ui:row>
			    	<ui:row>
      		  	<ui:cell-label>  
          			<sw:text>Description</sw:text>
				      </ui:cell-label>
  	    		 	<ui:cell-value>
    	  		 		<xsl:value-of select="$selected-ruleset/description"/>
		 		      </ui:cell-value>
      			</ui:row>
					</ui:rows>
				</ui:block>
    	</ui:content>          
    </ui:screen>  
  </xsl:template>
      
	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
		<xsl:choose>
			<xsl:when test="$step = 'add'">
				<xsl:call-template name="add-one-simple-rule"/>
			</xsl:when>
			<xsl:when test="$step = 'edit'">
				<xsl:call-template name="edit-one-simple-rule"/>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/core/browse-filter-raw.xsl" />
  <sw:include href="/lib/wizard.xsl"/>
  <sw:include href="/lib/vocabulary.xsl"/>

  <sw:include href="/lib/vza/fwm.xsl"/>
  <sw:include href="/lib/fwm.xsl"/>
	
</xsl:stylesheet>
