<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl browse cred"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:fwm="http://www.swsoft.com/xsl/cp/fwm"
>

	<xsl:variable name="eid" select="sw:ve-eid()"/>
	<!-- check permissions to show this page -->
	<xsl:variable name="cr-fwm-simple"
		select="cred:check-env('vzcp.env.manage.services_and_files',$eid)"/>
	<xsl:variable name="cr-fwm-advanced"
		select="$cr-fwm-simple"/>
	<!-- setup allowed only of user has ability choose mode -->
	<xsl:variable name="cr-fwm-setup" select="$cr-fwm-simple and $cr-fwm-advanced"/>
	<xsl:variable name="cr-fwm-simple-rule-add"
		select="$cr-fwm-simple"/>
	<xsl:variable name="cr-fwm-simple-rule-delete"
		select="$cr-fwm-simple"/>

	<xsl:param name="access-denied" select="not($cr-fwm-simple)"/>

	<xsl:variable name="fwm-simple-rules" select="sw:sesget('fwm-simple-rules')"/>
	<xsl:variable name="fwm-rules" select="sw:sesget('fwm-rules')"/>

	<xsl:template mode="screen" match="/">
		<ui:screen path-id="ve-fwm" id="03.02.01.18.07" icon="fwm">
			<ui:properties>
				<ui:description width="max">
					<sw:text>On this screen you can manage the Container firewall.</sw:text>
				</ui:description>
				<ui:form-get/>
			</ui:properties>

			<ui:content>
				<ui:block width="max">
					<!-- filter init -->
					<xsl:variable name="filter_init_">
						<xsl:call-template name="browse:init-filter">
							<xsl:with-param name="browse">
								<ui:browse-setup id="fwm" url="/vzdir/infrman/envs/fwm/simple"
									item-url="/vzdir/infrman/envs/fwm/simple-rule" item-url-tip="fwm_simple_rule_edit"
									select-column="fwm-simple-rule-uniq-id"/>
								<ui:cols>
									<xsl:if test="$cr-fwm-simple-rule-delete">
										<ui:column id="fwm-simple-rule-uniq-id" for-select="yes" hidden="yes"
											for-url="yes" encode="no"/>
									</xsl:if>
									<ui:column id="fwm-simple-name" show-url="no" align="left"
										title="{sw:text('Name')}" sorting="yes"/>
									<ui:column id="fwm-simple-description" align="left"
										title="{sw:text('Description')}" sorting="yes"/>
								</ui:cols>
							</xsl:with-param>
						</xsl:call-template>
					</xsl:variable>

					<xsl:variable name="filter">
						<xsl:call-template name="browse:fill-filter">
							<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
							<xsl:with-param name="rows">
								<ui:browse-rows>
									<xsl:for-each select="$fwm-simple-rules/set[selected]">
										<ui:row>
											<fwm-simple-rule-uniq-id>
												<xsl:value-of select="fwm-simple-rule-uniq-id"/>
											</fwm-simple-rule-uniq-id>
											<fwm-simple-name>
												<xsl:value-of select="name"/>
											</fwm-simple-name>
											<fwm-simple-description>
												<xsl:value-of select="description"/>
											</fwm-simple-description>
										</ui:row>
									</xsl:for-each>
								</ui:browse-rows>
							</xsl:with-param>
						</xsl:call-template>
					</xsl:variable>

					<ui:browse title="{sw:text('Access Rules')}">
						<ui:browse-buttons type="list-selection">
							<xsl:if test="$cr-fwm-simple-rule-add">
								<ui:button require-items="false" name="fwm-rule-add" icon="new"
									new-obj-title="{sw:text('Access Rule')}"
									submit-href="{$baseurl}/vzdir/infrman/envs/fwm/simple-rule" tip="fwm_simple_rule_add" auxiliary="true">
									<sw:text>Add Access Rule</sw:text>
								</ui:button>
							</xsl:if>						
							<xsl:if test="$cr-fwm-simple-rule-delete">
								<ui:button require-items="false" type="list-selection" tip="fwm_simple_rule_delete" icon="delete"
									confirmation="{sw:text('Are you sure you want to delete the selected access rule(s)?')}"
									script="if (!atLeastOne()) return false;" name="fwm-rule-delete">
									<sw:text>Delete</sw:text>
								</ui:button>
							</xsl:if>
							<xsl:if test="$cr-fwm-setup">
								<ui:button require-items="false" name="fwm-setup" icon="fwm"
									submit-href="{$baseurl}/vzdir/infrman/envs/fwm/setup?mode-selector=1" tip="fwm_setup" auxiliary="true">	
									<sw:text>Firewall Setup</sw:text>
								</ui:button>						
							</xsl:if>							
						</ui:browse-buttons>
						<ui:filter>
							<xsl:copy-of select="$filter"/>
						</ui:filter>
						<ui:browse-empty-msg>
							<sw:text>
			  				  	No access rules defined.
									</sw:text>
						</ui:browse-empty-msg>
						<ui:browse-js-many>
							<ui:warn>
								<sw:text>Select at least one access rule!</sw:text>
							</ui:warn>
						</ui:browse-js-many>
					</ui:browse>
				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/core/browse-filter-raw.xsl" />
	<sw:include href="/lib/vza/fwm.xsl"/>
	<sw:include href="/lib/fwm.xsl"/>

</xsl:stylesheet>
