<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz tem cred voc vzenv html env-samplem format"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl	="http://exslt.org/common"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
  xmlns:wiz		="http://www.swsoft.com/xsl/cp/wiz"
  xmlns:tem		="http://www.swsoft.com/xsl/cp/tem"
  xmlns:hn		="http://www.swsoft.com/xsl/cp/hn"  
  xmlns:env		="http://www.swsoft.com/xsl/cp/env"  
  xmlns:vzenv	="http://www.swsoft.com/xsl/cp/vzenv"
  xmlns:local	="http://www.swsoft.com/xsl/cp/local"
  xmlns:form	="http://www.swsoft.com/xsl/cp/form"
  xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
  xmlns:func	="http://exslt.org/functions"
	xmlns:cred 	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:voc  	="http://www.swsoft.com/xsl/cp/voc"
	xmlns:env-samplem			="http://www.swsoft.com/xsl/cp/env-samplem"
	xmlns:html	="http://www.swsoft.com/xsl/cp/html"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:format="http://www.swsoft.com/xsl/cp/format"
>
	<sw:include href="/layout/forms-list.xsl"/>
	<sw:include href="/lib/utils/format-resusage.xsl"/>	
	<sw:include href="/lib/swa/env-samplem.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>	
	<sw:include href="/lib/vt/hn-core.xsl"/>
	
	<sw:include href="/lib/vz/vzenv-net-core.xsl"/>
	<sw:include href="/lib/vz/vzenv-net-ui.xsl"/>
	<sw:include href="/lib/vz/vzenv-core.xsl"/>
	<sw:include href="/lib/vz/vzenv-net.xsl"/>
	<sw:include href="/lib/vz/vzenv-os.xsl"/>
	<sw:include href="/lib/vz/vzenv-qos.xsl"/>
	
  <xsl:param name="wiz_code" select="'migrate-ve'"/>
  
	<xsl:variable name="step_data"	select="wiz:getStep()"/>
	<xsl:variable name="form"				select="sw:sesget($wiz_data)"/>	
	<xsl:variable name="step"				select="$step_data/@id"/>
	
	<xsl:variable name="screen-id"			select="$step_data/@screen-id"/>

	<!-- check detail permissions to req -->
	<xsl:param name="access-denied" select="not(cred:check('vzcp.env.import'))"/>

  <!-- Wizard, Step 'Start' -->
  <xsl:template name="step_start">

		
  	<!-- Preload some data -->
  	<xsl:variable name="hn-title">
  		<xsl:choose>
  			<xsl:when test="$form/hn/eid!=''">
  				<xsl:value-of select="env:env2title(env:get-env($form/hn/eid)/env)"/>
  			</xsl:when>
  		</xsl:choose>
  	</xsl:variable>  	
  	<!-- /Preload some data -->  

  	<ui:screen id="{$screen-id}">
    <ui:properties>
      <ui:refresh-type>none</ui:refresh-type>
      <ui:description  mandatory="yes">     
       	<sw:text>
					Parallels Infrastructure Manager provides you with an effective tool for a fast and reliable physical to virtual machine migration. The migration procedure is rendered easy and smooth with the help of the Migration wizard, which consists of the following steps (some steps may be hidden if the server is configured in a certain way): <ol><li>Start - where you need to connect to the physical server being migrated; </li><li>Review Server - which allows you to check the physical server configuration; </li><li>Prepare Server - which gives you an opportunity to adjust the migration procedure details; </li><li>Configure Container - where you can set or edit the configuration of the Container you are going to migrate the physical server to; </li><li>Customize Container resources - designed for those who have selected the Customize Resources option at the previous step. It provides the resource parameters customization (optional). </li><li>Final - where you can review the migration settings and set the post-migration start/stop option. </li></ol> First you should set up the connection to the server.
      	</sw:text>
      </ui:description>      
		<ui:form-get/>
    </ui:properties>
    
    <ui:content>
      <ui:hidden name="step" value="{$step}"/>
      <ui:block mode="edit">
      
      	<!-- Setup connection -->
    		<ui:rows title="{sw:text('Source Physical Server')}">
    			<ui:row>
						<ui:cell-label><sw:text>IP Address or Hostname</sw:text></ui:cell-label>
						<ui:cell-input id="ip" maxlength="100" required="true" value="{$form/connect/ip}"/>
					</ui:row>
					<ui:row>
						<ui:cell-label>
	        		<sw:text>Administrator Name</sw:text>
	        	</ui:cell-label>
						<ui:cell-input id="user" maxlength="50" required="true" value="{$form/connect/user}"/>
					</ui:row>
    			<ui:row>
						<ui:cell-label>
	        		<sw:text>Administrator Password</sw:text>
	        	</ui:cell-label>
						<ui:cell-input id="password" maxlength="64" required="true" mode-password="true">
							<xsl:attribute name="value"><xsl:value-of select="$form/connect/password"/></xsl:attribute>
						</ui:cell-input>
					</ui:row>
    		</ui:rows>
    		<!-- @Setup connection -->
      	
      	<!-- Destination HN -->
      	<ui:rows title="{sw:text('Destination Hardware Node')}">
      		<ui:row>
						<ui:cell-label>
							<sw:text>Hardware Node</sw:text>
						</ui:cell-label>
			    	<ui:cell-selector id="hn" align="left" value="{$hn-title}" required="true"
			    		code-value="{$form/hn/eid}"
			    		link-tip="select_hn" 
				      link-onclick="open_details('{$baseurl}/vt/hns/select-one-popup?id=hn', 'hn_select');return false;"
				      link-caption="{sw:text('Select...')}"				      
				    />
					</ui:row>
      	</ui:rows>
      	
      	
        <ui:buttons>
		    	<xsl:call-template name="wiz:showButtons">
        		<xsl:with-param name="next-title" select="sw:text('Connect')"/>
        		<xsl:with-param name="next-sandclock" select="true()"/>
        	</xsl:call-template>
        </ui:buttons>
        
     </ui:block>
     
    </ui:content>   
    </ui:screen>
  </xsl:template>

	<!-- Wizard, Step 'Review HW' -->
  <xsl:template name="step_review_hw">

  	<ui:screen id="{$screen-id}">
  	
    <ui:properties>
      <ui:refresh-type>none</ui:refresh-type>
      <ui:description  mandatory="yes" width="max">
        <sw:text>
         	On this screen you can check the Hardware Node configuration. On the next step you will be asked to define the migration process details.
        </sw:text>
      </ui:description>      
      <ui:form-get/>
    </ui:properties>
    
    <ui:content>
      <ui:hidden name="step" value="{$step}"/>
      <ui:block mode="edit" width="max">
      
      	<xsl:variable name="sys" select="$form/hw/system"/>
      	<xsl:variable name="disk" select="$form/hw/disk"/>
      	<xsl:variable name="net" select="$form/hw/network"/>
      	<xsl:variable name="net-ifaces" select="$form/hw/network/interface[name!='lo']"/>
      	<!-- Hardware Info -->
    		<ui:rows title="{sw:text('Hardware Information')}">
	  			<ui:row>
	  				<ui:cell-label><sw:text>Architecture</sw:text></ui:cell-label>
	  				<ui:cell-value><xsl:value-of select="$sys/architecture"/></ui:cell-value>
					</ui:row>
					<ui:row>
	  				<ui:cell-label><sw:text>CPU</sw:text></ui:cell-label>
	  				<ui:cell-value>
	  					<sw:text>
	  						<xsl:with-param name="count" select="$sys/cpu/number"/>
	  						%count CPU - 
	  					</sw:text>
	  					&#160;<xsl:value-of select="$sys/cpu/name"/>
	  					,&#160;<xsl:value-of select="$sys/cpu/mhz"/>&#160;Mhz
	  				</ui:cell-value>
					</ui:row>
					<ui:row>
	  				<ui:cell-label><sw:text>Physical Memory</sw:text></ui:cell-label>
	  				<ui:cell-value>
	  					<sw:text>
	  						<xsl:with-param name="total" select="format:int2bytes($sys/memory/total,'mbyte')"/>
	  						<xsl:with-param name="free" select="format:int2bytes($sys/memory/free,'mbyte')"/>
	  						<xsl:with-param name="used" select="format:int2bytes($sys/memory/used,'mbyte')"/>
	  						Total %{total}, Used %{used}, Free %{free}
	  					</sw:text>
	  				</ui:cell-value>
					</ui:row>
					<ui:row>
	  				<ui:cell-label><sw:text>Swap Memory</sw:text></ui:cell-label>
	  				<ui:cell-value>
	  					<sw:text>
	  						<xsl:with-param name="total" select="format:int2bytes($sys/swap/total,'mbyte')"/>
	  						<xsl:with-param name="free" select="format:int2bytes($sys/swap/free,'mbyte')"/>
	  						<xsl:with-param name="used" select="format:int2bytes($sys/swap/used,'mbyte')"/>
	  						Total %{total}, Used %{used}, Free %{free}
	  					</sw:text>
	  				</ui:cell-value>
					</ui:row>
				</ui:rows>
				<!-- /Hardware Info -->		
				
				<!-- System Info -->
    		<ui:rows title="{sw:text('Network Information')}">
					<ui:row>
	  				<ui:cell-label><sw:text>Hostname</sw:text></ui:cell-label>
	  				<ui:cell-value><xsl:value-of select="$net/hostname"/></ui:cell-value>
					</ui:row>					
					<ui:row>
	  				<ui:cell-label><sw:text>Network Interfaces</sw:text></ui:cell-label>
	  				<ui:cell-value>
	  					<xsl:choose>
	  						<xsl:when test="$net-ifaces">
			  					<xsl:for-each select="$net-ifaces">
			  						<xsl:if test="position()!=1"><br/></xsl:if>
			  						<nobr><xsl:value-of select="name"/><xsl:if test="ipaddress!=''"> - <xsl:value-of select="ipaddress"/></xsl:if></nobr>
			  					</xsl:for-each>
			  				</xsl:when>
			  				<xsl:otherwise>
			  					<sw:text>No network interfaces.</sw:text>
			  				</xsl:otherwise>
			  			</xsl:choose>
	  				</ui:cell-value>
					</ui:row>
				</ui:rows>
				<!-- /System Info -->
				
						
				<!-- Disk  Info -->
    		<ui:rows title="{sw:text('Disk Partitions')}"  separate-tables="true">
    			<xsl:copy-of select="local:show-disks($disk/partition)"/>    			  		
				</ui:rows>
				<!-- /Disk Info -->
				
        <ui:buttons>
		    	<xsl:call-template name="wiz:showButtons"/>
        </ui:buttons>
        
     </ui:block>
     
    </ui:content>   
    </ui:screen>
  </xsl:template>    

	<!-- Wizard, Step 'Prepare HW' -->
  <xsl:template name="step_prepare_hw">

		<!-- Prepare data -->
		<xsl:variable name="voc-args">
			<category>service</category>            
		</xsl:variable>
		<xsl:variable name="voc" select="voc:get($voc-args, env:make-platform-ref($form/hn/eid))"/>
		<xsl:variable name="services-src" select="local:get-services($form/hn,$form/hw/id)"/>
		<xsl:variable name="services-sorted-rtf">
			<xsl:if test="$services-src/servicem/service">
					<xsl:for-each select="$services-src/servicem/service[not(xinetd) and (name=$voc[data=0 or data=2]/id  or not(name=$voc/id))]">
					<xsl:sort select="name"/>
					<xsl:copy-of select="."/>
				</xsl:for-each>
			</xsl:if>
		</xsl:variable>
		<xsl:variable name="services" select="exsl:node-set($services-sorted-rtf)"/>
		<xsl:variable name="distrs" select="tem:get-distributions($form/hn/eid)/packet/data/tem/distribution"/>
		<xsl:variable name="disk" select="$form/hw/disk"/>
		
		<xsl:variable name="local-part" select="local:get-local-partition()/partition"/>
		<xsl:variable name="node-part-sum-rtf">
			<xsl:for-each select="$form/hw/disk/partition">
				<p><xsl:value-of select="block_size * blocks/used"/></p>
			</xsl:for-each>
		</xsl:variable>
		<xsl:variable name="node-part-inodes-rtf">
			<xsl:for-each select="$form/hw/disk/partition">
				<p><xsl:value-of select="inodes/used"/></p>
			</xsl:for-each>
		</xsl:variable>
		<xsl:variable name="local-part-sum" select="$local-part/block_size * $local-part/blocks/free"/>
		<xsl:variable name="node-part-sum" select="sum(exsl:node-set($node-part-sum-rtf)/p)"/>
		<xsl:variable name="node-part-inodes" select="sum(exsl:node-set($node-part-inodes-rtf)/p)"/>
		<!-- /Prepare data -->

  	<ui:screen id="{$screen-id}">
  	
    <ui:properties>
      <ui:refresh-type>none</ui:refresh-type>
      <ui:description  mandatory="yes">
        <sw:text>
         	On this screen you can customize the migration of the HN.
        </sw:text>
      </ui:description>      
      <ui:form-get/>
    </ui:properties>
    
    <ui:content>
      <ui:hidden name="step" value="{$step}"/>
      
      <ui:block mode="edit">

				<xsl:if test="$local-part/inodes/free  &lt;=$node-part-inodes">
        	<ui:rows title="{sw:text('Disk Inodes Warning')}">
      			<ui:row>
      				<ui:cell>
				       	<img src="/{$theme}/icons/alert_red.gif" width="16" height="16" border="0"/>&#160;
			       		<sw:text>
			       			<xsl:with-param name="local-partition" select="$local-part/mount_point"/>
			       			<xsl:with-param name="server-used" select="$node-part-inodes"/>
			       			<xsl:with-param name="local-free" select="$local-part/inodes/free"/>
			       			Warning! The available disk inodes on the local VE_PRIVATE partition <b>%{local-partition}</b> are not sufficient for the server full migration.
							<br/><br/>
							The server uses <b>%{server-used}</b> disk inodes, but the local VE_PRIVATE partition has only <b>%{local-free}</b> free disk inodes.
							<br/><br/>Please remove some unused data from the server and restart the migration wizard or exclude some server paths from the migration.
			       		</sw:text>
			       	</ui:cell>
      			</ui:row>
      		</ui:rows>
	      </xsl:if>
				<xsl:if test="$local-part-sum&lt;=$node-part-sum">
        	<ui:rows title="{sw:text('Disk Space Warning')}">
      			<ui:row>
      				<ui:cell>
				       	<img src="/{$theme}/icons/alert_red.gif" width="16" height="16" border="0"/>&#160;
			       		<sw:text>
			       			<xsl:with-param name="local-partition" select="$local-part/mount_point"/>
			       			<xsl:with-param name="server-used" select="format:int2bytes($node-part-sum,'mbyte')"/>
			       			<xsl:with-param name="local-free" select="format:int2bytes($local-part-sum,'mbyte')"/>
			       			Warning! The disk space available on the local VE_PRIVATE partition <b>%{local-partition}</b> is not enough for the server full migration. <br/><br/>The server uses <b>%{server-used}</b> of disk space, but the local VE_PRIVATE partition has only <b>%{local-free}</b> of free disk space. <br/><br/> Please remove some unused data from the server and restart the migration wizard or exclude some server paths from the migration.
			       		</sw:text>
			       	</ui:cell>
      			</ui:row>
      		</ui:rows>
	      </xsl:if>

      	<xsl:if test="$form/warning">
      		<ui:rows title="{sw:text('Migration Warnings')}">
      			<ui:row>
      				<ui:cell>
								<img src="/{$theme}/icons/exclamation_32.gif" width="32" height="32" border="0"/>
							</ui:cell>
							<ui:cell>
								&#160;&#160;
							</ui:cell>
							<ui:cell cell-width="100%" align="left">
								<xsl:for-each select="$form/warning/message">
									<li><sw:text domain="vzagent-vocabulary" select="."/></li>
								</xsl:for-each>
							</ui:cell>
      			</ui:row>
      		</ui:rows>
      	</xsl:if>
      
      	<ui:rows title="{sw:text('Distribution selection')}">
      		<ui:row>
      			<ui:cell colspan="2" required="true">
      				<xsl:choose>
      					<xsl:when test="$form/distr-precalc and $form/distr-precalc!=''">
		      				<sw:text>
		      					<xsl:with-param name="distr" select="$form/distr-precalc"/>
										The following distribution has been detected: "%{distr}".
									</sw:text>
								</xsl:when>
								<xsl:otherwise>
									<sw:text>
										Could not detect the server OS distribution.
									</sw:text>
								</xsl:otherwise>
							</xsl:choose>
							<br/>
							<sw:text>
								Your Virtuozzo server is able to support the following distributions, please confirm the selected one. <br/> If you cannot specify the distribution version, select "generic".
      				</sw:text>
      			</ui:cell>
      		</ui:row>
      		<ui:row>
      			<!-- try to preselect distrib -->
		    		<xsl:variable name="sel-distr">
	    				<xsl:choose>
	    					<!-- If distrib version was specified -->
	    					<xsl:when test="contains($form/distr,'-')">
	    						<xsl:variable name="name" select="substring-before($form/distr,'-')"/>
	    						<xsl:choose>
	    							<xsl:when test="$distrs[version!='' and concat(name,'-',version)=$form/distr]">
	    								<!-- return name-version -->
	    								<xsl:value-of select="$form/distr"/>
	    							</xsl:when>
	    							<xsl:when test="$distrs[version='' and name=$name]">
	    								<!-- return only name -->
	    								<xsl:value-of select="$name"/>
	    							</xsl:when>
	    							<xsl:otherwise>
	    								<xsl:value-of select="''"/>
	    							</xsl:otherwise>
	    						</xsl:choose>
	    					</xsl:when>
    						<!-- If distrib version was NOT specified -->
    						<xsl:otherwise>
	    						<xsl:choose>
	    							<xsl:when test="$distrs[version='' and name=$form/distr]">
	    								<!-- return only name -->
	    								<xsl:value-of select="$form/distr"/>
	    							</xsl:when>
	    							<xsl:when test="$distrs[version!='' and name=$form/distr]">
	    								<!-- return name-version -->
	    								<xsl:value-of select="concat($form/distr,'-',$distrs[version!='' and name=$form/distr]/version[1])"/>
	    							</xsl:when>
	    							<xsl:otherwise>
	    								<xsl:value-of select="''"/>
	    							</xsl:otherwise>
	    						</xsl:choose>
	    					</xsl:otherwise>
	    				</xsl:choose>
	    			</xsl:variable>
	    			<ui:cell-list id="distr" value="{$sel-distr}" required="true" style="width:180px" colspan="2">
	    				<!-- check for unknown/empty distr -->
	    				<xsl:choose>
	    					<!-- check for empty distr -->
	    					<xsl:when test="$sel-distr='' and (not($form/distr) or $form/distr='')">
	    						<ui:list-item id=""
										title="{sw:text('-- Select the distribution --')}"
									/>
	    					</xsl:when>
	    					<!-- check for unknown distr -->
		    				<xsl:when test="$sel-distr='' and ($form/distr and $form/distr!='')">
		    					<ui:list-item id=""
										title="{sw:text('-- Select the distribution --')}"
									/>								
		    				</xsl:when>
		    			</xsl:choose>
		    			<!-- list distributions -->
							<xsl:for-each select="$distrs">
								<xsl:sort select="concat(name,version)"/>
								<xsl:variable name="id" select="concat(name,sw:if(version!='',concat('-',version),''))"/>
								<xsl:variable name="name-src" select="name"/>
								<xsl:variable name="name-nice">
									<xsl:choose>
										<xsl:when test="version!=''">
											<xsl:value-of select="concat(name,'-',version)"/>
										</xsl:when>
										<xsl:when test="$distrs[name=$name-src and version!='']">
											<xsl:value-of select="concat(name,'&#160;',sw:text('(generic)'))"/>
										</xsl:when>																					
										<xsl:otherwise>
											<xsl:value-of select="name"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:variable>
								<ui:list-item id="{$id}" title="{$name-nice}"/>
							</xsl:for-each>				
						</ui:cell-list>		
	    		</ui:row>
	    	</ui:rows>
	    	
				<!-- Show Quota Partion -->
				<ui:rows title="{sw:text('Quota migration')}">
	    		<xsl:variable name="parts" select="$form/hw/disk/partition[option='usrquota' or option='grpquota' or option='quota']"/>
	    		<xsl:choose>
	    			<xsl:when test="$parts">
			    		<ui:row>
			    			<ui:cell colspan="2">
			    				<sw:text>
			    					The disk quotas are migrated from the Linux server to the Virtuozzo Container. Please select the quota source partition.
			    				</sw:text>
			    			</ui:cell>
			    		</ui:row>
			    		<ui:row>
			    			<ui:cell-list value="{$form/quota/partition}" id="quota_partition" style="width:180px"
			    				colspan="2">
			    				<ui:list-item id="" title="{sw:text('Do not migrate')}" />
			    				<xsl:for-each select="$parts">
			    					<xsl:sort select="name" />
			    					<ui:list-item id="{name}" title="{name}" />
			    				</xsl:for-each>
			    			</ui:cell-list>
			    		</ui:row>
	    			</xsl:when>
						<xsl:otherwise>
							<ui:row>
								<ui:cell>
									<sw:text>Your server does not have disk quotas enabled on it.</sw:text>
								</ui:cell>
							</ui:row>
						</xsl:otherwise>
					</xsl:choose>					
      	</ui:rows>
      	
      	<!-- Exclude -->
    		<ui:rows title="{sw:text('Exclude Paths')}" separate-tables="true">
    			<xsl:choose>
    				<xsl:when test="$form/paths-req/path">
		    			<ui:row>
		    				<ui:cell>
		    					<sw:text>
		    						This path will be excluded from the migration.
		    					</sw:text>
		    				</ui:cell>
		    			</ui:row>
		    			<xsl:for-each select="$form/paths-req/path">
			    			<ui:row>
			    				<ui:cell-input value="{.}" disabled="true" width="40"/>
			    			</ui:row>
			    		</xsl:for-each>
		    			<ui:row>
		    				<ui:cell>
		    					<sw:text>
		    						You can additionally exclude some paths from the migration process.
		    					</sw:text>
		    				</ui:cell>
		    			</ui:row>
		    		</xsl:when>
		    		<xsl:otherwise>
		    			<ui:row>
		    				<ui:cell>
		    					<sw:text>
		    						You can exclude some paths from the migration process.
		    					</sw:text>
		    				</ui:cell>
		    			</ui:row>
		    		</xsl:otherwise>
		    	</xsl:choose>
	  			<xsl:call-template name="form:show-list">
		 				<xsl:with-param name="config">				
							<code>paths</code>
							<add_label><sw:text>Add a new row.</sw:text></add_label>
							<remove_label><sw:text>Remove this row.</sw:text></remove_label> 				
							<xsl:for-each select="$form/paths/path">
								<ui:row>
				  				<ui:cell-input nowrap="1" width="40" maxlength="200" id="path" value="{.}" tip="exclude_path"/>
								</ui:row>							
							</xsl:for-each>
							<ui:new-row>
			  				<ui:cell-input width="40" nowrap="1" maxlength="200" id="path" value="" tip="exclude_path"/>
							</ui:new-row>								
						</xsl:with-param>
					</xsl:call-template>	
				</ui:rows>
				<!-- /Exclude-->
				
				<!-- Shutdown Services -->
				<ui:rows title="{sw:text('Stop Services')}">
					<xsl:choose>
						<xsl:when test="$services-src/servicem/error">
							<ui:row>
								<ui:cell colspan="2">
									<img src="/{$theme}/icons/alert_red.gif" width="16" height="16" hspace="5"/>
									<sw:text>
										Managing system services on this OS distribution is not supported. <br/> In order to guarantee data consistency, please log in to your server and stop the running services using the data to be preserved.
									</sw:text>
								</ui:cell>
							</ui:row>
						</xsl:when>
						<xsl:when test="$services/service">
							<ui:row>
								<ui:cell colspan="7" cell-width="100%">
									<sw:text>
Before the migration is started, it is highly recommended to stop all the services below. Running services can modify some files during the migration, which may result in errors.
									</sw:text>
								</ui:cell>
							</ui:row>
							<xsl:variable name="total" select="count($services/service)"/>
							<xsl:for-each select="$services/service[not((position()+2) mod 3)]">
								<xsl:variable name="pos" select="position()*3-2"/>
								<xsl:variable name="curr" select="."/>
								<ui:row>									
									<ui:cell-check value="{name}" id="srv_{$pos}">
										<xsl:if test="$form/services/srv[.=$curr/name]">
											<xsl:attribute name="checked">true</xsl:attribute>
										</xsl:if>
									</ui:cell-check>
	   							<ui:cell nowrap="1" label="srv_{$pos}"><xsl:value-of select="name"/></ui:cell>
									<xsl:for-each select="following-sibling::*[position()&lt;3]">	
										<xsl:variable name="inpos" select="$pos+position()*3-2"/>
										<xsl:variable name="incurr" select="."/>
			   						<ui:cell-check value="{name}" id="srv_{$pos+position()}">
				   						<xsl:if test="$form/services/srv[.=$incurr/name]">
												<xsl:attribute name="checked">true</xsl:attribute>
											</xsl:if>
										</ui:cell-check>
		   							<ui:cell nowrap="1" label="srv_{$pos+position()}"><xsl:value-of select="name"/></ui:cell>
		   						</xsl:for-each>
		   						<xsl:if test="(count(following-sibling::*)&lt;3 and $total&gt;3) or ($total&lt;3)">
		   							<ui:cell colspan="2">&#160;</ui:cell>
		   						</xsl:if>
		   						<xsl:if test="(count(following-sibling::*)&lt;2 and $total&gt;2) or ($total&lt;2)">
		   							<ui:cell colspan="2">&#160;</ui:cell>
		   						</xsl:if>
		   						<ui:cell cell-width="100%">&#160;</ui:cell>
	   						</ui:row>
							</xsl:for-each>
						</xsl:when>
						<xsl:otherwise>
							<ui:row>
								<ui:cell colspan="2">
									<sw:text>The server has no running services.</sw:text>
								</ui:cell>
							</ui:row>
						</xsl:otherwise>
					</xsl:choose>
				</ui:rows>
				<!-- /Shutdown Services -->
				
        <ui:buttons>
		    	<xsl:call-template name="wiz:showButtons"/>
        </ui:buttons>
        
     </ui:block>
     
    </ui:content>   
    </ui:screen>
  </xsl:template>    
  
  <!-- Wizard, Step 'Prepare HW(windows)' -->
  <xsl:template name="step_prepare_hw_windows">
	
		<xsl:variable name="disk" select="$form/hw/disk"/>
		
		<xsl:variable name="local-part" select="local:get-local-partition()/partition"/>
		<xsl:variable name="node-part-sum-rtf">
			<xsl:for-each select="$form/hw/disk/partition">
				<p><xsl:value-of select="block_size * blocks/used"/></p>
			</xsl:for-each>
		</xsl:variable>
		<xsl:variable name="local-part-sum" select="$local-part/block_size * $local-part/blocks/free"/>
		<xsl:variable name="node-part-sum" select="sum(exsl:node-set($node-part-sum-rtf)/p)"/>
		<!-- /Prepare data -->

  	<ui:screen id="{$screen-id}">
  	
    <ui:properties>
      <ui:refresh-type>none</ui:refresh-type>
      <ui:description  mandatory="yes">
        <sw:text>
         	On this screen you can customize the HN migration.
        </sw:text>
      </ui:description>      
      <ui:form-get/>
    </ui:properties>
    
    <ui:content>
      <ui:hidden name="step" value="{$step}"/>
      
      <ui:block mode="edit">
				
				<xsl:if test="$local-part-sum&lt;=$node-part-sum">
        	<ui:rows title="{sw:text('Disk Space Warning')}">
      			<ui:row>
      				<ui:cell>
				       	<img src="/{$theme}/icons/alert_red.gif" width="16" height="16" border="0"/>&#160;
			       		<sw:text>
			       			<xsl:with-param name="local-partition" select="$local-part/mount_point"/>
			       			<xsl:with-param name="server-used" select="format:int2bytes($node-part-sum,'mbyte')"/>
			       			<xsl:with-param name="local-free" select="format:int2bytes($local-part-sum,'mbyte')"/>
			       			Warning! The disk space available on the local VE_PRIVATE partition <b>%{local-partition}</b> is not enough for the server full migration. <br/><br/>The server uses <b>%{server-used}</b> of disk space, but the local VE_PRIVATE partition has only <b>%{local-free}</b> of free disk space. <br/><br/> Please remove some unused data from the server and restart the migration wizard or exclude some server paths from the migration.
			       		</sw:text>
			       	</ui:cell>
      			</ui:row>
      		</ui:rows>
	      </xsl:if>

      	<xsl:if test="$form/warning">
      		<ui:rows title="{sw:text('Migration Warnings')}">
      			<ui:row>
      				<ui:cell>
								<img src="/{$theme}/icons/exclamation_32.gif" width="32" height="32" border="0"/>
							</ui:cell>
							<ui:cell>
								&#160;&#160;
							</ui:cell>
							<ui:cell cell-width="100%" align="left">
								<xsl:for-each select="$form/warning/message">
									<li><sw:text domain="vzagent-vocabulary" select="."/></li>
								</xsl:for-each>
							</ui:cell>
      			</ui:row>
      		</ui:rows>
      	</xsl:if>
      
      	<!-- Exclude -->
    		<ui:rows title="{sw:text('Select Drives for Migration')}">
    			<!-- $form/paths/path -->
    			<xsl:copy-of select="local:show-disks(
    				$disk/partition[fs_type=$form/hn-def/disk-supported-fs],
    				true(),$form/paths/path
    			)"/>    			  		    		
				</ui:rows>
				<!-- /Exclude-->
				
        <ui:buttons>
		    	<xsl:call-template name="wiz:showButtons"/>
        </ui:buttons>
        
     </ui:block>
     
    </ui:content>   
    </ui:screen>
  </xsl:template> 
  
  
  <!-- Wizard, Step 'Configure VE' -->
  <xsl:template name="step_config">

		<xsl:variable name="os_templates" select="vzenv:list-oses($form/hn/platform)"/>
		<xsl:variable name="sample_configs" select="env-samplem:list-samples('virtuozzo',$form/hn/eid,$form/hn/platform)"/>
		<xsl:variable name="conf" select="$form/ve"/>
		
		<xsl:variable name="os-rtf">
			<xsl:choose>
				<xsl:when test="$conf/os_template/name">
					<xsl:copy-of select="$conf/os_template"/>
				</xsl:when>
				<xsl:otherwise>
					<os_template>
						<xsl:variable name="os-templates" select="tem:list('os', $form/hn/eid)//tem/package"/>
						<name>
							<xsl:value-of select="$os-templates[contains(name,$form/distr)]/name[1]"/>
						</name>
						<version/>
					</os_template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

  	<ui:screen id="{$screen-id}">
  	
    <ui:properties>
      <ui:refresh-type>none</ui:refresh-type>
      <ui:description  mandatory="yes">
        <sw:text>
         	On this screen you can customize the configuration of the resulting Container.
        </sw:text>
      </ui:description>      
      <ui:form-get/>
    </ui:properties>
    
    <ui:content>
      <ui:hidden name="step" value="{$step}"/>
      <ui:block mode="edit">
      
      	<!-- OS -->
    		<ui:rows title="{sw:text('Container General Configuration')}">
    		
    			<ui:row>
						<ui:cell-label>
							<sw:text>Name</sw:text>
						</ui:cell-label>
						<ui:cell-input id="name" maxlength="255" required="true">
							<xsl:attribute name="value"><xsl:value-of select="$conf/name"/></xsl:attribute>
						</ui:cell-input>
					</ui:row>
    		
    			<ui:row>
      		 	<ui:cell-label>
	        		<sw:text>Select Container Sample</sw:text>
	        	</ui:cell-label>

	        	<xsl:variable name="tmpl-selector" select="concat($conf/template-id,'|',$conf/template-name)"/>
		        <ui:cell-list id="config" value="{$tmpl-selector}">
		        	<ui:list-item id="" title="{sw:text('Use precalculated resource parameters')}"/>
		        	<!--<xsl:attribute name="onchange">changedConfig(true)</xsl:attribute>-->
							<xsl:for-each select="$sample_configs">
								<xsl:sort select="name"/>
								<ui:list-item id="{concat(id,'|',name)}" title="{name}"/>
							</xsl:for-each>
						</ui:cell-list>
					</ui:row>
    		
	  			<ui:row>
						<xsl:variable name="setup">
							<xsl:copy-of select="$os-rtf"/>
							<init_on_start/>
							<os_templates><xsl:copy-of select="$os_templates"/></os_templates>
							<empty_os_text>&lt;<sw:text>No OS Template</sw:text>&gt;</empty_os_text>
							<empty_os_ver>&lt;<sw:text>No OS Version</sw:text>&gt;</empty_os_ver>
						</xsl:variable>
						<xsl:copy-of select="vzenv:show-os(exsl:node-set($setup))"/>
					</ui:row>
					<xsl:copy-of select="vzenv:edit-slm-mode($form/platform,$conf/slm,$form/hn-def/slm-hw-enabled,true())"/>
					<ui:row>		        	
						<ui:cell>
							<sw:text>Customize Resources</sw:text>
						</ui:cell>
	      		<ui:cell-check id="custom" checked="{$conf/custom = '1'}"/>
	      	</ui:row>  
				</ui:rows>
				
				<!-- Net -->
				<ui:rows title="{sw:text('Network Configuration')}">
   				<ui:row>
   					<ui:cell-label>
	        		<sw:text>Hostname</sw:text>
	        	</ui:cell-label>
						<ui:cell-input id="hostname" maxlength="256" required="true">
							<xsl:attribute name="value"><xsl:value-of select="$conf/hostname"/></xsl:attribute>
						</ui:cell-input>
					</ui:row>
					<ui:row>		        	
						<ui:cell>
							<sw:text>Customize Network Settings</sw:text>
						</ui:cell>
	      		<ui:cell-check id="custom_net" checked="{$conf/custom-net='1'}"/>
	      	</ui:row>  
				</ui:rows>
				
				<!-- Advanced -->
				<ui:rows title="{sw:text('Advanced')}" id="show_adv" status-def="0" status="{$conf/show_adv}" closed-text="{sw:text('Click to show the advanced settings (Container ID, etc.)')}">
					<ui:row>
						<ui:cell-check id="ask_veid" close="false">
              <xsl:if test="$conf/ask_veid=1">
                <xsl:attribute name="checked">true</xsl:attribute>
              </xsl:if>         
              <ui:control-slave>ve_id</ui:control-slave>
            </ui:cell-check>
						<ui:cell open="false" close="false">
	        		<nobr><sw:text>Assign Container ID</sw:text>&#160;&#160;</nobr>
	        	</ui:cell>
		         <ui:cell-input id="ve_id" maxlength="10" width="5" open="false">
							<xsl:attribute name="value"><xsl:value-of select="$conf/ve_id"/></xsl:attribute>
						</ui:cell-input>
		    	</ui:row>
			  </ui:rows>
			  <!-- /Advanced -->
				
				<xsl:variable name="confirm-message">
					<xsl:choose>
						<xsl:when test="$form/hn/windows and $form/ve/net/bridged[enabled='true']/iface/net-id=''">
							<sw:text>
								<xsl:with-param name="cr">\n</xsl:with-param>
								The Container will be created with a disconnected bridged network interface. To be able to start the Container, you will have to assign a virtual network to this interface after the migration.
								%{cr}%{cr}
								%{cr}To proceed, click OK.
								%{cr}To specify a virtual network now, click Cancel, select the Customize Network Settings checkbox, and click Next to manually specify the Container network configuration.
							</sw:text>
						</xsl:when>
					</xsl:choose>
				</xsl:variable>
				<xsl:variable name="js-confirm">
					<xsl:if test="$confirm-message!=''">
						if(!confirm('<xsl:value-of select="$confirm-message"/>')) return false;
					</xsl:if>
				</xsl:variable>
				
        <ui:buttons>
		    	<xsl:call-template name="wiz:showButtons">
						<xsl:with-param name="next-script" select="$js-confirm"/>	
					</xsl:call-template>
        </ui:buttons>
        
     </ui:block>
     
    </ui:content>   
    </ui:screen>
  </xsl:template>  
  
<!-- Wizard, Step 'Configure VE(windows)' -->
  <xsl:template name="step_config_windows">

		<xsl:variable name="conf" select="$form/ve"/>
			
  	<ui:screen id="{$screen-id}">
  	
    <ui:properties>
      <ui:refresh-type>none</ui:refresh-type>
      <ui:description  mandatory="yes">
        <sw:text>
         	On this screen you can customize the configuration of the resulting Container.
        </sw:text>
      </ui:description>      
      <ui:form-get/>
    </ui:properties>
    
    <ui:content>
      <ui:hidden name="step" value="{$step}"/>
      <ui:block mode="edit">
           
				<!-- Advanced -->
				<ui:rows title="{sw:text('Container configuration')}">
					
					<ui:row>
	 					<ui:cell-radio name="id_type" id="id_type_auto" value="auto">
	 						<xsl:if test="not($conf/ask_veid='1')">
	 							<xsl:attribute name="checked">true</xsl:attribute>
	 						</xsl:if>
	 						<ui:control-slave inverse="true">ve_id</ui:control-slave>
	 					</ui:cell-radio>
						<ui:cell-text cell-width="100%" align="left" colspan="2">
							<sw:text>Select Container ID automatically</sw:text>
						</ui:cell-text>
					</ui:row>
					
					<ui:row>
	 					<ui:cell-radio name="id_type" id="id_type_set" value="set">
	 						<xsl:if test="$conf/ask_veid='1'">
	 							<xsl:attribute name="checked">true</xsl:attribute>
	 						</xsl:if>
	 						<ui:control-slave>ve_id</ui:control-slave>
	 					</ui:cell-radio>
						<ui:cell-text cell-width="100%" align="left" close="false">
							<sw:text>Set Container ID manually to</sw:text>&#160;&#160;
						</ui:cell-text>
						<ui:cell-input id="ve_id" maxlength="10" width="5" open="false">
							<xsl:attribute name="value"><xsl:value-of select="$conf/ve_id"/></xsl:attribute>
						</ui:cell-input>
					</ui:row>
					
					<!--
					<ui:row>					
						<ui:cell-check id="ask_veid" close="false">
              <xsl:if test="$conf/ask_veid=1">
                <xsl:attribute name="checked">true</xsl:attribute>
              </xsl:if>         
              <ui:control-slave>ve_id</ui:control-slave>
            </ui:cell-check>
						<ui:cell open="false" close="false">
	        		<nobr><sw:text>Select Container ID</sw:text>&#160;&#160;</nobr>
	        	</ui:cell>
		         <ui:cell-input id="ve_id" maxlength="10" width="5" open="false">
							<xsl:attribute name="value"><xsl:value-of select="$conf/ve_id"/></xsl:attribute>
						</ui:cell-input>
		    	</ui:row>
		    	-->
			  </ui:rows>
			  <!-- /Advanced -->
				
        <ui:buttons>
		    	<xsl:call-template name="wiz:showButtons"/>
        </ui:buttons>
        
     </ui:block>
     
    </ui:content>   
    </ui:screen>
  </xsl:template>    
  
  <!-- Step 'QoS Custom Settings' -->
  <xsl:template name="step_custom">      
  	<ui:screen id="{$screen-id}">
  	
	  	<!-- Load some VZ data -->
	  	<xsl:variable name="qos-warns-src">
				<xsl:if test="sw:param('validate') and error:is-empty()">				
					<xsl:call-template name="sw:validateQoS">
						<xsl:with-param name="hn-eid" select="$form/hn/eid"/>
						<xsl:with-param name="data" select="$form/ve-qos"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:variable>				  	  	
	  	<xsl:variable name="qos-warns" select="exsl:node-set($qos-warns-src)"/>
	  	<xsl:if test="$qos-warns//error/code">
	  		<xsl:if test="error:put(sw:text('The resources validation has failed.'),$qos-warns/packet//error/message)"/>
	  	</xsl:if>  	
	  	<!-- /Load some VZ data -->  	
	  	
			<ui:properties>
				<ui:form-post/>			
				<ui:refresh-type>none</ui:refresh-type>
				<ui:description  mandatory="yes" width="full">
					<sw:text>
					Customize Container Configuration
					</sw:text>
				</ui:description>      
			</ui:properties>
	    
			<ui:content>
				<ui:hidden name="step" value="custom"/>    
				<ui:block mode="edit" width="100%">
				
					<!-- Show QoS warnings-->
					<xsl:call-template name="sw:getQoSValidateResults">
						<xsl:with-param name="qos" select="$form/ve-qos"/>
						<xsl:with-param name="qos-warns" select="$qos-warns"/>
					</xsl:call-template>	
			
					<!-- Show Form -->
					<xsl:call-template name="vzenv:edit-qos">
						<xsl:with-param name="platform-ref" select="env:make-platform-ref($form/hn/eid,$form/platform)"/>
						<xsl:with-param name="data" select="$form/ve-qos"/>
						<xsl:with-param name="slm-mode" select="$form/ve/slm"/>
						<xsl:with-param name="qos-warns" select="$qos-warns/packet/data/vzaenvm/validation"/>
						<xsl:with-param name="mode" select="'create'"/>	
						<xsl:with-param name="disk-quota-enabled" select="$form/hn-def/disk-quota-enabled='true'"/>					
						<xsl:with-param name="warn-restart" select="false()"/>	
					</xsl:call-template>					
					<ui:buttons>
						<xsl:call-template name="wiz:showButtons">
							<xsl:with-param name="buttons-ext">								
								<xsl:if test="$form/hn/linux">
									<ui:button type="Validate" tip="ve_qos_validate" name="validate" sandclock="true"><sw:text>Validate</sw:text></ui:button>
								</xsl:if>
							</xsl:with-param>
						</xsl:call-template>
					</ui:buttons>
						
				</ui:block>
			</ui:content>   
		</ui:screen>
  </xsl:template>       

 <!-- Wizard, Step 'Network Interfaces' -->
  <xsl:template name="step_net">
  	<ui:screen id="{$screen-id}">
  	<!-- Load some VZ data -->
  	<!-- /Load some VZ data -->  	
    <ui:properties>
      <ui:refresh-type>none</ui:refresh-type>
      <ui:description  mandatory="yes" width="max">
        <sw:text>
					On this step you can configure the Container network interfaces.
        </sw:text>
      </ui:description>      
      <ui:form-get/>
    </ui:properties>
    
    <ui:content>
      <ui:hidden name="step" value="net"/>    
      <ui:block mode="edit">
      
				<xsl:call-template name="vzenv:edit-net">
					<xsl:with-param name="env-form" select="$form"/>
					<xsl:with-param name="ve-net" select="$form/ve/net"/>						
					<xsl:with-param name="options-rtf">
						<exclude-hostname/>
					</xsl:with-param>												
				</xsl:call-template>
    		      
        <ui:buttons>
					<xsl:call-template name="wiz:showButtons">
						<xsl:with-param name="submit-title" select="sw:text('Clone')"/>
						<xsl:with-param name="submit-tip" select="'start_ve_clone'"/>
					</xsl:call-template>
				</ui:buttons>
     </ui:block>
    </ui:content>   
    </ui:screen>
  </xsl:template> 
  
  <!-- Wizard, Step 'Final Confirmation' -->
  <xsl:template name="step_final">
  
  	<ui:screen id="{$screen-id}">
  	
    <ui:properties>
      <ui:refresh-type>none</ui:refresh-type>
      <ui:description mandatory="yes">
        <sw:text>Now you are ready to migrate the server.</sw:text>
      </ui:description>      
      <ui:form-get/>
    </ui:properties>
    
    <ui:content>
      <ui:hidden name="step" value="{$step}"/>
      <ui:block mode="edit">
				<xsl:variable name="bullet">
					<img src="/{$theme}/icons/check_green.gif" width="16" height="16" hspace="5"/>&#160;
				</xsl:variable>
				<xsl:variable name="alert">
					<img src="/{$theme}/icons/alert_yellow.gif" width="16" height="16" hspace="5"/>
				</xsl:variable>
				<xsl:variable name="space">
					<img src="/{$theme}/images/1x1.gif" width="16" height="16" hspace="5"/>&#160;
				</xsl:variable>
				
				<ui:rows title="{sw:text('Migration Details')}">
					<ui:row>
						<ui:cell-label><sw:text>Source Physical Server Address</sw:text></ui:cell-label>
						<ui:cell-value><b><xsl:value-of select="$form/connect/ip"/></b></ui:cell-value>
					</ui:row>
					<ui:row>
						<ui:cell-label><sw:text>Destination Container</sw:text></ui:cell-label>
						<ui:cell-value><b><xsl:value-of select="$form/ve/name"/></b></ui:cell-value>
					</ui:row>
				</ui:rows>
								
				<!-- Review server setup -->
				<ui:rows title="{sw:text('Review Server Configuraton')}">
					<xsl:if test="$form/hn/linux">
						<ui:row>
							<ui:cell>
								<xsl:copy-of select="$bullet"/>
								<sw:text>
									<xsl:with-param name="distr" select="$form/distr"/>
									You have selected the "%{distr}" server distribution type.
								</sw:text>
							</ui:cell>
						</ui:row>
					</xsl:if>				
					<xsl:if test="$form/paths/path or $form/paths-req/path">
						<ui:row>
							<ui:cell>
								<xsl:copy-of select="$bullet"/>
								<sw:text>The following paths will be excluded from the migration:</sw:text>
								<xsl:for-each select="$form/paths-req/path">
									<br/><xsl:copy-of select="$space"/>&#160;&#160;<xsl:value-of select="."/>
								</xsl:for-each>
								<xsl:for-each select="$form/paths/path">
									<br/><xsl:copy-of select="$space"/>&#160;&#160;<xsl:value-of select="."/>
								</xsl:for-each>
							</ui:cell>
						</ui:row>
					</xsl:if>
					<xsl:if test="$form/quota/partition!=''">
						<ui:row>
							<ui:cell>
								<xsl:copy-of select="$bullet"/>
								<sw:text>
									<xsl:with-param name="part" select="$form/quota/partition"/>
									You have selected the "%{part}" partition for migrating the Linux disk quotas.
								</sw:text>
							</ui:cell>
						</ui:row>						
					</xsl:if>
					<xsl:if test="$form/services/srv">
						<ui:row>
							<ui:cell>
								<xsl:copy-of select="$bullet"/>
								<sw:text>The following services will be stopped during the migration:</sw:text>
								<xsl:for-each select="$form/services/srv">
									<br/><xsl:copy-of select="$space"/>&#160;-&#160;<xsl:value-of select="."/>
								</xsl:for-each>
							</ui:cell>
						</ui:row>
					</xsl:if>
				</ui:rows>
				
				<xsl:if test="$form/hn/linux">
					<!-- Review VE setup -->
					<ui:rows title="{sw:text('Review Container Configuraton')}">
						<ui:row>
							<ui:cell>
								<xsl:copy-of select="$bullet"/>
								<xsl:choose>
									<xsl:when test="$form/ve/template-id and $form/ve/template-id!=''">
										<sw:text>
											<xsl:with-param name="template-name" select="$form/ve/template-name"/>
											The Container resource settings will be copied from the "%{template-name}" Container sample.
										</sw:text>
									</xsl:when>
									<xsl:otherwise>
										<sw:text>
											The Container will use precalculated resource parameters.
										</sw:text>
									</xsl:otherwise>
								</xsl:choose>
							</ui:cell>
						</ui:row>
						<xsl:if test="$form/ve/os_template and $form/ve/os_template/name!=''">
							<ui:row>
								<ui:cell>
									<xsl:copy-of select="$bullet"/>
									<sw:text>
										<xsl:with-param name="os" select="concat(
											$form/ve/os_template/name,
											sw:if($form/ve/os_template/version!='',concat('/',$form/ve/os_template/version),'')
										)"/>
										The Container will be based on the "%{os}" Virtuozzo OS template.
									</sw:text>
								</ui:cell>
							</ui:row>
						</xsl:if>
						<xsl:if test="$form/ve/ve_id!=''">
							<ui:row>
								<ui:cell>
									<xsl:copy-of select="$bullet"/>
									<sw:text>
										<xsl:with-param name="id" select="$form/ve/ve_id"/>
										The Container ID will be <b>%{id}</b>.
									</sw:text>
								</ui:cell>
							</ui:row>
						</xsl:if>
						<ui:row>
							<ui:cell>
								<xsl:copy-of select="$bullet"/>
								<sw:text>
									<xsl:with-param name="name" select="$form/ve/hostname"/>
									The Container hostname will be <b>%{name}</b>.
								</sw:text>
							</ui:cell>
						</ui:row>
					</ui:rows>
	      </xsl:if>
      	<ui:rows title="{sw:text('Post-Migration Procedures')}">
      		<ui:row>
 						<ui:cell-check id="start">
 							<xsl:if test="$form/final/start='1'">
 								<xsl:attribute name="checked">true</xsl:attribute>
 							</xsl:if>
 						</ui:cell-check>
 						<ui:cell cell-width="100%">
 							<sw:text>Stop physical server and start Container after migration</sw:text>
 						</ui:cell>
					</ui:row>
					<xsl:if test="$form/quota/partition!=''">
						<ui:row>
							<ui:cell>
								<xsl:copy-of select="$alert"/>
							</ui:cell>
							<ui:cell>
								<!--<table border="0" width="100%"><tr><td>-->
								<sw:text>
You have chosen to migrate the disk quotas from your server. To manage the disk quotas inside the resulting Container, you should install Virtuozzo-compatible quota tools in the Container after the migration. The needed package can be found in the <b>quota-tools</b> directory of the Virtuozzo distribution set.
								</sw:text>
								<!--</td></tr></table>-->
							</ui:cell>
						</ui:row>
					</xsl:if>
      	</ui:rows>
	      
        <ui:buttons>
        	<xsl:call-template name="wiz:showButtons">
        		<xsl:with-param name="submit-title" select="sw:text('Migrate')"/>
        	</xsl:call-template>
        </ui:buttons>
        
     </ui:block>
     
    </ui:content>   
    </ui:screen>
  </xsl:template>
  
  <!-- Wizard, Common screen 'Operation Problem' -->
  <xsl:template name="local:show-problem">
  	<xsl:param name="oper-problem"/>
  	
  	<ui:screen id="{$screen-id}">
	    <ui:properties>
			<ui:form-get/>
	    </ui:properties>
			<ui:content>
				<ui:block>
					<ui:operation-problem>
		    		<xsl:copy-of select="$oper-problem"/>
						<ui:descr><sw:text>Unable to migrate to the Container.</sw:text></ui:descr>
					</ui:operation-problem>
				</ui:block>
			</ui:content>
    </ui:screen>
    
  </xsl:template> 
  
 
	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
	
	
		<xsl:choose>
			<xsl:when test="$step = 'review_hw'">
				<xsl:call-template name="step_review_hw"/>
			</xsl:when>
			<xsl:when test="$step = 'custom'">
				<xsl:call-template name="step_custom"/>
			</xsl:when>
			<xsl:when test="$step = 'prepare_hw'">
				<xsl:call-template name="step_prepare_hw"/>
			</xsl:when>
			<xsl:when test="$step = 'prepare_hw_windows'">
				<xsl:call-template name="step_prepare_hw_windows"/>
			</xsl:when>
			<xsl:when test="$step = 'final'">
				<xsl:call-template name="step_final"/>
			</xsl:when>
			<xsl:when test="$step = 'config'">
				<xsl:call-template name="step_config"/>
			</xsl:when>
			<xsl:when test="$step = 'net'">
				<xsl:call-template name="step_net"/>
			</xsl:when>
<!--			
			<xsl:when test="$step = 'config_windows'">
				<xsl:call-template name="step_config_windows"/>
			</xsl:when>
-->			
			<xsl:otherwise>
				<xsl:call-template name="step_start"/>
			</xsl:otherwise>
		</xsl:choose>
		
	</xsl:template>

	<!-- Ask VZA about VZ VE0 Info-->
	<func:function name="local:get-local-partition">
		<xsl:param name="ve-private" select="$form/hn-def/ve_private" />
		<xsl:variable name="req">
			<packet>
				<target><xsl:value-of select="$form/hw/id"/></target>		
				<dst>
					<target>hwm</target>
				</dst>
				<data>
					<hwm>
						<get_disk/>
					</hwm>
				</data>
			</packet>
		</xsl:variable>
		<xsl:variable name="disk" select="sw:xchg($req)/packet/data/hwm/disk"/>
		<xsl:variable name="res-rtf">
			<xsl:for-each select="$disk/partition[contains($ve-private,mount_point)]">
				<xsl:sort select="string-length(mount_point)" order="descending" data-type="number"/>
				<xsl:if test="position()=1"><xsl:copy-of select="."/></xsl:if>
			</xsl:for-each>
		</xsl:variable>
		<func:result select="exsl:node-set($res-rtf)"/>
	</func:function>
	
	
	<func:function name="local:show-disks">
		<xsl:param name="partition"/>
		<xsl:param name="allow-select" select="false()"/>
		<xsl:param name="unselected" select="/.."/>
		<func:result>
			<ui:browse>
				<ui:filter>
					<ui:browse-setup hide-filter-controls="true" post-only-rows="true" select-on-left="true"/>
					<ui:cols>
						<xsl:choose>
    					<xsl:when test="$form/hn/windows">
    						<ui:column id="disk-id" align="left" title="{sw:text('Drive')}">
    							<xsl:if test="$allow-select">
    								<xsl:attribute name="for-select">yes</xsl:attribute>
    							</xsl:if>
    						</ui:column>
    					</xsl:when>
    					<xsl:otherwise>
    						<ui:column id="disk-id" align="left" title="{sw:text('Name')}">
    							<xsl:if test="$allow-select">
    								<xsl:attribute name="for-select">yes</xsl:attribute>
    							</xsl:if>
    						</ui:column>    					
    						<ui:column id="mounted" align="left" title="{sw:text('Mounted')}"/>
    					</xsl:otherwise>
    				</xsl:choose>			    						
						<ui:column id="type" align="left" title="{sw:text('File System')}"/>
						<ui:column id="total-space" align="right" title="{sw:text('Total Space')}"/>
						<ui:column id="used-space" align="right" title="{sw:text('Used Space')}"/>
						<ui:column id="free-space" align="right" title="{sw:text('Free Space')}"/>
						<xsl:if test="$form/hn/linux">
							<ui:column id="total-inodes" align="right" title="{sw:text('Total Inodes')}"/>
  						<ui:column id="used-inodes" align="right" title="{sw:text('Used Inodes')}"/>
  						<ui:column id="free-inodes" align="right" title="{sw:text('Free Inodes')}"/>
						</xsl:if>
					</ui:cols>
					<ui:coords total="{count($partition)}" from="1" count="{count($partition)}"/>
					<ui:browse-rows>
						<xsl:for-each select="$partition">
							<xsl:variable name="id" select="sw:if($form/hn/windows,mount_point,name)"/>
							<ui:row>
								<xsl:if test="not($unselected[.=$id])">
									<xsl:attribute name="selected-checkbox">yes</xsl:attribute>
								</xsl:if>
								<xsl:if test="$id='C:\'">
									<xsl:attribute name="disable-checkbox">yes</xsl:attribute>
								</xsl:if>
			  				<disk-id><xsl:value-of select="$id"/></disk-id>
			  				<mounted><xsl:value-of select="mount_point"/></mounted>
			  				<type><xsl:value-of select="fs_type"/></type>
			  				<total-space><xsl:value-of select="format:int2bytes(blocks/total*block_size)"/></total-space>
			  				<used-space><xsl:value-of select="format:int2bytes(blocks/used*block_size)"/></used-space>
			  				<free-space><xsl:value-of select="format:int2bytes(blocks/free*block_size)"/></free-space>
			  				<xsl:if test="$form/hn/linux">
				  				<total-inodes><xsl:value-of select="inodes/total"/></total-inodes>
				  				<used-inodes><xsl:value-of select="inodes/used"/></used-inodes>
				  				<free-inodes><xsl:value-of select="inodes/free"/></free-inodes>
				  			</xsl:if>
							</ui:row>
						</xsl:for-each>
					</ui:browse-rows>
				</ui:filter>
			</ui:browse>    	
  	</func:result>
	</func:function>
	
	<!-- Ask VZA about Linux Box Services-->
	<func:function name="local:get-services">
		<xsl:param name="hn"/>			
		<xsl:param name="connect-id"/>
		<xsl:variable name="req">
			<packet>
				<target><xsl:value-of select="$connect-id"/></target>
				<dst>
					<!--<host><xsl:value-of select="$hn/eid"/></host>-->
					<target>servicem</target>
				</dst>
				<data>
					<servicem>
						<get/>
					</servicem>
				</data>
			</packet>
		</xsl:variable>
		<func:result select="sw:xchg($req)/packet/data"/>
	</func:function>

	<!-- credentials -->
	
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/vza/tem.xsl"/>
	<sw:include href="/lib/vza/hwm.xsl"/>
	
	<sw:include href="/lib/screen.xsl"/>
	
	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
