<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred vzenv local env show voc"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:error="http://www.swsoft.com/xsl/cp/error"
  xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
  xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
  xmlns:func="http://exslt.org/functions"
	xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
	xmlns:vt		="http://www.swsoft.com/xsl/cp/vt"
	xmlns:env		="http://www.swsoft.com/xsl/cp/env"	
	xmlns:vzenv		="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:local	="http://www.swsoft.com/xsl/cp/local"
	xmlns:show	="http://www.swsoft.com/xsl/cp/show"   
	xmlns:voc		="http://www.swsoft.com/xsl/cp/voc"   
 >
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vz/vzenv-core.xsl"/>
	<sw:include href="/lib/vz/vzenv-net.xsl"/>

  <xsl:param name="wiz_code" 					select="'ves_list_clone'"/>
  
	<xsl:variable name="step_data"			select="wiz:getStep()"/>
	<xsl:variable name="step"						select="$step_data/@id"/>
	<xsl:variable name="screen-id"			select="$step_data/@screen-id"/>
  <xsl:variable name="form" 					select="sw:sesget($wiz_data)"/>  
  
  <!-- izWard, Step 'Clone VEs ' -->
  <xsl:template name="step_clone">
  	
  	<ui:screen id="{$screen-id}">
  	
	    <ui:properties>
	      <ui:refresh-type>none</ui:refresh-type>	        
	      <ui:form-get/>
	    </ui:properties>
	    
	    <ui:content>
	      <ui:hidden name="step" value="clone"/>    
	      <ui:block mode="edit">
	      
	      	<!-- Setup VEs -->
	      	<xsl:for-each select="$form/env">
    				<xsl:variable name="env" select="."/>
    				<xsl:variable name="index" select="position()"/>
    				
    				<ui:rows separate-tables="true">    		
    					<!-- VE Block title -->			
    					<xsl:attribute name="title">
		        		<sw:text>
		        			<xsl:with-param name="title" select="$env/src/title"/>
		        			Settings for Cloning Container "%{title}"
		        		</sw:text>
		        	</xsl:attribute>
		        	<!-- Name -->
      				<ui:row>
      					<ui:cell-label>
      						<sw:text>Name</sw:text>
      					</ui:cell-label>
      					<ui:cell-input id="name_{$index}" maxlength="255" required="true" value="{$env/name}"/>
      				</ui:row>
	      			<!-- Hostname -->
	      			<ui:row>
	      				<ui:cell-label/>
								<ui:cell-text>
									<ui:text-disabled>
										<sw:text>Leave the field empty to use the existing hostname.</sw:text>
									</ui:text-disabled>
								</ui:cell-text>
							</ui:row>
      				<ui:row>
      					<ui:cell-label>
      						<sw:text>Hostname</sw:text>
      					</ui:cell-label>
      					<ui:cell-input id="hostname_{$index}" 
      						maxlength="{vzenv:get-hostname-lenght(env:make-platform-ref($env/src/hn-eid,$env/src/platform))}"
      						value="{$env/hostname}"
      					/>
      				</ui:row>      	
      				<!-- Net interfaces -->
      				<xsl:call-template name="local:show-ve-net-ifaces">
      					<xsl:with-param name="env" select="$env"/>
      					<xsl:with-param name="index" select="$index"/>
      				</xsl:call-template>
      				<!-- /Net interfaces -->
	      		</ui:rows>
      		</xsl:for-each>
	      	<!-- /Setup VEs -->
	      
	      	<!-- Advanced -->
					<ui:rows title="{sw:text('Post Procedures')}">
										
			      <ui:row>
			      	<ui:cell-check id="start" close="false" checked="{$form/clone/start}"/>
				      <ui:cell open="false">
								<sw:text>Start the Containers after cloning.</sw:text>
				      </ui:cell>
			      </ui:row>
		      	
        	</ui:rows>
					<!-- /Advanced -->		
	      
		  	  <ui:buttons>
	        	<xsl:call-template name="wiz:showButtons">
	        		<xsl:with-param name="submit-title" select="sw:text('Clone')"/>
							<xsl:with-param name="next-title" select="sw:text('Clone')"/>	        		
	        	</xsl:call-template>
	        </ui:buttons>
	        
	     	</ui:block>
	    </ui:content>   
    </ui:screen>
  </xsl:template>
  
 	<xsl:template name="local:show-ve-net-ifaces">
		<xsl:param name="env"/>
		<xsl:param name="index"/>
		
		<!-- Routed -->
		<xsl:for-each select="$env/net/routed[to-edit]">
			<xsl:variable name="iface" select="."/>
		
			<ui:row>			
				<ui:cell-label><sw:text>Routed Network</sw:text>&#160;</ui:cell-label>
			</ui:row>
	
			<ui:row>
				<ui:cell-text offset="1">
					<img src="/{$theme}/icons/networkadapter_16.gif" width="16" height="16"/>&#160;
					<sw:text>
						<xsl:with-param name="id" select="$iface/id"/>
						Virtual Network Interface %{id}
					</sw:text>
				</ui:cell-text>
			</ui:row>
		
			<xsl:for-each select="ips/ip[to-edit]">
				<xsl:call-template name="vzenv:edit-ip">
					<xsl:with-param name="code" select="concat('routed_ip_',$index,'_',$iface/index,'_',index)"/>
					<xsl:with-param name="ip" select="."/>				
					<xsl:with-param name="label" select="sw:text('IP Address')"/>					
					<xsl:with-param name="pool-enabled" select="$form/def/ips-pool-enabled"/>					
					<xsl:with-param name="hn-platform" select="$env/src/platform"/>
					<xsl:with-param name="offset" select="4"/>										
					<xsl:with-param name="label-as-text" select="vt:is-platform-windows($env/src/platform)"/>					
				</xsl:call-template>
			</xsl:for-each>
		</xsl:for-each>
		
		<!-- Bridged-->
		<xsl:if test="$env/net/bridged/iface[to-edit]">
			<ui:row>			
				<ui:cell-label><sw:text>Bridged Network</sw:text>&#160;</ui:cell-label>
			</ui:row>
			<!-- Cycle on ifaces -->
			<xsl:for-each select="$env/net/bridged/iface[to-edit]">
				<xsl:variable name="iface" select="."/>
				<xsl:variable name="iface-index" select="index"/>
				<ui:row>
					<ui:cell-text offset="1">
						<img src="/{$theme}/icons/virtualswitch_16.gif" width="16" height="16"/>&#160;
						<sw:text>
							<xsl:with-param name="id" select="$iface/id"/>
							Virtual Ethernet Interface %{id}
						</sw:text>
					</ui:cell-text>
				</ui:row>
				
				<xsl:for-each select="ips/ip[to-edit]">
					<xsl:call-template name="vzenv:edit-ip">
						<xsl:with-param name="code" select="concat('bridged_ip_',$index,'_',$iface-index,'_',index)"/>
						<xsl:with-param name="ip" select="."/>				
						<xsl:with-param name="label" select="sw:text('IP Address')"/>					
						<xsl:with-param name="pool-enabled" select="$form/def/ips-pool-enabled"/>					
						<xsl:with-param name="hn-platform" select="$env/src/platform"/>
						<xsl:with-param name="offset" select="4"/>										
						<xsl:with-param name="label-as-text" select="vt:is-platform-windows($env/src/platform)"/>					
					</xsl:call-template>
				</xsl:for-each>
								
			</xsl:for-each>
			<!-- /Cycle on ifaces -->	
		</xsl:if>
		
		
	</xsl:template> 
  
	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
			<xsl:choose>			
				<xsl:when test="$step = 'clone'">
					<xsl:call-template name="step_clone"/>
				</xsl:when>				
			</xsl:choose>
	</xsl:template>
	 	
	<!-- UI modules -->
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>
	
	<!-- System modules -->
	<sw:include href="/lib/common.xsl"/>			

		
</xsl:stylesheet>
