<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred vzenv local env show voc hn"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:error="http://www.swsoft.com/xsl/cp/error"
  xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
  xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
  xmlns:func="http://exslt.org/functions"
	xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"	
	xmlns:env		="http://www.swsoft.com/xsl/cp/env"
	xmlns:vzenv		="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:local	="http://www.swsoft.com/xsl/cp/local"	
	xmlns:hn		="http://www.swsoft.com/xsl/cp/hn"	
	xmlns:show	="http://www.swsoft.com/xsl/cp/show"   
	xmlns:voc		="http://www.swsoft.com/xsl/cp/voc"   	
	xmlns:vt		="http://www.swsoft.com/xsl/cp/vt"   		
 >
	<sw:include href="/lib/vt/env-core.xsl"/>		
	<sw:include href="/lib/vz/vzenv-core.xsl"/>		
	<sw:include href="/lib/vz/vzenv-qos.xsl"/>		
	<sw:include href="/lib/vz/vzenv-net.xsl"/>		
	<sw:include href="/lib/vt/hn-select.xsl"/>		

  <xsl:param name="wiz_code" 					select="'ves_list_migrate'"/>
  
	<xsl:variable name="step_data"			select="wiz:getStep()"/>
	<xsl:variable name="step"						select="$step_data/@id"/>
	<xsl:variable name="screen-id"			select="$step_data/@screen-id"/>
  <xsl:variable name="form" 					select="sw:sesget($wiz_data)"/>

	<xsl:variable name="set-hn" select="sw:base64-decode($request/http_request/get/parameter[name = 'set_hn']/value)"/>

	<!-- Wizard, Step 'Migrate' -->
  <xsl:template name="step_migrate">
  
  	<ui:screen id="{$screen-id}">
  	
	    <ui:properties>
	      <ui:refresh-type>none</ui:refresh-type>
	      <ui:description  mandatory="yes">
	        <sw:text>
	        	Here you can specify the details of the Containers migration from one Hardware Node to another. The selected Containers are grouped by the source HN. Please select a destination HN for each group.
	        </sw:text>
	      </ui:description>      
	      <ui:form-get/>
	    </ui:properties>
	    
	    <ui:content>
	      <ui:hidden name="step" value="migrate"/>    
	      <ui:block mode="edit">
	      
	      	<xsl:variable name="all-hns" select="hn:list()/hn"/>
	      
	      	<xsl:for-each select="$form/def/hn">
	      		<xsl:variable name="hn" select="."/>
	      		<xsl:variable name="pos" select="position()"/>
	      		<xsl:variable name="selected-eid">
					<xsl:choose>
						<xsl:when test="$set-hn"><xsl:value-of select="$set-hn"/></xsl:when>
						<xsl:otherwise><xsl:value-of select="$form/migrate/hn/src=$hn/eid"/></xsl:otherwise>
					</xsl:choose>
	      		</xsl:variable>
	      		
	      		<ui:rows>
	      			<xsl:attribute name="title">
	      				<sw:text>
	      					<xsl:with-param name="hn" select="$hn/title"/>
	      					Migration From HN %hn
	      				</sw:text>
	      			</xsl:attribute>
	      			<ui:row>
	      				<ui:cell-label><sw:text>Containers to migrate</sw:text></ui:cell-label>
			    			<ui:cell-text>
			      			<xsl:for-each select="$form/def/env[hn-eid=$hn/eid]">
			      				<xsl:variable name="env" select="."/>
			      				<xsl:if test="position()!=1">,</xsl:if>
			      				<nobr><xsl:value-of select="title"/></nobr>
			      			</xsl:for-each>
			      		</ui:cell-text>
			      	</ui:row>
			      	<ui:row>
			      		<ui:cell-label><sw:text>To Hardware Node</sw:text></ui:cell-label>
		      			<xsl:variable name="dest-hns" select="$all-hns[eid!=$hn/eid]"/>
		      			<xsl:choose>
		      				<xsl:when test="$dest-hns">
										<ui:cell-list id="hn_{position()}" value="{$selected-eid}">
											<ui:list-item id="" title="{sw:text('-- Select HN --')}"/>
											<xsl:for-each select="$dest-hns">
												<ui:list-item id="{eid}" title="{hostname}">
													<xsl:if test="not(platform=$hn/platform or (
						      					$hn/platform='linux.i386' and vt:is-platform-linux(platform)
		    					 				))">
														<xsl:attribute name="id"></xsl:attribute>
														<xsl:attribute name="disabled">true</xsl:attribute>
														<xsl:attribute name="title"><xsl:value-of select="hostname"/>&#160;<sw:text>(Deny)</sw:text></xsl:attribute>
													</xsl:if>
												</ui:list-item>
											</xsl:for-each>
										</ui:cell-list>
									</xsl:when>
									<xsl:otherwise>
										<ui:cell-text>
											<sw:text>No Hardware Nodes are available.</sw:text>
										</ui:cell-text>
									</xsl:otherwise>
								</xsl:choose>
			      	</ui:row>
	      		</ui:rows>	      		
	      	</xsl:for-each>
	      	
	      	<xsl:if test="$form/def/hn[vt:is-platform-linux(platform)]">
						<ui:rows title="{sw:text('Live Migration')}">
							<ui:row>
								<ui:cell-check id="zero" checked="{$form/migrate/options/zero='1'}" close="false" colspan="2">
								</ui:cell-check>
								<ui:cell open="false">
									&#160;<sw:text>
										Perform live migration to avoid service interruption.
									</sw:text>
								</ui:cell>
							</ui:row>
						</ui:rows>
					</xsl:if>
					
		   		<ui:rows title="{sw:text('Advanced Options')}" id="options" status="{$form/apply/options}" 
		   			closed-text="{sw:text('Click to set up the advanced options.')}"
		   		>
		    		<ui:row>
		    			<ui:cell-check id="clean" checked="{$form/migrate/options/clean='1'}" close="false" colspan="2"/>
		    			<ui:cell open="false">
		    				&#160;<sw:text>Remove the private areas from the source Hardware Node after the migration.</sw:text>
		    			</ui:cell>
		    		</ui:row>
		    		<ui:row>
		    			<ui:cell-check id="notstart" checked="{$form/migrate/options/notstart='1'}" close="false" colspan="2"/>
		    			<ui:cell open="false">
		    				&#160;<sw:text>Do not start the Container after the migration.</sw:text>
		    			</ui:cell>
		    		</ui:row>
		    		<ui:row>
		    			<ui:cell-check id="force" checked="{$form/migrate/options/force='1'}" close="false" colspan="2"/>
		    			<ui:cell open="false">
		    				&#160;<sw:text>Force the migration. Ignore possible conflicts in IP addresses or applications.</sw:text>
		    			</ui:cell>
		    		</ui:row>
		    	</ui:rows>
					
	        <ui:buttons>
	        	<xsl:call-template name="wiz:showButtons">
	        		<xsl:with-param name="submit-title" select="sw:text('Migrate')"/>
							<xsl:with-param name="next-title" select="sw:text('Next')"/>	        		
	        	</xsl:call-template>
	        </ui:buttons>
	        
	     	</ui:block>
	    </ui:content>   
    </ui:screen>
  </xsl:template>  

	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
			<xsl:choose>			
				<xsl:when test="$step = 'migrate'">
					<xsl:call-template name="step_migrate"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="step_migrate"/>
				</xsl:otherwise>
			</xsl:choose>
	</xsl:template>
	
	<!-- UI modules -->
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>
	
	<!-- System modules -->
	<sw:include href="/lib/common.xsl"/>				
		
</xsl:stylesheet>
