<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl func wiz vzenv tem cred env-samplem vzapackagem voc vz"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:vzenv="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:tem="http://www.swsoft.com/xsl/cp/tem"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:env-samplem="http://www.swsoft.com/xsl/cp/env-samplem"
	xmlns:voc="http://www.swsoft.com/xsl/cp/voc"
	xmlns:vzapackagem="http://www.swsoft.com/xsl/cp/vzapackagem"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"	
	xmlns:vt="http://www.swsoft.com/xsl/cp/vt"	
	xmlns:vz="http://www.swsoft.com/xsl/cp/vz"
	xmlns:ts="http://www.swsoft.com/xsl/cp/ts"
	xmlns:ve="http://www.swsoft.com/xsl/cp/ve"
>
	
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/swa/env-samplem.xsl"/>
	<sw:include href="/lib/vz/vzenv-apps.xsl"/>
	<sw:include href="/lib/vz/vzenv-qos.xsl"/>
	<sw:include href="/lib/vz/vzenv-net.xsl"/>
	<sw:include href="/lib/vz/vzenv-net-ui.xsl"/>
	<sw:include href="/lib/vz/vzenv-net-core.xsl"/>
	<sw:include href="/lib/vz/vzenv-offline.xsl"/>
	<sw:include href="/lib/vz/vzenv-os.xsl"/>
	<sw:include href="/lib/vz/apps.xsl"/>
	<sw:include href="/lib/ts.xsl"/>

	<xsl:param name="wiz_code" select="'manageve'"/>
	<xsl:variable name="step_data" select="wiz:getStep()"/>
	<xsl:variable name="step" select="$step_data/@id"/>
	<xsl:variable name="step-cred" select="$step_data/@cred"/>
	<xsl:variable name="screenid" select="$step_data/@screenid"/>
	<xsl:variable name="screen-icon" select="'preferences'"/>
	<xsl:variable name="form" select="sw:sesget($wiz_data)"/>

	<!-- check detail permissions to req -->
	<xsl:param name="access-denied" 
		select="($step='apps' and not(cred:check-env('vzcp.env.manage.properties.application',sw:ve-eid()))) 
			or ($step!='apps' and not(cred:check-env('vzcp.env.manage.properties.preferences',sw:ve-eid())))"/>
	<!-- Reinstall Wizard, Step 'General Settings' -->
	<xsl:template name="step_gen">

		<xsl:variable name="oper-problem" select="voc:check-operation('vzaenvm','set')"/>

		<ui:screen id="{$screenid}" icon="{$screen-icon}">
			<!--<ui:tab-bar id="vzve" current-tab="summary"/>-->

			<!-- Load some VZ data -->
			<!-- /Load some VZ data -->

			<ui:properties>
				<ui:refresh-type>none</ui:refresh-type>
				<ui:form method="get" action="/vz/cp/vzdir/infrman/envs/manage"/>
					<ui:description width="full">
						<sw:text>
							On this screen you can manage the main settings of the Container.
						</sw:text>
					</ui:description>
			</ui:properties>

			<ui:content>
				<ui:hidden name="step" value="gen"/>

				<xsl:choose>
					<xsl:when test="$oper-problem=''">

						<ui:block mode="edit">

							<ui:rows title="{sw:text('General Configuration')}">
								<ui:row>
									<ui:cell-label>
										<sw:text>Name</sw:text>
									</ui:cell-label>
									<ui:cell-input id="name" maxlength="255" value="{$form/gen/name}">
										<!-- require name only if VE had name before editing -->
										<xsl:if test="not($form/def/have_empty_name)">
											<xsl:attribute name="required">true</xsl:attribute>
										</xsl:if>
									</ui:cell-input>
								</ui:row>
								<ui:row>
									<ui:cell-label>
										<sw:text>Description</sw:text>
									</ui:cell-label>
									<ui:cell-input id="description" maxlength="1000" value="{$form/gen/description}" width="42"/>
								</ui:row>
							</ui:rows>


							<!-- OS Upgrade -->
							<xsl:if test="$form/hn/linux and not(sw:is-ez-package($form/os_template/name))">

								<xsl:variable name="os_templates" select="tem:list('os', $form/hn/eid)"/>
								<xsl:variable name="disable-os" select="not(ve:context-state() = $env-state/running)"/>
								<ui:rows title="{sw:text('OS Template')}">
									<ui:row>
										<ui:cell-label>
											<sw:text>Name</sw:text>
										</ui:cell-label>
										<ui:cell>
											<xsl:value-of select="$form/os_template/name"/>
										</ui:cell>
									</ui:row>
									<ui:row>
										<ui:cell-label>
											<sw:text>Version</sw:text>
										</ui:cell-label>
										<xsl:variable name="vers"
											select="$os_templates//package[name=($form/os_template/name)]/version"/>
										<ui:cell-list id="os_version" value="{$form/gen/os_version}">
											<xsl:if test="$disable-os">
												<xsl:attribute name="disabled">true</xsl:attribute>
											</xsl:if>
											<xsl:attribute name="onchange">
											v = <xsl:value-of
													select="count($vers[mark=$form/gen/os_version]/preceding-sibling::version)"
													/>;
											if(this.selectedIndex!=v){
												if(!window.confirm('<sw:text>Warning! Upgrading the OS may render the Container non-operational. Please make sure you have a recent Container backup. Click OK to proceed with the upgrade.</sw:text>')){
													this.selectedIndex = v;
												}
											}
										</xsl:attribute>
											<xsl:for-each select="$vers">
												<xsl:sort select="mark" data-type="number"/>
												<xsl:choose>
													<xsl:when
														test="not(number(mark) &gt; number($form/gen/os_version))
													and not(mark=$form/gen/os_version)
													and not(string(mark)=$form/os_template/old-version/text())
												"> </xsl:when>
													<xsl:otherwise>
														<ui:list-item id="{mark}">
															<xsl:attribute name="title">
																<xsl:value-of select="mark"/>
																<xsl:if test="mark=$form/os_template/version"
																		>
																(&#160;<sw:text>current</sw:text>&#160;)
															</xsl:if>
															</xsl:attribute>
														</ui:list-item>
													</xsl:otherwise>
												</xsl:choose>
											</xsl:for-each>
										</ui:cell-list>
									</ui:row>
									<xsl:if test="$disable-os">
										<ui:row>
											<ui:cell/>
											<ui:cell>
												<sw:text>
													<span class="inactive"
													    >For its OS template to be changed, the Container has to be running.</span>
												</sw:text>
											</ui:cell>
										</ui:row>
									</xsl:if>
								</ui:rows>
							</xsl:if>

							<!-- Advanced -->
							<ui:rows title="{sw:text('Advanced')}">
								<xsl:if test="$form/voc-capabilities/*">
									<ui:row>
										<ui:cell colspan="2">
											<b>
												<sw:text>Options</sw:text>
											</b>
										</ui:cell>
									</ui:row>
								</xsl:if>

								<xsl:if test="$form/hn/linux">
									<ui:row>
										<ui:cell-check id="disabled">
											<xsl:if test="$form/gen/disabled=1">
												<xsl:attribute name="checked">true</xsl:attribute>
											</xsl:if>
											<!-- Don`t allow disable Service VE -->
											<xsl:if test="$form/ve-id=1">
												<xsl:attribute name="disabled">true</xsl:attribute>
											</xsl:if>
										</ui:cell-check>
										<ui:cell>
											<sw:text>Disable this Container</sw:text>
										</ui:cell>
									</ui:row>
									<ui:row>
										<ui:cell/>
										<ui:cell>
											<sw:text>
												<span class="inactive">When disabled, the Container cannot be started. Besides, the management of disabled Containers with Virtuozzo Power Panels is not accessible to the Container root.</span>
											</sw:text>
										</ui:cell>
									</ui:row>
								</xsl:if>
								<ui:row>
									<ui:cell-check id="start_after_boot">
										<xsl:if test="$form/gen/start_after_boot=1">
											<xsl:attribute name="checked">true</xsl:attribute>
										</xsl:if>
									</ui:cell-check>
									<ui:cell cell-width="100%">
										<sw:text>Start on the Hardware Node boot</sw:text>
									</ui:cell>
								</ui:row>

								<xsl:if test="$form/voc-capabilities/*">
									<ui:row>
										<ui:cell colspan="2">
											<b>
												<sw:text>Capabilities</sw:text>
											</b>
										</ui:cell>
									</ui:row>
									<xsl:copy-of
										select="vzenv:show-net-capabilites($form/voc-capabilities,$form/capabilities)"/>
								</xsl:if>

							</ui:rows>

							<!-- windows specific sets': TS and WINS -->
							<xsl:if test="$form/hn/windows">
								<ui:rows title="{sw:text('Terminal Services')}" separate-tables="true" >
									<ui:row>
										<ui:cell-label>
									  	<sw:text>Mode</sw:text>
										</ui:cell-label>
										<ui:cell-list id="tsmode" value="{$form/gen/tsmode}" width="150">
											<xsl:for-each select="$tsmodes/mode">
												<xsl:sort select="value"/>
												<ui:list-item id="{value}" title="{title}"/>
											</xsl:for-each>
										</ui:cell-list>									
									</ui:row>
								  <xsl:copy-of select="ts:show-lic-servers($form/gen/tslicservers)"/>
								</ui:rows>
							</xsl:if>

							<xsl:copy-of select="vzenv:show-offline-selector($form)"/>

							<ui:buttons>
								<xsl:call-template name="wiz:showButtons"/>
							</ui:buttons>
						</ui:block>

					</xsl:when>
					<xsl:otherwise>
						<ui:block>
							<ui:operation-problem>
								<xsl:copy-of select="$oper-problem"/>
								<ui:descr>
									<sw:text>Unable to manage the general settings of this Container.</sw:text>
								</ui:descr>
							</ui:operation-problem>
						</ui:block>
					</xsl:otherwise>
				</xsl:choose>

			</ui:content>
		</ui:screen>
	</xsl:template>


	<!-- Screen 'Network' -->
	<xsl:template name="step_net">

		<xsl:variable name="oper-problem" select="voc:check-operation('vzaenvm','set')"/>

		<ui:screen path-id="{$screenid}" id="{$screenid}" title="{$step_data/@title}" icon="networkadapter">
			<!--<ui:tab-bar id="vzve" current-tab="network"/>-->
			<ui:properties>
				<ui:refresh-type>none</ui:refresh-type>
	      <ui:form-get/>				
				<ui:description mandatory="yes">
					<sw:text>
					On this screen you can manage the network settings of the Container.
					</sw:text>
				</ui:description>
			</ui:properties>

			<ui:content>
				<ui:hidden name="step" value="net"/>

				<xsl:choose>
					<xsl:when test="$oper-problem=''">

						<ui:block mode="edit">

							<xsl:call-template name="vzenv:edit-net">
								<xsl:with-param name="env-form" select="$form"/>
							</xsl:call-template>
							
							<xsl:variable name="new-iface-warning">
								<xsl:if test="$form/hn/windows">
									<sw:text>
										Attention! The added network interface will be inactive until the Container is restarted.\n\n
										Do you want to restart the Container immediately after the network settings are updated?
									</sw:text>							
								</xsl:if>
							</xsl:variable>
							<xsl:variable name="new-iface-js">
								<xsl:variable name="routed-disabled" select="not($form/net/routed/enabled='true')"/>
								<xsl:variable name="bridged-disabled" select="not($form/net/bridged/enabled='true')"/>								
								<xsl:if test="$form/hn/windows and not($form/net-flags/restart-ve) and (
									$form/net-flags/new-iface or $routed-disabled or $bridged-disabled
								)">
									<xsl:if test="$routed-disabled or $bridged-disabled"> 
										if(
											<xsl:choose>
												<xsl:when test="$routed-disabled">
													document.getElementById('routed_enabled').checked
												</xsl:when>
												<xsl:otherwise>
													false										
												</xsl:otherwise>
											</xsl:choose>
											||
											<xsl:choose>
												<xsl:when test="$bridged-disabled">
													document.getElementById('bridged_enabled').checked
												</xsl:when>
												<xsl:otherwise>
													false										
												</xsl:otherwise>
											</xsl:choose>
										){
									</xsl:if>
										newHiddenObj('restart_ve','restart_ve',confirm('<xsl:value-of select="$new-iface-warning"/>')?'true':'false','defaultForm');
									<xsl:if test="$routed-disabled or $bridged-disabled"> 
										}
									</xsl:if>
								</xsl:if>
							</xsl:variable>

							<ui:buttons>
								<xsl:call-template name="wiz:showButtons">
									<xsl:with-param name="submit-script" select="$new-iface-js"/>
								</xsl:call-template>
							</ui:buttons>

						</ui:block>

					</xsl:when>
					<xsl:otherwise>
						<ui:block>
							<ui:operation-problem>
								<xsl:copy-of select="$oper-problem"/>
								<ui:descr>
									<sw:text>Unable to manage the network settings of this Container.</sw:text>
								</ui:descr>
							</ui:operation-problem>
						</ui:block>
					</xsl:otherwise>
				</xsl:choose>

			</ui:content>
		</ui:screen>
	</xsl:template>

	<!-- Wizard, Step 'QoS' -->
	<xsl:template name="step_qos">

		<xsl:variable name="oper-problem" select="voc:check-operation('vzaenvm','set')"/>

		<ui:screen path-id="{$screenid}" id="{$screenid}" title="{$step_data/@title}" icon="statistics">

			<!-- Load some VZ data -->
			<xsl:variable name="qos-warns-src">
				<xsl:if
					test="sw:param('validate') and error:is-empty()">
					<xsl:call-template name="sw:validateQoS">
						<xsl:with-param name="hn-eid" select="$form/hn/eid"/>
						<xsl:with-param name="data" select="$form/qos"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:variable>
			<xsl:variable name="qos-warns" select="exsl:node-set($qos-warns-src)"/>
			<xsl:if test="$qos-warns//error/code">
				<xsl:if
					test="error:put(sw:text('The resources validation has failed.'),$qos-warns/packet//error/message)"
				/>
			</xsl:if>
			<!-- /Load some VZ data -->

			<ui:properties>
				<ui:form-post/>			
				<ui:refresh-type>none</ui:refresh-type>
				<ui:description mandatory="yes" width="full">
					<sw:text>
          Manage the Container resources.
        </sw:text>
				</ui:description>
			</ui:properties>

			<ui:content>
				<ui:hidden name="step" value="qos"/>

				<xsl:choose>
					<xsl:when test="$oper-problem=''">

						<ui:block mode="edit" width="full">

							<!-- Show QoS warnings-->
							<xsl:call-template name="sw:getQoSValidateResults">
								<xsl:with-param name="qos" select="$form/qos"/>
								<xsl:with-param name="qos-warns" select="$qos-warns"/>
							</xsl:call-template>

							<xsl:call-template name="vzenv:edit-qos">
								<xsl:with-param name="platform-ref" select="env:make-platform-ref($form/hn/eid,$form/hn/platform)"/>
								<xsl:with-param name="data" select="$form/qos"/>
								<xsl:with-param name="mode" select="$form/qos-mode"/>
								<xsl:with-param name="slm-supported" select="$form/def/slm-hn-enabled"/>
								<xsl:with-param name="res-curr" select="$form/qos-current"/>
								<xsl:with-param name="qos-warns" select="$qos-warns/packet/data/vzaenvm/validation"/>
							</xsl:call-template>														

							<ui:buttons>
								<xsl:call-template name="wiz:showButtons">
									<xsl:with-param name="buttons-ext">
										<xsl:if test="$form/hn/linux and $form/qos/slm-mode!='slm'">
											<ui:button tip="ve_qos_validate" name="validate" sandclock="true">
												<sw:text>Validate</sw:text>
											</ui:button>
										</xsl:if>
									</xsl:with-param>
								</xsl:call-template>
							</ui:buttons>

						</ui:block>

					</xsl:when>
					<xsl:otherwise>
						<ui:block>
							<ui:operation-problem>
								<xsl:copy-of select="$oper-problem"/>
								<ui:descr>
									<sw:text>Unable to modify the extended resources of this Container.</sw:text>
								</ui:descr>
							</ui:operation-problem>
						</ui:block>
					</xsl:otherwise>
				</xsl:choose>

			</ui:content>
		</ui:screen>
	</xsl:template>

	<!-- Screen 'Applications' -->
	<xsl:template name="step_apps">

		<xsl:variable name="oper-problem" select="voc:check-operation('vzapackagem','install')"/>

		<ui:screen id="{$screenid}" icon="app_package">
			<!-- Load some VZ data -->
			<!-- /Load some VZ data -->

			<ui:properties>
	      <ui:form-get/>			
				<ui:description mandatory="yes" width="max">
					<sw:text>
						Manage the Container applications.
					</sw:text>
				</ui:description>
			</ui:properties>

			<ui:content>
				<xsl:choose>
					<xsl:when test="$oper-problem=''">
						<ui:hidden name="step" value="apps"/>

						<ui:block mode="edit" width="max">

							<xsl:variable name="setup">
								<xsl:if test="$form/hn/linux">
									<ui:linux/>
								</xsl:if>
								<ui:tips>
									<ui:check-add>select_install_app</ui:check-add>
									<ui:check-remove>select_deinstall_app</ui:check-remove>
									<ui:add>click_install_apps</ui:add>
									<ui:remove>click_deinstall_apps</ui:remove>
								</ui:tips>
								<ui:captions>
									<ui:available>
										<sw:text>Available Applications</sw:text>
									</ui:available>
									<ui:selected>
										<sw:text>Installed/Scheduled Applications</sw:text>
									</ui:selected>
									<ui:no-available>
										<sw:text>No applications available.</sw:text>
									</ui:no-available>
									<ui:no-selected>
										<sw:text>No applications installed or scheduled for installation.</sw:text>
									</ui:no-selected>
								</ui:captions>
								<ui:installed-apps>
									<xsl:copy-of select="$form/apps_src/app"/>
								</ui:installed-apps>
							</xsl:variable>
							<xsl:variable name="app-available"
								select="vzenv:prepare-ve-apps($form/apps, $form/os_template, exsl:node-set($setup), $form/eid, $form/hn-eid)"/>
							<xsl:copy-of select="$app-available"/>
							<xsl:if test="$activeMode!='vzcc' or exsl:node-set($app-available)//ui:app">
								<ui:buttons>
									<xsl:call-template name="wiz:showButtons">
										<xsl:with-param name="show-cancel" select="false()"/>
									</xsl:call-template>
								</ui:buttons>
							</xsl:if>
						</ui:block>

					</xsl:when>
					<xsl:otherwise>
						<ui:block>
							<ui:operation-problem>
								<xsl:copy-of select="$oper-problem"/>
								<ui:descr>
									<sw:text>Unable to manage the applications in this Container.</sw:text>
								</ui:descr>
							</ui:operation-problem>
						</ui:block>
					</xsl:otherwise>
				</xsl:choose>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<!-- Screen 'Apply VE Sample' -->
	<xsl:template name="step_apply">

		<xsl:variable name="oper-problem" select="voc:check-operation('vzaenvm','set')"/>

		<ui:screen path-id="{$screenid}" id="{$screenid}" title="{$step_data/@title}"
			icon="app_package">
			<!-- Load some VZ data -->
			<!-- /Load some VZ data -->

			<ui:properties>
				<ui:refresh-type>none</ui:refresh-type>
	      <ui:form-get/>				
				<ui:description mandatory="yes">
					<sw:text>
			    	On this screen you can change the Container resources configuration by applying some Container sample.
			    </sw:text>
				</ui:description>
			</ui:properties>

			<ui:content>
				<ui:hidden name="step" value="apply"/>

				<xsl:choose>
					<xsl:when test="$oper-problem=''">

						<!-- Prepare browse data -->
						<xsl:variable name="filter_init_">
							<xsl:call-template name="browse:init-filter">
								<xsl:with-param name="browse">
									<ui:browse-setup id="apply-envsamples" url="/vzdir/infrman/envs/manage"
										item-url="/vzdir/infrman/envs/manage?tab=apply&amp;step=apply"
										select-type="radio" items-title="{sw:text('Container Samples')}" select-on-left="true"
										select-id="{concat($form/ve-template/id,'/',$form/ve-template/descr)}"/>
									<ui:cols sorting-col="ve-tmpl-name">
										<ui:column id="id" for-url="yes" hidden="yes" for-select="yes"/>
										<ui:column id="ve-tmpl-name" show-url="no" title="{sw:text('Sample Name')}"
											filter="auto" post-apply-templates="yes"/>
										<ui:column id="comment" nav-type="title" hidden="yes"
											title="{sw:text('Description')}" filter="auto"/>
									</ui:cols>
								</xsl:with-param>
							</xsl:call-template>
						</xsl:variable>

						<xsl:variable name="browse_result" select="env-samplem:list-samples('virtuozzo','',$form/hn/platform,$form/ve-eid)"/>

						<xsl:variable name="filter">
							<xsl:call-template name="browse:fill-filter">
								<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
								<xsl:with-param name="rows">
									<ui:browse-rows>
										<xsl:for-each
											select="$browse_result[
												vt:is-platform-windows($form/hn/platform) or 
						        		env_config/os_template/name=$form/os-name
						        		or not(env_config/os_template/name)
						        		or env_config/os_template/name=''
						        	]">
											<ui:row>
												<id>
													<xsl:value-of select="id"/>
												</id>
												<ve-tmpl-name>
													<xsl:value-of select="name"/>
												</ve-tmpl-name>
												<comment>
													<xsl:value-of select="sw:base64-decode(comment)"/>
												</comment>
											</ui:row>
										</xsl:for-each>
									</ui:browse-rows>
								</xsl:with-param>
							</xsl:call-template>
						</xsl:variable>

						<!-- /Prepare browse data -->

						<!-- Sample Info -->
						<ui:block mode="edit">
							<xsl:call-template name="vzenv:view-template-full">
								<xsl:with-param name="template-info" select="$form/ve-template-src"/>
							</xsl:call-template>
						</ui:block>

						<ui:block mode="edit">
							<!-- Show Templates -->
							<ui:browse title="{sw:text('Select Container Sample')}">
								<ui:filter>
									<xsl:copy-of select="$filter"/>
								</ui:filter>
								<ui:browse-empty-msg>
									<sw:text>No Container samples available.</sw:text>
								</ui:browse-empty-msg>
							</ui:browse>

							<xsl:if test="$form/hn/linux">
								<ui:rows title="{sw:text('Advanced Options')}" id="options"
									status="{$form/apply/options}" closed-text="Click to set up advanced options.">
									<ui:row>
										<ui:cell-check id="restart" checked="{$form/apply/restart='1'}" close="false"
											colspan="2"/>
										<ui:cell open="false">
											<sw:text>Restart the Container if the resources change requires a restart</sw:text>
										</ui:cell>
									</ui:row>
								</ui:rows>
							</xsl:if>

							<ui:buttons>
								<xsl:call-template name="wiz:showButtons">
									<xsl:with-param name="submit-title" select="sw:text('Apply')"/>
								</xsl:call-template>
							</ui:buttons>
						</ui:block>

					</xsl:when>
					<xsl:otherwise>
						<ui:block>
							<ui:operation-problem>
								<xsl:copy-of select="$oper-problem"/>
								<ui:descr>
									<sw:text>Unable to configure the resources of this Container.</sw:text>
								</ui:descr>
							</ui:operation-problem>
						</ui:block>
					</xsl:otherwise>
				</xsl:choose>

			</ui:content>
		</ui:screen>
	</xsl:template>

	<!-- main document handler -->
	<xsl:template mode="screen" match="/">

		<xsl:choose>
			<xsl:when test="$step = 'net'">
				<xsl:call-template name="step_net"/>
			</xsl:when>
			<xsl:when test="$step = 'qos'">
				<xsl:call-template name="step_qos"/>
			</xsl:when>
			<xsl:when test="$step = 'apps'">
				<xsl:call-template name="step_apps"/>
			</xsl:when>
			<xsl:when test="$step = 'apply'">
				<xsl:call-template name="step_apply"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="step_gen"/>
			</xsl:otherwise>

		</xsl:choose>

	</xsl:template>

	<sw:include href="/lib/core/browse-filter-raw.xsl" />
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>

	<sw:include href="/lib/vocabulary.xsl"/>

	<sw:include href="/lib/vza/tem.xsl"/>
	<sw:include href="/lib/vza/hwm.xsl"/>
	<sw:include href="/lib/vza/vzapackagem.xsl"/>

</xsl:stylesheet>
