<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" 
	extension-element-prefixes="sw exsl cred env vzenv local"		
	xmlns:exsl				="http://exslt.org/common"
	xmlns:sw					="http://www.swsoft.com/xsl/cp" 
	xmlns:local				="http://www.swsoft.com/xsl/cp/local"
	xmlns:ui					="http://www.swsoft.com/xsl/cp/ui"
	xmlns:vt					="http://www.swsoft.com/xsl/cp/vt"
	xmlns:ve					="http://www.swsoft.com/xsl/cp/ve"
	xmlns:env					="http://www.swsoft.com/xsl/cp/env"
	xmlns:cred				="http://www.swsoft.com/xsl/cp/cred"
  xmlns:vzenv				="http://www.swsoft.com/xsl/cp/vzenv"
>

	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/vt/core.xsl"/>
	<sw:include href="/lib/vt/ve-core.xsl"/>
	<sw:include href="/lib/vz/vzenv-net-core.xsl"/>

	<xsl:param name="access-denied" select="not(cred:check-env('vzcp.env.view', sw:ve-eid()))"/>

	<xsl:template mode="screen" match="/">
		<!-- Prepare data -->
		<xsl:variable name="env" select="env:get-env(sw:ve-eid())/env"/>
		<!-- Post screen -->
		<ui:screen id="03.02.01.03.02" icon="network_config">
			<ui:properties>
				<ui:form-get/>
				<ui:description width="full">
					<sw:text>On this screen you can view and manage the network settings of the Container.</sw:text>
				</ui:description>
			</ui:properties>
			<ui:tab-bar id="vzve" current-tab="network" current-subtab="summary"/>
			<ui:content>
				<ui:block>
					<xsl:call-template name="local:view">
						<xsl:with-param name="env" select="$env"/>
					</xsl:call-template>
					
					<ui:buttons>
						<xsl:if test="cred:check-env('vzcp.env.manage.properties.preferences',$env/eid)">
							<ui:button tip="config_network" sandclock="false" icon="network_config" type="ok"
								submit-href="{$baseurl}/vzdir/infrman/envs/manage?tab=net"
								>
								<sw:text>Configure</sw:text>
							</ui:button>
						</xsl:if>
					</ui:buttons>
				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>
	
	<!-- View VE Net Inferfaces -->
	<xsl:template name="local:view">
		<xsl:param name="env"/>
		
		<!-- Load Data -->
		<xsl:variable name="hn-platform" select="ve:ve2platform($env)"/>
		<xsl:variable name="linux" select="vt:is-platform-linux($hn-platform)"/>
		<xsl:variable name="win" select="vt:is-platform-windows($hn-platform)"/>
		<xsl:variable name="net-rtf">
			<xsl:call-template name="vzenv:env2net">
				<xsl:with-param name="env" select="$env"/>
				<xsl:with-param name="hn-platform" select="$hn-platform"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="net" select="exsl:node-set($net-rtf)"/>
		
		<!--======== Global Network =============-->
		<ui:rows title="{sw:text('Global Network Configuration')}" separate-tables="true">
			<ui:row>
				<ui:cell-text>
					<img src="/{$theme}/icons/network_16.gif" width="16" height="16"/>
					&#160;<sw:text>All Interfaces</sw:text>
				</ui:cell-text>
			</ui:row>
			<ui:row>
				<ui:cell-label offset="3"><sw:text>Hostname</sw:text></ui:cell-label>
				<ui:cell-value>
					<xsl:variable name="hostname" select="$env/virtual_config/hostname"/>
					<xsl:choose>
						<xsl:when test="$hostname!=''">
							<a href="http://{$hostname}" target="_blank"><xsl:value-of select="$hostname"/></a>
						</xsl:when>
						<xsl:otherwise>
							<ui:text-disabled><sw:text>Not Assigned</sw:text></ui:text-disabled>
						</xsl:otherwise>
					</xsl:choose>
				</ui:cell-value>
			</ui:row>
			<xsl:if test="$linux">
				<xsl:call-template name="local:view-dns">
					<xsl:with-param name="iface" select="$net"/>
					<xsl:with-param name="hn-platform" select="$hn-platform"/>
				</xsl:call-template>
			</xsl:if>
			<xsl:call-template name="local:view-search">
				<xsl:with-param name="iface" select="$net"/>
				<xsl:with-param name="hn-platform" select="$hn-platform"/>
			</xsl:call-template>
		</ui:rows>

		<!--======== Routed Network =============-->
		<xsl:if test="true()">
			<xsl:variable name="iface" select="$net/routed"/>
			<ui:rows title="{sw:text('Routed Network')}" separate-tables="true">
				<xsl:choose>
					<!-- Routed Network Enabled -->
					<xsl:when test="$iface/enabled='true'">
						<ui:row>
							<ui:cell-text colspan="2">
								<img src="/{$theme}/icons/networkadapter_16.gif" width="16" height="16"/>&#160;
								<sw:text>
									<xsl:with-param name="id" select="$iface/id"/>
									Virtual Network Interface %{id}
								</sw:text>
							</ui:cell-text>
						</ui:row>
						<xsl:call-template name="local:view-ips">
							<xsl:with-param name="iface" select="$iface"/>
							<xsl:with-param name="hn-platform" select="$hn-platform"/>
						</xsl:call-template>
						<xsl:if test="not($linux)">
							<xsl:call-template name="local:view-dns">
								<xsl:with-param name="iface" select="$iface"/>
								<xsl:with-param name="hn-platform" select="$hn-platform"/>
							</xsl:call-template>
							<xsl:call-template name="local:view-search">
								<xsl:with-param name="iface" select="$iface"/>
								<xsl:with-param name="hn-platform" select="$hn-platform"/>
							</xsl:call-template>
							<xsl:call-template name="local:view-wins">
								<xsl:with-param name="iface" select="$iface"/>
								<xsl:with-param name="hn-platform" select="$hn-platform"/>
							</xsl:call-template>		
							<xsl:call-template name="local:view-gateway">
								<xsl:with-param name="iface" select="$iface"/>
								<xsl:with-param name="hn-platform" select="$hn-platform"/>
							</xsl:call-template>	
						</xsl:if>
					</xsl:when>
					<!-- Routed Network Disabled -->
					<xsl:otherwise>
						<ui:row>
							<ui:cell-text>
								<img src="/{$theme}/icons/networkadapter_16.gif" width="16" height="16"/>&#160;
								<sw:text>
									The host-routed network mode is disabled.
								</sw:text>
							</ui:cell-text>
						</ui:row>
					</xsl:otherwise>
				</xsl:choose>
			</ui:rows>
		</xsl:if>
		
		
		<!--======== Bridged Network =============-->
		<xsl:if test="true()">
			<xsl:variable name="bridged" select="$net/bridged"/>
			<ui:rows title="{sw:text('Bridged Network')}" separate-tables="true">
				<xsl:choose>
					<!-- Routed Network Enabled -->
					<xsl:when test="$bridged/enabled='true'">
						<xsl:for-each select="$bridged/iface">
							<xsl:variable name="iface" select="."/>
							<ui:row>
								<ui:cell-text>
									<img src="/{$theme}/icons/virtualswitch_16.gif" width="16" height="16"/>&#160;
									<sw:text>
										<xsl:with-param name="id" select="$iface/id"/>
										Virtual Ethernet Interface %{id}
									</sw:text>
								</ui:cell-text>
							</ui:row>
							<ui:row>
								<ui:cell-label offset="3">
									<sw:text>Virtual Network</sw:text>
								</ui:cell-label>
								<ui:cell-text>
									<xsl:choose>
										<xsl:when test="net-id!=''">
											<xsl:value-of select="net-id"/>
										</xsl:when>
										<xsl:otherwise>
											<sw:text>Not Assigned</sw:text>
										</xsl:otherwise>
									</xsl:choose>
								</ui:cell-text>
							</ui:row>
							<ui:row>
								<ui:cell-label offset="3">
									<sw:text>MAC Address</sw:text>
								</ui:cell-label>
								<ui:cell-text>
									<xsl:choose>
										<xsl:when test="mac-address-current!=''">
											<xsl:value-of select="mac-address-current"/>
										</xsl:when>
										<xsl:otherwise>
											<sw:text>Not Assigned</sw:text>
										</xsl:otherwise>
									</xsl:choose>
								</ui:cell-text>
							</ui:row>
							<xsl:call-template name="local:view-ips">
								<xsl:with-param name="iface" select="$iface"/>
								<xsl:with-param name="hn-platform" select="$hn-platform"/>
							</xsl:call-template>
							<xsl:if test="$win">
								<xsl:call-template name="local:view-dns">
									<xsl:with-param name="iface" select="$iface"/>
									<xsl:with-param name="hn-platform" select="$hn-platform"/>
								</xsl:call-template>
								<xsl:call-template name="local:view-wins">
									<xsl:with-param name="iface" select="$iface"/>
									<xsl:with-param name="hn-platform" select="$hn-platform"/>
								</xsl:call-template>
							</xsl:if>
							<xsl:call-template name="local:view-gateway">
								<xsl:with-param name="iface" select="$iface"/>
								<xsl:with-param name="hn-platform" select="$hn-platform"/>
							</xsl:call-template>				
							<xsl:if test="$win">	
								<xsl:call-template name="local:view-search">
									<xsl:with-param name="iface" select="$iface"/>
									<xsl:with-param name="hn-platform" select="$hn-platform"/>
								</xsl:call-template>								
							</xsl:if>
						</xsl:for-each>
					</xsl:when>
					<!-- Routed Network Disabled -->
					<xsl:otherwise>
						<ui:row>
							<ui:cell-text>
								<img src="/{$theme}/icons/virtualswitch_16.gif" width="16" height="16"/>&#160;
								<sw:text>
									The bridged network mode is disabled.
								</sw:text>
							</ui:cell-text>
						</ui:row>
					</xsl:otherwise>
				</xsl:choose>
			</ui:rows>
		</xsl:if>
		
	</xsl:template>

	<!-- View IPs Data -->
	<xsl:template name="local:view-ips">
		<xsl:param name="iface"/>
		<xsl:param name="hn-platform"/>
		
		<xsl:variable name="win" 	select="vt:is-platform-windows($hn-platform)"/>
		
		<ui:row>
			<ui:cell-label offset="3">
				<sw:text>IP Addresses</sw:text></ui:cell-label>
			<ui:cell>
				<xsl:choose>
					<xsl:when test="$iface/dhcp='true'">
						<xsl:choose>
							<xsl:when test="$iface/dhcp-ips/ip">
								<xsl:for-each select="$iface/dhcp-ips/ip">
									<xsl:sort select="sw:ip2number(address)" data-type="number"/>
									<xsl:value-of select="address"/><xsl:if test="$win"> / <xsl:value-of select="netmask"/></xsl:if>
									<xsl:if test="position()!=last()">,&#160;</xsl:if>
								</xsl:for-each>
								&#160;<sw:text>(was received from the DHCP server)</sw:text>
							</xsl:when>
							<xsl:otherwise>
								<sw:text>The IP address will be received from the DHCP server.</sw:text>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:when test="$iface/ips/ip">
						<xsl:for-each select="$iface/ips/ip">
							<xsl:sort select="sw:ip2number(address)" data-type="number"/>
							<xsl:value-of select="address"/><xsl:if test="$win"> / <xsl:value-of select="netmask"/></xsl:if>
							<xsl:if test="position()!=last()">,&#160;</xsl:if>
						</xsl:for-each>
				   </xsl:when>
				   <xsl:otherwise>
						<sw:text>No IP address assigned.</sw:text>
				   </xsl:otherwise>
				 </xsl:choose>		
			</ui:cell>
		</ui:row>
	</xsl:template>
	
	<!-- View DNS Data -->
	<xsl:template name="local:view-dns">
		<xsl:param name="iface"/>
		<xsl:param name="hn-platform"/>
		
		<xsl:if test="$iface/dns_ips/ip">
			<ui:row>
				<ui:cell-label offset="3"><sw:text>DNS Servers</sw:text></ui:cell-label>
				<ui:cell>
					<xsl:for-each select="$iface/dns_ips/ip">
						<xsl:sort select="sw:ip2number(.)" data-type="number"/>
						<xsl:value-of select="."/>
						<xsl:if test="position()!=last()">,&#160;</xsl:if>
					</xsl:for-each>
				</ui:cell>
			</ui:row>
		</xsl:if>
	</xsl:template>
	
	<!-- View Search Domains Data -->
	<xsl:template name="local:view-search">
		<xsl:param name="iface"/>
		<xsl:param name="hn-platform"/>
		
		<xsl:if test="$iface/search_domains/dom">
			<ui:row>
				<ui:cell-label offset="3"><sw:text>Search Domains</sw:text></ui:cell-label>
				<ui:cell>
					<xsl:for-each select="$iface/search_domains/dom">
						<xsl:sort select="sw:ip2number(.)" data-type="number"/>
						<xsl:value-of select="."/>
						<xsl:if test="position()!=last()">,&#160;</xsl:if>
					</xsl:for-each>
				</ui:cell>
			</ui:row>
		</xsl:if>
	</xsl:template>

	<!-- View WINS Servers Data -->
	<xsl:template name="local:view-wins">
		<xsl:param name="iface"/>
		<xsl:param name="hn-platform"/>
		
		<xsl:if test="$iface/wins_servers/ip">
			<ui:row>
				<ui:cell-label offset="3"><sw:text>WINS Servers</sw:text></ui:cell-label>
				<ui:cell>
					<xsl:for-each select="$iface/wins_servers/ip">
						<xsl:sort select="sw:ip2number(.)" data-type="number"/>
						<xsl:value-of select="."/>
						<xsl:if test="position()!=last()">,&#160;</xsl:if>
					</xsl:for-each>
				</ui:cell>
			</ui:row>
		</xsl:if>
	</xsl:template>
	

	<!-- View Default Gateway Data -->
	<xsl:template name="local:view-gateway">
		<xsl:param name="iface"/>
		<xsl:param name="hn-platform"/>
		
		<xsl:if test="$iface/default_gateway!=''">
			<ui:row>
				<ui:cell-label offset="3"><sw:text>Default Gateway</sw:text></ui:cell-label>
				<ui:cell>
					<xsl:value-of select="$iface/default_gateway"/>
				</ui:cell>
			</ui:row>
		</xsl:if>
	</xsl:template>	

	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/screen.xsl"/>
	
</xsl:stylesheet>
