<!--
	Copyright (c) SWsoft, 1999-2007
	All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred vzapackagem voc error func local"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse" xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:voc="http://www.swsoft.com/xsl/cp/voc" xmlns:vzapackagem="http://www.swsoft.com/xsl/cp/vzapackagem"
	xmlns:error="http://www.swsoft.com/xsl/cp/error" xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:func="http://exslt.org/functions" xmlns:dynamic="http://www.swsoft.com/xsl/cp/dynamic"
	xmlns:env="http://www.swsoft.com/xsl/cp/env">

	<!-- System modules -->
	<sw:include href="/lib/vocabulary.xsl" />
	<sw:include href="/lib/cred.xsl" />
	<sw:include href="/lib/dynamic.xsl" />
	<sw:include href="/lib/vt/env-core.xsl"/>

	<!-- VZA functionality modules -->
	<sw:include href="/lib/vza/vzapackagem.xsl" />
	
	<!-- Screen 'Applications(Advanced)' -->
	<xsl:template mode="screen" match="/">
		<xsl:variable name="eid" select="sw:ve-eid()"/>
		<xsl:variable name="oper-problem" select="voc:check-operation('vzapackagem','install')"/>
		<ui:screen id="03.02.01.09.01">
			<!-- <ui:screen id="{$screenid}" title="{$step_data/@title}" icon="env_upgrade">-->
			<!-- Load some VZ data -->
			<!-- /Load some VZ data -->
			
			<xsl:if test="$activeMode='vzcc'">
				<ui:tab-bar id="vzve" current-tab="soft" current-subtab="pkg" />
			</xsl:if>
			
			<ui:properties>
				<ui:description mandatory="yes" width="max">
					<sw:text>Manage your Container applications working with individual software packages.</sw:text>
				</ui:description>
				<ui:form-get/>
			</ui:properties>

			<ui:content>
				<xsl:choose>
					<xsl:when test="($oper-problem='' and not(/packet/cookie/list)) 
										or env:get-env($eid)/env/status/transition=$env-trans/updating">
						<ui:block>
							<ui:hidden name="list" value="1"/>
							<ui:rows title="{sw:text('Progress')}">
								<ui:row>
									<ui:cell-value>
										<ui:raw>
											<xsl:variable name="task-id" select="sw:sesget(concat('ve-update-action-id.', $eid))"/>
											
											<div>
												<img id="refresh_img" width="16" border="0" height="16"
													src="/{$theme}/icons/indicator.gif" />&#160;<span id="list_result">
													<xsl:choose>
														<xsl:when test="not(string($task-id)='')">
															<xsl:variable name="task-desk" select="sw:sesget(concat('ve-update-action-type.', $eid))"/>
															<xsl:choose>
																<xsl:when test="$task-desk='install'">
																	<sw:text>Installing the Container package(s)...</sw:text>
																</xsl:when>
																<xsl:when test="$task-desk='remove'">
																	<sw:text>Removing the Container package(s)...</sw:text>
																</xsl:when>
																<xsl:otherwise>
																	<sw:text>Updating the Container package(s)...</sw:text>
																</xsl:otherwise>
															</xsl:choose>
														</xsl:when>
														<xsl:otherwise>
															<sw:text>Getting list of the installed packages...</sw:text>
														</xsl:otherwise>
													</xsl:choose>
												</span>
											</div>
											
											<xsl:variable name="send-ui-name" select="'get_rpms'" />
											<xsl:variable name="recv-ui-name" select="'list_rpms'" />
											<xsl:variable name="div-name" select="'list_result'" />
											
											<xsl:call-template name="dynamic:error-reporter-script" />
								
											<script>
												var timerID;
												function recv(content) {
													clearTimeout(timerID);
													<!-- replace progress with initial message -->
													var div_obj = document.getElementById('list_result');
													if (content.length &gt; 1) {
														if (content[0] != 'retry') {
															document.getElementById('list_result').innerHTML = content[1];
															doSubmit();
														} else if(content[0] =='retry') {
															document.getElementById('list_result').innerHTML = content[1];
															timerID = setTimeout("<xsl:value-of select="$send-ui-name"/>()", 3000);
														} 
													} 
												}
											</script>
											
											<xsl:call-template name="dynamic:ajax-sender-func">
												<xsl:with-param name="sender-func" select="$send-ui-name"/>
												<xsl:with-param name="reciever-func" select="$recv-ui-name" />
												<xsl:with-param name="request-url" select="'/vz/cp/vzdir/infrman/envs/packages/packages-dynamic'"/>
											</xsl:call-template>
									
											<xsl:call-template name="dynamic:ajax-reciever-func">
												<xsl:with-param name="reciever-func" select="$recv-ui-name"/>
												<xsl:with-param name="ui-func" select="'recv'" />
											</xsl:call-template>
											
											<script>
												<xsl:value-of select="$send-ui-name"/>();
											</script>
										</ui:raw>
									</ui:cell-value>
								</ui:row>
							</ui:rows>					
						</ui:block>
					</xsl:when>
					<xsl:when test="$oper-problem=''">
						<!-- Add browse with installed packages -->

						<xsl:variable name="setup">
							<ui:setup>
								<id>installed</id>
								<url>/vzdir/infrman/envs/packages/index</url>
								<title>
									<sw:text>Installed Packages</sw:text>
								</title>
								<show-status />
								<empty>
									<sw:text>No installed packages.</sw:text>
								</empty>
								<action-empty>
									<sw:text>You have to select at least one package to update or uninstall.</sw:text>
								</action-empty>
								<href><xsl:value-of select="$baseurl"/>/vzdir/infrman/envs/packages/list-control</href>
								<action>
									<id>install_new</id>
									<global/>
									<href><xsl:value-of select="$baseurl"/>/vzdir/infrman/envs/packages/install</href>
									<caption>
										<sw:text>Install New Package</sw:text>
									</caption>
									<tip>install_packages</tip>
									<icon>install</icon>
								</action>
								<action>
									<id>upgrade</id>
									<caption>
										<sw:text>Update</sw:text>
									</caption>
									<tip>select_update_packages</tip>
									<icon>installupdate</icon>
								</action>
								<action>
									<id>ve_upgrade</id>
									<global/>
									<caption>
										<sw:text>Update All</sw:text>
									</caption>
									<tip>all_packages_update</tip>
									<icon>installupdate</icon>
								</action>
								<action>
									<id>uninstall</id>
									<caption>
										<sw:text>Uninstall</sw:text>
									</caption>
									<tip>select_deinstall_packages</tip>
									<icon>uninstall</icon>
								</action>
							</ui:setup>
						</xsl:variable>

						<xsl:variable name="rpms" select="local:list-rpms()/packet/data/vzapackagem/packages/package" />
						<xsl:variable name="pkgs"
							select="local:list-rpm-updates()/packet/data/vzapackagem/packages/package" />
						<xsl:copy-of select="local:show-rpms(exsl:node-set($setup)/ui:setup, $rpms, $pkgs)" />
					</xsl:when>
					<xsl:otherwise>
						<ui:block>
							<ui:operation-problem>
								<xsl:copy-of select="$oper-problem" />
								<ui:descr>
									<sw:text>Unable to manage packages in this Container.</sw:text>
								</ui:descr>
							</ui:operation-problem>
						</ui:block>
					</xsl:otherwise>
				</xsl:choose>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<!-- TODO Make it use some kind of cache -->
	<func:function name="local:list-rpms">
		<func:result select="vzapackagem:list-installed-rpms(sw:ve-eid(), true())" />
	</func:function>

	<!-- TODO Make it use some kind of cache -->
	<func:function name="local:list-rpm-updates">
		<func:result select="vzapackagem:list-rpm-updates(sw:ve-eid())" />
	</func:function>
	
	<!-- UI modules -->
	<sw:include href="rpm-browse.xsl" />
</xsl:stylesheet>