<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred vzapackagem dynamic local func voc"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:exsl="http://exslt.org/common"
	xmlns:func="http://exslt.org/functions" 
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui" 
	xmlns:dynamic="http://www.swsoft.com/xsl/cp/dynamic"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:voc="http://www.swsoft.com/xsl/cp/voc" 
	xmlns:local="http://www.swsoft.com/xsl/cp/local" 
	xmlns:error="http://www.swsoft.com/xsl/cp/error" 
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:task="http://www.swsoft.com/xsl/cp/task"
	xmlns:vzenv="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:global="http://www.swsoft.com/xsl/cp/global"
	xmlns:vzapackagem="http://www.swsoft.com/xsl/cp/vzapackagem"
	>

	<sw:include href="/lib/swa/system.xsl" />
	<sw:include href="/lib/common.xsl" />
	<sw:include href="/lib/dynamic.xsl" />
	<sw:include href="/lib/swa/op_log.xsl" />
	<sw:include href="/layout/ext-tasks.xsl" />
	<sw:include href="/lib/vt/env-core.xsl" />
	<sw:include href="/lib/vza/vzapackagem.xsl" />
	<sw:include href="/lib/dynamic.xsl" />
	<sw:include href="/lib/screen.xsl" />
	<sw:include href="/lib/vz/vzenv-apps.xsl"/>

	<!-- check permissions to show this page -->
	<xsl:param name="access-denied" select="not(cred:check-env('vzcp.env.manage.properties.application', sw:ve-eid()))" />

	<xsl:template mode="screen" match="/">
		<xsl:call-template name="dynamic:create-ajax-handler">
			<xsl:with-param name="request-handler" select="sw:if(sw:param('mode')='available', 'local:load-available-packages', 'local:load-packages')" />
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="local:report-task">
		<xsl:param name="eid"/>
		<xsl:param name="task-id"/>
		
		<xsl:variable name="task" select="task:get($task-id)"/>
		<xsl:if test="not(task:is-running($task))">
			<xsl:if test="sw:sesput(concat('ve-update-action-id.', $eid), '')"/>
		</xsl:if>
		<xsl:variable name="task-desk" select="sw:sesget(concat('ve-update-action-type.', $eid))"/>
			
		<result>
			<xsl:choose>
				<xsl:when test="$task-desk='install'">
					<sw:text>Installing the Container package(s)...</sw:text>
				</xsl:when>
				<xsl:when test="$task-desk='remove'">
					<sw:text>Removing the Container package(s)...</sw:text>
				</xsl:when>
				<xsl:otherwise>
					<sw:text>Updating the Container package(s)...</sw:text>
				</xsl:otherwise>
			</xsl:choose>
			<br/>
			<xsl:for-each select="$task">
				<xsl:call-template name="dynamic:describe-task">
					<xsl:with-param name="task" select="." />
					<xsl:with-param name="last" select="position()=last()" />
				</xsl:call-template>
		</xsl:for-each>
		</result>
		<status>retry</status>
	</xsl:template>

	<func:function name="local:load-packages">
		<xsl:variable name="eid" select="sw:ve-eid()"/>
		
		<xsl:variable name="task-id" select="sw:sesget(concat('ve-update-action-id.', $eid))"/>
		<func:result>
			<xsl:choose>
				<xsl:when test="not(string($task-id)='')">
					<xsl:call-template name="local:report-task">
						<xsl:with-param name="eid" select="$eid"/>
						<xsl:with-param name="task-id" select="$task-id"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:when test="vzenv:is-ve-updating($eid) or sw:sesget(concat('ve-rpm-list.', $eid))='1'">
					<result>
						<sw:text>Getting up-to-date status for the installed packages...</sw:text>
					</result>
					<status>retry</status>
				</xsl:when>
				<xsl:otherwise>
					<xsl:if test="sw:sesput(concat('ve-rpm-list.', $eid), '1')"/>
					<xsl:variable name="rpms" select="vzapackagem:list-installed-rpms($eid, true())"/>
					<xsl:if test="sw:sesput('vzapackagem-list-rpms-eid', $eid)"/>
					
					<xsl:choose>
						<xsl:when
							test="not(local:process-error(sw:text('Failed to list the installed packages.'), $rpms))">
							<xsl:variable name="rpm-updates" select="vzapackagem:list-rpm-updates($eid)"/>
							
							
							<xsl:choose>
								<xsl:when
									test="not(local:process-error(
												sw:text('Failed to retrieve the current status of the installed packages.'), 
												$rpm-updates))">
									<result>
										<sw:text>Getting up-to-date status for the installed packages...</sw:text>
									</result>
									<status>ok</status>
								</xsl:when>
								<xsl:otherwise>
									<result>
										<sw:text>Getting up-to-date status for the installed packages...</sw:text>
									</result>
									<status>error</status>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:when>
						<xsl:otherwise>
							<result>
								<sw:text>Getting list of the installed packages...</sw:text>
							</result>
							<status>error</status>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:if test="sw:sesput(concat('ve-rpm-list.', $eid), '')"/>
				</xsl:otherwise>
			</xsl:choose>
		</func:result>
	</func:function>
	
	<func:function name="local:load-available-packages">
		<xsl:variable name="eid" select="sw:ve-eid()"/>
		
		<xsl:variable name="task-id" select="sw:sesget(concat('ve-update-action-id.', $eid))"/>
		<func:result>
			<xsl:choose>
				<xsl:when test="not(string($task-id)='')">
					<xsl:call-template name="local:report-task">
						<xsl:with-param name="eid" select="$eid"/>
						<xsl:with-param name="task-id" select="$task-id"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:when test="vzenv:is-ve-updating($eid)">
					<result>
						<sw:text>Getting a list of the available packages...</sw:text>
					</result>
					<status>retry</status>
				</xsl:when>
				<xsl:otherwise>
					<xsl:variable name="rpms" select="vzapackagem:list-installed-rpms($eid)"/>
					<xsl:if test="sw:sesput('vzapackagem-list-rpms-eid', $eid)"/>

					<xsl:choose>
						<xsl:when
							test="not(local:process-error(sw:text('Failed to list the installed packages.'), $rpms))">
							<xsl:variable name="rpm-updates" select="vzapackagem:list-available-rpms($eid)"/>

							<xsl:choose>
								<xsl:when
									test="not(local:process-error(
												sw:text('Failed to list the available packages.'), 
												$rpm-updates))">
									<result>
										<sw:text>Getting a list of the available packages...</sw:text>
									</result>
									<status>ok</status>
								</xsl:when>
								<xsl:otherwise>
									<result>
										<sw:text>Getting a list of the available packages...</sw:text>
									</result>
									<status>error</status>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:when>
						<xsl:otherwise>
							<result>
								<sw:text>Getting a list of the available packages...</sw:text>
							</result>
							<status>error</status>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
		</func:result>
	</func:function>
	
	<func:function name="local:process-error">
		<xsl:param name="msg" />
		<xsl:param name="responce" />
		<xsl:variable name="error" select="$responce/packet/data/error|$responce/packet/data/vzapackagem/error" />
		<xsl:choose>
			<xsl:when test="$error">
				<xsl:if test="error:put($msg, $error/message, '')" />
				<func:result select="true()" />
			</xsl:when>
			<xsl:otherwise>
				<func:result select="false()" />
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
</xsl:stylesheet>
