<!--
	Copyright (c) SWsoft, 1999-2007
	All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred vzapackagem voc error func local"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse" xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:voc="http://www.swsoft.com/xsl/cp/voc" xmlns:vzapackagem="http://www.swsoft.com/xsl/cp/vzapackagem"
	xmlns:error="http://www.swsoft.com/xsl/cp/error" xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:func="http://exslt.org/functions" xmlns:set="http://exslt.org/sets">

	<func:function name="local:show-rpms">
		<xsl:param name="setup" />
		<xsl:param name="rpms" />
		<xsl:param name="pkgs" select="/.." />

		<func:result>
			<!-- Installed packages -->
			<xsl:call-template name="local:create-rpm-browse">
				<xsl:with-param name="rpms" select="$rpms" />
				<xsl:with-param name="pkgs" select="$pkgs" />
				<xsl:with-param name="setup" select="$setup[1]" />
			</xsl:call-template>
		</func:result>
	</func:function>

	<xsl:template name="local:create-rpm-browse">
		<xsl:param name="rpms" />
		<xsl:param name="pkgs" />
		<xsl:param name="setup" />

		<ui:block mode="edit" width="full">

			<ui:browse title="{$setup/title}">
				<ui:filter>
					<xsl:copy-of select="local:fill-rpm-browse-filter($rpms, $pkgs, $setup)" />
				</ui:filter>
				<ui:browse-empty-msg>
					<xsl:copy-of select="$setup/empty" />
				</ui:browse-empty-msg>
				<ui:browse-js-many>
					<ui:warn>
						<xsl:copy-of select="$setup/action-empty" />
					</ui:warn>
				</ui:browse-js-many>
				

				<ui:browse-buttons type="list-selection">
					<xsl:for-each select="$setup/action">
						<ui:button type="list-selection" tip="{tip}" icon="{icon}" name="{id}" sandclock="false">
							<xsl:if test="not(global)">
								<xsl:attribute name="script">if (!atLeastOne()) return false;</xsl:attribute>
							</xsl:if>
							<xsl:choose>
								<xsl:when test="string(href)!=''">
									<xsl:attribute name="submit-href"><xsl:value-of select="href"/></xsl:attribute>
								</xsl:when>
								<xsl:when test="string($setup/href)!=''">
									<xsl:attribute name="submit-href"><xsl:value-of select="$setup/href" /></xsl:attribute>
								</xsl:when>
							</xsl:choose>
							<xsl:copy-of select="caption" />
						</ui:button>
					</xsl:for-each>
				</ui:browse-buttons>
			</ui:browse>
		</ui:block>
	</xsl:template>

	<func:function name="local:fill-rpm-browse-filter">
		<xsl:param name="rpms" />
		<xsl:param name="pkgs" />
		<xsl:param name="setup" />

		<func:result>
			<xsl:call-template name="browse:fill-filter">
				<xsl:with-param name="filter" select="local:init-rpms-browse-filter($setup, set:distinct($rpms/arch))" />
				<xsl:with-param name="rows">
					<ui:browse-rows>
						<xsl:for-each select="$rpms">
							<xsl:variable name="rpm" select="." />
							<xsl:variable name="split" select="sw:split(string(version), ':')" />
							<xsl:variable name="version" select="sw:if(count($split)=2, $split[2], $split[1])" />
							<xsl:variable name="epoch" select="sw:if(count($split)=2, $split[1], '0')" />
							<ui:row>
								<id><xsl:value-of select="vzapackagem:generate-id($rpm)"/></id>
								<name>
									<xsl:value-of select="name" />
								</name>
								<version>
									<xsl:value-of select="$version" />
								</version>
								<rpm-epoch>
									<xsl:value-of select="sw:if($epoch='0', '', $epoch)" />
								</rpm-epoch>
								<arch>
									<!-- HACK -->
									<xsl:value-of select="arch" />
								</arch>
								<xsl:if test="$setup/show-status">
									<rpm-summary>
										<xsl:value-of select="summary" />
									</rpm-summary>
									<rpm-status>
										<xsl:choose>
											<xsl:when test="$pkgs[name=$rpm/name 
												and local:is-new-version(version, $rpm/version)]">1</xsl:when>
											<xsl:otherwise>0</xsl:otherwise>
										</xsl:choose>
									</rpm-status>
								</xsl:if>
							</ui:row>
						</xsl:for-each>
					</ui:browse-rows>
				</xsl:with-param>
			</xsl:call-template>
		</func:result>
	</func:function>
	
	<func:function name="local:is-new-version">
		<xsl:param name="version" />
		<xsl:param name="old-version" />

		<!-- TODO make some lexicographic order comparator -->
		<func:result select="not(string($version)=string($old-version))" />
	</func:function>

	<func:function name="local:init-rpms-browse-filter">
		<xsl:param name="setup" />
		<xsl:param name="arch-list" />

		<xsl:variable name="filter_init">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="{$setup/id}" url="{$setup/url}" />
					<!-- item-url="" -->
					<ui:cols>
						<ui:column id="id" data-type="str" hidden="yes" for-select="yes" for-url="yes" />
						<ui:column id="name" data-type="str" sorting="yes" title="{sw:text('Name')}"
							width="{sw:if($setup/show-status, '20%', '75%')}" filter="auto"/>
						<ui:column id="rpm-epoch" title="{sw:text('Epoch')}" width="5%" sorting="yes" align="left"
							data-type="str" filter="auto"/>
						<ui:column id="version" title="{sw:text('Version')}" width="10%" sorting="yes" align="left"
							data-type="str" filter="auto"/>
						<ui:column id="arch" title="{sw:text('Arch')}" width="5%" sorting="yes" align="center"
							data-type="str" filter="select">
							<xsl:for-each select="$arch-list">
								<xsl:sort select="."/>
								<ui:filter-option value="{.}" title="{.}"/>
							</xsl:for-each>
						</ui:column>
						<xsl:if test="$setup/show-status">
							<ui:column id="rpm-summary" title="{sw:text('Summary')}" width="55%" data-type="str"
								sorting="yes" align="left" />
							<ui:column id="rpm-status" title="{sw:text('Status')}" width="5%" data-type="int"
								sorting="yes" align="center" post-apply-templates="yes" filter="select">
								<ui:filter-option value="1" title="Has Updates"/>
								<ui:filter-option value="0" title="Up-to-date"/>
							</ui:column>
						</xsl:if>
					</ui:cols>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>
		<func:result select="exsl:node-set($filter_init)" />
	</func:function>

	<sw:include href="/lib/screen.xsl" />
	<sw:include href="/lib/core/browse-filter-raw.xsl" />
</xsl:stylesheet>