<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred vzenv voc local func proc"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl	="http://exslt.org/common"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
  xmlns:ui	="http://www.swsoft.com/xsl/cp/ui"
  xmlns:local ="http://www.swsoft.com/xsl/cp/local"
  xmlns:func	="http://exslt.org/functions"
	xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
	xmlns:voc		="http://www.swsoft.com/xsl/cp/voc"
	xmlns:vzenv   ="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:proc	="http://www.swsoft.com/xsl/cp/proc"	
	xmlns:env	="http://www.swsoft.com/xsl/cp/env"	
  >

  <xsl:template mode="screen" match="/">
  	
  	<xsl:variable name="oper-problem" select="voc:check-operation('proc_info')"/>
  	<xsl:variable name="is-windows" select="env:eid2info(sw:hn-eid())/windows"/>
  
    <ui:screen id="03.02.01.10.00">
	    <ui:properties>
	      <ui:description width="full">
			        <sw:text>
						A process is a running instance of an executable program.
						<br/>
						On this page, you can see a list of processes running in your Container with detailed information on each process.
						<br/>
	    		    </sw:text>
	      	<xsl:choose>
	      		<xsl:when test="$is-windows">
			        <sw:text>
						You may also send a signal to end any process.
	    		    </sw:text>
	      		</xsl:when>
	      		<xsl:otherwise>
			        <sw:text>
						You may also kill any process or send other signals to it.
	    		    </sw:text>
	      		</xsl:otherwise>
	      	</xsl:choose>
	        <ui:form-get/>
	      </ui:description>      
	    </ui:properties>

			<ui:tab-bar id="vzve" current-tab="services" current-subtab="procs"/>

	    <ui:content>
				<xsl:choose>
					<xsl:when test="$oper-problem=''">
						<ui:stop-sign icon="exclamation">
						<xsl:choose>
							<xsl:when test="$is-windows">
					    	 	<sw:text>WARNING: Terminating critical processes can cause undesired results including loss of data and system instability.</sw:text>
							</xsl:when>
							<xsl:otherwise>
					    	 	<sw:text>WARNING: Wrong signals to critical processes can cause undesired results including loss of data and system instability.</sw:text>
							</xsl:otherwise>
						</xsl:choose>
						
			    	</ui:stop-sign>
					
						<ui:java-script>
							
							var div_browse = null;
							var refresh = 500; //in msecs, should be 1 min (60000 ms)
							var counter_receive = 0;
							var counter_refresh = 0;
							var refreshTimer = null;
							var timerOn = false;
	
							function receiveContent(req){
							
								if(!timerOn){
									return false;
								}
								if (req.readyState == 4){
									if (req.status == 200){
										refreshContent(req);
									}else{
										alert("There was a problem retrieving the XML data:\n" + req.statusText); //debug
									}
								}
	
								return true;
							}
							
							function refreshContent(req){
								// get new content
								var content = req.readyState==4?req.responseText:'';
								// update content
								if(content!=''){
									div_browse.innerHTML = content;								
									// run counter
									counter_receive++;
									if(timerOn){
										refreshTimer = setTimeout(refreshBrowse,refresh);
									}
								}
								
							}
							
							function refreshBrowse(){
								if(timerOn){
									if (div_browse){
										requestContent('/vz/cp/vzdir/infrman/envs/procs-dynamic',receiveContent
											,'<xsl:value-of select="$ticket"/>','<xsl:value-of select="$ticketid"/>'
										);
									}else{
										window.location.reload();
									}
								}
							}
							
							function initBrowse(){
								div_browse = document.getElementById('div_browse');
								refreshBrowse();
							}
							
							function switchRefresh(state){
			
								if(state!=null){
									if(state==timerOn){
										return true;
									}
								}
								btn = document.getElementById('btn_refresh');								
								timerOn = state!=null?state:!timerOn;
								
								if(!timerOn){
									btn.value = '<sw:text>Enable Autorefresh</sw:text>';
									clearTimeout(refreshTimer);
									refreshTimer = null;
								}else{
									btn.value = '<sw:text>Disable Autorefresh</sw:text>';
									initBrowse();
								}
								
								document.defaultForm.timerOn.value = timerOn?'1':'0';								
								
							}
							
							<xsl:if test="sw:param('timerOn')='1'">
								addEventToObject(window,'onload',switchRefresh);
							</xsl:if>
						</ui:java-script>
						
						<ui:block width="full">
							<xsl:call-template name="proc:post-browse">
								<xsl:with-param name="simple" select="$is-windows"/>
							</xsl:call-template>
					  </ui:block>
					  
					</xsl:when>
			    <xsl:otherwise>
			    	<ui:block>
				    	<ui:operation-problem>
				    		<xsl:copy-of select="$oper-problem"/>
								<ui:descr><sw:text>Unable to manage processes in this Container.</sw:text></ui:descr>
							</ui:operation-problem>
						</ui:block>
					</xsl:otherwise>
				</xsl:choose>
    	</ui:content>
    </ui:screen>
  </xsl:template>
	
	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/screen.xsl"/>
	
	<sw:include href="/lib/proc-func.xsl"/>
	
</xsl:stylesheet>
