<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred voc securitym"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
	xmlns:env  ="http://www.swsoft.com/xsl/cp/env"	
	xmlns:voc  ="http://www.swsoft.com/xsl/cp/voc"
	xmlns:securitym="http://www.swsoft.com/xsl/cp/securitym"
>

	<sw:include href="/lib/swa/securitym.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>
	

  <xsl:variable name="showform" select="not(sw:sesget('msg'))"/>
	
	<xsl:param name="access-denied" 
		select="not(securitym:check-operation('environment.interaction.setUserPassword',
			securitym:context-scope('ve.vz.vt')))"/>

	<xsl:template mode="screen" match="/">
		<xsl:variable name="screen_title">
			<sw:text>
				Change Administrative Password				
			</sw:text>
		</xsl:variable>
	
		<xsl:variable name="oper-problem" select="voc:check-operation('vzaenvm','set')"/>
		<xsl:variable name="env-info" select="env:eid2info(sw:ve-eid())"/>
		
    <ui:screen id="03.02.01.03.06" title="{$screen_title}" bg="pwd">
      <ui:properties>
        <ui:width value="fixed"/>
        <ui:description>
          <sw:text>
			You are going to change the password of the administrative account for this Container.
			<br/>
			To maintain security, it is recommended to occasionally change your password. 
			The password should have 6 characters or more. 
			Please do not choose passwords which are easy for others to guess.			
          </sw:text>
        </ui:description>      
        <ui:form-get/>
      </ui:properties>
    	    	
      <xsl:if test="$showform">
        <ui:content>
          <xsl:choose>
          	<xsl:when test="$oper-problem!=''">
          		<ui:block>
	        		  <ui:operation-problem>
					    		<xsl:copy-of select="$oper-problem"/>
									<ui:descr>
										<sw:text>
											Unable to change the password of the administrative account now.											
										</sw:text>
									</ui:descr>
								</ui:operation-problem>
							</ui:block>
          	</xsl:when>
            <xsl:otherwise>
              <ui:block mode="edit">
        			  <ui:rows>
        					<ui:row>
        						<ui:cell-label>
        	        		<sw:text>Password</sw:text>
        	        	</ui:cell-label>
        						<ui:cell-input id="passwd" maxlength="64" required="true" mode-password="true"/>
        					</ui:row>
        					<ui:row>
        						<ui:cell-label>
        	        		<sw:text>Retype the password</sw:text>
        	        	</ui:cell-label>
        						<ui:cell-input id="retype" maxlength="64" required="true" mode-password="true"/>
        					</ui:row>               
        			  </ui:rows>              
                <ui:buttons>
                  <ui:button type="ok" name="_submit" tip="submit_root_pwd_change_{sw:if($env-info/windows,'win','nix')}">
                    <sw:text>Change</sw:text>
                  </ui:button>
					<ui:button type="cancel" sandclock="false"
						tip="discard_pwd_change">
						<sw:text>Discard</sw:text>
					</ui:button>
                </ui:buttons>
              </ui:block>
            </xsl:otherwise>
          </xsl:choose>
        </ui:content>
    </xsl:if>
    
    <!-- After succseeful submit - nothing to show -->
    <xsl:if test="not($showform)">
      <ui:content>
      </ui:content>
    </xsl:if>    

    </ui:screen>
  </xsl:template>

	<sw:include href="/lib/screen.xsl"/>
	
	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
