<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl func wiz vzapackagem vzenv cred voc env securitym"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:form="http://www.swsoft.com/xsl/cp/form"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:voc="http://www.swsoft.com/xsl/cp/voc"
	xmlns:vzenv="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:vzapackagem="http://www.swsoft.com/xsl/cp/vzapackagem"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:vt="http://www.swsoft.com/xsl/cp/vt"	
	xmlns:ve="http://www.swsoft.com/xsl/cp/ve"
	xmlns:securitym="http://www.swsoft.com/xsl/cp/securitym"
>

	<sw:include href="/lib/vt/env-core.xsl"/>

	<xsl:param name="wiz_code" select="'env-reinstall'"/>
	<xsl:variable name="sched" select="sw:sesget('sched')"/>

	<xsl:variable name="step_data" select="wiz:getStep()"/>
	<xsl:variable name="form" select="sw:sesget($wiz_data)"/>
	<xsl:variable name="step" select="$step_data/@id"/>

	<xsl:variable name="screen-id" select="$step_data/@screen-id"/>
	<xsl:variable name="app-list-type" select="sw:sesget('app-list-type')"/>

	<xsl:variable name="eid" select="sw:ve-eid()"/>
	<xsl:variable name="env" select="env:get-env($eid)/env"/>
	<xsl:variable name="platform-is-linux" select="vt:is-platform-linux(ve:ve2platform($env))"/>	
	
	<xsl:variable name="dir-for-saved-content" select="sw:if($platform-is-linux,'/old','c:\reinstall')"/>
	
	<xsl:param name="access-denied" select="not(cred:check-env('vzcp.support.troubleshooting',$eid))"/>

	<!-- Wizard, Step 'Introduction' -->
	<xsl:template name="step_intro">

		<ui:screen id="{$screen-id}" icon="env_reinstall">
			<xsl:variable name="tmpls" select="vzapackagem:get-env-templates($env, true())"/>

			<xsl:variable name="pkgs" select="vzapackagem:list-compatible4env($eid, 'os')/packet/data/vzapackagem/packages/package"/>
			<xsl:variable name="os" select="$tmpls[vzapackagem:is-os(.)][1]"/>
			<xsl:variable name="known-os" select="$pkgs[vzapackagem:is-os(.)]"/>
			<xsl:variable name="os-newpkgm" select="sw:is-ez-package($os/name)"/>
			<xsl:choose>
				<xsl:when
					test="$platform-is-linux and not( not($os/name = '') and $known-os[vzapackagem:equals(., $os)])">
					<ui:properties>
						<xsl:choose>
							<xsl:when test="$step='intro'">	 
								<ui:refresh-type>GET</ui:refresh-type>
							</xsl:when>
							<xsl:otherwise>
								<ui:refresh-type>none</ui:refresh-type>
							</xsl:otherwise>
						</xsl:choose>
						<ui:description mandatory="yes">
							<sw:text>
								<xsl:with-param name="dir" select="$dir-for-saved-content"/>
								On this screen you can reset the Container to its original state. 
								<br/>Optionally, you may copy all the files from the previous installation to the <b>%{dir}</b> directory.
							</sw:text>
						</ui:description>
						<ui:form-get/>
					</ui:properties>

					<xsl:call-template name="local:post-tab"/>

					<ui:content>
						<ui:hidden name="step" value="{$step}"/>
						<ui:block mode="view" width="max">
							<ui:operation-problem>
								<ui:type>custom</ui:type>
								<ui:descr>
									<sw:text>Reinstallation is not available for this Container.</sw:text>
								</ui:descr>
								<ui:reason>
									<xsl:choose>
										<xsl:when test="$os/name = ''">
											<sw:text>The Container is not based on any OS template.</sw:text>
										</xsl:when>
										<xsl:when test="not($known-os)">
											<sw:text>No OS templates are available on the Hardware Node.</sw:text>
										</xsl:when>
										<xsl:when test="not($known-os[vzapackagem:equals(., $os)])">
											<sw:text>
												<xsl:with-param name="name" select="$os/name"/>
												<xsl:with-param name="version" select="$os/version"
													/>
											The <b>%{name} (%{version})</b> OS template is not available on the Hardware Node.
  										</sw:text>
										</xsl:when>
									</xsl:choose>
								</ui:reason>

								<xsl:if
									test="$os/name != '' and (not($known-os) or not($known-os[vzapackagem:equals(., $os)]))">
									<ui:solution>
										<sw:text>
											<xsl:with-param name="name" select="sw:app-id2title($os/name,$os/version)"
												/>
										Check that the <b>%name</b> OS template is installed on the Hardware Node and try again.
									</sw:text>
									</ui:solution>

									<xsl:if test="$os/name = $known-os/name">
										<ui:solution>
											<sw:text>
												<xsl:with-param name="name" select="$os/name"
													/>
											Upgrade/downgrade the Container to another version of the <b>%{name}</b> OS template and try again.
										</sw:text>
										</ui:solution>
									</xsl:if>
								</xsl:if>
								<ui:solution>
									<sw:text>Use backups to restore the Container from its backup.</sw:text>
								</ui:solution>
							</ui:operation-problem>
						</ui:block>
					</ui:content>
				</xsl:when>
				<xsl:otherwise>

					<ui:properties>
						<xsl:choose>
							<xsl:when test="$step='intro'">
								<ui:refresh-type>GET</ui:refresh-type>
							</xsl:when>
							<xsl:otherwise>
								<ui:refresh-type>none</ui:refresh-type>
							</xsl:otherwise>
						</xsl:choose>
						<ui:description mandatory="yes">
							<sw:text>
								<xsl:with-param name="dir" select="$dir-for-saved-content"/>
								On this screen you can reset the Container to its original state. 
								<br/>Optionally, you may copy all the files from the previous installation to the <b>%{dir}</b> directory.
								<br/>Please make sure that you have backed up the files before the operation.
							</sw:text>
						</ui:description>
					</ui:properties>

					<xsl:call-template name="local:post-tab"/>

					<ui:content>
						<ui:hidden name="step" value="{$step}"/>
						<ui:block mode="edit">

							<!-- Ask to VE stop -->
							<xsl:variable name="ask-stop" select="ve:context-state() = $env-state/running"/>
							<xsl:if test="$ask-stop">
								<ui:rows>
									<ui:row>
										<ui:cell colspan="2">
											<sw:text>Your Container is running now. It should be stopped before the reinstallation.</sw:text>
										</ui:cell>
									</ui:row>
									<ui:row>
										<ui:cell-check id="stop"/>
										<ui:cell align="left" cell-width="100%">
											<sw:text>Yes, I want to stop this Container.</sw:text>
										</ui:cell>
									</ui:row>
								</ui:rows>
							</xsl:if>

							<ui:buttons>
								<ui:button tip="reinstall" name="next">
									<xsl:if test="$ask-stop">
										<xsl:attribute name="script"
												>if(!document.defaultForm.stop.checked) alert('<xsl:value-of
												select="sw:html-escape(sw:text('You must confirm the Container stopping.'),'escape-quote')"
											/>'); return document.defaultForm.stop.checked;</xsl:attribute>
										<xsl:attribute name="sandclock">true</xsl:attribute>
									</xsl:if>
									<xsl:if test="voc:check-operation('vzaenvm', 'recover_template')!='' or $sched">
										<xsl:attribute name="disabled">true</xsl:attribute>
									</xsl:if>
									<sw:text>Prepare to Reinstall</sw:text>
								</ui:button>
							</ui:buttons>

						</ui:block>

					</ui:content>
				</xsl:otherwise>
			</xsl:choose>
		</ui:screen>
	</xsl:template>

	<!-- Wizard, Step 'Setup' -->
	<xsl:template name="step_setup">
		<ui:screen id="{$screen-id}">

			<ui:properties>
				<ui:refresh-type>none</ui:refresh-type>
				<ui:description mandatory="yes">
					<sw:text>
          The reinstall operation is about to start, 
          please make sure that you know what you are doing.
          <br/>
          Check twice the information below.
        </sw:text>
				</ui:description>
				<ui:form-get/>
			</ui:properties>

			<xsl:call-template name="local:post-tab"/>

			<xsl:variable name="is-debian" select="contains(sw:sesget('base_set')/name, 'debian-')"/>

			<ui:content>
				<ui:hidden name="step" value="{$step}"/>

				<ui:block mode="edit">

					<!-- Setup Data Options -->
					<ui:rows title="{sw:text('Data Options')}">
						<ui:row>
							<ui:cell colspan="2">
								<sw:text>What do you want to do with the Container files?</sw:text>
							</ui:cell>
						</ui:row>
						<!-- Preserve -->
						<ui:row>
							<ui:cell-radio name="data" id="data_preserve" value="preserve"
								checked="{$form/setup/data='preserve'}"/>
							<ui:cell cell-width="100%">
								<b>
									<sw:text>
                Keep the existing Container contents
              </sw:text>
								</b>
							</ui:cell>
						</ui:row>
						<ui:row>
							<ui:cell/>
							<ui:cell cell-width="100%">
								<sw:text>
									<xsl:with-param name="dir" select="$dir-for-saved-content"/>
                	Keep the existing Container contents in the <b>%{dir}</b>&#160;directory and install a fresh Container from the sample.
              </sw:text>
							</ui:cell>
						</ui:row>
						<!-- Reinstall -->
						<ui:row>
							<ui:cell-radio name="data" id="data_reinstall" value="reinstall">
								<xsl:if test="$form/setup/data='reinstall'">
									<xsl:attribute name="checked">true</xsl:attribute>
								</xsl:if>
							</ui:cell-radio>
							<ui:cell cell-width="100%">
								<b>
									<sw:text>
                Drop the existing Container contents
              </sw:text>
								</b>
							</ui:cell>
						</ui:row>
						<ui:row>
							<ui:cell/>
							<ui:cell cell-width="100%">
								<sw:text>
    						The system will be reinstalled from the OS template. Please note that if you have customized some template<br/> files, they will return to their original state.<br/> So your custom configuration will be lost.<br/>
								</sw:text>
							</ui:cell>
						</ui:row>
					</ui:rows>

					<!-- Custom Reinstall Options -->
					<xsl:if test="count($form/custom-scripts/script) &gt; 0">
						<ui:rows title="{sw:text('Reinstall Options')}">
							<ui:row>
								<ui:cell colspan="2">
									<sw:text>What custom scripts do you want to run after the Container reinstallation?</sw:text>
								</ui:cell>
							</ui:row>
							<xsl:for-each select="$form/custom-scripts/script">
								<xsl:sort select="name"/>
								<xsl:variable name="script-id" select="sw:base64-encode(name)"/>
								<ui:row>
									<ui:cell-check id="custom_script"
										value="{$script-id}"
										checked="{($form/setup/custom-scripts-selected/id = $script-id)}"/>
									<ui:cell cell-width="100%">
										<b>
											<xsl:value-of select="sw:if(description,sw:base64-decode(description),name)"/>
										</b>
									</ui:cell>
								</ui:row>
							</xsl:for-each>
						</ui:rows>
					</xsl:if>
					
					<!-- Setup Password Options -->
					<xsl:variable name="pwd-labels-rtf">
						<xsl:choose>
							<xsl:when test="$platform-is-linux">
								<action>
									<sw:text>What do you want to do with the password database?</sw:text>
								</action>
								<keep>
									<sw:text>Keep the password database</sw:text>
								</keep>
								<drop>
									<sw:text>Drop the password database. All Container users and groups will be lost.</sw:text>
								</drop>
							</xsl:when>
							<xsl:otherwise>
								<action>
									<sw:text>What do you want to do with the administrative account password?</sw:text>
								</action>
								<keep>
									<sw:text>Keep the password</sw:text>
								</keep>
								<drop>
									<sw:text>Set a new password</sw:text>
								</drop>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
					<xsl:variable name="pwd-labels" select="exsl:node-set($pwd-labels-rtf)"/>

					<xsl:if test="securitym:check-operation('environment.interaction.setUserPassword',securitym:env-scope(sw:ve-eid()))">	
						<ui:rows title="{sw:text('Password Options')}">
							<!-- XXX: ugly hardcode of debian template name -->
							<xsl:if test="not($is-debian)">
								<ui:row>
									<ui:cell colspan="3">
										<xsl:copy-of select="$pwd-labels/action"/>
									</ui:cell>
								</ui:row>
								<!-- Preserve passwords -->
								<ui:row>
									<ui:cell-radio name="passw" id="passw_preserve" value="preserve">
										<xsl:if test="$form/setup/passw='preserve'">
											<xsl:attribute name="checked">true</xsl:attribute>
										</xsl:if>
										<ui:control-slave inverse="true">root_pwd</ui:control-slave>
										<ui:control-slave inverse="true">root_pwd_re</ui:control-slave>
									</ui:cell-radio>
									<ui:cell cell-width="100%" colspan="2">
										<b>
											<xsl:copy-of select="$pwd-labels/keep"/>
										</b>
									</ui:cell>
								</ui:row>
							</xsl:if>

							<!-- Drop passwords -->

							<!-- hardcode for debian -->
							<xsl:choose>
								<xsl:when test="$is-debian">
									<ui:hidden name="passw" id="passw_reset" value="reset"/>
									<ui:row>
										<ui:cell colspan="3">
											<b>
												<sw:text>
			    						This Container is based on a Debian OS template, so the password database will be reset.
			    					</sw:text>
											</b>
										</ui:cell>
									</ui:row>
								</xsl:when>
								<xsl:otherwise>
									<ui:row>
										<ui:cell-radio name="passw" id="passw_reset" value="reset">
											<xsl:if test="$form/setup/passw='reset'">
												<xsl:attribute name="checked">true</xsl:attribute>
											</xsl:if>
											<ui:control-slave>root_pwd</ui:control-slave>
											<ui:control-slave>root_pwd_re</ui:control-slave>
										</ui:cell-radio>
										<ui:cell colspan="2">
											<b>
												<xsl:copy-of select="$pwd-labels/drop"/>
											</b>
										</ui:cell>
									</ui:row>
								</xsl:otherwise>
							</xsl:choose>
							<ui:row>
								<ui:cell type="offset"/>
								<ui:cell-label show-aster="true">
									<sw:text>
										Set the administrative account password
					    		</sw:text>
								</ui:cell-label>
								<ui:cell-input id="root_pwd" maxlength="64" required="true" mode-password="true">
									<xsl:attribute name="value">
										<xsl:value-of select="$form/setup/root_pwd"/>
									</xsl:attribute>
								</ui:cell-input>
							</ui:row>
							<ui:row>
								<ui:cell type="offset"/>
								<ui:cell-label show-aster="true">
									<sw:text>Retype the password</sw:text>
								</ui:cell-label>
								<ui:cell-input id="root_pwd_re" maxlength="64" required="true" mode-password="true">
									<xsl:attribute name="value">
										<xsl:value-of select="$form/setup/root_pwd_re"/>
									</xsl:attribute>
								</ui:cell-input>
							</ui:row>
							<!-- Drop passwords -->
						</ui:rows>
					</xsl:if>

					<ui:buttons>
						<xsl:call-template name="wiz:showButtons"/>
					</ui:buttons>

				</ui:block>

			</ui:content>
		</ui:screen>
	</xsl:template>

	<!-- Wizard, Step 'Final Confirmation' -->
	<xsl:template name="step_final">
		<ui:screen id="{$screen-id}">

			<ui:properties>
				<ui:refresh-type>none</ui:refresh-type>
				<ui:description mandatory="yes">
					<table cellpadding="0" cellspacing="0" border="0">
						<tr>
							<td valign="center" style="padding-right:5px">
								<img src="/{$theme}/icons/exclamation_32.gif" width="32" height="32" border="0"/>
							</td>
							<td valign="top">
								<sw:text>
	                The reinstall operation is about to start, 
	                please make sure that you know what you are doing.
	                <br/>
	                Check twice the information below.
	              </sw:text>
							</td>
						</tr>
					</table>
				</ui:description>
				<ui:form-get/>
			</ui:properties>

			<xsl:call-template name="local:post-tab"/>

			<ui:content>
				<ui:hidden name="step" value="{$step}"/>
				<ui:block mode="edit">

					<ui:raw>
						<br/>
						<sw:text>You have selected the following reinstallation options</sw:text>
						<ul>
							<xsl:choose>
								<xsl:when test="$form/setup/data = 'reinstall'">
									<li>
										<sw:text>
	                      Reinstall all the template files. Please note that if you have customized some template files, they will return to their original state, so your custom configuration will be lost.
	                    </sw:text>
									</li>
								</xsl:when>
								<xsl:when test="$form/setup/data = 'preserve'">
									<li>
										<sw:text>
											<xsl:with-param name="dir" select="$dir-for-saved-content"/>
	                  	Keep the existing Container contents in the <b>%{dir}</b>&#160;directory and install a fresh Container from the sample.
	                  </sw:text>
									</li>
								</xsl:when>
							</xsl:choose>
							<p/>
							<xsl:if test="$form/setup/passw = 'reset'">
								<li>
									<sw:text>The password database will be reset to its initial state.</sw:text>
								</li>
								<p/>
								<li>
									<sw:text>
										The new administrative account password will be set.
	                </sw:text>
								</li>
							</xsl:if>
							<p/>
							<xsl:if test="count($form/setup/custom-scripts-selected/id) &gt; 0">
								<li>
									<sw:text>The custom scripts to be run after the Container reinstallation:</sw:text><p/>
									<xsl:for-each select="$form/custom-scripts/script">
										<xsl:sort select="name"/>
										<xsl:variable name="script-id" select="sw:base64-encode(name)"/>
										<xsl:if test="$form/setup/custom-scripts-selected/id = $script-id">
											<b>
												<xsl:value-of select="sw:if(description,sw:base64-decode(description),name)"/>
											</b>
										</xsl:if>
										<p/>
									</xsl:for-each>																		
								</li>
							</xsl:if>
							<p/>							
						</ul>
					</ui:raw>

					<ui:buttons>
						<xsl:call-template name="wiz:showButtons">
							<xsl:with-param name="submit-title" select="sw:text('Reinstall')"/>
						</xsl:call-template>
					</ui:buttons>

				</ui:block>

			</ui:content>
		</ui:screen>
	</xsl:template>

	<!-- Wizard, Common screen 'Operation Problem' -->
	<xsl:template name="local:show-problem">
		<xsl:param name="oper-problem"/>
		<ui:screen id="{$screen-id}" icon="env_reinstall">
			<ui:properties>
				<ui:description mandatory="yes">
					<sw:text>
						<xsl:with-param name="dir" select="$dir-for-saved-content"/>
						On this screen you can reset the Container to its original state. 
						<br/>Optionally, you may copy all the files from the previous installation to the <b>%{dir}</b> directory.
						<br/>Please note that any reinstall actions can be performed only when the Container is down.
					</sw:text>
				</ui:description>
				<ui:form-get/>
			</ui:properties>
			<xsl:call-template name="local:post-tab"/>			
			<ui:content>
				<ui:block>
					<ui:operation-problem>
						<xsl:copy-of select="$oper-problem"/>
						<ui:descr>
							<sw:text>Unable to reinstall the Container.</sw:text>
						</ui:descr>
					</ui:operation-problem>
				</ui:block>
			</ui:content>
		</ui:screen>

	</xsl:template>


	<xsl:template name="local:post-tab">
		<xsl:choose>
			<xsl:when test="$activeMode = 'vzcp' or $activeMode = 'plesk'">
				<ui:tab-bar id="maintance" current-tab="reinstall"/>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<!-- main document handler -->
	<xsl:template mode="screen" match="/">

		<xsl:variable name="oper-problem" select="voc:check-operation('vzaenvm', 'recover_template')"/>

		<xsl:choose>
			<xsl:when test="$oper-problem">
				<xsl:call-template name="local:show-problem">
					<xsl:with-param name="oper-problem" select="$oper-problem"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="$step = 'final'">
				<xsl:call-template name="step_final"/>
			</xsl:when>
			<xsl:when test="$step = 'setup'">
				<xsl:call-template name="step_setup"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="step_intro"/>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

	<!-- credentials -->
	<sw:include href="/lib/vocabulary.xsl"/>

	<sw:include href="/lib/vza/vzapackagem.xsl"/>

	<sw:include href="/lib/wizard.xsl"/>

	<sw:include href="/lib/screen.xsl"/>

</xsl:stylesheet>
