<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl cred env vzenv proc vt"
	xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:sw			="http://www.swsoft.com/xsl/cp"
	xmlns:ui			="http://www.swsoft.com/xsl/cp/ui"
	xmlns:vzenv		="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:ve			="http://www.swsoft.com/xsl/cp/ve"
	xmlns:env			="http://www.swsoft.com/xsl/cp/env"
	xmlns:hwm			="http://www.swsoft.com/xsl/cp/hwm"
	xmlns:cred		="http://www.swsoft.com/xsl/cp/cred"
	xmlns:proc		="http://www.swsoft.com/xsl/cp/proc"
	xmlns:vt			="http://www.swsoft.com/xsl/cp/vt"
	xmlns:hn			="http://www.swsoft.com/xsl/cp/hn"
	xmlns:ubcs		="http://www.swsoft.com/xsl/cp/ubcs"
>
	
	<sw:include href="/lib/vt/ve-core.xsl"/>
	<sw:include href="/lib/vz/vzenv-qos.xsl"/>
	<sw:include href="/lib/vt/hn-core.xsl"/>
	<sw:include href="/lib/vt/core.xsl"/>

	<!-- check permissions to show this page -->
	<xsl:param name="access-denied"
		select="not(cred:check-env('vzcp.env.manage.resources',sw:ve-eid()))"/>


	<xsl:template mode="screen" match="/">
		<xsl:variable name="eid" select="sw:ve-eid()"/>
		<xsl:variable name="env" select="env:get-env($eid)/env"/>
		<xsl:variable name="env-platform" select="ve:ve2platform($env)"/>

		<!-- Get data -->
		<xsl:variable name="args">
			<config>
				<qos/>
			</config>
		</xsl:variable>
		<xsl:variable name="config" select="$env/virtual_config"/>
		<xsl:variable name="config-res-src">
			<slm-mode><xsl:value-of select="$config/slm_mode"/></slm-mode>
			<xsl:for-each select="$config/qos">
				<res>
					<xsl:copy-of select="node()"/>
					<soft_src>
						<xsl:value-of select="soft"/>
					</soft_src>
					<hard_src>
						<xsl:value-of select="hard"/>
					</hard_src>
				</res>
			</xsl:for-each>
		</xsl:variable>
		<xsl:variable name="config-res" select="exsl:node-set($config-res-src)"/>
		<!--|-->

		<xsl:variable name="sysinfo-rtf">
			<xsl:call-template name="proc:sysinfo">
				<xsl:with-param name="eid" select="$eid"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="sysinfo" select="exsl:node-set($sysinfo-rtf)"/>

		<xsl:variable name="vequota" select="env:get-quota($eid)"/>

		<xsl:variable name="ubcs-rtf">
			<xsl:call-template name="ubcs:get"/>
		</xsl:variable>
		<xsl:variable name="ubcs" select="exsl:node-set($ubcs-rtf)"/>

		<xsl:variable name="current-src">
			<xsl:call-template name="sw:getQoSCurrentValues">
				<xsl:with-param name="eid" select="$eid"/>
				<xsl:with-param name="qos-limit" select="$config/qos"/>
				<xsl:with-param name="ubcs" select="$ubcs"/>
				<xsl:with-param name="sysinfo" select="$sysinfo"/>
				<xsl:with-param name="vequota" select="$vequota"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="current" select="exsl:node-set($current-src)"/>

		<!-- catch alert from vzagent -->
		<xsl:variable name="total-alerts" select="vzenv:get-all-alerts($sysinfo)"/>

		<xsl:variable name="ses-tab" select="sw:sesget('ve-resource-mode')"/>

		<xsl:variable name="tab"
			select="sw:if(sw:param('tab'), 
						string(sw:param('tab')), 
						sw:if($ses-tab, $ses-tab, 'cpu'))"/>

		<xsl:if test="sw:sesput('ve-resource-mode', $tab)"/>
		<xsl:variable name="screen-id">
			<xsl:choose>
				<xsl:when test="$tab='disk'">03.02.01.14.03</xsl:when>
				<xsl:when test="$tab='memory'">03.02.01.14.04</xsl:when>
				<xsl:otherwise>03.02.01.14.02</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<ui:screen id="{$screen-id}" icon="env_resources">
			<xsl:if test="$activeMode != 'vzcc'">
				<xsl:attribute name="title">
					<sw:text>Resources</sw:text>
				</xsl:attribute>
			</xsl:if>
			<ui:properties>
				<ui:description width="full">
					<xsl:choose>
						<xsl:when test="$tab='disk'">
							<sw:text>
								On this screen you can see detailed information on the Container disk usage.
							</sw:text>
						</xsl:when>
						<xsl:when test="$tab='memory'">
							<sw:text>
								On this screen you can see detailed information on the Container memory usage.
							</sw:text>
						</xsl:when>
						<xsl:when test="$tab='cpu'">
							<sw:text>
								On this screen you can see detailed information on the Container CPU usage.
							</sw:text>
						</xsl:when>
					</xsl:choose>
				</ui:description>
				<ui:form-get/>
				<ui:refresh-type>POST</ui:refresh-type>
			</ui:properties>

			<xsl:choose>
				<xsl:when test="$activeMode = 'vzcc'">
					<ui:tab-bar id="vzve" current-tab="res" current-subtab="{$tab}"/>
				</xsl:when>
				<xsl:otherwise>
					<ui:tab-bar id="resources" current-tab="{$tab}"/>
				</xsl:otherwise>
			</xsl:choose>
                                                          
			<ui:content>
				<ui:block width="full">
					
					<!-- Translate data into internal format -->
					<xsl:variable name="qos-src">
						<xsl:call-template name="vzenv:conv-qos-data">
							<xsl:with-param name="platform-ref" select="env:make-platform-ref($env/parent_eid,$env-platform)"/>
							<xsl:with-param name="data" select="$config-res"/>
							<xsl:with-param name="mode" select="$tab"/>
							<xsl:with-param name="res-curr" select="$current"/>
						</xsl:call-template>
					</xsl:variable>
					<xsl:variable name="qos" select="exsl:node-set($qos-src)/ui:qos-data"/>
					<!-- /Translate data into internal format -->

					<xsl:call-template name="vzenv:view-qos">
						<xsl:with-param name="qos" select="$qos"/>						
						<xsl:with-param name="total-alerts" select="$total-alerts"/>						
					</xsl:call-template>
					
				</ui:block>
				<xsl:if test="$total-alerts/alerts/alert">
					<ui:raw>
						<div style="padding:2px;margin-top:5px; width:300px">
							<table border="0" cellspacing="2" cellpadding="2">
								<tr>
									<td colspan="2">
										<b>
											<sw:text>Legend</sw:text>
										</b>
									</td>
								</tr>
								<tr>
									<td>
										<table border="0" cellspacing="0" cellpadding="0"
											style="height:5px;width:5px; border: 1px solid black">
											<tr class="rowYellow">
												<td>
													<img src="/{$theme}/images/1x1.gif" height="10" width="10"
														style="vertical-align:auto"/>
												</td>
											</tr>
										</table>
									</td>
									<td>
										<sw:text>The resource is in the yellow zone.</sw:text>
									</td>
								</tr>
								<tr>
									<td>
										<table border="0" cellspacing="0" cellpadding="0"
											style="height:5px;width:5px; border: 1px solid black">
											<tr class="rowRed">
												<td>
													<img src="/{$theme}/images/1x1.gif" height="10" width="10"
														style="vertical-align:auto"/>
												</td>
											</tr>
										</table>
									</td>
									<td style="background-color:transparent">
										<sw:text>The resource is in the red zone.</sw:text>
									</td>
								</tr>
							</table>
						</div>
					</ui:raw>
				</xsl:if>
				
				<xsl:if test="$activeMode='vzcc' and cred:check-context('vzcp.env.manage.properties.preferences','ve.vz.vt')">
					<ui:block width="full">
						<ui:buttons>
							<ui:button tip="change_qos_ext" sandclock="false" icon="env_resources" type="ok"
								submit-href="{$baseurl}/vzdir/infrman/envs/manage?tab=qos"
							>
								<sw:text>Configure</sw:text>
							</ui:button>
						</ui:buttons>
					</ui:block>
				</xsl:if>

			</ui:content>

		</ui:screen>
	</xsl:template>

	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/vt/env-private.xsl"/>

	<sw:include href="/lib/vt/env-quota.xsl"/>
	<sw:include href="/lib/vz/ubcs.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>

	<sw:include href="/lib/vza/hwm.xsl"/>

</xsl:stylesheet>
