<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl	="http://exslt.org/common"
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:voc		="http://www.swsoft.com/xsl/cp/voc"
	xmlns:env		="http://www.swsoft.com/xsl/cp/env"
>

	<sw:include href="/lib/vt/env-core.xsl"/>

	<xsl:variable name="ve-eid" select="sw:ve-eid()"/>
	<xsl:param name="access-denied" 
		select="not(cred:check-env('vzcp.env.manage.services.login',$ve-eid))"/>	

	<xsl:variable name="env-config" select="env:get-env($ve-eid)/env/virtual_config"/>
	<xsl:variable name="ip-address"	select="$env-config/address/ip[1]"/>		
	
	<xsl:template mode="screen" match="/">
		<ui:screen id="03.02.01.15.02" title="{sw:text('Remote Desktop')}" icon="remote">
			<ui:properties>
				<ui:width value="fixed"/>
				<ui:description mandatory="yes">
					<sw:text>
						You are going to establish a connection to the Container via the Remote Desktop terminal in the browser window. <br/> 
						The Remote Desktop window will pop up after you click the "Login" button. 
						To view this window, you need to use IE 5.0 or higher with Javascript and ActiveX support enabled.<br/> 
						As an alternative, you can use your favorite standalone RDP client.
					</sw:text>
				</ui:description>
				<ui:form-get/>
			</ui:properties>

			<xsl:variable name="oper-problem" select="voc:check-operation('rdp')"/>

			<ui:content>
				<xsl:choose>
					<!-- Can`t show RDP screen -->
					<xsl:when test="$oper-problem!=''">
						<ui:block>
							<ui:operation-problem>
								<xsl:copy-of select="$oper-problem"/>
								<ui:descr>
									<sw:text>Cannot open the RDP connection.</sw:text>
								</ui:descr>
							</ui:operation-problem>
						</ui:block>
					</xsl:when>
          <xsl:when test="not($ip-address != '')">
						<ui:block>
              <ui:operation-problem>
              	<ui:reason>
              		<sw:text>The Container has no IP address assigned.</sw:text>
              	</ui:reason>
								<ui:solution>
									<xsl:choose>
										<xsl:when test="cred:check-env('vzcp.env.manage.properties.preferences',$ve-eid)">
											<ui:i18n-link  href="{$baseurl}/vzdir/infrman/envs/manage?tab=net" tip="vzenv_network_setup">
  		  		  			  	<_>Please %{aopen}assign an IP address%{aclose} and try again.</_>
											</ui:i18n-link>
										</xsl:when>
										<xsl:otherwise>
											<sw:text>Please assign an IP address and try again.	</sw:text>
										</xsl:otherwise>
									</xsl:choose>
								</ui:solution>
                <ui:descr>
									<sw:text>Unable to connect to this Container via RDP.</sw:text>
								</ui:descr>
								<ui:env-eid><xsl:value-of select="$ve-eid"/></ui:env-eid>
              </ui:operation-problem>
            </ui:block>
          </xsl:when>
					<xsl:otherwise>
						<ui:block mode="edit">
							<ui:buttons>
								<ui:button type="ok" name="_submit" tip="rdp_open_window" script="return openRDP();"
									disabled="{sw:if(contains($http-user-agent,'MSIE'),'false','true')}">
									<sw:text>Login_button</sw:text>
								</ui:button>
							</ui:buttons>
							<ui:java-script>
if (this.name == 'topFrame')
	this.location = '<xsl:value-of
									select="$baseurl"
									/>/panel/plesk/top';
function openRDP(){
	<![CDATA[if (is.ie){]]>
		window.open('<xsl:value-of
									select="$baseurl"
								/>/vzdir/infrman/envs/services/rdp-popup','_blank','width=820,height=610,scrollbars=yes,toolbar=no,status=no,resizable=yes,menubar=no,location=no,directories=no');
	}
	return false;
}
			       </ui:java-script>
						</ui:block>
					</xsl:otherwise>
				</xsl:choose>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>


</xsl:stylesheet>
