<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred voc hwm env"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl	="http://exslt.org/common"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
  xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
	xmlns:env		="http://www.swsoft.com/xsl/cp/env"
	xmlns:vzenv		="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:voc		="http://www.swsoft.com/xsl/cp/voc"	
	xmlns:hwm		="http://www.swsoft.com/xsl/cp/hwm"
	xmlns:ve		="http://www.swsoft.com/xsl/cp/ve"
>
  
  <sw:include href="/lib/vt/env-core.xsl"/>
  
  <xsl:variable name="showform" 	select="not(sw:sesgetstr('ssh-login')) or  not(sw:sesgetstr('ssh-password'))"/>
	<xsl:variable name="java-mode"	select="sw:sesgetstr('java_mode')"/>
	<xsl:variable name="js-mode"		select="sw:sesgetstr('js_mode')"/>
	<xsl:variable name="eid"				select="sw:ve-eid()"/>
	<xsl:param name="access-denied" select="not(cred:check-env('vzcp.env.manage.services.login',$eid))"/>

  <xsl:template mode="screen" match="/">

		<ui:screen id="03.02.01.15.01" icon="connect">
			<ui:properties>
			  <ui:width value="fixed"/>
			  <ui:description mandatory="yes">
					<xsl:choose>
						<xsl:when test="($java-mode = 'notdef') and ($js-mode != 0)">
							<!-- try activeX -->
					    <sw:text>
					      You are going to open an SSH terminal in the browser window. <br/>
								 The SSH window will pop up after the login and password are submitted. 
								 To view this window, you need IE 5.0 or higher with Javascript and ActiveX support enabled. <br/>
								 As an alternative, you can use your favorite standalone SSH client.
							</sw:text>
						</xsl:when>
						<xsl:when test="($java-mode = 'enabled') and ($js-mode != 0)">
							<!-- try java plugin -->
					    <sw:text>
					      You are going to open an SSH terminal in the browser window. <br/>
					      The SSH window will pop up after the login and password are submitted.
					      To view this window, you need the Mozilla or Opera browsers with Javascript and Java enabled.
					      As an alternative, you can use your favorite standalone SSH client.
							</sw:text>						
						</xsl:when>
						<xsl:when test="($java-mode = 'disabled') or ($js-mode = 0)">
					    <sw:text>
					      You are going to open an SSH terminal in the browser window.
							</sw:text>						
						</xsl:when>
					</xsl:choose>	                                                                                                                      
			  </ui:description>      
			  <ui:form-get/>
			</ui:properties>
		  
    <xsl:if test="$showform">
			<xsl:variable name="vestate" select="ve:context-state()"/>
			<xsl:variable name="service-status" select="exsl:node-set(vzenv:ve-offline-status('vzpp',$eid))"/>

			<xsl:variable name="repair-offline-ready">
				<xsl:choose>
					<xsl:when test="$vestate = $env-state/repairing">
						<xsl:variable name="service-status-for-repair" select="exsl:node-set(vzenv:ve-offline-status('vzpp',$eid))"/>
						<xsl:value-of select="$service-status-for-repair/service-present"/>
					</xsl:when>
					<xsl:otherwise>0</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
			
			<xsl:variable name="oper-problem" select="voc:check-operation('ssh','','',$eid)"/>
			
      <ui:content>
        <xsl:choose>
					<xsl:when test="$java-mode = 'disabled'">
            <!-- no activeX, no java -->
						<ui:stop-sign>
              <sw:text>
                The Java plugin is probably not installed properly or Java is disabled in your browser.<br/>
								Install the Java plugin, enable Java support in your browser, log in, and try again.
								As an alternative, you can use your favorite standalone SSH client.
  	        	</sw:text>
    	    	</ui:stop-sign>
          </xsl:when>					

					<xsl:when test="$js-mode = 0">
            <!-- no js -->
						<ui:stop-sign>
			<sw:text>
				Cannot connect to the Container via SSH. Javascript is probably disabled in your browser.<br/> Log out of Parallels Infrastructure Manager, enable Javascript, log in, and try again. As an alternative, you can use your favorite standalone SSH client.
			</sw:text>
    	    	</ui:stop-sign>
          </xsl:when>					

          <xsl:when test="$oper-problem!=''">
        		<ui:block>
				    	<ui:operation-problem>
				    		<xsl:copy-of select="$oper-problem"/>
								<ui:descr><sw:text>Unable to connect to this Container via SSH.</sw:text></ui:descr>
							</ui:operation-problem>
						</ui:block>
					</xsl:when>
 
          <xsl:when test="not($service-status/ip-address != '')">
						<ui:block>
              <ui:operation-problem>
              	<ui:reason>
              		<sw:text>The Container has no host-routed IP address assigned.</sw:text>
              	</ui:reason>
								<ui:solution>
									<xsl:choose>
										<xsl:when test="cred:check-env('vzcp.env.manage.properties.preferences',$eid)">
											<ui:i18n-link  href="{$baseurl}/vzdir/infrman/envs/manage?tab=net" tip="vzenv_network_setup">
  		  		  			  	<_>Please %{aopen}assign an IP address%{aclose} and try again.</_>
											</ui:i18n-link>
										</xsl:when>
										<xsl:otherwise>
											<sw:text>Please assign an IP address and try again.	</sw:text>
										</xsl:otherwise>
									</xsl:choose>
								</ui:solution>
                <ui:descr>
									<sw:text>Unable to connect to this Container via SSH.</sw:text>
								</ui:descr>
								<ui:env-eid><xsl:value-of select="$eid"/></ui:env-eid>
              </ui:operation-problem>
            </ui:block>
          </xsl:when>

          <xsl:when test="(($vestate != $env-state/repairing) and ($service-status/service-present = 0)) or (($vestate = $env-state/repairing) and ($repair-offline-ready = 0))">
						<ui:block>
              <ui:operation-problem>
              	<ui:reason>
              		<sw:text>Offline management for the vzpp service is disabled.</sw:text>
              	</ui:reason>
								<ui:solution>
									<xsl:choose>
										<xsl:when test="cred:check-env('vzcp.env.manage.properties.preferences',$eid)">
											<ui:i18n-link  href="{$baseurl}/vzdir/infrman/envs/manage?tab=gen" tip="configure_ve">
  		  		  			  	<_>Please %{aopen}enable%{aclose} the offline management for the vzpp service and try again.</_>
											</ui:i18n-link>
										</xsl:when>
										<xsl:otherwise>
											<sw:text>Please enable the offline management for the vzpp service and try again.</sw:text>
										</xsl:otherwise>
									</xsl:choose>
								</ui:solution>
                <ui:descr>
									<sw:text>Unable to connect to this Container via SSH.</sw:text>
								</ui:descr>
								<ui:env-eid><xsl:value-of select="$eid"/></ui:env-eid>
              </ui:operation-problem>
            </ui:block>
          </xsl:when>

          <xsl:otherwise>
            <ui:block mode="edit">
            	<ui:rows>
            		<ui:row>
            			<ui:cell-label><sw:text>Login</sw:text></ui:cell-label>
              		<ui:cell-input id="login" value="{sw:sesgetstr('ssh-login')}"/>
              	</ui:row>
              	<ui:row>
              		<ui:cell-label><sw:text>Password</sw:text></ui:cell-label>
	              	<ui:cell-input mode-password="true" id="password"/>
	              </ui:row>
	            </ui:rows>
	            <ui:buttons>
	            	<ui:button type="ok" name="_submit" sandclock="false" tip="ssh_open_window">
	            		<xsl:if test="cred:check-env('vzcp.env.manage.services.login',$eid)">
		            		<xsl:attribute name="onclick">openSSH();return false;</xsl:attribute>
		            	</xsl:if>
	            		<sw:text>Login_button</sw:text>
	            	</ui:button>
	            </ui:buttons>
            </ui:block>
          </xsl:otherwise>            
        </xsl:choose>
<ui:java-script>
		if (this.name == 'topFrame')
   		this.location = '<xsl:value-of select="$baseurl"/>/panel/plesk/top';
<![CDATA[
    function openSSH(){
    	top.sshPopupLogin = document.defaultForm.login.value;
      top.sshPopupPassword = document.defaultForm.password.value;
			if ((top.sshPopupLogin == '') || (top.sshPopupPassword == '')) {
				alert(']]><sw:text select="'Empty login or password !'"/><![CDATA[');
				return;
			} 
     	if (is.ie && !is.ie4 && !is.opera) {
				window.open(']]><xsl:value-of select="$baseurl"/><![CDATA[/vzdir/infrman/envs/services/ssh-popup','_blank','width=700,height=500,toolbar=no,status=no,resizable=yes,menubar=no,location=no,directories=no');
      } else {
				window.open(']]><xsl:value-of select="$baseurl"/><![CDATA[/vzdir/infrman/envs/services/ssh-popup-java','_blank','width=700,height=500,toolbar=no,status=no,resizable=yes,menubar=no,location=no,directories=no');
			}
		}
]]>
</ui:java-script>

      </ui:content>
    </xsl:if>
      
    <xsl:if test="not($showform)">
      <ui:content>
		<!-- Javascript moved to the form -->
		<ui:hidden name="password" value="{sw:sesget('ssh-login')}"/>
		<ui:hidden name="password" value="{sw:sesget('ssh-password')}"/>
      </ui:content>
    </xsl:if>    
    </ui:screen>
  </xsl:template>

  <sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/vz/vzenv-offline.xsl"/>
	<sw:include href="/lib/vza/hwm.xsl"/>
	
</xsl:stylesheet>
