<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred vzenv voc here func servicem"
  xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl		="http://exslt.org/common"
  xmlns:sw			="http://www.swsoft.com/xsl/cp"
  xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
  xmlns:browse	="http://www.swsoft.com/xsl/cp/browse"     
	xmlns:cred  	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:vzenv   	="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:voc			="http://www.swsoft.com/xsl/cp/voc"
	xmlns:here		="http://www.swsoft.com/xsl/cp/here"
	xmlns:func		="http://exslt.org/functions"
	xmlns:servicem ="http://www.swsoft.com/xsl/cp/servicem"
	xmlns:ve="http://www.swsoft.com/xsl/cp/ve"
>

	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/swa/servicem.xsl"/>	

	<xsl:variable name="eid" select="sw:ve-eid()"/>
	<xsl:variable name="srv-type" select="'windows'"/>

  <xsl:template mode="screen" match="/">
  	<xsl:variable name="oper-problem" select="voc:check-operation('servicem')"/>
  	<ui:screen id="03.02.01.07.07">
	<ui:properties>
		<ui:description width="full">
			<sw:text>
			On this screen you can manage system services of the Container. A service is a background system-level application.
			<br/>Services typically provide users with support for client/server systems, Web and database servers, 
			<br/>and other server-based functionality, both locally and across the network.
			</sw:text>
		</ui:description>      
		<ui:form-get/>
	</ui:properties>

		<xsl:if test="$activeMode = 'vzcc'">	
			<ui:tab-bar id="vzve" current-tab="services" current-subtab="system"/>
		</xsl:if>

    <ui:content>
      <xsl:choose>
        <xsl:when test="$oper-problem=''">
					<ui:block width="full">
				 		<xsl:variable name="filter_init_">
							<xsl:call-template name="browse:init-filter">
								<xsl:with-param name="browse">
									<ui:browse-setup id="services"
										item-url="/vzdir/infrman/envs/services/system/service-win" url="/vzdir/infrman/envs/services/system/index-win"
										item-url-tip="service_screen"
									/>
					        <ui:cols>
					        	<ui:column id="name" 					hidden="yes" for-url="yes" for-select="yes" encode="no"/>
					        	<ui:column id="display-name" nav-type="id" title="{sw:text('Name')}"  filter="auto"  for-select="no" for-url="no"/>
					        	<ui:column id="service-state-win"	sorting="yes" align="center" title="{sw:text('Status')}" apply-templates="yes"/>
										<ui:column id="startup-type"	sorting="yes" align="center" title="{sw:text('Startup Type')}"/>
					        	<ui:column id="status-hiden"  title="{sw:text('Status')}" filter="select" hidden="yes">
					        		<ui:filter-option value="Stopped" title="{sw:text('Stopped')}"/>
					        		<ui:filter-option value="Running" title="{sw:text('Running')}"/>
					        	</ui:column>
										<ui:column id="startup-type-hiden" title="{sw:text('Startup Type')}" filter="select" hidden="yes">
											<ui:filter-option value="Automatic" title="{sw:text('Automatic')}"/>
											<ui:filter-option value="Manual" 		title="{sw:text('Manual')}"/>
											<ui:filter-option value="Disabled" 	title="{sw:text('Disabled')}"/>
                    </ui:column>
										<ui:column id="logon-as" filter="auto" sorting="yes" align="center"  title="{sw:text('Log on as')}"/>
					        </ui:cols>
								</xsl:with-param>
							</xsl:call-template>
				    </xsl:variable>
				    
						<xsl:variable name="browse_result" select="servicem:get($eid)"/>
						<xsl:choose>
							<xsl:when test="$browse_result/servicem/error">
								<ui:operation-problem>
  				      	<ui:type>vza-error</ui:type>
          				<ui:descr>
			            	<sw:text>Error getting a list of services.</sw:text>
      			      </ui:descr>
			            <ui:vza-error>
      			      	<xsl:copy-of select="$browse_result/servicem/error/*"/>
			            </ui:vza-error>
  			          <ui:reason>
        			    	<sw:text>The service subsystem is not available. This can be caused by a resource shortage, Parallels Infrastructure Manager overloading, etc.</sw:text>
			            </ui:reason>
      			      <ui:solution>
            				<sw:text>Wait 30 seconds and try again.</sw:text>
			            </ui:solution>
      			    </ui:operation-problem>
							</xsl:when>
							<xsl:otherwise>
						    <xsl:variable name="service-list" select="$browse_result/servicem"/>
						    <xsl:variable name="filter">
						    	<xsl:call-template name="browse:fill-filter">
										<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
										<xsl:with-param name="rows">					
							        <ui:browse-rows>
							        	<xsl:for-each select="$service-list/service">
													<xsl:variable name="name" select="string(name)" />
													<xsl:variable name="display-name" select="sw:base64-decode(display_name)" />
													<xsl:variable name="startup-type" select="string(startup_type)" />
													<xsl:variable name="status" select="string(status)" />
													<ui:row>
														<name>
															<xsl:value-of select="sw:base64-encode(concat($name,'|',$display-name))"/>
														</name>
														<display-name>
															<xsl:value-of select="$display-name"/>
														</display-name>
														<service-state-win>
															<sw:text domain="vzagent-vocabulary" select="$status"/>
														</service-state-win>
														<startup-type>
															<sw:text domain="vzagent-vocabulary" select="$startup-type"/>
														</startup-type>
														<status-hiden>
															<xsl:value-of select="$status"/>
														</status-hiden>
														<startup-type-hiden>
															<xsl:value-of select="$startup-type"/>
														</startup-type-hiden>
														<logon-as>
															<xsl:value-of select="logon_as"/>							
														</logon-as>
													</ui:row>
									     	</xsl:for-each> 
						        	</ui:browse-rows>
						        </xsl:with-param>
									</xsl:call-template>
						    </xsl:variable>
						     
								<ui:browse>
									<ui:browse-buttons>
										<ui:button type="list-selection" tip="start_srvs_act" icon="service_start" 
											script="if (!atLeastOne()) return false;" name="start">
											<sw:text>Start Service</sw:text>
										</ui:button>
										<ui:button type="list-selection" tip="restart_srvs_act" icon="service_restart"
											confirmation="{sw:text('Are you sure you want to restart the selected service(s)?')}" 
											script="if (!atLeastOne()) return false;" name="restart">
											<sw:text>Restart Service</sw:text>
										</ui:button>
										<ui:button type="list-selection" tip="stop_srvs_act" icon="service_stop" 
											confirmation="{sw:text('Are you sure you want to stop the selected service(s)?')}" 							
											script="if (!atLeastOne()) return false;" name="stop">
											<sw:text>Stop Service</sw:text>
										</ui:button>
									</ui:browse-buttons>
			
									<ui:filter>
			        			<xsl:copy-of select="$filter"/>
			        		</ui:filter>
						         
			            <ui:browse-empty-msg>
					        	<sw:text>
					          	No services available for this Container. 
					          	<br/> 
					          	Probably your Container is misconfigured or having a resource shortage.
			      		    </sw:text>	      	        
									</ui:browse-empty-msg>
			                
			            <ui:browse-js-many>
			            	<ui:warn><sw:text>Select at least one service!</sw:text></ui:warn>
			            </ui:browse-js-many>
			             
			          </ui:browse>
							</xsl:otherwise>
						</xsl:choose>
					</ui:block>
				</xsl:when>
			
		    <xsl:otherwise>
					<ui:block>
						<ui:operation-problem>
		  	  		<xsl:copy-of select="$oper-problem"/>
							<ui:descr><sw:text>Unable to manage the services in this Container.</sw:text></ui:descr>
						</ui:operation-problem>
					</ui:block>
  			</xsl:otherwise>        
	  	</xsl:choose>

	  </ui:content>
    </ui:screen>
  </xsl:template>  


	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/core/browse-filter-raw.xsl" />

</xsl:stylesheet>
