<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred env voc here func servicem"
  xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl		="http://exslt.org/common"
  xmlns:sw			="http://www.swsoft.com/xsl/cp"
  xmlns:ui			="http://www.swsoft.com/xsl/cp/ui"
  xmlns:browse	="http://www.swsoft.com/xsl/cp/browse"     
	xmlns:cred  	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:env   	="http://www.swsoft.com/xsl/cp/env"
	xmlns:voc			="http://www.swsoft.com/xsl/cp/voc"
	xmlns:here		="http://www.swsoft.com/xsl/cp/here"
	xmlns:func		="http://exslt.org/functions"
	xmlns:servicem="http://www.swsoft.com/xsl/cp/servicem"
	xmlns:ve="http://www.swsoft.com/xsl/cp/ve"
>
	<sw:include href="/lib/swa/servicem.xsl"/>	
	<sw:include href="/lib/vt/env-core.xsl"/>

	<xsl:variable name="eid" select="sw:ve-eid()"/>

	<!-- restore or set tab -->
	<xsl:variable name="tab-pre">
		<xsl:choose>
			<xsl:when test="sw:param('tab')">
				<!-- in case GET present, it beat all -->
				<xsl:value-of select="sw:param('tab')"/>
			</xsl:when>
			<xsl:otherwise>
				<!-- try use session -->
				<xsl:choose>
					<xsl:when test="$activeMode = 'vzcc'">
						<xsl:value-of select="sw:sesgetstr('cur-tab-for-service-vzcc')"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="sw:sesgetstr('cur-tab-for-service-vzpp')"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>	
	
	<!-- main tab logic -->
	<xsl:variable name="srv-type">
		<xsl:choose>
			<xsl:when test="$tab-pre != ''">
				<xsl:value-of select="$tab-pre"/>
			</xsl:when>
			<!-- no get, no prev session, init -->
			<xsl:when test="$activeMode = 'vzcc'">
				<xsl:value-of select="'sysv-all'"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="'sysv-standart'"/>
			</xsl:otherwise>
		</xsl:choose>	
	</xsl:variable>
	<!-- store in session -->

	<xsl:variable name="save-tab">
		<xsl:choose>
			<xsl:when test="$activeMode = 'vzcc'">
				<xsl:variable name="save-tab" select="sw:sesputstr('cur-tab-for-service-vzcc',$srv-type)"/>
				<xsl:value-of select="sw:sesgetstr('cur-tab-for-service-vzcc')"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="save-tab" select="sw:sesputstr('cur-tab-for-service-vzpp',$srv-type)"/>		
			</xsl:otherwise>
		</xsl:choose>	
	</xsl:variable>
	
	<xsl:variable name="screen-id">
		<xsl:choose>
			<xsl:when test="$srv-type = 'sysv-all'">
				<xsl:value-of select="'03.02.01.07.01'"/>
			</xsl:when>
			<xsl:when test="$srv-type = 'xinetd-all'">
				<xsl:value-of select="'03.02.01.07.02'"/>
			</xsl:when>
			<xsl:when test="$srv-type = 'sysv-standart'">
				<xsl:value-of select="'03.02.01.07.03'"/>
			</xsl:when>
			<xsl:when test="$srv-type = 'xinetd-standart'">
				<xsl:value-of select="'03.02.01.07.04'"/>
			</xsl:when>			
		</xsl:choose>
	</xsl:variable>

  <func:function name="here:isServiceStandart">
		<xsl:param name="standart"/>
		<xsl:param name="name"/>
		<xsl:param name="type"/>
		<xsl:variable name="rc" select="count($standart[(@id = $name) and ((@type = $type) or ($type = '' and not(@type)))]) = 1"/>
		<func:result select="$rc"/>
  </func:function>

  <xsl:template mode="screen" match="/">
  	<xsl:variable name="oper-problem" select="voc:check-operation('servicem')"/>
  	<xsl:variable name="is-debian-ve" select="contains(sw:sesget('base_set')/name, 'debian')"/>
  	<ui:screen id="{$screen-id}">
			<ui:properties>
				<ui:description width="full">
					<sw:text>
					On this screen you can manage system services of the Container. A service is a background system-level application.
					<br/>Services typically provide users with support for client/server systems, Web and database servers, 
					<br/>and other server-based functionality, both locally and across the network.
					</sw:text>
				</ui:description>      
				<ui:form-get/>
			</ui:properties>

			<xsl:choose>
				<xsl:when test="$activeMode = 'vzcc'">	
					<ui:tab-bar id="vzve" current-tab="services" current-subtab="{$srv-type}"/>
				</xsl:when>
				<xsl:otherwise>
					<ui:tab-bar id="services" current-tab="{$srv-type}"/>				
				</xsl:otherwise>
			</xsl:choose>
			
			<ui:content>
				<xsl:choose>
					<xsl:when test="$oper-problem='' and not($is-debian-ve)">
						<ui:block width="full">
							<xsl:variable name="filter_init_">
								<xsl:call-template name="browse:init-filter">
									<xsl:with-param name="browse">
										<ui:browse-setup id="services"
											item-url="/vzdir/infrman/envs/services/system/service?tab={$srv-type}" url="/vzdir/infrman/envs/services/system/index?tab={$srv-type}"
											item-url-tip="service_screen"
											items-title="{sw:text('Services')}"
										/>
										<ui:cols>
											<ui:column id="id" nav-type="id" title="{sw:text('Name')}" filter="auto" encode="no" for-select="yes"/>
											<ui:column id="service-state" align="center" 
												title="{sw:text('Status')}"
												apply-templates="yes"/>
											<ui:column id="service-state-src" hidden="yes"
												title="{sw:text('Status')}"
												filter="select"
											>
												<ui:filter-option value="0" title="{sw:text('Stopped')}"/>
												<ui:filter-option value="1" title="{sw:text('Running')}"/>
											</ui:column>
											<ui:column id="service-autostart" filter="select" sorting="yes" align="center" apply-templates="yes" title="{sw:text('Autostart')}">
												<ui:filter-option value="1" title="{sw:text('Enable')}"/>
												<ui:filter-option value="0" title="{sw:text('Disable')}"/>
											</ui:column>										
										</ui:cols>
									</xsl:with-param>
								</xsl:call-template>
							</xsl:variable>
							
							<xsl:variable name="browse_result" select="servicem:get($eid)"/>
							<xsl:choose>
								<xsl:when test="$browse_result/servicem/error">
									<ui:operation-problem>
										<ui:type>vza-error</ui:type>
										<ui:descr>
											<sw:text>Error getting a list of services.</sw:text>
										</ui:descr>
										<ui:vza-error>
											<xsl:copy-of select="$browse_result/servicem/error/*"/>
										</ui:vza-error>
										<ui:reason>
											<sw:text>The service subsystem is not available. This can be caused by a resource shortage, Parallels Infrastructure Manager overloading, etc.</sw:text>
										</ui:reason>
										<ui:solution>
											<sw:text>Check the resources page.</sw:text>
										</ui:solution>
									</ui:operation-problem>
								</xsl:when>
								<xsl:otherwise>							
									<xsl:variable name="standart-service-list" select="sw:document('standart-services.xml')/services/service[not(type) or (type = $srv-type)]"/>
									<xsl:variable name="service-list-rtf">
										<xsl:choose>
											<xsl:when test="$srv-type = 'sysv-standart'">
												<xsl:copy-of select="$browse_result/servicem/service[not(xinetd) and here:isServiceStandart($standart-service-list,name,'')]"/>
											</xsl:when>
											<xsl:when test="$srv-type = 'sysv-all'">
												<xsl:copy-of select="$browse_result/servicem/service[not(xinetd)]"/>
											</xsl:when>				    		
											<xsl:when test="$srv-type = 'xinetd-standart'">
												<xsl:copy-of select="$browse_result/servicem/service[xinetd and here:isServiceStandart($standart-service-list,name,'xinetd')]"/>
											</xsl:when>
											<xsl:when test="$srv-type = 'xinetd-all'">
												<xsl:copy-of select="$browse_result/servicem/service[xinetd]"/>
											</xsl:when>				    		
										</xsl:choose>
									</xsl:variable>
									<xsl:variable name="service-list" select="exsl:node-set($service-list-rtf)"/>
									<xsl:variable name="xinetd-info" select="$browse_result/servicem/service[name = 'xinetd']"/>
									<xsl:variable name="xinetd-autostart" select="sw:if($xinetd-info/level = 3,1,0)"/>
									<xsl:variable name="xinetd-state" select="sw:if($xinetd-info/state = 1,1,0)"/>

									<xsl:variable name="filter">
										<xsl:call-template name="browse:fill-filter">
											<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
											<xsl:with-param name="rows">					
												<ui:browse-rows>
													<xsl:for-each select="$service-list/service">
														<xsl:variable name="id" select="name"/>
														<ui:row>
															<id>
																<xsl:value-of select="$id"/>
															</id>
															<service-state-src>
																	<xsl:value-of select="state"/>
															</service-state-src>
															<service-state>
																<state>
																	<xsl:value-of select="state"/>
																</state>
																<level>
																	<xsl:value-of select="level"/>
																</level>
															</service-state>
															<service-autostart>
																<xsl:value-of select="sw:if(level = 3,1,0)"/>
															</service-autostart>
															<xsl:copy-of select="xinetd"/>
														</ui:row>
													</xsl:for-each> 
												</ui:browse-rows>
											</xsl:with-param>
											<xsl:with-param name="cookies">	
												<xinetd-state>
													<xsl:value-of select="$xinetd-state"/>  
												</xinetd-state>
												<xinetd-autostart>
													<xsl:value-of select="$xinetd-autostart"/>  
												</xinetd-autostart>
											</xsl:with-param>
										</xsl:call-template>
									</xsl:variable>
									 
									<ui:browse>
									
										<ui:browse-buttons>
											<xsl:choose>
												<xsl:when test="$srv-type = 'xinetd-all' or $srv-type = 'xinetd-standart'">
													<ui:button type="list-selection" tip="enable_srv_xinetd" icon="env_start" 
														script="if (!atLeastOne()) return false;" name="start" auxiliary="true">
														<sw:text>Enable</sw:text>
													</ui:button>
													<ui:button type="list-selection" tip="disable_srv_xinetd" icon="env_stop" 
														confirmation="{sw:text('Are you sure you want to disable the selected service(s)?')}"
														script="if (!atLeastOne()) return false;" name="stop" auxiliary="true">
														<sw:text>Disable</sw:text>
													</ui:button>									
												</xsl:when>
												<xsl:otherwise>
													<ui:button type="list-selection" tip="start_srvs_act" icon="service_start" 
														script="if (!atLeastOne()) return false;" name="start" auxiliary="true">
														<sw:text>Start Service</sw:text>
													</ui:button>
													<ui:button type="list-selection" tip="restart_srvs_act" icon="service_restart"
														confirmation="{sw:text('Are you sure you want to restart the selected service(s)?')}" 
														script="if (!atLeastOne()) return false;" name="restart" auxiliary="true">
														<sw:text>Restart Service</sw:text>
													</ui:button>
													<ui:button type="list-selection" tip="stop_srvs_act" icon="service_stop" 
														confirmation="{sw:text('Are you sure you want to stop the selected service(s)?')}" 							
														script="if (!atLeastOne()) return false;" name="stop" auxiliary="true">
														<sw:text>Stop Service</sw:text>
													</ui:button>
													<ui:button type="list-selection" tip="enable_autostart_group" icon="enable"
														confirmation="{sw:text('Are you sure you want to enable the autostart for the selected service(s)?')}" 
														script="if (!atLeastOne()) return false;" name="enable" auxiliary="true">
														<sw:text>Enable Autostart</sw:text>
													</ui:button>
													<ui:button type="list-selection" tip="disable_autostart_group" icon="disable" 
														confirmation="{sw:text('Are you sure you want to disable the autostart for the selected service(s)?')}"
														script="if (!atLeastOne()) return false;" name="disable" auxiliary="true">
														<sw:text>Disable Autostart</sw:text>
													</ui:button>										
												</xsl:otherwise>
											</xsl:choose>
										</ui:browse-buttons>
				
										<ui:filter>
											<xsl:copy-of select="$filter"/>
										</ui:filter>
											 
										<ui:browse-empty-msg>
											<sw:text>
												No services available for this Container. 
												<br/> 
												Probably your Container is misconfigured or having a resource shortage.
											</sw:text>	      	        
										</ui:browse-empty-msg>
												
										<ui:browse-js-many>
											<ui:warn><sw:text>Select at least one service!</sw:text></ui:warn>
										</ui:browse-js-many>
									</ui:browse>
									<ui:java-script>          
										function xWarn(service) {
											var message;
											if (service == 'xinetd'){
												if (confirm('<sw:text>Stopping the xinetd service will stop all the dependent services as well. Are you sure you want to stop it?</sw:text>')){
													showSandclock();
													return true
												}else{
													return false
												}
											}
											return true
										}				 
									</ui:java-script>     
								</xsl:otherwise>
							</xsl:choose>
						</ui:block>
					</xsl:when>
					<xsl:otherwise>
						<ui:block>
							<ui:operation-problem>
								<xsl:choose>
									<xsl:when test="$is-debian-ve">
										<ui:type>custom</ui:type>
										<ui:reason>
											<sw:text>Unable to manage the services in Debian Containers.</sw:text>
										</ui:reason>
									</xsl:when>
									<xsl:otherwise>
										<xsl:copy-of select="$oper-problem"/>
									</xsl:otherwise>
								</xsl:choose>
								<ui:descr><sw:text>Unable to manage the services in this Container.</sw:text></ui:descr>
							</ui:operation-problem>
						</ui:block>
					</xsl:otherwise>        
				</xsl:choose>
			</ui:content>
		</ui:screen>
  </xsl:template>  

	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/core/browse-filter-raw.xsl" />

</xsl:stylesheet>
