<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl wiz cred fwm"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl	="http://exslt.org/common"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
  xmlns:error	="http://www.swsoft.com/xsl/cp/error"
  xmlns:wiz		="http://www.swsoft.com/xsl/cp/wiz"
  xmlns:ui	="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
	xmlns:fwm   ="http://www.swsoft.com/xsl/cp/fwm"
	xmlns:local	="http://www.swsoft.com/xsl/cp/local"
 >

  <xsl:param name="wiz_code" 					select="'service-management'"/>
  
	<xsl:variable name="step_data"			select="wiz:getStep()"/>
	<xsl:variable name="step"						select="$step_data/@id"/>
	<xsl:variable name="screen-id"			select="$step_data/@screen-id"/>
	<xsl:variable name="screen-title"		select="$step_data/@screen-title"/>
	<xsl:variable name="path-id"				select="string(wiz:getSteps()/step[1]/@screen-id)"/>

  <xsl:variable name="form" 					select="sw:sesget($wiz_data)"/>
	<xsl:param name="access-denied" 
		select="not($step_data/@cred!='' and cred:check-context($step_data/@cred,$step_data/@security-obj-type))"/>

  <xsl:variable name="screen-icon" select="'service'"/>

  <xsl:template name="local:srv-detail">
  	<ui:screen path-id="{$path-id}" id="{$screen-id}" title="{$screen-title}" icon="{$screen-icon}">
  		<ui:properties>
				<ui:refresh-type>none</ui:refresh-type>
	      <ui:description mandatory="yes" >
	        <sw:text>
						<xsl:with-param name="display-name" select="$form/display-name"/>
						On this screen you can change the startup type of the "%{display-name}" service.
	        </sw:text>
	      </ui:description>      
	    </ui:properties>

	    <ui:content>
	      <ui:hidden name="step" value="{$step}"/>
	      <ui:block mode="edit">
				
				<ui:rows separate-tables="true" title="{sw:text('General')}">
					<ui:row>
						<ui:cell-label>
							<sw:text>Service Name</sw:text> 
						</ui:cell-label>
						<ui:cell-value>
							<xsl:value-of select="$form/name"/>
						</ui:cell-value>
					</ui:row>
					<ui:row>
						<ui:cell-label>
							<sw:text>Display Name</sw:text> 
						</ui:cell-label>
						<ui:cell-value>
							<xsl:value-of select="$form/display-name"/>
						</ui:cell-value>
					</ui:row>
					<ui:row>
						<ui:cell-label>
							<sw:text>Description</sw:text>
						</ui:cell-label>
						<ui:cell-value>
							<xsl:value-of select="$form/description"/>
						</ui:cell-value>
					</ui:row>
					<ui:row>
						<ui:cell-label>
							<sw:text>Status</sw:text>
						</ui:cell-label>
						<ui:cell-value>
							<xsl:value-of select="$form/status"/>
						</ui:cell-value>
					</ui:row>
					<ui:row>
						<ui:cell-label>
							<sw:text>Log on as</sw:text>
						</ui:cell-label>
						<ui:cell-value>
							<xsl:value-of select="$form/logon-as"/>
						</ui:cell-value>
					</ui:row>					
					<ui:row>
						<ui:cell-label>
							<sw:text>Startup Type</sw:text>
						</ui:cell-label>
						<ui:cell-list id="startup-type" value="{$form/startup-type}" width="150">
							<ui:list-item id="Automatic" title="{sw:text('Automatic')}"/>													
							<ui:list-item id="Manual" title="{sw:text('Manual')}"/>
							<ui:list-item id="Disabled" title="{sw:text('Disabled')}"/>
						</ui:cell-list>
					</ui:row>
				</ui:rows>

				<ui:rows separate-tables="true" title="{sw:text('Dependencies')}">
					<xsl:choose>
						<xsl:when test="count($form/depended-on/service) = 0">
							<ui:row>
								<ui:cell-label>
									<sw:text>This service does not depend on any system components.</sw:text> 
								</ui:cell-label>
							</ui:row>
						</xsl:when>
						<xsl:otherwise>
							<ui:row>
								<ui:cell-label>
									<sw:text>This service depends on the following system components:</sw:text> 
								</ui:cell-label>
							</ui:row>
							<ui:row>
								<ui:cell-value>&#160;</ui:cell-value>
								<ui:cell-value>
									<xsl:for-each select="$form/depended-on/service">
										<xsl:variable name="link-name" select="sw:base64-encode(concat(name,'|',display-name))"/>
										<ui:link href="{$baseurl}/vzdir/infrman/envs/services/system/service-win?cmd=v&amp;name={$link-name}">
											<xsl:value-of select="display-name"/>
											<xsl:if test="position() != last()">
												<br/>
											</xsl:if>											
										</ui:link>
									</xsl:for-each>
								</ui:cell-value>
							</ui:row>
						</xsl:otherwise>
					</xsl:choose>							

					<ui:row>
						<xsl:choose>
							<xsl:when test="count($form/dependent/service) = 0">
								<ui:cell-label>
									<sw:text>No system component depends on this service.</sw:text> 
								</ui:cell-label>
							</xsl:when>
							<xsl:otherwise>
								<ui:row>
									<ui:cell-label>
										<sw:text>The following system components depend on this service:</sw:text>
									</ui:cell-label>
								</ui:row>
								<ui:row>
									<ui:cell-value>&#160;</ui:cell-value>
									<ui:cell-value>
										<xsl:for-each select="$form/dependent/service">
											<xsl:variable name="link-name" select="sw:base64-encode(concat(name,'|',display-name))"/>
											<ui:link href="{$baseurl}/vzdir/infrman/envs/services/system/service-win?cmd=v&amp;name={$link-name}">
												<xsl:value-of select="display-name"/>
												<xsl:if test="position() != last()">
													<br/>
												</xsl:if>											
											</ui:link>
										</xsl:for-each>
									</ui:cell-value>
								</ui:row>
							</xsl:otherwise>
						</xsl:choose>
					</ui:row>
				</ui:rows>

				<ui:buttons>
		    	<xsl:call-template name="wiz:showButtons"/>
		  	</ui:buttons>
	    	</ui:block>
	  	</ui:content>   
	  </ui:screen>
	</xsl:template>


	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
		<xsl:call-template name="local:srv-detail"/>
	</xsl:template>
	
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>

</xsl:stylesheet>
