<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred voc"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"	
	xmlns:voc="http://www.swsoft.com/xsl/cp/voc"
>
	<sw:include href="/lib/vt/env-core.xsl"/>

	<!-- check permissions to show this page -->
	<xsl:param name="access-denied"
		select="not(cred:check-env('vzcp.env.manage.services_and_files',sw:ve-eid()))"/>

	<xsl:variable name="svc" select="/packet/cookie/servicem/service/name"/>
	<xsl:variable name="svc-description" select="string(voc:get('service', env:make-platform-ref(sw:ve-parent()))[id = $svc]/long)"/>

	<xsl:variable name="no-autostart"/>

	<!-- check return code and put error -->
	<xsl:variable name="eval">
		<xsl:choose>
			<xsl:when test="/packet/cookie/servicem/error">
				<xsl:variable name="errmsg">
					<sw:text>
						<xsl:with-param name="svc" select="$svc"
						/>
            Failed to get information on the %svc service
          </sw:text>
				</xsl:variable>
				<xsl:if test="error:put(string($errmsg),string(/packet/cookie/servicem/error/message))"/>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>

	<xsl:variable name="screen-id">
		<xsl:choose>
			<xsl:when test="/packet/cookie/servicem/service/xinetd">
				<xsl:value-of select="'03.02.01.07.06'"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="'03.02.01.07.05'"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>


	<xsl:template mode="screen" match="/">
		<ui:screen id="{$screen-id}" title="{$svc}" icon="service" tip="srv_screen">
			<ui:properties>
				<ui:description mandatory="yes">
					<xsl:if test="$svc-description != ''">
						<xsl:value-of select="sw:text($svc-description)"/>
						<br/>
					</xsl:if>
					<xsl:choose>
						<xsl:when test="/packet/cookie/servicem/service/xinetd">
							<sw:text>
								<xsl:with-param name="srv" select="$svc"
									/>
		          On this screen you can disable or enable your <b>%{srv}</b>&#160;service depending on its current state.<br/>
							</sw:text>
						</xsl:when>
						<xsl:otherwise>
							<sw:text>
								<xsl:with-param name="srv" select="$svc"
									/>
		          On this screen you can start, stop, or restart your <b>%{srv}</b>&#160;service depending on its current state.<br/>
		          You can also enable/disable the Autostart service option.
		        </sw:text>
						</xsl:otherwise>
					</xsl:choose>
				</ui:description>
				<ui:form-get/>
			</ui:properties>

			<xsl:variable name="xinetd-state" select="string(/packet/cookie/xinetd-state)"/>
			<xsl:variable name="xinetd-autostart" select="string(/packet/cookie/xinetd-autostart)"/>

			<ui:content>
				<ui:block>
					<xsl:if test="/packet/cookie/servicem/service/xinetd">
						<ui:i18n-link href="{$baseurl}/vzdir/infrman/envs/services/system/service?id=xinetd" tip="xinetd_screen">
							<_>The autostart option for this service is inherited from the %{aopen}xinetd service%{aclose}.</_>
						</ui:i18n-link>
					</xsl:if>

					<xsl:for-each select="/packet/cookie/servicem/service">
						<ui:raw>
							<table>
								<tr>
									<td align="right">
										<sw:text>Service is </sw:text>
									</td>
									<xsl:choose>
										<xsl:when test="not(xinetd)">
											<xsl:choose>
												<xsl:when test="state = 1">
													<td>
														<font color="green">
															<sw:text>Running</sw:text>
														</font>
													</td>
													<td>
														<img onmouseover="callTip('srv_sysv_running_icon',event)"
															onmouseout="callTip()" src="/{$theme}/icons/srv_running.gif"
															height="16" width="16" alt="{sw:text('Running')}"/>
													</td>
												</xsl:when>
												<xsl:when test="state = 0">
													<td>
														<font color="red">
															<sw:text>Stopped</sw:text>
														</font>
													</td>
													<td>
														<img onmouseover="callTip('srv_sysv_stopped_icon',event)"
															onmouseout="callTip()" src="/{$theme}/icons/srv_stopped.gif"
															height="16" width="16" alt="{sw:text('Stopped')}"/>
													</td>
												</xsl:when>
												<xsl:otherwise>
													<td>
														<sw:text>in an unknown state</sw:text>
													</td>
													<td>&#160;</td>
												</xsl:otherwise>
											</xsl:choose>
										</xsl:when>
										<xsl:when test="xinetd">
											<xsl:choose>
												<xsl:when test="(level = 0) and ($xinetd-state = 1)">
													<!-- xinetd subservices run and enable  -->
													<td>
														<font color="green">
															<sw:text>Enabled</sw:text>
														</font>
													</td>
													<td>
														<img onmouseover="callTip('srv_xinetd_enabled_running_icon',event)"
															onmouseout="callTip()" src="/{$theme}/icons/srv_running.gif"
															height="16" width="16" alt="{sw:text('Enabled')}"/>
													</td>
												</xsl:when>
												<xsl:when test="(level = 0) and ($xinetd-state = 0)">
													<!-- xinetd subservices stop and enable -->
													<td>
														<font color="grey">
															<sw:text>Enabled</sw:text>
														</font>
													</td>
													<td>
														<img onmouseover="callTip('srv_xinetd_enabled_not_runing_icon',event)"
															onmouseout="callTip()"
															src="/{$theme}/icons/srv_enabled_not_running.gif" height="16"
															width="16" alt="{sw:text('Enabled')}"/>
													</td>
												</xsl:when>
												<xsl:when test="not(level != '') and ($xinetd-state = 0)">
													<!-- xinetd subservices stop and disable -->
													<td>
														<font color="grey">
															<sw:text>Disabled</sw:text>
														</font>
													</td>
													<td>
														<img onmouseover="callTip('srv_xinetd_disabled_not_running_icon',event)"
															onmouseout="callTip()" src="/{$theme}/icons/srv_stopped.gif"
															height="16" width="16" alt="{sw:text('Disabled')}"/>
													</td>
												</xsl:when>
												<xsl:when test="not(level != '') and ($xinetd-state = 1)">
													<!-- xinetd subservices disabled -->
													<td>
														<font color="red">
															<sw:text>Disabled</sw:text>
														</font>
													</td>
													<td>
														<img onmouseover="callTip('srv_xinetd_disabled_running_icon',event)"
															onmouseout="callTip()" src="/{$theme}/icons/srv_stopped.gif"
															height="16" width="16" alt="{sw:text('Disabled')}"/>
													</td>
												</xsl:when>
												<xsl:otherwise>
													<td>
														<sw:text>in an unknown state</sw:text>
													</td>
													<td>&#160;</td>
												</xsl:otherwise>
											</xsl:choose>
										</xsl:when>
									</xsl:choose>
								</tr>

								<xsl:if test="not($no-autostart)">
									<xsl:choose>
										<xsl:when test="xinetd">
											<tr>
												<td align="right">
													<sw:text>Autostart is</sw:text>
												</td>
												<xsl:choose>
													<xsl:when test="$xinetd-autostart = 1">
														<td>
															<font color="grey">
																<sw:text>Enabled</sw:text>
															</font>
														</td>
														<td>
															<img onmouseover="callTip('srv_xinetd_autostart_yes_icon',event)"
																onmouseout="callTip()"
																src="/{$theme}/icons/autostart_yes_disabled.gif" height="16"
																width="16" alt="{sw:text('Enabled')}"/>
														</td>
													</xsl:when>
													<xsl:otherwise>
														<td>
															<font color="grey">
																<sw:text>Disabled</sw:text>
															</font>
														</td>
														<td>
															<img onmouseover="callTip('srv_xinetd_autostart_no_icon',event)"
																onmouseout="callTip()"
																src="/{$theme}/icons/autostart_no_disabled.gif" height="16"
																width="16" alt="{sw:text('Disabled')}"/>
														</td>
													</xsl:otherwise>
												</xsl:choose>
											</tr>
										</xsl:when>

										<xsl:otherwise>
											<tr>
												<td align="right">
													<sw:text>Autostart is</sw:text>
												</td>
												<xsl:choose>
													<xsl:when test="level = 3">
														<td>
															<font color="green">
																<sw:text>Enabled</sw:text>
															</font>
														</td>
														<td>
															<img onmouseover="callTip('srv_sysv_autostart_yes_icon',event)"
																onmouseout="callTip()" src="/{$theme}/icons/autostart_yes.gif"
																height="16" width="16" alt="{sw:text('Enabled')}"/>
														</td>
													</xsl:when>
													<xsl:otherwise>
														<td>
															<font color="red">
																<sw:text>Disabled</sw:text>
															</font>
														</td>
														<td>
															<img onmouseover="callTip('srv_sysv_autostart_no_icon',event)"
																onmouseout="callTip()" src="/{$theme}/icons/autostart_no.gif"
																height="16" width="16" alt="{sw:text('Disabled')}"/>
														</td>
													</xsl:otherwise>
												</xsl:choose>
											</tr>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:if>
							</table>
						</ui:raw>

						<ui:buttons>
							<xsl:choose>
								<xsl:when test="not(xinetd)">
									<xsl:choose>
										<xsl:when test="state = 1">
											<ui:button tip="restart_srv" name="restart_service" width="150">
												<sw:text>Restart Service</sw:text>
											</ui:button>
											<xsl:choose>
												<xsl:when test="$svc = 'xinetd'">
													<ui:button tip="stop_srv" name="stop_service" width="150"
														confirmation="{sw:text('Stopping the xinetd service will stop all the dependent services as well. Are you sure you want to stop it?')}">
														<sw:text>Stop Service</sw:text>
													</ui:button>
												</xsl:when>
												<xsl:otherwise>
													<ui:button tip="stop_srv" name="stop_service" width="150">
														<sw:text>Stop Service</sw:text>
													</ui:button>
												</xsl:otherwise>
											</xsl:choose>
										</xsl:when>
										<xsl:when test="state = 0">
											<ui:button tip="start_srv" name="start_service" width="150">
												<sw:text>Start Service</sw:text>
											</ui:button>
										</xsl:when>
										<xsl:otherwise>
											<!-- unknown state - no control available -->
										</xsl:otherwise>
									</xsl:choose>
								</xsl:when>
								<xsl:when test="xinetd">
									<xsl:choose>
										<xsl:when test="(level = 0) and ($xinetd-state = 1)">
											<!-- xinetd subservices run and enable  -->
											<ui:button tip="disable_srv_xinetd" name="disable_service" width="150">
												<sw:text>Disable Service</sw:text>
											</ui:button>
										</xsl:when>
										<xsl:when test="(level = 0) and ($xinetd-state = 0)">
											<!-- xinetd subservices stop and enable -->
											<ui:button tip="disable_srv_xinetd" name="disable_service" width="150">
												<sw:text>Disable Service</sw:text>
											</ui:button>
										</xsl:when>
										<xsl:when test="not(level != '') and ($xinetd-state = 0)">
											<!-- xinetd subservices stop and disable -->
											<ui:button tip="enable_srv_xinetd" name="enable_service" width="150">
												<sw:text>Enable Service</sw:text>
											</ui:button>
										</xsl:when>
										<xsl:when test="not(level != '') and ($xinetd-state = 1)">
											<!-- xinetd subservices disabled -->
											<ui:button tip="enable_srv_xinetd" name="enable_service" width="150">
												<sw:text>Enable Service</sw:text>
											</ui:button>
										</xsl:when>
										<xsl:otherwise>
											<!-- unknown state - no control available -->
										</xsl:otherwise>
									</xsl:choose>
								</xsl:when>
							</xsl:choose>

							<xsl:if test="not(xinetd) and not($no-autostart)">
								<xsl:choose>
									<xsl:when test="/packet/cookie/servicem/service/level = 3">
										<ui:button tip="disable_autostart" name="noautostart_service" width="150">
											<sw:text>Disable Autostart</sw:text>
										</ui:button>
									</xsl:when>
									<xsl:otherwise>
										<ui:button tip="enable_autostart" name="autostart_service" width="150">
											<sw:text>Enable Autostart</sw:text>
										</ui:button>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:if>

						</ui:buttons>

					</xsl:for-each>
				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/common.xsl"/>


	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
