<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="exsl sw error wiz hwm form func local cred env ve vzenv format"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl	="http://exslt.org/common"
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:error	="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz		="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:hwm		="http://www.swsoft.com/xsl/cp/hwm"
	xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
	xmlns:form	="http://www.swsoft.com/xsl/cp/form"
	xmlns:func	="http://exslt.org/functions"
	xmlns:local	="http://www.swsoft.com/xsl/cp/local"
	xmlns:cred	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:env		="http://www.swsoft.com/xsl/cp/env"
	xmlns:ve		="http://www.swsoft.com/xsl/cp/ve"
	xmlns:vzenv	="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:format="http://www.swsoft.com/xsl/cp/format"
>

	<sw:include href="/lib/utils/format-resusage.xsl"/>

	<xsl:variable name="ve-eid" select="sw:ve-eid()"/>
	<!-- check permissions to show this page -->
	<xsl:param name="wiz_code" select="'ve_shaping'"/>
	<xsl:variable name="step_data" select="wiz:getStep()"/>
	<xsl:variable name="step" select="$step_data/@id"/>
	<xsl:variable name="path-id" select="string(wiz:getSteps()/step[1]/@screen-id)"/>
	<xsl:param name="access-denied" select="not(cred:check-env('vzcp.env.view',$ve-eid))"/>
	<xsl:variable name="form" select="sw:sesget($wiz_data)"/>
	<xsl:variable name="env" 		select="env:get-env($ve-eid)/env"/>
 	<xsl:variable name="env-platform"	select="ve:ve2platform($env)"/>

	<!-- Wizard, Step Config -->
	<xsl:template name="step_edit">
		<ui:screen path-id="{$path-id}" id="{$step_data/@screen-id}" icon="{$step_data/@screen-icon}">
			<ui:properties>
				<ui:description mandatory="yes" width="max">
					<sw:text>
						The traffic shaping (or network bandwidth management) allows you to control the network bandwidth for the outgoing traffic.
					</sw:text>
				</ui:description>
				<ui:form-get/>
				<ui:no-refresh/>
			</ui:properties>

			<ui:content>
				<ui:hidden name="step" value="edit"/>
				<xsl:if test="not($form/hn/shaping)">
					<ui:block width="max">
						<ui:alert>
							<sw:text>
								The traffic shaping is disabled on this Hardware Node. <br/> Your changes will take effect after the traffic shaping is enabled.<br/>
							</sw:text>
						</ui:alert>
							<xsl:if test="cred:check-hw('vzcp.hn.manage.config.network',sw:hn-eid())">
								 <ui:i18n-link href="{$baseurl}/vzdir/infrman/hns/config/traffic" tip="hw_config_network">
									<_>Click %{aopen}here%{aclose} to manage network traffic on the Hardware Node.</_>
								</ui:i18n-link>
							</xsl:if>
					</ui:block>
				</xsl:if>
				<xsl:if test="count($form/hn/range) = 0">
					<ui:block width="max">
						<ui:alert>
							<sw:text>
								No network class is defined to configure rates for.
							</sw:text>
						</ui:alert>
							<xsl:if test="cred:check-hw('vzcp.hn.manage.config.network',sw:hn-eid())">
								<ui:i18n-link href="{$baseurl}/vzdir/infrman/hns/config/accounting" tip="configure_accounting">
									<_>Click %{aopen}here%{aclose} to manage network traffic accounting on the Hardware Node.</_>
								</ui:i18n-link>
							</xsl:if>
					</ui:block>
				</xsl:if>
				<ui:block>
					<xsl:copy-of select="vzenv:show-rate-selector($form)"/>
				</ui:block>
				<ui:block width="max">
					<ui:buttons>
						<xsl:call-template name="wiz:showButtons">
							<xsl:with-param name="disable-submit" select="sw:if(count($form/hn/range) = 0,true(),false())"/>
						</xsl:call-template>
					</ui:buttons>
				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<!-- Wizard, Step View -->
	<xsl:template name="step_view">
		<ui:screen path-id="{$path-id}" id="{$step_data/@screen-id}" icon="{$step_data/@screen-icon}">
			<ui:properties>
				<ui:description mandatory="yes" width="max">
					<sw:text>
						The traffic shaping (or network bandwidth management) allows you to control the network bandwidth for the outgoing traffic.
					</sw:text>
				</ui:description>
				<ui:form-get/>
			</ui:properties>
			<ui:tab-bar id="vzve" current-tab="network" current-subtab="shaping"/>
			<ui:content>
				<ui:block width="max">
					<ui:rows>
						<xsl:attribute name="title">
							<sw:text>
								<xsl:with-param name="state" select="sw:if($form/hn/shaping, sw:text('enabled'), sw:text('disabled'))"/>
								The traffic shaping is  %{state} on this Hardware Node.
							</sw:text>
						</xsl:attribute>
						<ui:row type="head">
							<ui:cell width="20%" align="left">
								<sw:text>Class ID</sw:text>
							</ui:cell>
							<xsl:if test="$form/ve/linux">
								<ui:cell width="20%" align="right">
									<nowrap>
										<sw:text>Total Rate</sw:text>
									</nowrap>
								</ui:cell>
							</xsl:if>
							<ui:cell width="20%" align="right">
								<nowrap>
									<xsl:choose>
										<xsl:when test="$form/rate-type = 'custom'">
											<sw:text>Rate Guarantee</sw:text>
										</xsl:when>
										<xsl:otherwise>
											<sw:text>Default Rate Guarantee</sw:text>
										</xsl:otherwise>
									</xsl:choose>
								</nowrap>
							</ui:cell>
						</ui:row>

						<xsl:for-each select="$form/hn/range">
							<xsl:sort select="class_id" data-type="number"/>
							<xsl:variable name="class-id" select="class_id"/>
							<xsl:variable name="class" select="$form/hn/class[id = $class-id]"/>
							<xsl:variable name="ve-rate" select="$form/ve/interface_rate[class_id = $class-id]/rate"/>							
							<xsl:if test="$class/totalrate or not($form/ve/linux)">
								<ui:row>
									<ui:cell	align="left">
										<nowrap>
											<sw:text>
												<xsl:with-param name="id" select="$class-id"/>
												Class %{id}
											</sw:text>
										</nowrap>
									</ui:cell>									
									<xsl:if test="$form/ve/linux">
										<ui:cell align="right">
											<xsl:choose>
												<xsl:when test="$class-id = 0">
													<sw:text>Not Available</sw:text>
												</xsl:when>									
												<xsl:when test="not($class/totalrate)">
													<sw:text>Not Configured</sw:text>
												</xsl:when>
												<xsl:when test="not($ve-rate != '') and not(($form/rate-type = 'default') and $form/ve/linux)">
													<!-- not applayable -->
													&#160;													
												</xsl:when>
												<xsl:otherwise>
													<xsl:value-of select="format:kbps2bps($class/totalrate,'','yes','#,##0.00')/value"/>
												</xsl:otherwise>
											</xsl:choose>
										</ui:cell>
									</xsl:if>
									<ui:cell align="right">
										<xsl:choose>
											<xsl:when test="($class-id = 0) or (not($class/totalrate) and $form/ve/linux)">
												<sw:text>Not Available</sw:text>
											</xsl:when>
											<xsl:when test="not($ve-rate != '') and ($form/rate-type = 'default') and $form/ve/linux">
												<!-- get hnode rate only if no one rate in ve configured -->
												<xsl:value-of select="format:kbps2bps($form/hn/class[id = $class-id]/rate,'','yes','#,##0.00')/value"/>
											</xsl:when>
											<xsl:when test="not($ve-rate != '')">
												<sw:text>Not Limited</sw:text>
											</xsl:when>
											<xsl:otherwise>
												<xsl:value-of select="format:kbps2bps($ve-rate,'','yes','#,##0.00')/value"/>
											</xsl:otherwise>
										</xsl:choose>
									</ui:cell>
								</ui:row>
							</xsl:if>
						</xsl:for-each>
					</ui:rows>
					
					<xsl:if test="$form/ve/linux">
						<ui:rows>
							<ui:row>
								<ui:cell>
									<xsl:choose>
										<xsl:when test="$form/ve/rate_bound = 1">
											<sw:text>Do not allow to exceed the rate guarantees</sw:text>
										</xsl:when>
										<xsl:otherwise>
											<sw:text>Allow to exceed the rate guarantees</sw:text>
										</xsl:otherwise>
									</xsl:choose>
								</ui:cell>
							</ui:row>
						</ui:rows>
					</xsl:if>
	
					<ui:buttons>
						<xsl:if test="cred:check-env('vzcp.env.manage.properties.preferences',$ve-eid)">
							<ui:button tip="vzenv_network_shaping" sandclock="false" icon="traffic_shape" type="ok"
								submit-href="{$baseurl}/vzdir/infrman/envs/shaping?mode=edit"
								>
								<sw:text>Configure</sw:text>
							</ui:button>
						</xsl:if>
					</ui:buttons>
					
				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
		<xsl:choose>
			<xsl:when test="$step = 'edit'">
				<xsl:call-template name="step_edit"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="step_view"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/traffic.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vz/vzenv-rate.xsl"/>	

</xsl:stylesheet>
