<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred vzapackagem dynamic local func voc"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:exsl="http://exslt.org/common"
	xmlns:func="http://exslt.org/functions" 
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui" 
	xmlns:dynamic="http://www.swsoft.com/xsl/cp/dynamic"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:voc="http://www.swsoft.com/xsl/cp/voc" 
	xmlns:local="http://www.swsoft.com/xsl/cp/local" 
	xmlns:error="http://www.swsoft.com/xsl/cp/error" 
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:vzenv="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:vzapackagem="http://www.swsoft.com/xsl/cp/vzapackagem"
	>

	<sw:include href="/lib/swa/system.xsl" />
	<sw:include href="/lib/common.xsl" />
	<sw:include href="/lib/vt/env-core.xsl" />
	<sw:include href="/lib/vza/vzapackagem.xsl" />
	<sw:include href="/lib/dynamic.xsl" />
	<sw:include href="/lib/screen.xsl" />

	<!-- check permissions to show this page -->

	<xsl:template mode="screen" match="/">
		<xsl:call-template name="dynamic:create-ajax-handler">
			<xsl:with-param name="request-handler" select="'local:load-packages'" />
		</xsl:call-template>
	</xsl:template>

	<func:function name="local:load-packages">
		<xsl:variable name="eid" select="sw:ve-eid()"/>
		<func:result>
			<xsl:choose>
				<xsl:when test="not(cred:check-env('vzcp.env.manage.properties.application', $eid))">
					<result>
						<sw:text>You are not allowed to view the updates for the installed software.</sw:text>
					</result>
					<status>error</status>
				</xsl:when>
				<xsl:when test="env:get-env($eid)/env/status/transition=$env-trans/updating">
					<result>
						<sw:text>Getting a list of updates for the installed software...</sw:text>
					</result>
					<status>retry</status>
				</xsl:when>
				<xsl:when test="sw:sesget('vzapackagem-list-ve-updates')/empty or not(string(sw:sesget('vzapackagem-list-ve-updates'))='')">
				 	<result>
				 		<sw:text>Getting a list of updates for the installed software...</sw:text>
				 	</result>
				 	<status>ok</status>
				</xsl:when>
				<xsl:otherwise>
					<xsl:variable name="updates" select="vzapackagem:list-ve-updates($eid)"/>

					<xsl:choose>
						<xsl:when
							test="not(local:process-error(
												sw:text('Failed to retrieve a list of updates for the installed software.'), 
												$updates))">
							<xsl:variable name="empty">
								<empty/>
							</xsl:variable>
							<xsl:if test="sw:sesput('vzapackagem-list-ve-updates', 
											sw:if(string($updates)='', exsl:node-set($empty)/empty, $updates))"/>

							<result>
								<sw:text>Getting a list of updates for the installed software...</sw:text>
							</result>
							<status>retry</status>
						</xsl:when>
						<xsl:otherwise>
							<xsl:if test="sw:sesput('vzapackagem-list-ve-updates', /..)"/>

							<result>
								<sw:text>Error getting a list of updates for the installed software.</sw:text>
							</result>
							<status>error</status>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
		</func:result>
	</func:function>
	
	<func:function name="local:process-error">
		<xsl:param name="msg" />
		<xsl:param name="responce" />
		<xsl:variable name="error" select="$responce/packet/data/error|$responce/packet/data/vzapackagem/error" />
		<xsl:choose>
			<xsl:when test="$error">
				<xsl:if test="error:put($msg, $error/message, '')" />
				<func:result select="true()" />
			</xsl:when>
			<xsl:otherwise>
				<func:result select="false()" />
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
</xsl:stylesheet>
