<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet
	version="1.0"
	extension-element-prefixes="sw exsl cred vzenv"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:vzenv="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:voc="http://www.swsoft.com/xsl/cp/voc"
	xmlns:vzapackagem="http://www.swsoft.com/xsl/cp/vzapackagem"
	xmlns:dynamic="http://www.swsoft.com/xsl/cp/dynamic"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui">
	<xsl:output method="xml"/>
	
	<sw:include href="/lib/screen.xsl" />
	<sw:include href="/lib/vza/vzapackagem.xsl"/>
	<sw:include href="/lib/dynamic.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>
	
	<!-- check permissions to show this page -->
	<xsl:param name="access-denied" select="not(cred:check-env('vzcp.env.manage.properties.application', sw:ve-eid()))" />

	<xsl:template mode="screen" match="/">
		<ui:screen id="03.02.01.05.02">

			<xsl:variable name="form" select="/packet"/>
			<xsl:variable name="eid" select="sw:ve-eid()"/>
			
			<ui:properties>
				<ui:refresh-type>none</ui:refresh-type>
				<ui:form-get/>
			</ui:properties>

			<ui:content>
				<ui:hidden name="step" value="autoupgrade"/>

				<xsl:variable name="oper-problem" select="voc:check-operation('vzapackagem', 'install')"/>
				
				<xsl:choose>
					<xsl:when test="(env:get-env($eid)/env/status/transition=$env-trans/updating or $oper-problem='') and not($form/cookie/list)">
						<ui:block>
							<ui:hidden name="list" value="1"/>
							<ui:rows title="{sw:text('Software Status')}">
								<ui:row>
									<ui:cell-value>
										<ui:raw>
											<div>
												<img id="refresh_img" width="16" border="0" height="16"
													src="/{$theme}/icons/indicator.gif" />&#160;<span id="list_result">
													<sw:text>Getting a list of updates for the installed software...</sw:text>
												</span>
											</div>
											
											<xsl:variable name="send-ui-name" select="'get_updates'" />
											<xsl:variable name="recv-ui-name" select="'list_updates'" />
											<xsl:variable name="div-name" select="'list_result'" />
											
											<xsl:call-template name="dynamic:error-reporter-script" />
								
											<script>
												var timerID;
												function recv(content) {
													clearTimeout(timerID);
													<!-- replace progress with initial message -->
													var div_obj = document.getElementById('list_result');
													if (content.length &gt; 1) {
														if (content[0] != 'retry') {
															document.getElementById('list_result').innerHTML = content[1];
															doSubmit();
														} else if(content[0] =='retry') {
															document.getElementById('list_result').innerHTML = content[1];
															timerID = setTimeout("<xsl:value-of select="$send-ui-name"/>()", 5000);
														} 
													} 
												}
											</script>
											
											<xsl:call-template name="dynamic:ajax-sender-func">
												<xsl:with-param name="sender-func" select="$send-ui-name"/>
												<xsl:with-param name="reciever-func" select="$recv-ui-name" />
												<xsl:with-param name="request-url" select="'/vz/cp/vzdir/infrman/envs/upgrade-dynamic'"/>
											</xsl:call-template>
									
											<xsl:call-template name="dynamic:ajax-reciever-func">
												<xsl:with-param name="reciever-func" select="$recv-ui-name"/>
												<xsl:with-param name="ui-func" select="'recv'" />
											</xsl:call-template>
											
											<script>
												<xsl:value-of select="$send-ui-name"/>();
											</script>
										</ui:raw>
									</ui:cell-value>
								</ui:row>
							</ui:rows>					
						</ui:block>
					</xsl:when>
					<xsl:when test="$oper-problem">
						<ui:block>
							<ui:operation-problem>
								<xsl:copy-of select="$oper-problem"/>
								<xsl:choose>
									<xsl:when test="env:get-env($eid)/env/status/transition=$env-trans/updating">
										<ui:descr>
											<sw:text>The software of this Container is already being updated.</sw:text>
										</ui:descr>
									</xsl:when>
									<xsl:otherwise>
										<ui:descr>
											<sw:text>Unable to update the software of this Container.</sw:text>
										</ui:descr>
									</xsl:otherwise>
								</xsl:choose>
							</ui:operation-problem>
						</ui:block>
					</xsl:when>
					<xsl:when test="not($form/has-updates) or $form/has-updates=''">
						<ui:block>
							<ui:rows title="{sw:text('Software Status')}">
								<ui:row>
									<ui:cell-label>
										<sw:text>The Container software is already up-to-date.</sw:text>
									</ui:cell-label>
								</ui:row>
							</ui:rows>
						</ui:block>
					</xsl:when>
					<xsl:otherwise>
						<ui:block mode="view">
							<ui:rows title="{sw:text('Warning')}">
								<ui:row>
									<ui:cell-text colspan="2">
										<br/>
										<img src="/{$theme}/icons/alert_yellow.gif" width="16" height="16" border="0"/>
										&#160;
										<sw:text>
											This action will update the software in the Container to the latest versions. 
											<br/> 
											<br/> 
											It can affect the functionality of the installed sofware. Please do not run 
											update if you are not sure it is really necessary.
										</sw:text>
										<br/>
										<br/>
									</ui:cell-text>
								</ui:row>
							</ui:rows>
							
							<ui:rows title="{sw:text('Software Status')}">
								<ui:row>
									<ui:cell-label><sw:text>Updates available</sw:text></ui:cell-label>
									<ui:cell>
										<xsl:for-each select="$form/has-updates/*">
											<xsl:sort select="name"/>
											<xsl:if test="position() &gt; 1">, </xsl:if>
											<xsl:value-of select="vzapackagem:app-title(.)"/>
										</xsl:for-each>
									</ui:cell>
								</ui:row>
							</ui:rows>
							
							<xsl:if test="not(sw:is-ez-package(vzapackagem:eid2os-template($eid)/name))">
								<ui:rows title="{sw:text('Configure Updating')}" id="options"
									status="{$form/autoupgrade/options}" closed-text="{sw:text('Click to configure the updating procedure.')}">
									<ui:row>
										<ui:cell-check id="force" checked="{$form/autoupgrade/force}" close="false"
											colspan="2"/>
										<ui:cell open="false">
											<sw:text>Force software update (NOT RECOMMENDED)</sw:text>
										</ui:cell>
									</ui:row>
								</ui:rows>
							</xsl:if>

							<ui:rows title="{sw:text('Confirmation')}">
								<ui:row>
									<ui:cell-check id="confirm" checked="{$form/autoupgrade/confirm}" close="false"
										colspan="2"/>
									<ui:cell open="false">
										<sw:text>Yes, I want to update the Container</sw:text>
									</ui:cell>
								</ui:row>
							</ui:rows>

							<ui:buttons>
								<ui:button tip="update_start" name="next" id="next" type="ok" sandclock="false">
									<sw:text>Update</sw:text>
								</ui:button>
								<ui:button type="cancel" tip="update_cancel" name="cancel" id="cancel"
									sandclock="false">
									<sw:text>Cancel</sw:text>
								</ui:button>
							</ui:buttons>
						</ui:block>
					</xsl:otherwise>
				</xsl:choose>
			</ui:content>
		</ui:screen>
	</xsl:template>

</xsl:stylesheet>
