<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz vzenv local cred voc vz"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:local="http://www.swsoft.com/xsl/cp/local"
  xmlns:error="http://www.swsoft.com/xsl/cp/error"
  xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
  xmlns:vzenv="http://www.swsoft.com/xsl/cp/vzenv"
  xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
  xmlns:func="http://exslt.org/functions"
	xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
	xmlns:voc		="http://www.swsoft.com/xsl/cp/voc"
	xmlns:env		="http://www.swsoft.com/xsl/cp/env"	
	xmlns:vz		="http://www.swsoft.com/xsl/cp/vz"
 >

  <xsl:param 		name="wiz_code"				select="'ve-create-volume'"/>
	<xsl:variable name="step_data"		select="wiz:getStep()"/>
	<xsl:variable name="step"					select="$step_data/@id"/>
	<xsl:variable name="screenid"			select="$step_data/@screenid"/>
	<xsl:variable name="screen-title"	select="sw:text('Create Volume')"/>
	<xsl:variable name="screen-icon"	select="'mount_device'"/>
	<xsl:variable name="path-id"			select="string(wiz:getSteps()/step[1]/@screenid)"/>
	
  <xsl:variable name="form" select="sw:sesget($wiz_data)"/>
  <!-- check permissions to show this page -->
	<xsl:param name="access-denied" select="not(cred:check-env('vzcp.env.manage.properties.hardware',$form/eid))"/>

  <!-- Reinstall Wizard, Step 'General Settings' -->
  <xsl:template name="step_gen">
  	<xsl:variable name="env-info" select="env:eid2info($form/eid)"/>
  	
  	<ui:screen path-id="{$path-id}" id="{$screenid}" title="{$screen-title}" icon="{$screen-icon}">
  	
	<ui:properties>
		<ui:refresh-type>none</ui:refresh-type>      
		<ui:description mandatory="yes">
			<sw:text>
				On this screen you can add a new disk volume to the Container by creating an image file of a specific size and mounting it to an unoccupied drive letter inside the Container.
			</sw:text>
		</ui:description>	  
		<ui:form-get/>
    </ui:properties>
    
	<ui:content>
	      <ui:hidden name="step" value="gen"/>    
	      <ui:block mode="edit">

	   			<ui:rows>	   		
						<ui:row>
	   					<ui:cell-label>
		        		<sw:text>Mount Point</sw:text>
		        	</ui:cell-label>
		        	
		        	<xsl:choose>
			        	<xsl:when test="$env-info/windows">
				        	<ui:cell-list id="point" required="true" width="10">
										<xsl:attribute name="value"><xsl:value-of select="$form/gen/point"/></xsl:attribute>
										<xsl:copy-of select="vz:ve-drive-selector($form/eid)"/>
									</ui:cell-list>
								</xsl:when>
								<xsl:otherwise>
									<ui:cell-input id="point" tip="ve_create_volume_point" maxlength="256" 
										required="true" value="{$form/gen/point}"
									/>
								</xsl:otherwise>
							</xsl:choose>
		        	
						</ui:row>					
						<ui:row>
	   					<ui:cell-label>
		        		<sw:text>Volume Size</sw:text>
		        	</ui:cell-label>
							<ui:cell-input id="size" width="15" maxlength="256" required="true" value="{$form/gen/size}" close="false">
								&#160;
							</ui:cell-input>
							<ui:cell-list id="size_unit" tip="ve_create_volume_size" width="10" value="{$form/gen/size-unit}" open="false">
								<ui:list-item id="1024" title="{sw:text('KB')}"/>
								<ui:list-item id="1048576" title="{sw:text('MB')}"/>
								<ui:list-item id="1073741824" title="{sw:text('GB')}"/>
							</ui:cell-list>
						</ui:row>				
					</ui:rows>
	
	        <ui:buttons>
	          <xsl:call-template name="wiz:showButtons">
	          	<xsl:with-param name="submit-title" select="sw:text('Create')"/>
	          	<xsl:with-param name="submit-tip" select="'submit_create_volume'"/>
	          	<xsl:with-param name="submit-sandclock" select="false()"/>
	          </xsl:call-template>
	        </ui:buttons>
	        
	     	</ui:block>
	    </ui:content>   
    </ui:screen>
  </xsl:template>
  

	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
	
			<xsl:choose>
			
				<xsl:when test="$step = 'gen'">
					<xsl:call-template name="step_gen"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="step_gen"/>
				</xsl:otherwise>
				
			</xsl:choose>
		
	</xsl:template>
	
	<!-- UI modules -->	
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>
	
	<!-- System modules -->
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>		
	
	<!-- VZ functionality modules -->	
	<sw:include href="/lib/vz/devices.xsl"/>		
	<sw:include href="/lib/vt/env-core.xsl"/>		
	
	<!-- VZA functionality modules -->	
	<sw:include href="/lib/vza/dev.xsl"/>	
	
	<!-- none -->
	
</xsl:stylesheet>
