<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred dev voc error"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:voc="http://www.swsoft.com/xsl/cp/voc"
	xmlns:dev="http://www.swsoft.com/xsl/cp/dev"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:vt		="http://www.swsoft.com/xsl/cp/vt"		
>

	<!-- UI modules -->
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/core/browse-filter-raw.xsl" />

	<!-- System modules -->
	<sw:include href="/lib/common.xsl"/>

	<!-- VT functionality modules -->
	<sw:include href="/lib/vt/env-core.xsl"/>

	<!-- VZA functionality modules -->
	<sw:include href="/lib/vza/dev.xsl"/>


	<xsl:template mode="screen" match="/">

		<!-- Init default data -->
		<xsl:variable name="eid" select="sw:ve-eid()"/>
		<xsl:variable name="env-info" select="env:eid2info($eid)"/>
		<xsl:variable name="voc-args">
			<category>vz_dev</category>
		</xsl:variable>
		<xsl:variable name="voc" select="voc:get($voc-args, env:make-platform-ref($env-info/hn-eid,$env-info/platform) )"/>
		<xsl:variable name="system-drive" select="$voc[id='fixed_drive']/value[1]"/>
		<xsl:variable name="cred" select="cred:check-env('vzcp.env.manage.properties.hardware',$eid)"/>

		<ui:screen id="03.02.01.08.00">
		
		

			<xsl:variable name="filter_init_">
				<xsl:call-template name="browse:init-filter">
					<xsl:with-param name="browse">
						<ui:browse-setup id="ve-volumes" item-url="/vzdir/infrman/envs/volumes/edit" url="/vzdir/infrman/envs/volumes/index"/>
						<ui:cols sorting-col="volume-point">
							<ui:column id="volume-point" title="{sw:text('Mount Point')}"
								show-url="{sw:if($cred,'yes','no')}" for-url="yes" filter="auto" for-select="yes"
								for-select-condition="raw-size!='' and volume-point!='{$system-drive}'"/>
							<ui:column id="volume-dev" title="{sw:text('Device')}" filter="auto"/>
							<xsl:if test="vt:is-platform-windows($env-info/platform)">
								<ui:column id="volume-size" title="{sw:text('Size')}" data-type="int"
									display-type="size/byte" display-unit="mbyte" show-unit="true"/>
							</xsl:if>
						</ui:cols>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:variable>

			<xsl:variable name="browse-result" select="dev:get-mounts($eid)"/>
			<xsl:if test="$browse-result[error|dev/error]">
				<xsl:if
					test="error:put(sw:text('Error listing the volumes.'),$browse-result/error/message|$browse-result/dev/error/message)"
				/>
			</xsl:if>

			<xsl:variable name="filter">
				<xsl:call-template name="browse:fill-filter">
					<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
					<xsl:with-param name="rows">
						<ui:browse-rows>
							<xsl:for-each select="$browse-result/vzadevm/mount">
								<ui:row>
									<xsl:if test="string(size)='' or number(size) &lt; 0">
										<xsl:attribute name="disable-item-url">true</xsl:attribute>
									</xsl:if>
									<volume-dev>
										<xsl:value-of select="device"/>
									</volume-dev>
									<volume-point>
										<xsl:value-of select="point"/>
									</volume-point>
									<raw-size>
										<xsl:value-of select="size"/>
									</raw-size>
									<volume-size>
										<xsl:value-of select="sw:if(string(size)='' or number(size) &lt; 0, sw:text('n/a'), size)"/>
									</volume-size>
								</ui:row>
							</xsl:for-each>
						</ui:browse-rows>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:variable>


			<ui:properties>
				<ui:no-default-form/>
				<ui:description mandatory="yes">
					<sw:text>
						On this screen you can configure the virtual disk volumes of the Container. The C: volume is always present in the Container as the mount point for the root.efd image file. You can add new volumes to the Container by creating additional image files, mounting existing image files, or mounting existing devices of the Hardware Node.
					</sw:text>
				</ui:description>				
				<ui:form-get/>
			</ui:properties>

			<ui:content>

				<ui:block width="full">

					<ui:browse title="{sw:text('Volumes')}">

						<ui:browse-js-many>
							<ui:warn>
								<sw:text>Select at least one volume!</sw:text>
							</ui:warn>
						</ui:browse-js-many>

						<ui:browse-js-one>
							<ui:warn>
								<sw:text>Select only one volume!</sw:text>
							</ui:warn>
						</ui:browse-js-one>

						<ui:filter>
							<xsl:copy-of select="$filter"/>
						</ui:filter>

						<xsl:if test="$cred">
							<ui:browse-buttons type="list-selection">
								<ui:button type="list-selection" require-items="false" tip="create_volume" icon="create_volume"	
									new-obj-title="{sw:text('Volume')}"
									name="create" submit-href="create"
								>
									<sw:text>New Volume</sw:text>
								</ui:button>
								<ui:button type="list-selection" require-items="false" tip="mount_image" icon="mount_image"
									name="mount_image" submit-href="mount-image"
								>
									<sw:text>Mount Disk Image</sw:text>
								</ui:button>
								<ui:button type="list-selection" require-items="false" tip="mount_device" icon="mount_device"
									name="mount_device" submit-href="mount-device"
								>
									<sw:text>Mount Device</sw:text>
								</ui:button>
								<ui:button type="list-selection" tip="unmount_volumes" icon="unmount_volumes"
									confirmation="{sw:text('Are you sure you want to unmount the selected volume(s) and retain the volume image(s)?')}"
									script="if (!atLeastOne()) return false;" name="unmount">
									<sw:text>Unmount</sw:text>
								</ui:button>
								<ui:button type="list-selection" tip="delete_volumes" icon="delete"
									confirmation="{sw:text('Are you sure you want to delete the selected volume(s) and volume image(s)?')}"
									script="if (!atLeastOne()) return false;" name="delete">
									<sw:text>Delete</sw:text>
								</ui:button>
							</ui:browse-buttons>
						</xsl:if>

						<!-- form definition for other controls -->
						<ui:form action="list-control"/>

						<ui:browse-empty-msg>
							<sw:text>No volumes could be found.</sw:text>
						</ui:browse-empty-msg>

					</ui:browse>
				</ui:block>
			</ui:content>

		</ui:screen>
	</xsl:template>

	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
