<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred vz env-samplem trace"
  xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl		="http://exslt.org/common"
  xmlns:sw			="http://www.swsoft.com/xsl/cp"
  xmlns:vz			="http://www.swsoft.com/xsl/cp/vz"  
  xmlns:ui			="http://www.swsoft.com/xsl/cp/ui"   
  xmlns:browse		="http://www.swsoft.com/xsl/cp/browse"   
  xmlns:cred		="http://www.swsoft.com/xsl/cp/cred"
  xmlns:sample		="http://www.swsoft.com/xsl/cp/sample"	
  xmlns:env-samplem	="http://www.swsoft.com/xsl/cp/env-samplem"
  xmlns:trace		="http://www.swsoft.com/xsl/cp/trace"
  xmlns:vt			="http://www.swsoft.com/xsl/cp/vt"	
  >

	<sw:include href="/lib/trace.xsl"/>	
	<sw:include href="/lib/vt/core.xsl"/>		
	<sw:include href="/lib/vt/env-core.xsl"/>			
	<sw:include href="/lib/vz/core.xsl"/>		
	<sw:include href="/lib/swa/env-samplem.xsl"/>	
	
	<!-- check permissions to show this page -->
	<xsl:variable name="cr-list"				select="cred:check('vzcp.envsamples')"/>
	<xsl:variable name="cr-create"			select="$cr-list"/>
	<xsl:variable name="cr-upload"			select="$cr-create"/>
	<xsl:variable name="cr-split"				select="$cr-create"/>
	<xsl:variable name="cr-clone"				select="$cr-create"/>
	<xsl:variable name="cr-delete"			select="$cr-create"/>
	<xsl:variable name="cr-manage"			select="$cr-create"/>
	<xsl:variable name="cr-setdef"			select="$cr-manage"/>
	<xsl:variable name="cr-download"		select="$cr-manage"/>
	<xsl:variable name="def-samples"		select="vz:default-samples()"/>

	<xsl:param name="access-denied" select="not($cr-list)"/>

	<xsl:template mode="screen" match="/">
		<xsl:variable name="filter_init_">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="envsamples" url="/vzdir/infrman/envsamples/index" 
						item-url="/vzdir/infrman/envsamples/sample"
					/>
					<ui:cols sorting-col="sample-name">
						<ui:column id="id" for-url="yes" hidden="yes">
							<xsl:if test="$cr-clone or $cr-delete">
								<xsl:attribute name="for-select">yes</xsl:attribute>
							</xsl:if>
						</ui:column>
						<ui:column id="sample-name" show-url="{sw:if($cr-manage,'yes','no')}"
							title="{sw:text('Name')}" filter="auto" 
							post-apply-templates='yes'
						/>
						<ui:column id="platform-os" title="{sw:text('Platform')}" filter="select" apply-templates="yes" align="center">
							<xsl:copy-of select="vt:vza-platform-oses()"/>
						</ui:column>
						<ui:column id="arch" title="{sw:text('Architecture')}"/>			
						<ui:column id="comment" title="{sw:text('Description')}" filter="auto"/> 						
						<ui:column id="os_template" title="{sw:text('OS Template')}"/>
							<xsl:if test="$cr-download">
								<ui:column id="envsample-download" title="{sw:text('Save')}" post-apply-templates='yes'/>
							</xsl:if>  
					</ui:cols>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

    <xsl:variable name="browse_result" select="env-samplem:list-samples('virtuozzo')"/>    
    <xsl:variable name="filter">
    	<xsl:call-template name="browse:fill-filter">
				<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
				<xsl:with-param name="rows">					
	        <ui:browse-rows>
	        	<xsl:for-each select="$browse_result">	        		
	            <ui:row>	            	
	            	<id>								
									<xsl:value-of select="id"/>
								</id>
								<sample-name>
									<xsl:if test="id = $def-samples/objectId">
										<xsl:attribute name="default">1</xsl:attribute>
									</xsl:if>
									<xsl:value-of select="name"/>
								</sample-name>
								<xsl:if test="$cr-download">
									<envsample-download>
										<xsl:value-of select="id"/>
									</envsample-download>
								</xsl:if>
								<pos>
									<xsl:value-of select="position()"/>
								</pos>
								<platform-os>
									<xsl:value-of select="sw:title(vt_version/platform)"/>
								</platform-os>
								<arch>
									<xsl:value-of select="vt_version/architecture"/>
								</arch>								
	              <comment><xsl:value-of select="sw:base64-decode(comment)"/></comment>
	              <os_template>
	              	<xsl:copy-of select="sw:app-id2title(env_config/os_template/name,env_config/os_template/version,sw:text('Any'))"/>
	              </os_template>
	            </ui:row>
	          </xsl:for-each> 
        	</ui:browse-rows>
        </xsl:with-param>    
			</xsl:call-template>
    </xsl:variable>

		<ui:screen id="03.02.01.23.00">

			<ui:properties>
				<ui:form-get/>
				<ui:no-default-form/>	   
				<ui:description width="full">
					<sw:text>
						On this screen you can see a list of Container samples available in Parallels Infrastructure Manager.
						<br/>A Container sample is a configuration file that holds the default settings for the creation of a new Container.
					</sw:text>
				</ui:description>    
			</ui:properties>
			<ui:content>    
				<ui:block width="full">
				
					<ui:browse>
						<xsl:attribute name="title"><sw:text>Samples</sw:text></xsl:attribute>
						
						<ui:browse-js-many>
							<ui:warn><sw:text>Select at least one sample!</sw:text></ui:warn>
						</ui:browse-js-many>			
						<ui:browse-js-one>
							<ui:warn><sw:text>Please select one sample to be used by default.</sw:text></ui:warn>
						</ui:browse-js-one>		
						
						<ui:filter>
							<xsl:copy-of select="$filter"/>
						</ui:filter>       
						       
			      <ui:browse-buttons type="list-selection">
			      
							<ui:button type="list-selection" tip="sample" icon="env_sample_new" require-items="false"
								new-obj-title="{sw:text('Sample')}" cred="vzcp.envsamples"
								submit-href="{$baseurl}/vzdir/infrman/envsamples/manage"
							>
								<sw:text>New Sample</sw:text>
							</ui:button>
			      
							<xsl:if test="$cr-clone">
			        	<ui:button type="list-selection" tip="clone_envsample" icon="clone" 
			          	script="if (!atLeastOne()) return false;" name="clone" width="150">
			            <sw:text>Clone</sw:text>
				        </ui:button>
							</xsl:if>
							
							<xsl:if test="$cr-setdef">
			          <ui:button type="list-selection" tip="set_def_envsample" icon="task" 
			            script="if (!onlyOne()) return false;" name="setdef" width="150">
			            <sw:text>Set as default</sw:text>
			          </ui:button>
			         </xsl:if>
							
							<xsl:if test="$cr-delete">
			          <ui:button type="list-selection" tip="delete_envsample" icon="delete" 
				          confirmation="{sw:text('Are you sure you want to delete the selected Container sample(s)?')}" 
			  	        script="if (!atLeastOne()) return false;" name="delete" width="150">
			    	      <sw:text>Delete</sw:text>
			      	  </ui:button>                
							</xsl:if>
			      </ui:browse-buttons>        
			
			      <!-- form definition for other controls -->
			      <ui:form action="list-control"/>
			
			      <ui:browse-empty-msg>
			        <sw:text>No Container samples could be found.</sw:text>
			      </ui:browse-empty-msg>
	
	      	</ui:browse>
      	</ui:block>
    	</ui:content>          
		</ui:screen>
	</xsl:template>  

  <sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/core/browse-filter-raw.xsl"/>
  
</xsl:stylesheet>
