<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred vzenv"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl	="http://exslt.org/common"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
  xmlns:error	="http://www.swsoft.com/xsl/cp/error"
  xmlns:wiz		="http://www.swsoft.com/xsl/cp/wiz"
  xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
  xmlns:vzenv		="http://www.swsoft.com/xsl/cp/vzenv"
  xmlns:env		="http://www.swsoft.com/xsl/cp/env"
  xmlns:hn		="http://www.swsoft.com/xsl/cp/hn"
  xmlns:func	="http://exslt.org/functions"
	xmlns:cred	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:hwm		="http://www.swsoft.com/xsl/cp/hwm"
 >
 
 	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vt/hn-core.xsl"/>
 	<sw:include href="/lib/vz/vzenv-qos.xsl"/>
	
  <xsl:param name="wiz_code" select="'envsample_split'"/>
  
	<xsl:variable name="step_data"	select="wiz:getStep()"/>
	<xsl:variable name="step"				select="$step_data/@id"/>
	<xsl:variable name="screenid"		select="$step_data/@screenid"/>
	<xsl:variable name="screen-title"		select="$step_data/@screen-title"/>
	<xsl:variable name="path-id"		select="string(wiz:getSteps()/step[@id = 'gen']/@screenid)"/>

  <xsl:variable name="form" select="sw:sesget($wiz_data)"/>

	<xsl:param name="access-denied" select="not(cred:check('vzcp.envsamples'))"/>

  <xsl:variable name="screen-icon" select="'env_sample_split'"/>
    

  <!-- Wizard, Step 'General Settings' -->
  <xsl:template name="step_gen">
  
  	<!-- Preload some data -->
  	<xsl:variable name="hn-title">
  		<xsl:choose>
  			<xsl:when test="$form/hn/eid!=''">
  				<xsl:value-of select="env:env2title(env:get-env($form/hn/eid)/env)"/>
  			</xsl:when>
  		</xsl:choose>
  	</xsl:variable>  	
  	<!-- /Preload some data -->  
  
  	<ui:screen path-id="{$path-id}" id="{$screenid}" title="{$screen-title}" icon="{$screen-icon}">
  	
    <ui:properties>
     	<ui:form-get/> 
      <ui:refresh-type>none</ui:refresh-type>
      <ui:description  mandatory="yes">
        <sw:text>
			The wizard will create a new Container sample upon which you will be able to base the Containers of this Hardware Node.
        </sw:text>
      </ui:description>      
    </ui:properties>
    
    <ui:content>
      <ui:hidden name="step" value="gen"/>    
      <ui:block mode="edit">
      	
      	<ui:rows title="{sw:text('HN Selection')}">
      		<ui:row>
						<ui:cell-label>
							<sw:text>Hardware Node</sw:text>
						</ui:cell-label>
			    	<ui:cell-selector id="hn" align="left" value="{$hn-title}" required="true"
			    		code-value="{$form/hn/eid}"
			    		link-tip="select_hn" 
				      link-onclick="open_details('{$baseurl}/vt/hns/select-one-popup?id=hn&amp;platform=linux');return false;"
				      link-caption="{sw:text('Select...')}"				      
				    />
					</ui:row>
      	</ui:rows>
      	
   			<ui:rows title="{sw:text('Container Sample Configuration')}">
   				<ui:row>
						<ui:cell colspan="2">
							<sw:text>Please specify a name and description of the Container sample.</sw:text>
						</ui:cell>
					</ui:row>
					<ui:row>
   					<ui:cell-label>
	        		<sw:text>Name</sw:text>
	        	</ui:cell-label>
						<ui:cell-input id="name" maxlength="256" required="true">
							<xsl:attribute name="value"><xsl:value-of select="$form/gen/name"/></xsl:attribute>
						</ui:cell-input>
					</ui:row>
					<ui:row>
   					<ui:cell-label valign="top">
	        		<sw:text>Description</sw:text>
	        	</ui:cell-label>
						<ui:cell-inputblock id="descr" maxlength="65545" rows="5" cols="20">
							<xsl:value-of select="$form/gen/descr"/>
						</ui:cell-inputblock>
					</ui:row>
				</ui:rows>
				
				<ui:rows title="{sw:text('Number of Containers')}">
					<ui:row>
						<ui:cell colspan="2">
							<sw:text>The Container sample will be created by dividing the Hardware Node resources by the requested number of Containers.</sw:text>
						</ui:cell>
					</ui:row>
					<ui:row>
   					<ui:cell-label>
	        		<sw:text>Number</sw:text>
	        	</ui:cell-label>
						<ui:cell-input id="count" maxlength="256" required="true">
							<xsl:attribute name="value"><xsl:value-of select="$form/gen/count"/></xsl:attribute>
						</ui:cell-input>
					</ui:row>
				</ui:rows>
				
        <ui:buttons>
        	<xsl:call-template name="wiz:showButtons"/>
        </ui:buttons>
        
     	</ui:block>
    </ui:content>   
    </ui:screen>
  </xsl:template>
  
  <!-- Wizard, Step 'Final' -->
  <xsl:template name="step_final">
  	<ui:screen path-id="{$path-id}" id="{$screenid}" title="{$screen-title}" icon="{$screen-icon}">
  	
    <ui:properties>
    	<ui:form-get/>    
      <ui:refresh-type>none</ui:refresh-type>
      <ui:description  mandatory="yes">
        <sw:text>
          The Container sample will be created with the following settings: 
        </sw:text>
      </ui:description>      
    </ui:properties>
    
    <ui:content>
      <ui:hidden name="step" value="final"/>    
      <ui:block>
      	
    		<!-- Show QoS -->
    		<xsl:variable name="qos-rtf">
    			<xsl:for-each select="$form/env_config/qos">
    				<res>
    					<xsl:copy-of select="*"/>
    				</res>
    			</xsl:for-each>
    		</xsl:variable>
      	<xsl:call-template name="vzenv:review-qos">
					<xsl:with-param name="hn-eid" select="$form/hn/eid"/>
      		<xsl:with-param name="platform-ref" select="env:make-platform-ref($form/hn/eid,$form/hn/platform)"/>
					<xsl:with-param name="all-qos" select="exsl:node-set($qos-rtf)"/>
					<xsl:with-param name="only-changed" select="false()"/>
					<xsl:with-param name="slm-mode" select="$form/env_config/slm_mode"/>
					<xsl:with-param name="validate" select="false()"/>
					<xsl:with-param name="rows-title" select="sw:text('Resources')"/>
				</xsl:call-template>
      	
        <ui:buttons>
        	<xsl:call-template name="wiz:showButtons">
        		<xsl:with-param name="submit-title" select="sw:text('Submit')"/>
        	</xsl:call-template>
        </ui:buttons>
        
     	</ui:block>
    </ui:content>   
    </ui:screen>
  </xsl:template>  
  
	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
	
			<xsl:choose>
			
				<xsl:when test="$step = 'gen'">
					<xsl:call-template name="step_gen"/>
				</xsl:when>
				<xsl:when test="$step = 'final'">
					<xsl:call-template name="step_final"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="step_gen"/>
				</xsl:otherwise>
				
			</xsl:choose>
		
	</xsl:template>
	
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>
	
	<sw:include href="/lib/vza/hwm.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>			
	
</xsl:stylesheet>
