<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:error="http://www.swsoft.com/xsl/cp/error"
  xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
  xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
  xmlns:env="http://www.swsoft.com/xsl/cp/env" 
  xmlns:func="http://exslt.org/functions"
  xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
  xmlns:voc="http://www.swsoft.com/xsl/cp/voc"
>
<sw:include href="/lib/vt/env-core.xsl"/>

<!-- check permissions to show this page -->
<xsl:variable	name="cr-sample-upload"	select="cred:check('vzcp.envsamples')"/>
<xsl:param		name="wiz_code"			select="'envsample_upload'"/>
<xsl:variable	name="step_data"		select="wiz:getStep()"/>
<xsl:variable	name="step"				select="$step_data/@id"/>
<xsl:variable	name="screenid"			select="$step_data/@screenid"/>
<xsl:variable	name="path-id"			select="string(wiz:getSteps()/step[@id = 'gen']/@screenid)"/>

<xsl:variable name="form" select="sw:sesget($wiz_data)"/>

<xsl:param name="access-denied" select="not($cr-sample-upload)"/>

<xsl:variable name="screen-title">
	<sw:text>Upload Container Sample</sw:text>
</xsl:variable>

<xsl:variable name="screen-icon" select="'env_sample_upload'"/>

<!-- Wizard, Step 'General Settings' -->
<xsl:template name="step_gen">
	<ui:screen path-id="{$path-id}" id="{$screenid}" title="{$screen-title}" icon="{$screen-icon}">
		<ui:properties>
			<ui:refresh-type>none</ui:refresh-type>
			<ui:description  mandatory="yes">
				<sw:text>
					Upload a Container sample configuration file.
				</sw:text>
			</ui:description>
		</ui:properties>

		<ui:content>
			<ui:hidden name="step" value="gen"/>
			<xsl:variable name="name-pattern" select="voc:get-pattern(
				env:make-platform-ref(sw:master-eid()), 'pattern.vesampleconfig'
			)" />
		
		<ui:block mode="edit">

		<ui:rows title="{sw:text('Sample Configuration')}">
			<ui:row>
				<ui:cell-label>
					<sw:text>File</sw:text>
				</ui:cell-label>
				<xsl:choose>
					<xsl:when test="error:is-empty()">
						<ui:cell-file id="upload" required="true"/>
					</xsl:when>
					<xsl:otherwise>
						<ui:cell-file id="upload" disabled="yes" required="true"/>
					</xsl:otherwise>
				</xsl:choose>
			</ui:row>
			<ui:row>
				<ui:cell-label>
					<sw:text>Name</sw:text>
				</ui:cell-label>
				<ui:cell-input id="name" maxlength="{$name-pattern/max}" required="true" value="{$form/gen/name}"/>
			</ui:row>
		</ui:rows>

		<ui:buttons>
			<xsl:call-template name="wiz:showButtons"/>
		</ui:buttons>

		</ui:block>
	</ui:content>
	</ui:screen>
</xsl:template>

	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
			<xsl:choose>
				<xsl:when test="$step = 'gen'">
					<xsl:call-template name="step_gen"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="step_gen"/>
				</xsl:otherwise>
			</xsl:choose>
	</xsl:template>
	
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>

	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
