<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred local licensem"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" 
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz" 
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:func="http://exslt.org/functions" 
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"	
	xmlns:backups	="http://www.swsoft.com/xsl/cp/backups"
	xmlns:licensem="http://www.swsoft.com/xsl/cp/licensem"
>

	<sw:include href="/lib/vt/backups-core.xsl"/>
  <sw:include href="/lib/vt/backups-forms.xsl"/>  	
  
	<xsl:param name="wiz_code" select="'vz-hn-setup-backups'"/>

	<xsl:variable name="step_data" select="wiz:getStep()"/>
	<xsl:variable name="step" select="$step_data/@id"/>
	<xsl:variable name="form" select="sw:sesget($wiz_data)"/>

	<xsl:param name="access-denied" select="not(cred:check-context('vzcp.hn.backups.configure','hn.vz.vt'))"/>

	<!-- Wizard, General Step  -->
	<xsl:template name="step_gen">


		<ui:screen id="{$step_data/@screen-id}">
			<ui:properties>
				<ui:description mandatory="yes">
					<sw:text>
						Configure the Container backup settings specific for this Hardware Node.
					</sw:text>
					<xsl:if test="$form/def/hn/master">
						<br/><br/>
						<img src="/{$theme}/icons/alert_yellow.gif" width="16" height="16"/>&#160;<sw:text>
							As this is the Master Node of the Virtuozzo Group, these settings also serve as the global backup settings for this group. 
							The global settings can be overridden individually for each slave Hardware Node on the corresponding screens.
						</sw:text>
					</xsl:if>
				</ui:description>
				<ui:form-get/>
			</ui:properties>

			<ui:content>
				<ui:hidden name="step" value="gen"/>
				<ui:block mode="edit">
								
					<xsl:if test="not($form/def/hn/master)">
						<ui:rows title="{sw:text('Container Backup Settings')}">
							<ui:row>
								<ui:cell-radio id="usage_mode_global" name="usage_mode" value="global" 
									checked="{boolean($form/gen/use-global-settings)}"
									onclick="enableSelfConfig(0)"
								/>
								<ui:cell cell-width="100%" align="left" colspan="2">
									<sw:text>Use global settings for backing up Containers of this Node</sw:text>
								</ui:cell>						
							</ui:row>
							<ui:row>
								<ui:cell-radio id="usage_mode_self" name="usage_mode" value="self" 
									checked="{not(boolean($form/gen/use-global-settings))}"
									onclick="enableSelfConfig(1)"
								/>
								<ui:cell cell-width="100%" align="left" colspan="2">
									<sw:text>Use local settings for backing up Containers of this Node</sw:text>
								</ui:cell>						
							</ui:row>
						</ui:rows>
					</xsl:if>
					
					<xsl:call-template name="backups:edit-core-options">
						<xsl:with-param name="options" select="$form/core-options"/>
						<xsl:with-param name="visible" select="$form/def/hn/master or not($form/gen/use-global-settings)"/>						
					</xsl:call-template>
					
					<!-- Common script -->
					<ui:java-script>
						var backup_divs=new Array(
							'div_core_defaults','div_core_limits','div_core_incremental'
						);
						function enableSelfConfig(enable){
							var div = null;
							for(i=0;i&lt;(backup_divs.length);i++){
								div = document.getElementById(backup_divs[i]);
								if(div){
									div.style.display = (enable==1?'block':'none');
								}
							}			      	
						}
						<!--enableSelfConfig(<xsl:value-of select="sw:if($form/gen/use-global-settings,'0','1')"/>);-->
					</ui:java-script>
					<!-- /Common script -->	      		      
					
					<xsl:call-template name="local:edit-storage-options"/>
					
					<ui:buttons>
						<xsl:call-template name="wiz:showButtons"/>
					</ui:buttons>

				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>
	
	<!-- Wizard, Error screen -->
  <xsl:template name="show-core-options-error">
  	  
  	<ui:screen  id="{$step_data/@screen-id}">
  	
	    <ui:properties>
	    	<ui:refresh-type>none</ui:refresh-type>
	    	<ui:form-get/>
		</ui:properties>
	    
	    <ui:content>
	      <ui:block>

					<ui:operation-problem>
						<ui:type>vza-error</ui:type>
						<ui:descr>
							<sw:text>The backup settings are unavailable now.</sw:text>
						</ui:descr>
						<ui:vza-error>
							<xsl:copy-of select="$form/core-options/error/*"/>
						</ui:vza-error>
					</ui:operation-problem>
				
	     	</ui:block>
	    </ui:content>   
    </ui:screen>
  </xsl:template>
  
  <xsl:template name="local:edit-storage-options">
  	<xsl:variable name="options" select="$form/storage-config"/>
	
		<ui:rows title="{sw:text('Local Backups Location Settings')}" separate-tables="true">
			<xsl:choose>
				<!-- On Windows -->
				<xsl:when test="$form/def/hn/windows">
					<ui:row>
						<ui:cell-label>
							<sw:text>Storage Location</sw:text>
						</ui:cell-label>									
						<ui:cell-list id="storage_type" value="{$options/location/type}"
							onchange="changeLocation(selectedIndex&lt;0?'':options[selectedIndex].value)"
						>
							<ui:list-item id="local" title="{sw:text('Local Drive')}"/>
							<ui:list-item id="share" title="{sw:text('Network Share')}"/>
						</ui:cell-list>
					</ui:row>
		
					<ui:row div_id="row_local_path">
						<ui:cell-label show-aster="true">
							<sw:text>Local Path</sw:text>
						</ui:cell-label>
						<ui:cell-input id="local_path" maxlength="200" value="{$options/location/local/path}"/>
					</ui:row>
				
					<ui:row div_id="row_share_path">
						<ui:cell-label show-aster="true">
							<sw:text>Network Path</sw:text>
						</ui:cell-label>
						<ui:cell-input id="share_path" maxlength="200" value="{$options/location/share/path}"/>
					</ui:row>
				
					<ui:row div_id="row_share_name">
						<ui:cell-label show-aster="true">
							<sw:text>User Name</sw:text>
						</ui:cell-label>
						<ui:cell-input id="share_login_name" maxlength="200" value="{$options/location/share/login/name}"/>
					</ui:row>
					<ui:row div_id="row_share_domain">
						<ui:cell-label>
							<sw:text>User Domain</sw:text>
						</ui:cell-label>
						<ui:cell-input id="share_login_domain" maxlength="200" value="{$options/location/share/login/domain}"/>
					</ui:row>
					<ui:row div_id="row_share_password">
						<ui:cell-label>
							<sw:text>User Password</sw:text>
						</ui:cell-label>
						<ui:cell-input id="share_login_password" maxlength="200" value="{$options/location/share/login/password}"
							mode-password="true"
						/>
					</ui:row>
				</xsl:when>
				<!-- On Linux -->
				<xsl:otherwise>
	
					<ui:row div_id="row_local_path">
						<ui:cell-label show-aster="true">
							<sw:text>Location Path</sw:text>
						</ui:cell-label>
						<ui:cell-input id="local_path" maxlength="200" value="{$options/location/local/path}"/>
					</ui:row>
				
				</xsl:otherwise>
			</xsl:choose>
			
		</ui:rows>

		<!-- Common script -->
		<xsl:if test="$form/def/hn/windows">	
			<ui:java-script>
				function changeLocation(type){
					showObjExt('row_local_path',type=='local');
					showObjExt('row_share_path',type=='share');
					showObjExt('row_share_name',type=='share');
					showObjExt('row_share_domain',type=='share');				
					showObjExt('row_share_password',type=='share');				
				}
				changeLocation('<xsl:value-of select="$options/location/type"/>');
			</ui:java-script>
		</xsl:if>
		<!-- /Common script -->	     
	
	</xsl:template>
					


	<!-- main document handler -->
	<xsl:template mode="screen" match="/">

		<xsl:choose>
			<xsl:when test="$form/core-options/error">
				<xsl:call-template name="show-core-options-error"/>
			</xsl:when>	
			<xsl:when test="$step = 'gen'">
				<xsl:call-template name="step_gen"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="step_gen"/>
			</xsl:otherwise>

		</xsl:choose>

	</xsl:template>

	<!-- Includes -->
	<!-- UI modules -->
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>

	<!-- System modules -->
	<sw:include href="/lib/vocabulary.xsl"/>
	<!-- /Includes -->

</xsl:stylesheet>
