<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred hwm form format"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:hwm="http://www.swsoft.com/xsl/cp/hwm"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:form="http://www.swsoft.com/xsl/cp/form"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:format="http://www.swsoft.com/xsl/cp/format"
>

	<sw:include href="/lib/utils/format-resusage.xsl"/>

	<!-- check permissions to show this page -->
	<xsl:variable name="cred"		select="cred:check-hw('vzcp.hn.manage.config.network',sw:hn-eid())"/>
	<xsl:param name="wiz_code"	select="'vznet_interfaces'"/>
	<xsl:variable name="step_data"	select="wiz:getStep()"/>
	<xsl:variable name="step" 			select="$step_data/@id"/>
	<xsl:variable name="path-id"		select="string(wiz:getSteps()/step[1]/@screen-id)"/>
	<xsl:param name="access-denied" select="not($cred)"/>
	<xsl:variable name="form" select="sw:sesget($wiz_data)"/>

	<xsl:template name="step_control">
		<ui:screen path-id="{$path-id}" id="{$step_data/@screen-id}" title="{$step_data/@screen-title}"
			icon="{$step_data/@screen-icon}">
			<ui:properties>
				<ui:description mandatory="yes" width="max">
					<sw:text>Select the network interfaces for Virtuozzo traffic accounting and shaping.</sw:text>
				</ui:description>
				<ui:no-refresh/>
				<ui:form-get/>
			</ui:properties>
			<ui:tab-bar id="vzhn" current-tab="network" current-subtab="traffic"/>
			<ui:content>
				<ui:hidden name="step" value="config"/>
				<xsl:if test="not($form/config/shaping)">
					<ui:block width="max">
						<ui:alert>
							<sw:text>
								The traffic shaping is disabled on this Hardware Node. <br/> Your changes will take effect after the traffic shaping is enabled.
							</sw:text>
						</ui:alert>
					</ui:block>
				</xsl:if>
				<ui:block width="max">
					<ui:rows title="{sw:text('Virtuozzo Network Interfaces')}" mode="edit">
						<xsl:for-each select="$form/interfaces/interface">
							<xsl:sort select="name" data-type="text"/>
							<xsl:variable name="cur-net-device-id"	select="name"/>
							<xsl:variable name="iface-selected" select="$form/config/interface[net_device_id = $cur-net-device-id]"/>
							<ui:row>
								<ui:cell-check name="{$cur-net-device-id}" id="{$cur-net-device-id}" cell-width="15" 
									value="{$cur-net-device-id}" align="left">
									<xsl:if test="$iface-selected != ''">
										<xsl:attribute name="checked">true</xsl:attribute>
									</xsl:if>
									<ui:control-slave>
										<xsl:value-of select="concat($cur-net-device-id, '_bandwidth')"/>
									</ui:control-slave>
								</ui:cell-check>
								<ui:cell align="left" cell-width="10%">
									<xsl:value-of select="$cur-net-device-id"/>
								</ui:cell>
								<ui:cell-text align="right" cell-width="5%">
									<sw:text>Bandwidth:</sw:text>
								</ui:cell-text>

								<xsl:variable name="bandwidth-detail-rtf">
									<xsl:choose>
										<xsl:when test="error:has-errors()">
											<factor>
												<xsl:value-of select="$iface-selected/bandwidth-factor"/>
											</factor>
											<value>
												<xsl:value-of select="$iface-selected/bandwidth"/>
											</value>
										</xsl:when>
										<xsl:otherwise>
											<xsl:copy-of	select="format:kbps2bps($iface-selected/bandwidth,'','no','#0.00')"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:variable>
								<xsl:variable name="bandwidth-detail" select="exsl:node-set($bandwidth-detail-rtf)"/>
								<ui:cell-input  maxlength="9" id="{concat($cur-net-device-id, '_bandwidth')}" name="{concat($cur-net-device-id, '_bandwidth')}"
									value="{$bandwidth-detail/value}" cell-width="10%" width="10"></ui:cell-input>
								<!-- Units -->
								<ui:cell-list id="{concat($cur-net-device-id, '_factor')}" style="width:55px" value="{$bandwidth-detail/factor}">
									<ui:list-item id="1000" title="{sw:text('Kbps')}"/>
									<ui:list-item id="1000000" title="{sw:text('Mbps')}"/>
									<ui:list-item id="1000000000" title="{sw:text('Gbps')}"/>
								</ui:cell-list>								

								<ui:cell-text align="right" cell-width="5%">
									<nobr>
										<sw:text>IP addresses:</sw:text>
									</nobr>
								</ui:cell-text>
								<ui:cell-text align="left" cell-width="70%">
									<xsl:if test="not(ipaddress)">
										<sw:text>Not specified.</sw:text>
									</xsl:if>
									<xsl:for-each select="ipaddress">
										<xsl:if test="position() &gt; 1">
											<br/>
										</xsl:if>
										<xsl:value-of select="."/>
									</xsl:for-each>
								</ui:cell-text>
							</ui:row>
						</xsl:for-each>
					</ui:rows>
					<ui:buttons>
						<xsl:call-template name="wiz:showButtons"/>
					</ui:buttons>
				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
		<xsl:call-template name="step_control"/>
	</xsl:template>

	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
