<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred hwm form local format"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:hwm="http://www.swsoft.com/xsl/cp/hwm"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:form="http://www.swsoft.com/xsl/cp/form"
	xmlns:func="http://exslt.org/functions"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:format="http://www.swsoft.com/xsl/cp/format"
	xmlns:set	="http://exslt.org/sets"
>

	<sw:include href="/lib/utils/format-resusage.xsl"/>

	<xsl:variable name="hn-eid" select="sw:hn-eid()"/>
	<!-- check permissions to show this page -->
	<xsl:variable name="cred" select="cred:check-hw('vzcp.hn.manage.config.network',$hn-eid)"/>
	<xsl:param name="wiz_code" select="'vznet_shaping'"/>
	<xsl:variable name="step_data" select="wiz:getStep()"/>
	<xsl:variable name="step" select="$step_data/@id"/>
	<xsl:variable name="path-id" select="string(wiz:getSteps()/step[1]/@screen-id)"/>
	<xsl:param name="access-denied" select="not($cred)"/>
	<xsl:variable name="form" select="sw:sesget($wiz_data)"/>

	<!-- Wizard, General Step  -->
	<xsl:template name="step_config">
		<ui:screen path-id="{$path-id}" id="{$step_data/@screen-id}" title="{$step_data/@screen-title}" icon="{$step_data/@screen-icon}">
			<ui:properties>
				<ui:description mandatory="yes" width="max">
					<sw:text>
						The traffic shaping (or network bandwidth management) allows you to control the network bandwidth for the outgoing traffic.
					</sw:text>
				</ui:description>
				<ui:no-refresh/>
				<ui:form-get/>
			</ui:properties>
			<ui:content>
				<ui:hidden name="step" value="config"/>
				<xsl:if test="not($form/config/shaping)">
					<ui:block width="max">
						<ui:alert>
							<sw:text>
								The traffic shaping is disabled on this Hardware Node. <br/> Your changes will take effect after the traffic shaping is enabled.
							</sw:text>
						</ui:alert>
					</ui:block>
				</xsl:if>
				<xsl:choose>
					<xsl:when test="count($form/config/range) &gt; 0">
						<!-- foreach by range, for show not configured class -->
						<xsl:for-each select="set:distinct($form/config/range[class_id != 0]/class_id)/..">
							<xsl:sort select="class_id" data-type="number"/>
							<xsl:variable name="class-id" select="class_id"/>
							<xsl:variable name="total-rate-name" select="concat('totalrate_', $class-id)"/>
							<xsl:variable name="rate-name" 			 select="concat('rate_', $class-id)"/>
							<xsl:variable name="factor-totalrate-name" select="concat('factor_totalrate_', $class-id)"/>
							<xsl:variable name="factor-rate-name" 		 select="concat('factor_rate_', $class-id)"/>
							<ui:block width="max">
								<ui:rows title="{concat(sw:text('Class'), ' ', $class-id)}" mode="edit">
									<ui:row>
										<ui:cell-check name="class" id="{$class-id}" close="false" cell-width="100%" colspan="9"
											value="{$class-id}" checked="{$form/config/class/id = $class-id}" align="left">
											<ui:control-slave>
												<xsl:value-of select="$total-rate-name"/>
											</ui:control-slave>
											<xsl:if test="$form/hn/linux">
												<ui:control-slave>
													<xsl:value-of select="$rate-name"/>
												</ui:control-slave>
											</xsl:if>
										</ui:cell-check>
										<ui:cell label-for="{$class-id}" open="false" align="left">
											<nobr>
												<sw:text>Enable shaping for this class</sw:text>
											</nobr>
										</ui:cell>
									</ui:row>
									<ui:row>
										<ui:cell cell-width="10%" align="left">
											<nobr>
												<sw:text>Total Rate</sw:text>
											</nobr>
										</ui:cell>

										<xsl:variable name="totalrate-detail-rtf">
											<xsl:choose>
												<xsl:when test="error:has-errors()">
													<factor>
														<xsl:value-of select="$form/config/class[id = $class-id]/totalrate-factor"/>
													</factor>
													<value>
														<xsl:value-of select="$form/config/class[id = $class-id]/totalrate"/>
													</value>
												</xsl:when>
												<xsl:otherwise>
													<xsl:copy-of select="format:kbps2bps($form/config/class[id = $class-id]/totalrate,'','no','#0.00')"/>
												</xsl:otherwise>
											</xsl:choose>
										</xsl:variable>
										<xsl:variable name="totalrate-detail" select="exsl:node-set($totalrate-detail-rtf)"/>
										<ui:cell-input nowrap="1" maxlength="10" id="{$total-rate-name}"
											value="{$totalrate-detail/value}" tip="totalrate"
											cell-width="10%" width="10"/>
										<ui:cell-list id="{$factor-totalrate-name}" style="width:55px" value="{$totalrate-detail/factor}"> 
											<ui:list-item id="1000" title="{sw:text('Kbps')}"/>
											<ui:list-item id="1000000" title="{sw:text('Mbps')}"/>
											<ui:list-item id="1000000000" title="{sw:text('Gbps')}"/>
										</ui:cell-list>
									</ui:row>
									<xsl:if test="$form/hn/linux">
										<ui:row>
											<ui:cell cell-width="10%" align="left">
												<nobr>
													<sw:text>Rate Guarantee</sw:text>
												</nobr>
											</ui:cell>
											<xsl:variable name="rate-detail-rtf">
												<xsl:choose>
													<xsl:when test="error:has-errors()">
														<factor>
															<xsl:value-of select="$form/config/class[id = $class-id]/rate-factor"/>
														</factor>
														<value>
															<xsl:value-of select="$form/config/class[id = $class-id]/rate"/>
														</value>
													</xsl:when>
													<xsl:otherwise>
														<xsl:copy-of select="format:kbps2bps($form/config/class[id = $class-id]/rate,'','no','#0.00')"/>
													</xsl:otherwise>
												</xsl:choose>
											</xsl:variable>
											<xsl:variable name="rate-detail" select="exsl:node-set($rate-detail-rtf)"/>
											<ui:cell-input nowrap="1" maxlength="10" id="{$rate-name}"
												value="{$rate-detail/value}" tip="rate"
												cell-width="10%" width="10"/>
											<ui:cell-list id="{$factor-rate-name}" style="width:55px" value="{$rate-detail/factor}"> 
												<ui:list-item id="1000" title="{sw:text('Kbps')}"/>
												<ui:list-item id="1000000" title="{sw:text('Mbps')}"/>
												<ui:list-item id="1000000000" title="{sw:text('Gbps')}"/>
											</ui:cell-list>											
										</ui:row>
									</xsl:if>
								</ui:rows>
							</ui:block>
						</xsl:for-each>
						<ui:block width="max">
							<ui:buttons>
								<xsl:call-template name="wiz:showButtons"/>
							</ui:buttons>
						</ui:block>
					</xsl:when>
					<xsl:otherwise>
						<ui:block width="max">
							<ui:rows>
								<ui:row>
									<ui:cell>
										<sw:text>
											No network class is defined to configure rates for.
										</sw:text>
									</ui:cell>
								</ui:row>
								<ui:row>
									<ui:cell>
										<ui:i18n-link href="{$baseurl}/vzdir/infrman/hns/config/accounting" tip="configure_accounting">
											<_>Click %{aopen}here%{aclose} to manage network traffic accounting on the Hardware Node.</_>
    					      </ui:i18n-link>
    					    </ui:cell>
    				  	</ui:row>
    				  </ui:rows>
							<ui:buttons>
								<xsl:call-template name="wiz:showButtons">
									<xsl:with-param name="disable-submit" select="true()"/>
								</xsl:call-template>
							</ui:buttons>
						</ui:block>						
					</xsl:otherwise>
				</xsl:choose>

			</ui:content>
		</ui:screen>
	</xsl:template>

	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
		<xsl:choose>
			<xsl:when test="$step = 'config'">
				<xsl:call-template name="step_config"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="step_config"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/traffic.xsl"/>

</xsl:stylesheet>
