<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred show local format"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" 
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz" 
	xmlns:env="http://www.swsoft.com/xsl/cp/env" 
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui" 
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:networkm	="http://www.swsoft.com/xsl/cp/networkm"
	xmlns:computerm	="http://www.swsoft.com/xsl/cp/computerm"	
	xmlns:vznet			="http://www.swsoft.com/xsl/cp/vznet"
	xmlns:set				="http://exslt.org/sets"
	xmlns:format="http://www.swsoft.com/xsl/cp/format"
>
	
	<sw:include href="/lib/utils/format-resusage.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>	
	<sw:include href="/lib/vza/networkm.xsl"/>
	<sw:include href="/lib/swa/computerm.xsl"/>
	<sw:include href="/lib/vz/vznet-core.xsl"/>	

	<!-- check permissions to show this page -->
	<xsl:variable name="hn-eid" 					select="sw:hn-eid()"/>
	<xsl:variable name="cred"							select="cred:check-hw('vzcp.hn.manage.config.network',$hn-eid)"/>
	<xsl:variable name="cred-acc"					select="$cred"/>
	<xsl:variable name="cred-shaping"			select="$cred"/>
	<xsl:variable name="cred-interfaces"	select="$cred"/>
	<xsl:param name="access-denied" select="not($cred)"/>
	<xsl:variable name="netconfig"	select="local:initData($hn-eid)"/>

	<!-- Wizard, General Step  -->
	<xsl:template name="step_manage">
		<ui:screen id="03.02.01.32.03" icon="traffic_log">

			<ui:properties>
				<ui:description mandatory="yes" width="max">
					<sw:text>
						Virtuozzo allows you to track the inbound and outbound network traffic as well as to shape the 
						outgoing traffic for Containers. 
						<br/> 
						A network class is a range of IP addresses for which Virtuozzo counts and shapes the traffic.
					</sw:text>
				</ui:description>
				<ui:form-get/>
			</ui:properties>

			<ui:tab-bar id="vzhn" current-tab="network" current-subtab="traffic"/>
			<ui:content>
				<ui:block width="max">
					<ui:hidden name="stub" value="stub"/>

					<ui:rows title="{sw:text('Traffic Accounting')}">
						<xsl:call-template name="local:show-account-class">
							<xsl:with-param name="netconfig" select="$netconfig"/>
						</xsl:call-template>
					</ui:rows>

					<xsl:if test="$cred-acc">
						<ui:buttons>
							<ui:button tip="configure_accounting" name="configure_accounting" width="150"
								submit-href="{$baseurl}/vzdir/infrman/hns/config/accounting" sandclock="false">
								<sw:text>Configure Accounting</sw:text>
							</ui:button>
						</ui:buttons>
					</xsl:if>
				</ui:block>

				<!-- Shaping by iface -->
				<xsl:if test="($cred-shaping or $cred-interfaces) and $netconfig/hn/linux">
					<ui:block width="max">
						<ui:rows>
							<xsl:attribute name="title">
								<sw:text>
									<xsl:with-param name="state" select="sw:if($netconfig/vznet/shaping, sw:text('Enabled'), sw:text('Disabled'))"/>
									Interfaces Configuration (Shaping %{state})
								</sw:text>
							</xsl:attribute>
							<ui:row type="head">
								<ui:cell width="20%" align="left">
									<sw:text>Interface</sw:text>
								</ui:cell>
								<ui:cell width="20%" align="right">
									<nowrap>
										<sw:text>Bandwidth</sw:text>
									</nowrap>
								</ui:cell>
							</ui:row>
							<xsl:for-each select="$netconfig/vznet/stat-by-iface/interface">
								<xsl:sort select="name"/>
								<xsl:variable name="device-name" select="name"/>
								<xsl:variable name="cur-iface-stat" select="$netconfig/vznet/interface[net_device_id = $device-name]"/>
								<ui:row>
									<ui:cell align="left">
										<xsl:value-of select="$device-name"/>
									</ui:cell>
									<ui:cell align="right">
										<xsl:choose>
											<xsl:when test="not($cur-iface-stat/bandwidth)">
												<sw:text>Not Configured</sw:text>
											</xsl:when>
											<xsl:otherwise>
												<xsl:value-of select="format:kbps2bps($cur-iface-stat/bandwidth,'','yes','#,##0.00')/value"/>
											</xsl:otherwise>
										</xsl:choose>									
									</ui:cell>
								</ui:row>
							</xsl:for-each>
						</ui:rows>

						<ui:buttons>
							<xsl:if test="$cred-interfaces">
								<ui:button tip="configure_interfaces" name="configure_interfaces" width="150"
									submit-href="{$baseurl}/vzdir/infrman/hns/config/interfaces" sandclock="false">
									<sw:text>Configure Interfaces</sw:text>
								</ui:button>
							</xsl:if>
						</ui:buttons>
					</ui:block>
				</xsl:if>

				<!-- Shaping by class -->
				<xsl:if test="$cred-shaping or $cred-interfaces">
					<ui:block width="max">
						<ui:rows>
							<xsl:attribute name="title">
								<sw:text>
									<xsl:with-param name="state" select="sw:if($netconfig/vznet/shaping, sw:text('Enabled'), sw:text('Disabled'))"/>
									Rates Configuration (Shaping %{state})
								</sw:text>
							</xsl:attribute>
							<ui:row type="head">
								<ui:cell width="20%" align="left">
									<sw:text>Class ID</sw:text>
								</ui:cell>
								<ui:cell width="20%" align="right">
									<nowrap>
										<sw:text>Total Rate</sw:text>
									</nowrap>
								</ui:cell>
								<xsl:if test="$netconfig/hn/linux">
									<ui:cell width="20%" align="right">
										<nowrap>
											<sw:text>Rate Guarantee </sw:text>
										</nowrap>
									</ui:cell>
								</xsl:if>
							</ui:row>
							<xsl:for-each select="set:distinct($netconfig/vznet/range/class_id)/..">
								<xsl:sort select="class_id" data-type="number"/>
								<xsl:variable name="class-id" select="class_id"/>
								<ui:row>
									<ui:cell	align="left">
										<nowrap>
											<sw:text>
												<xsl:with-param name="id" select="$class-id"/>
												Class %{id}
											</sw:text>
										</nowrap>
									</ui:cell>
									<xsl:variable name="class" select="$netconfig/vznet/class[id = $class-id]"/>
									<ui:cell align="right">
										<xsl:choose>
											<xsl:when test="$class-id = 0">
												<sw:text>Not Available</sw:text>
											</xsl:when>										
											<xsl:when test="not($class/totalrate)">
												<sw:text>Not Configured</sw:text>
											</xsl:when>
											<xsl:otherwise>
												<xsl:value-of select="format:kbps2bps($class/totalrate,'','yes','#,##0.00')/value"/>
											</xsl:otherwise>
										</xsl:choose>
									</ui:cell>
									<xsl:if test="$netconfig/hn/linux">
										<ui:cell align="right">
											<xsl:choose>
												<xsl:when test="$class-id = 0">
													<sw:text>Not Available</sw:text>
												</xsl:when>											
												<xsl:when test="not($class/rate)">
													<sw:text>Not Configured</sw:text>
												</xsl:when>
												<xsl:otherwise>
													<xsl:value-of select="format:kbps2bps($class/rate,'','yes','#,##0.00')/value"/>
												</xsl:otherwise>
											</xsl:choose>
										</ui:cell>
									</xsl:if>
								</ui:row>
							</xsl:for-each>
						</ui:rows>
						<ui:buttons>
							<xsl:if test="$cred-shaping">
								<ui:button tip="enable_shaping" sandclock="true" name="enable_shaping" width="150"
									submit-href="{$baseurl}/vzdir/infrman/hns/config/traffic-control?enable_shaping=yes">
									<xsl:if test="$netconfig/vznet/shaping">
										<xsl:attribute name="disabled">true</xsl:attribute>
									</xsl:if>
									<sw:text>Enable Shaping</sw:text>
								</ui:button>
								<ui:button tip="disable_shaping" sandclock="true" name="disable_shaping" width="150"
									confirmation="{sw:text('Are you sure you want to disable traffic shaping?')}"
									submit-href="{$baseurl}/vzdir/infrman/hns/config/traffic-control?disable_shaping=yes">
									<xsl:if test="not($netconfig/vznet/shaping)">
										<xsl:attribute name="disabled">true</xsl:attribute>
									</xsl:if>
									<sw:text>Disable Shaping</sw:text>
								</ui:button>
							</xsl:if>
							<xsl:if test="$cred-shaping">
								<ui:button tip="configure_shaping" name="configure_shaping" width="150"
									submit-href="{$baseurl}/vzdir/infrman/hns/config/shaping" sandclock="false">
									<sw:text>Configure Rates</sw:text>
								</ui:button>
							</xsl:if>
						</ui:buttons>
					</ui:block>
				</xsl:if>
				
			</ui:content>
		</ui:screen>
	</xsl:template>

	<!-- show current classes: number and ip ranges. -->
	<xsl:template name="local:show-account-class">
		<xsl:param name="netconfig"/>
		<!-- headers -->
		<ui:row type="head">
			<ui:cell cell-width="16%" align="left">
				<sw:text>Class ID</sw:text>
			</ui:cell>
			<ui:cell cell-width="16%" align="right">
				<sw:text>Network</sw:text>
			</ui:cell>
		</ui:row>
		<xsl:for-each select="$netconfig/vznet/range">
			<xsl:sort select="class_id" data-type="number"/>
			<xsl:variable name="class-id" select="class_id"/>
			<xsl:variable name="ip"       select="ip_address/ip"/>
			<xsl:variable name="netmask"  select="ip_address/netmask"/>
			<ui:row>
				<ui:cell align="left">
					<sw:text>
						<xsl:with-param name="class" select="$class-id"/>
						Class %{class}
					</sw:text>
				</ui:cell>
				<ui:cell align="right">
					<xsl:value-of select="sw:if($netmask = '255.255.255.255', $ip, concat($ip, '/', $netmask))"/>
				</ui:cell>			
			</ui:row>
		</xsl:for-each>
	</xsl:template>


	<func:function name="local:initData">
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>
		<!-- get account/shaper config for hnode -->
 		<xsl:variable name="netconfig-raw"	select="networkm:get-config($hn-eid)"/>
		<!-- get netwrok statistic for node, by interface -->
		<xsl:variable name="netstat-iface-raw"  select="vznet:remove-loopback-and-down-iface($hn-eid,computerm:get-network($hn-eid))"/>
		<xsl:variable name="netinfo-rtf">
			<vznet>
				<stat-by-iface>
					<xsl:copy-of select="$netstat-iface-raw"/>
				</stat-by-iface>				
				<xsl:copy-of select="$netconfig-raw/range"/>
				<xsl:copy-of select="$netconfig-raw/shaping"/>
				<xsl:copy-of select="$netconfig-raw/interface"/>
				<xsl:copy-of select="$netconfig-raw/class"/>
			</vznet>
			<hn>
				<xsl:copy-of select="env:eid2info($hn-eid)"/>
			</hn>
		</xsl:variable>
		<func:result select="exsl:node-set($netinfo-rtf)"/>
	</func:function>


	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
		<xsl:choose>
			<xsl:when test="not($cred)">
				<xsl:call-template name="access-denied-screen"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="step_manage"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
