<!--
		 Copyright (c) SWsoft, 1999-2007
		 All rights reserved.
   -->

<xsl:stylesheet version="1.0" 
	extension-element-prefixes="sw func exsl cred format" 
	exclude-result-prefixes="sw exsl cred ui local alertm vzhn"
	
	xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:sw			="http://www.swsoft.com/xsl/cp"
	xmlns:func		="http://exslt.org/functions"
	xmlns:ui			="http://www.swsoft.com/xsl/cp/ui"  
	xmlns:cred  		="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local  		="http://www.swsoft.com/xsl/cp/local"
	xmlns:envm			="http://www.swsoft.com/xsl/cp/envm"	
	xmlns:vt	   		="http://www.swsoft.com/xsl/cp/vt"
	xmlns:update		="http://www.swsoft.com/xsl/cp/update"
	xmlns:env   		="http://www.swsoft.com/xsl/cp/env"
	xmlns:hn   			="http://www.swsoft.com/xsl/cp/hn"
	xmlns:vzhn			="http://www.swsoft.com/xsl/cp/vzhn"
	xmlns:system			="http://www.swsoft.com/xsl/cp/system"
	xmlns:format			="http://www.swsoft.com/xsl/cp/format"
	xmlns:alertm			="http://www.swsoft.com/xsl/cp/alertm"
	xmlns:licensem	="http://www.swsoft.com/xsl/cp/licensem"
>

	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/update.xsl"/>
	<sw:include href="/lib/utils/format-number.xsl"/>
	<sw:include href="/lib/utils/format-resusage.xsl"/>
	<sw:include href="/lib/show-resource.xsl"/> 
	<sw:include href="/lib/swa/envm.xsl"/> 
	<sw:include href="/lib/vt/hn-core.xsl"/>
	<sw:include href="/lib/vz/vzhn-info.xsl"/>
	<sw:include href="/lib/summary.xsl"/>
	<sw:include href="/lib/swa/system.xsl"/>
	<sw:include href="/lib/swa/alertm.xsl"/>
	<sw:include href="/lib/swa/licensem.xsl"/>

	<!--XXX need move to core -->	
	<sw:include href="/lib/vzdir/infrman/hns/resources.xsl"/>
		
	<!-- Init data -->
	<xsl:variable name="hn-eid" select="sw:hn-eid()"/>
	<xsl:param name="access-denied" select="not(cred:check-hw('vzcp.hn.view', $hn-eid))"/>
	<xsl:variable name="env"  select="env:get-env($hn-eid)/env"/>
	<xsl:variable name="hn-platform" select="hn:hn2platform($env)"/>
	
	<!-- get alerts for node -->
	<xsl:variable name="hnode-alerts" select="alertm:get($hn-eid,true())/alert/data"/>
	
	<!-- resource for node: license include -->
	<xsl:variable name="resources"	select="exsl:node-set(vzhn:load-summary-info($hn-eid,true()))/resources"/>

	<!-- updates -->
	<xsl:variable name="updates" select="update:get-last-update-profile($hn-eid)"/>

	<!-- data for screen -->
	<xsl:variable name="hn-state"				select="$env/status/state"/>
	<xsl:variable name="hn-transition"	select="$env/status/transition"/>
	<xsl:variable name="lic-status-id"		select="$resources/group[id = 'common']/resource[id = 'license']/lic-status/id"/>
	<xsl:variable name="lic-status-text"	select="$resources/group[id = 'common']/resource[id = 'license']/lic-status/text"/>	
	<xsl:variable name="ve-lic-limit"		select="$resources/group[id = 'common']/resource[id = 'license']/ve-total"/>
	<xsl:variable name="kernel-version"				select="$resources/group[id = 'common']/resource[id = 'kernel']/value"/>
	<xsl:variable name="kernel-update-state"	select="local:get-update-status($updates,'kernel')"/>
	<xsl:variable name="vz-version"						select="$resources/group[id = 'vz']/resource[id = 'virtuozzo']/version"/>
	<xsl:variable name="vz-release"						select="$resources/group[id = 'vz']/resource[id = 'virtuozzo']/release"/>
	<xsl:variable name="vz-full-version"			select="sw:if($vz-release !='',concat($vz-version,'-',$vz-release),$vz-version)"/>
	<xsl:variable name="arch"									select="$resources/group[id = 'common']/resource[id = 'arch']/value/raw/architecture"/>
	<xsl:variable name="arch-full"						select="$resources/group[id = 'common']/resource[id = 'arch']/value/formatted"/>
	<xsl:variable name="vz-update-state"			select="local:get-update-status($updates,'virtuozzo')"/>
	<xsl:variable name="disk-usage">
		<xsl:for-each select="$resources/group[id = 'disk']">
			<xsl:value-of select="sum(resource/values/cur) div sum(resource/values/total)"/>
		</xsl:for-each>
	</xsl:variable>
	<xsl:variable name="disk-usage-color"		select="sw:get-color-by-category($disk-usage,'hn-disk')"/>
	<xsl:variable name="load-average" 			select="$resources/group[id = 'cpu']/resource[id = 'loadavg']/value"/>
	<xsl:variable name="load-average-color"	select="$resources/group[id = 'cpu']/resource[id = 'loadavg']/alert/color"/>
	<xsl:variable name="cpu-load" 		select="$resources/group[id = 'cpu']/resource[id = 'cpu']/fraction"/>
	<xsl:variable name="mem-percent" 	select="$resources/group[id = 'mem']/resource[id = 'mem']/fraction"/>
	<xsl:variable name="mem-stat" 	 	select="$resources/group[id = 'mem']/resource[id = 'mem']/values"/>		
	<xsl:variable name="swap-percent" select="$resources/group[id = 'mem']/resource[id = 'swap']/fraction"/>
	<xsl:variable name="swap-stat" 	 	select="$resources/group[id = 'mem']/resource[id = 'swap']/values"/>
	<xsl:variable name="mem-plus-swap-rtf">
		<xsl:for-each select="$resources/group[id = 'mem']">
			<fraction>
				<xsl:value-of select="sum(resource/values/cur) div sum(resource/values/total)"/>
			</fraction>
			<values>
				<total>
					<xsl:value-of select="sum(resource/values/total)"/>						
				</total>
				<free>
					<xsl:value-of select="sum(resource/values/free)"/>					
				</free>
				<cur>
					<xsl:value-of select="sum(resource/values/cur)"/>					
				</cur>					
			</values>					
		</xsl:for-each>
	</xsl:variable>
	<xsl:variable name="mem-plus-swap" 				select="exsl:node-set($mem-plus-swap-rtf)"/>
	<xsl:variable name="mem-plus-swap-color"	select="sw:get-color-by-category($mem-plus-swap/fraction,'hn-mem-swap')"/>
	<xsl:variable name="disk-stat"		 	select="$resources/group[id = 'disk']/resource[id = 'diskspace']"/>
	<xsl:variable name="os-name"				select="$resources/group[id = 'common']/resource[id = 'arch']/value/raw/platform"/>
	<xsl:variable name="os-name-detail"	select="$resources/group[id = 'common']/resource[id = 'arch']/value/raw/name"/>
	<xsl:variable name="uptime"					select="$resources/group[id = 'common']/resource[id = 'uptime']/value"/>
	<xsl:variable name="processor"			select="$resources/group[id = 'common']/resource[id = 'processor']/mhz-num/value"/>
	<xsl:variable name="processor-cores"				select="$resources/group[id = 'common']/resource[id = 'processor']/cores"/>	
	<xsl:variable name="processor-hyperthreads"	select="$resources/group[id = 'common']/resource[id = 'processor']/hyperthreads"/>
	
	<xsl:variable name="hn-hostname"	select="$resources/group[id = 'common']/resource[id = 'hostname']/value"/>
	<xsl:variable name="hn-ips"				select="$resources/group[id = 'common']/resource[id = 'ips']/value"/>	

	<!-- get statistic for commitmetment -->
	<xsl:variable name="hn-summary-state"	select="hn:get-vzcp-summary($hn-eid,$mem-plus-swap/values/total,$disk-stat,'all')"/>
	<xsl:variable name="hn-mem-commitment"	select="$hn-summary-state/commitment/mem-swap"/>
	<xsl:variable name="hn-disk-commitment" select="$hn-summary-state/commitment/disks"/>
	<!-- ve's stat from summary -->
	<xsl:variable name="ve-running" 	select="format:normalize-number($hn-summary-state/vestat/running)"/>
	<xsl:variable name="ve-total" 		select="format:normalize-number($hn-summary-state/vestat/total)"/>
	<xsl:variable name="ve-stopped" 	select="$ve-total - $ve-running"/>
	<xsl:variable name="ve-alerted" 	select="format:normalize-number($hn-summary-state/vestat/alerted)"/> 

	<xsl:template mode="screen" match="/">
		<ui:screen id="03.02.01.27.01" cred="vzcp.hn.view" security-obj-type="hn.vz.vt">
			<ui:tab-bar id="vzhn" current-tab="summary"/>
			<ui:content>
				<ui:block>
					<ui:summary-cols>
						<ui:summary-col>					
							<xsl:call-template name="local:show-server-status"/>																															
							<xsl:call-template name="local:show-server-config"/>			
							<xsl:call-template name="local:show-ves"/>							
						</ui:summary-col>						
						<ui:summary-col>
							<xsl:call-template name="local:show-tasks"/>
							<xsl:call-template name="local:show-disk"/>																								
							<xsl:call-template name="local:show-memory"/>
							<xsl:call-template name="local:show-commits"/>							
						</ui:summary-col>
					</ui:summary-cols>
				</ui:block>
			</ui:content>
		</ui:screen>    
	</xsl:template>
	
	<!-- Post ui:summary-block with Server Status -->
	<xsl:template name="local:show-server-status">			
		<ui:summary-block title="{sw:text('Server Status')}">
			<ui:summary-generic>
				<item label="{sw:text('Status')}" id="hn_summary_status" icon="{sw:if($hn-state = $env-state/running, 'green','grey')}">
					<value>
						<xsl:value-of select="hn:state2info($hn-state)/text-capitalized"/>
					</value>
				</item>
				<xsl:variable name="lic-icon" select="licensem:statuses()[@value = $lic-status-id]/@icon"/>
				<item label="{sw:text('License')}" icon="{$lic-icon}">
					<value>
						<xsl:value-of select="sw:title(sw:lc($lic-status-text))"/>
					</value>
				</item>
				<!-- show group alert if exists -->
				<xsl:variable name="cr-logs" select="cred:check-context('vzcp.log.list','vzcp')"/>
				<item icon-id="hn_summary_alert" label="{sw:text('Alerts')}">
					<xsl:attribute name="icon">
						<xsl:choose>
							<xsl:when test="$hnode-alerts/event_data/type = 3">red</xsl:when>
							<xsl:when test="$hnode-alerts/event_data/type = 2">red</xsl:when>
							<xsl:when test="$hnode-alerts/event_data/type = 1">yellow</xsl:when>
							<xsl:otherwise>green</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
					<xsl:choose>
						<xsl:when test="$cr-logs">
							<value>
								<a href="{$baseurl}/core/alerts?branch=env-home,management&amp;filter_action=force_search&amp;filter_alert-category=server_group_alert"><sw:text>Show</sw:text></a>
								<input id="current-summary-type" type="hidden" value="hn_summary"/>
							</value>																											
						</xsl:when>
						<xsl:otherwise>
							<value>
								<xsl:choose>
									<xsl:when test="$hnode-alerts/event_data/description != ''">
										<sw:text domain="vzagent-vocabulary" select="$hnode-alerts/event_data/description"/>
									</xsl:when>
									<xsl:otherwise>
										<sw:text>No Alerts</sw:text>
									</xsl:otherwise>
								</xsl:choose>
								<input id="current-summary-type" type="hidden" value="hn_summary"/>
							</value>
						</xsl:otherwise>
					</xsl:choose>
				</item>
					
				<item label="{sw:text('Kernel')}" icon="{$kernel-update-state}">
					<value>
						<xsl:value-of select="$kernel-version"/>&#160;
					</value>
				</item>
				<item label="{sw:text('Virtuozzo')}" icon="{$vz-update-state}">
					<value>
						<xsl:value-of select="$arch"/>,&#160;<xsl:value-of select="$vz-full-version"/>
					</value>									
					<xsl:choose>
						<xsl:when test="vt:is-platform-windows($hn-platform)"/>
						<xsl:when test="not(cred:check-hw('vzcp.hn.manage.update',$hn-eid))"/>
						<xsl:when test="$kernel-update-state = 'grey'">
							<action-link href="{$baseurl}/vzdir/maintman/updates/update"><sw:text>Check for update</sw:text></action-link>
						</xsl:when>
						<xsl:when test="$kernel-update-state = 'yellow' or $vz-update-state = 'yellow'">
							<action-link href="{$baseurl}/vzdir/maintman/updates/update"><sw:text>Update</sw:text></action-link>
						</xsl:when>													
					</xsl:choose>
				</item>
				<item label="{sw:text('RAM+Swap Usage')}" icon="{$mem-plus-swap-color}">
					<value>
						<xsl:value-of select="format:percent($mem-plus-swap/fraction)"/>
					</value>									
				</item>
				<item label="{sw:text('Disk Usage')}" icon="{$disk-usage-color}">
					<value>
						<xsl:value-of select="format:percent($disk-usage)"/>
					</value>									
				</item>
				<item label="{sw:text('CPU Usage')}" icon="green">
					<value>
						<xsl:value-of select="format:percent($cpu-load)"/>
					</value>									
				</item>
				
				<xsl:if test="vt:is-platform-linux($hn-platform)">
					<item label="{sw:text('Load Average')}" icon="{$load-average-color}">
						<value>
							<xsl:value-of select="$load-average"/>
						</value>									
					</item>								
				</xsl:if>
			</ui:summary-generic>
		</ui:summary-block>
	</xsl:template>

	<!-- Post ui:summary-block with Server Configuration -->
	<xsl:template name="local:show-server-config">			
	

		<xsl:variable name="vzconfig" select="envm:get-vt-settings($hn-eid)"/>
	
		<ui:summary-block title="{sw:text('Server Configuration')}">
		
			<ui:summary-generic>
				<xsl:variable name="role-name"	select="system:get-node-role($hn-eid)"/>
				<xsl:if test="$role-name != ''">
					<item label="{sw:text('Group Role')}">
						<value>
							<xsl:value-of select="$role-name"/>
						</value>
					</item>
				</xsl:if>
				<xsl:if test="$vzconfig/parameter[id='in_cluster']/value='yes'">
					<item label="{sw:text('In Cluster')}">
						<value>
							<sw:text>Yes</sw:text>
						</value>
					</item>
				</xsl:if>
				<item label="{sw:text('Hostname')}">
					<value>
						<xsl:value-of select="$hn-hostname"/>
					</value>
				</item>
				<item label="{sw:text('IP Address')}" wrap="true">
					<value>
						<xsl:value-of select="$hn-ips"/>
					</value>
				</item>
				<item label="{sw:text('Architecture')}">
					<value>
						<xsl:value-of select="$arch-full"/>
					</value>
				</item>								
				<item label="{sw:text('CPU')}">
					<value>
						<xsl:value-of select="$processor"/>
					</value>
				</item>
				<xsl:if test="$processor-cores &gt; 0">
					<item label="{sw:text('Cores per CPU')}">
						<value>
							<xsl:value-of select="$processor-cores"/>
						</value>
					</item>
				</xsl:if>
				<xsl:if test="$processor-hyperthreads &gt; 0">
					<item label="{sw:text('CPU Hyperthreads')}">
						<value>
							<xsl:value-of select="$processor-hyperthreads"/>
						</value>
					</item>				
				</xsl:if>
				<item label="{sw:text('OS')}">
					<xsl:choose>
						<xsl:when test="$os-name = 'Linux'"><xsl:attribute name="icon">os_lin</xsl:attribute></xsl:when>
						<xsl:when test="$os-name = 'Windows'"><xsl:attribute name="icon">os_win</xsl:attribute></xsl:when>
					</xsl:choose>
					<value>
						<xsl:value-of select="$os-name"/>
					</value>
				</item>								
		
				<item label="{sw:text('Uptime')}">
					<value>
						<xsl:value-of select="$uptime"/>
						<xsl:if test="string($uptime) =''">
							<ui:text-disabled><sw:text>n/a</sw:text></ui:text-disabled>
						</xsl:if>
					</value>
				</item>								
			</ui:summary-generic>																	
		</ui:summary-block>				
	</xsl:template>							
							
	<!-- Post ui:summary-block with VEs -->
	<xsl:template name="local:show-ves">			
		<ui:summary-block title="{sw:text('Containers')}">
			<ui:tally title="{sw:text('Status')}">
				<ui:tally-sum href="/vz/cp/vz/hns/envs/index?tab-force=default&amp;filter_action=force_search&amp;filter_ve-status=">
					<xsl:value-of select="$ve-total"/>
				</ui:tally-sum>
				<ui:tally-row href="/vz/cp/vz/hns/envs/index?tab-force=default&amp;filter_action=force_search&amp;filter_ve-status=ve-status_running" title="{sw:text('Running')}" icon="green">
					<xsl:value-of select="$ve-running"/>
				</ui:tally-row>
				<ui:tally-row href="/vz/cp/vz/hns/envs/index?tab-force=default&amp;filter_action=force_search&amp;filter_ve-status=ve-status_not_running" title="{sw:text('Stopped')}" icon="grey">
					<xsl:value-of select="$ve-stopped"/>
				</ui:tally-row>
				<ui:tally-row href="/vz/cp/vz/hns/envs/index?tab-force=default&amp;filter_action=force_search&amp;filter_ve-status=alert-type-icon_ra" title="{sw:text('Require Attention')}" icon="yellow">
					<xsl:value-of select="$ve-alerted"/>
				</ui:tally-row>
			</ui:tally>
			
			<ui:tally title="{sw:text('Details')}">
				<ui:tally-row title="{sw:text('Number of Containers Allowed by License')}&#160;" wrap="{true()}">
					<xsl:choose>
						<xsl:when test="$ve-lic-limit=''"><sw:text>Unlimited</sw:text></xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$ve-lic-limit"/>
						</xsl:otherwise>
					</xsl:choose>
				</ui:tally-row>
			</ui:tally>
		</ui:summary-block>			
	</xsl:template>							
	
	<!-- Post ui:summary-block with Tasks -->
	<xsl:template name="local:show-tasks">			
		<ui:summary-block title="{sw:text('Tasks')}">
			<ui:summary-tasks/>
		</ui:summary-block>	
	</xsl:template>
	
	<!-- Post ui:summary-block with Commit Information -->
	<xsl:template name="local:show-commits">		
		<ui:summary-block title="{sw:text('Resources Commitments')}">
			<ui:table>
				<col-header align="left"><sw:text>Resource</sw:text></col-header>			
				<col-header align="right"><sw:text>Value</sw:text></col-header>							
				<col-header align="right"><sw:text>Percentage</sw:text></col-header>				
				<row>				
					<col>
						<sw:text>Disk</sw:text>
					</col>
					<xsl:choose>
						<xsl:when test="$hn-disk-commitment/total/value = -1">
							<col align="right">
								<img src="/{$theme}/icons/red_16.gif" style="margin-right: 5px"/>
								<sw:text>Unlimited</sw:text>
							</col>
							<col>
								<sw:text>n/a</sw:text>
							</col>
						</xsl:when>
						<xsl:otherwise>
							<col align="right">
								<xsl:if test="$hn-disk-commitment/total/fraction &gt;= 1">
									<img src="/{$theme}/icons/red_16.gif" style="margin-right: 5px"/>
								</xsl:if>							
								<xsl:value-of select="format:int2bytes($hn-disk-commitment/total/value,'', 'yes', '#,##0.#')"/>
							</col>
							<col align="right">
								<xsl:value-of select="format:percent($hn-disk-commitment/total/fraction)"/>
							</col>		
						</xsl:otherwise>
					</xsl:choose>
				</row>
				<row>
					<col>
						<sw:text>Memory</sw:text>
					</col>
					<xsl:choose>
						<xsl:when test="$hn-mem-commitment/value = -1">
							<col align="right">
								<img src="/{$theme}/icons/red_16.gif" style="margin-right: 5px"/>
								<sw:text>Unlimited</sw:text>
							</col>
							<col>
								<sw:text>n/a</sw:text>
							</col>							
						</xsl:when>
						<xsl:otherwise>						
							<col>
								<xsl:if test="$hn-mem-commitment/fraction &gt;= 1">
									<img src="/{$theme}/icons/red_16.gif" style="margin-right: 5px"/>
								</xsl:if>
								<xsl:value-of select="format:int2bytes($hn-mem-commitment/value,'', 'yes', '#,##0.#')"/>
							</col>
							<col>
								<xsl:value-of select="format:percent($hn-mem-commitment/fraction)"/>
							</col>				
						</xsl:otherwise>						
					</xsl:choose>
				</row>
			</ui:table>
		</ui:summary-block>			
	</xsl:template>
	
	<!-- Post ui:summary-block with Memory Information -->
	<xsl:template name="local:show-memory">	
		<ui:summary-block title="{sw:text('Memory')}">
			<ui:table>
				<col-header align="left"><sw:text>Resource</sw:text></col-header>
				<col-header align="center"><sw:text>Used</sw:text></col-header>
				<col-header align="right"><sw:text>Free</sw:text></col-header>							
				<col-header align="right"><sw:text>Total</sw:text></col-header>	
				<row>
					<col><sw:text>Physical Memory</sw:text></col>
					<col>
						<xsl:variable name="t">
							<sw:text>
								<xsl:with-param name="proc" select="format:percent($mem-percent)"/>
								Memory usage is %{proc}
							</sw:text>									
						</xsl:variable>
						<ui:meter-block before="{format:int2bytes($mem-stat/cur,'', 'yes', '#,##0.#')}" after="{format:percent($mem-percent)}" fraction="{$mem-percent}" tip="{sw:html-escape($t,'escape-all')}"/>			
					</col>
					<col><xsl:value-of select="format:int2bytes($mem-stat/free,'', 'yes', '#,##0.#')"/></col>
					<col><xsl:value-of select="format:int2bytes($mem-stat/total,'', 'yes', '#,##0.#')"/></col>
				</row>
				<row>
					<col><sw:text>Swap Space</sw:text></col>
					<col>
						<xsl:variable name="t">
							<sw:text>
								<xsl:with-param name="proc" select="format:percent($swap-percent)"/>
								Swap space usage is %{proc}
							</sw:text>									
						</xsl:variable>
						<ui:meter-block before="{format:int2bytes($swap-stat/cur,'', 'yes', '#,##0.#')}" after="{format:percent($swap-percent)}" fraction="{$swap-percent}" tip="{sw:html-escape($t,'escape-all')}"/>
					</col>
					<col><xsl:value-of select="format:int2bytes($swap-stat/free,'', 'yes', '#,##0.#')"/></col>
					<col><xsl:value-of select="format:int2bytes($swap-stat/total,'', 'yes', '#,##0.#')"/></col>
				</row>
				<row>
					<col>
						<sw:text>RAM+Swap</sw:text>
					</col>
					<col>
						<xsl:variable name="t">
							<sw:text>
								<xsl:with-param name="proc" select="format:percent($mem-plus-swap/fraction)"/>
								Swap space usage is %{proc}
							</sw:text>									
						</xsl:variable>
						<ui:meter-block before="{format:int2bytes($mem-plus-swap/values/cur,'', 'yes', '#,##0.#')}" after="{format:percent($mem-plus-swap/fraction)}" fraction="{$mem-plus-swap/fraction}" tip="{sw:html-escape($t,'escape-all')}"/>
					</col>
					<col><xsl:value-of select="format:int2bytes($mem-plus-swap/values/free,'', 'yes', '#,##0.#')"/></col>	
					<col><xsl:value-of select="format:int2bytes($mem-plus-swap/values/total,'', 'yes', '#,##0.#')"/></col>
				</row>
			</ui:table>
		</ui:summary-block>			
	</xsl:template>
	
	<!-- Post ui:summary-block with Disk Information -->
	<xsl:template name="local:show-disk">	
		<ui:summary-block title="{sw:text('Disk')}">
			<ui:table>
				<col-header align="left"><sw:text>Mount Point</sw:text></col-header>
				<col-header align="center"><sw:text>Used</sw:text></col-header>
				<col-header align="right"><sw:text>Free</sw:text></col-header>							
				<col-header align="right"><sw:text>Total</sw:text></col-header>
				<xsl:for-each select="$disk-stat">
					<xsl:variable name="mount-point" select="name"/>
					<row>
						<col>
							<xsl:value-of select="$mount-point"/>
						</col>
						<col>
							<xsl:variable name="t">
								<sw:text>
									<xsl:with-param name="proc" select="format:percent(fraction)"/>
									Disk space usage is %{proc}
								</sw:text>									
							</xsl:variable>
							<ui:meter-block before="{format:int2bytes(values/cur,'', 'yes', '#,##0.#')}" after="{format:percent(fraction)}" fraction="{fraction}" tip="{sw:html-escape($t,'escape-all')}"/>
						</col>
						<col><xsl:value-of select="format:int2bytes(values/free,'', 'yes', '#,##0.#')"/></col>
						<col><xsl:value-of select="format:int2bytes(values/total,'', 'yes', '#,##0.#')"/></col>
					</row>
				</xsl:for-each>
			</ui:table>						
		</ui:summary-block>
	</xsl:template>

	<func:function name="local:get-update-status">
		<xsl:param name="updates"/>
		<xsl:param name="type"/>
		<func:result>
			<xsl:choose>
				<xsl:when test="not($updates) or not($updates/major)">
					<!-- updates not checked -->
					<xsl:value-of select="'grey'"/>
				</xsl:when>
				<xsl:when test="($type='kernel' and not($updates/latest-kernel)) 
							or ($type='virtuozzo' and ($updates/major+$updates/minor)=0)">
					<!-- all up to date -->
					<xsl:value-of select="'green'"/>
				</xsl:when>
				<xsl:otherwise>
					<!-- updates present and available -->
					<xsl:value-of select="'yellow'"/>
				</xsl:otherwise>
			</xsl:choose>
		</func:result>
	</func:function>

</xsl:stylesheet>
