<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->
<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl func wiz cred check local voc date dynamic updateui"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:dynamic="http://www.swsoft.com/xsl/cp/dynamic"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:check="http://www.swsoft.com/xsl/cp/check"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:update="http://www.swsoft.com/xsl/cp/update"
	xmlns:voc="http://www.swsoft.com/xsl/cp/voc"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:updateui="http://www.swsoft.com/xsl/cp/update-screen"
	xmlns:date="http://exslt.org/dates-and-times"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:hwm="http://www.swsoft.com/xsl/cp/hwm"
	xmlns:request="http://www.swsoft.com/xsl/cp/request"
	xmlns:set="http://exslt.org/sets"
	xmlns:nbh="http://www.swsoft.com/xsl/cp/nbh"
>

	<!-- check permissions to show this page -->
	<xsl:param name="access-denied"
		select="not(cred:check-hw('vzcp.hn.manage.config.network',sw:hn-eid()))"/>

	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
		<ui:screen id="03.02.01.33.01">
			<ui:properties>
				<ui:refresh-type>none</ui:refresh-type>
				<ui:description mandatory="true">
					<sw:text>Configure the Virtuozzo name-based hosting service settings.</sw:text>
				</ui:description>
				<ui:form-get/>
			</ui:properties>

			<ui:content>
				<xsl:call-template name="local:add-services"/>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<xsl:template name="local:add-services">
		<xsl:variable name="raw-id" select="sw:param('id')"/>
		<xsl:variable name="id" select="sw:if(string($raw-id)='', '', sw:base64-decode($raw-id))"/>

		<xsl:variable name="service" select="local:get-service($id)"/>

		<ui:hidden id="id" name="id" value="{$id}"/>

		<xsl:variable name="ips" select="local:list-ips($service)"/>

		<ui:block>
			<ui:rows title="{sw:text('Service Status')}">
				<ui:row>
					<ui:cell-check id="enabled" name="enabled" align="left"
						checked="{not($service/disabled='1')}" close="false"/>
					<ui:cell-label label-for="enabled" open="false">
						<sw:text>Enable this service.</sw:text>
					</ui:cell-label>
				</ui:row>
			</ui:rows>
			<ui:rows title="{sw:text('Service Settings')}">
				<xsl:for-each select="$service">
					<ui:row>
						<ui:cell-label label-for="name">
							<sw:text>Name</sw:text>
						</ui:cell-label>
						<ui:cell-input id="name" name="name" align="left" value="{id}" width="16"
							required="true"/>
					</ui:row>
					<ui:row>
						<ui:cell-label label-for="protocol" onselect="checkFields()">
							<sw:text>Protocol</sw:text>
						</ui:cell-label>
						<ui:cell-list id="protocol" name="protocol" align="left" value="{string(protocol)}">
							<xsl:call-template name="local:choose-protocol"/>
						</ui:cell-list>
					</ui:row>
					<ui:row>
						<ui:cell-label label-for="external_ip">
							<sw:text>IP Address</sw:text>
						</ui:cell-label>
						<ui:cell-list id="external_ip" name="external_ip" align="left"
							value="{string(external_ip)}" disabled="{sw:if(protocol='SMTP', 'true', 'false')}">
							<xsl:call-template name="local:choose-ip">
								<xsl:with-param name="ip" select="string(external_ip)"/>
								<xsl:with-param name="ips" select="$ips"/>
							</xsl:call-template>
						</ui:cell-list>
					</ui:row>
					<ui:row>
						<ui:cell-label label-for="port">
							<sw:text>Port</sw:text>
						</ui:cell-label>
						<ui:cell-input id="port" name="port" align="left" value="{port}" width="5"
							required="true" disabled="{sw:if(protocol='SMTP', 'true', 'false')}"/>
					</ui:row>
				</xsl:for-each>
			</ui:rows>

			<xsl:if test="$ips/invalid-ip">
				<ui:rows>
					<ui:row>
						<ui:cell>
							<ui:text-disabled>
								<sw:text>
									* - The IP address is present in the name-based hosting configuration file but is not available on the Hardware Node.
								</sw:text>
							</ui:text-disabled>
						</ui:cell>
					</ui:row>
				</ui:rows>
			</xsl:if>

			<ui:hidden id="service" name="service" value="1"/>

			<ui:buttons>
				<ui:button type="ok" sandclock="true" name="service" tip="update_config"
					submit-href="/vz/cp/vzdir/infrman/hns/nbh/control">
					<sw:text>Submit</sw:text>
				</ui:button>
				<ui:button type="cancel" tip="discard_config_change">
					<sw:text>Cancel</sw:text>
				</ui:button>
			</ui:buttons>
			
			<ui:raw>
				<script>
					var proto = document.getElementById('protocol');
					addEventToObject(proto,'onchange',checkFields);
					addEventToObject(proto,'onfocus',checkFields);

					function checkFields() {
						var proto = document.getElementById('protocol');
						if (proto.value == 'SMTP') {
							document.getElementById('external_ip').disabled=true;
							document.getElementById('port').disabled=true;
						} else {
							document.getElementById('external_ip').disabled=false;
							document.getElementById('port').disabled=false;
						}
					}
				</script>
			</ui:raw>
		</ui:block>
	</xsl:template>


	<func:function name="local:get-service">
		<xsl:param name="id"/>

		<xsl:variable name="saved-data" select="sw:sesget('nbh-control-data')/service"/>
		<func:result
			select="sw:if(error:has-errors() and $saved-data, $saved-data, nbh:get-services()[string(id)=$id])"
		/>
	</func:function>

	<xsl:template name="local:choose-ip">
		<xsl:param name="ip"/>
		<xsl:param name="ips"/>

		<xsl:for-each select="$ips/*[name()='ip' or .=$ip]">
			<xsl:sort select="string(.)"/>
			<ui:list-item id="{.}">
				<xsl:attribute name="title">
					<xsl:choose>
						<xsl:when test="name()='invalid-ip'">
							<xsl:value-of select="."/>*
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="."/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</ui:list-item>
		</xsl:for-each>
	</xsl:template>

	<xsl:template name="local:choose-protocol">
		<xsl:variable name="proto-ref">
			<p>FTP</p>
			<p>HTTP</p>
			<p>POP3</p>
			<p>SMTP</p>
		</xsl:variable>

		<xsl:for-each select="exsl:node-set($proto-ref)/p">
			<xsl:sort select="string(.)"/>
			<ui:list-item id="{.}">
				<xsl:attribute name="title">
					<xsl:value-of select="."/>
				</xsl:attribute>
			</ui:list-item>
		</xsl:for-each>
	</xsl:template>

	<func:function name="local:list-ips">
		<xsl:param name="services"/>

		<xsl:variable name="hw-ids"
			select="hwm:get-network(sw:hn-eid())/interface[not(name='lo')]/ipaddress"/>

		<xsl:variable name="ip-rtf">
			<xsl:for-each select="$services/external_ip|exsl:node-set($hw-ids)">
				<ip><xsl:value-of select="."/></ip>
			</xsl:for-each>
		</xsl:variable>

		<xsl:variable name="res-rtf">
			<xsl:for-each select="set:distinct(exsl:node-set($ip-rtf)/ip)">
				<xsl:variable name="ip" select="."/>
				<xsl:choose>
					<xsl:when test="string($ip)=''"/>
					<xsl:when test="$hw-ids=$ip">
						<ip>
							<xsl:value-of select="$ip"/>
						</ip>
					</xsl:when>
					<xsl:otherwise>
						<invalid-ip>
							<xsl:value-of select="$ip"/>
						</invalid-ip>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
		</xsl:variable>

		<func:result select="exsl:node-set($res-rtf)"/>
	</func:function>

	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/vza/nbh.xsl"/>
	<sw:include href="/lib/vza/hwm.xsl"/>
</xsl:stylesheet>
