<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->
<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl func wiz cred check local voc date dynamic updateui"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:dynamic="http://www.swsoft.com/xsl/cp/dynamic"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:check="http://www.swsoft.com/xsl/cp/check"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:update="http://www.swsoft.com/xsl/cp/update"
	xmlns:voc="http://www.swsoft.com/xsl/cp/voc"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:updateui="http://www.swsoft.com/xsl/cp/update-screen"
	xmlns:date="http://exslt.org/dates-and-times"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:nbh="http://www.swsoft.com/xsl/cp/nbh"
>

	<!-- check permissions to show this page -->
	<xsl:param name="access-denied"
		select="not(cred:check-hw('vzcp.hn.manage.config.network',sw:hn-eid()))"/>
	
	<xsl:variable name="status" select="nbh:get-status()"/>
	<xsl:variable name="enabled" select="string($status)='1'"/>
	<xsl:variable name="error" select="$status[name()='error']"/>

	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
		<ui:screen id="03.02.01.33.00">
			<ui:tab-bar id="vzhn" current-tab="network" current-subtab="nbh"/>
			<ui:properties>
				<ui:description mandatory="true" width="max">
					<sw:text>On this screen you can configure Virtuozzo name-based hosting (NBH).</sw:text>
					<br/>
					<sw:text>Virtuozzo provides the name-based virtual hosting support for the HTTP, FTP, POP3, and SMTP protocols.</sw:text>
				</ui:description>
				<ui:form-get/>
			</ui:properties>
			
			<xsl:if test="not($error)">
				<xsl:call-template name="local:add-actions"/>
			</xsl:if>
			
			<ui:content>
				<xsl:choose>
					<xsl:when test="$error">
						<xsl:call-template name="local:add-oper-problem"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="local:add-status"/>
						<xsl:call-template name="local:add-services"/>
					</xsl:otherwise>
				</xsl:choose>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<xsl:template name="local:add-status">
		<ui:block mode="view" width="max">
			<ui:rows title="{sw:text('Status')}">
				<ui:row>
					<ui:cell>
						<xsl:choose>
							<xsl:when test="$error">
								<xsl:if test="error:put(sw:text('Cannot get the name-based hosting support status.'), $error/message)"/>
								<sw:text> Name-based hosting is <b>NOT AVAILABLE</b>. </sw:text>
							</xsl:when>
							<xsl:when test="$enabled">
								<sw:text> Name-based hosting is <b>ENABLED</b>. </sw:text>
							</xsl:when>
							<xsl:otherwise>
								<sw:text> Name-based hosting is <b>DISABLED</b>. </sw:text>
							</xsl:otherwise>
						</xsl:choose>

					</ui:cell>
				</ui:row>
			</ui:rows>
		</ui:block>
	</xsl:template>

	<xsl:template name="local:add-actions">
		<sw:die>
			Move ui:button from ui:toolbar-custom to toolbars.xml   
			Ask baza@
		</sw:die>
		<ui:toolbar-custom>
			<ui:button submit-href="{$baseurl}/vzdir/infrman/hns/nbh/control?enable=1" icon="enable" name="enable" tip="enable_nbh"
				sandclock="true" disabled="{$enabled or $error}">
				<sw:text>Enable</sw:text>
			</ui:button>
			<ui:button submit-href="{$baseurl}/vzdir/infrman/hns/nbh/control?disable=1" icon="disable" name="disable" tip="disable_nbh"
				sandclock="true" disabled="{not($enabled) or $error}">
				<sw:text>Disable</sw:text>
			</ui:button>
		</ui:toolbar-custom>
	</xsl:template>

	<xsl:template name="local:add-services">
		<ui:block width="max">
			<ui:browse title="{sw:text('Name-Based Hosting Services')}">
				<ui:filter>
					<xsl:copy-of select="local:create-services-browse-filter()"/>
				</ui:filter>
				<ui:browse-empty-msg>
					<sw:text>No name-based hosting services have been configured for this Hardware
					Node.</sw:text>
				</ui:browse-empty-msg>

				<ui:browse-js-many>
					<ui:warn>
						<sw:text> To perform any action on the name-based hosting services in this list, you have to select at least one. </sw:text>
					</ui:warn>
				</ui:browse-js-many>

				<ui:browse-buttons>
					<ui:button tip="add_nbh_service" icon="maintenance" name="add_service"
						new-obj-title="{sw:text('Service')}"					
						submit-href="{$baseurl}/vzdir/infrman/hns/nbh/add-service" require-items="false">
						<sw:text>New Service</sw:text>
					</ui:button>				
					<ui:button tip="enable_nbh_service" icon="service_start"
						script="if (!atLeastOne()) return false;" name="enable_service"
						submit-href="{$baseurl}/vzdir/infrman/hns/nbh/control?enable_service=1">
						<sw:text>Enable</sw:text>
					</ui:button>
					<ui:button tip="disable_nbh_service" icon="service_stop"
						script="if (!atLeastOne()) return false;" name="disable_service"
						submit-href="{$baseurl}/vzdir/infrman/hns/nbh/control?disable_service=1">
						<sw:text>Disable</sw:text>
					</ui:button>
					<ui:button tip="remove_nbh_service" icon="delete"
						script="if (!atLeastOne()) return false;" name="remove_service"
						submit-href="{$baseurl}/vzdir/infrman/hns/nbh/control?remove_nbh_service=1">
						<sw:text>Delete</sw:text>
					</ui:button>
				</ui:browse-buttons>
			</ui:browse>
		</ui:block>
	</xsl:template>
	
	<xsl:template name="local:add-oper-problem">
		<ui:block width="max">
			<ui:operation-problem>
				<ui:type>vza-error</ui:type>
				<ui:descr>
					<sw:text>Name-based hosting cannot be managed.</sw:text>
				</ui:descr>
				<ui:vza-error>
					<xsl:copy-of select="$error/*"/>
				</ui:vza-error>
				<ui:reason>
					<sw:text>Error getting the name-based hosting support status.</sw:text>
				</ui:reason>
			</ui:operation-problem>
		</ui:block>
	</xsl:template>

	<func:function name="local:create-services-browse-filter">
		<xsl:variable name="img-on">
			<xsl:choose>
				<xsl:when test="$enabled">
					<img src="/{$theme}/icons/check_green.gif" width="16" height="16" border="0"/>
				</xsl:when>
				<xsl:otherwise>
					<img src="/{$theme}/icons/check_grey.gif" width="16" height="16" border="0"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="img-off">
			<xsl:choose>
				<xsl:when test="$enabled">
					<img src="/{$theme}/icons/del_red.gif" width="16" height="16" border="0"/>
				</xsl:when>
				<xsl:otherwise>
					<img src="/{$theme}/icons/del_grey.gif" width="16" height="16" border="0"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<xsl:variable name="services" select="nbh:get-services()"/>

		<func:result>
			<xsl:choose>
				<xsl:when test="$services[name()='error']">
					<xsl:if test="error:put(sw:text('Failed to list the name-based hosting services.'), $services[name()='error']/message)"/>					
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="browse:fill-filter">
						<xsl:with-param name="filter" select="local:init-services-browse-filter()"/>
						<xsl:with-param name="rows">
							<ui:browse-rows>
								<xsl:for-each select="$services">
									<xsl:sort select="protocol"/>
									<ui:row>
										<xsl:copy-of select="id|protocol"/>
		
										<!-- handle ip ant port -->
										<xsl:choose>
											<xsl:when test="external_ip">
												<xsl:copy-of select="external_ip"/>
											</xsl:when>
											<xsl:otherwise>
												<external_ip/>
											</xsl:otherwise>
										</xsl:choose>
										<xsl:choose>
											<xsl:when test="port">
												<xsl:copy-of select="port"/>
											</xsl:when>
											<xsl:otherwise>
												<port/>
											</xsl:otherwise>
										</xsl:choose>
		
										<!-- handle status icon -->
										<enabled>
											<ui:raw>
												<xsl:copy-of select="sw:if(disabled='1', $img-off, $img-on)"/>
											</ui:raw>
										</enabled>
									</ui:row>
								</xsl:for-each>
							</ui:browse-rows>
						</xsl:with-param>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</func:result>
	</func:function>

	<func:function name="local:init-services-browse-filter">
		<xsl:variable name="filter_init">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="nbh-services" url="/vzdir/infrman/hns/nbh/config"
						item-url="/vzdir/infrman/hns/nbh/config-service"/>
					<ui:cols>
						<ui:column id="id" data-type="str" sorting="no" title="{sw:text('Name')}" width="40%"
							for-select="yes" for-url="yes" show-url="yes"/>
						<ui:column id="protocol" title="{sw:text('Protocol')}" sorting="no" width="20%"
							align="center"/>
						<ui:column id="external_ip" title="{sw:text('IP Address')}" sorting="no" width="20%"/>
						<ui:column id="port" title="{sw:text('Port')}" width="10%" sorting="no" align="right"/>
						<ui:column id="enabled" title="{sw:text('Enabled')}" width="10%" sorting="no"
							align="center" apply-templates="yes"/>
					</ui:cols>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>
		<func:result select="exsl:node-set($filter_init)"/>
	</func:function>

	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/core/browse-filter-raw.xsl" />
	<sw:include href="/lib/vza/nbh.xsl"/>
</xsl:stylesheet>
