<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl sw func local cred nbh html"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:nbh="http://www.swsoft.com/xsl/cp/nbh"
	xmlns:request="http://www.swsoft.com/xsl/cp/request"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"	
	xmlns:func="http://exslt.org/functions"
	xmlns:check="http://www.swsoft.com/xsl/cp/check"
	xmlns:voc="http://www.swsoft.com/xsl/cp/voc"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:html="http://www.swsoft.com/xsl/cp/html"
>
	<sw:include href="/lib/core/check-funcs.xsl"/>
	<sw:include href="/layout/lib/html.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>

	<xsl:output method="xml"/>

	<!-- check permissions to this page -->
	<xsl:param name="access-denied"
		select="not(cred:check-hw('vzcp.hn.manage.config.network', sw:hn-eid()))"/>

	<xsl:template match="/">
		<xsl:choose>
			<!-- Enable NBH -->
			<xsl:when test="sw:param('enable')='1'">
				<xsl:call-template name="local:action">
					<xsl:with-param name="command" select="'start'"/>
					<xsl:with-param name="msg-ok"
						select="sw:text('Name-based hosting has been successfully enabled.')"/>
					<xsl:with-param name="msg-error" select="sw:text('Failed to enable name-based hosting.')"
					/>
				</xsl:call-template>
			</xsl:when>

			<!-- Disable NBH -->
			<xsl:when test="sw:param('disable')='1'">
				<xsl:call-template name="local:action">
					<xsl:with-param name="command" select="'stop'"/>
					<xsl:with-param name="msg-ok"
						select="sw:text('Name-based hosting has been successfully disabled.')"/>
					<xsl:with-param name="msg-error" select="sw:text('Failed to disable name-based hosting.')"
					/>
				</xsl:call-template>
			</xsl:when>

			<xsl:when test="sw:param('enable_service')='1'">
				<xsl:variable name="command" select="local:get-services-status-command(true())"/>
				<xsl:call-template name="local:action">
					<xsl:with-param name="command" select="$command"/>
					<xsl:with-param name="msg-ok"
						select="sw:text('The name-based hosting services have been successfully enabled.')"/>
					<xsl:with-param name="msg-error"
						select="sw:text('Failed to enable the name-based hosting services.')"/>
				</xsl:call-template>
				<ui:redirect location="/vz/cp/vzdir/infrman/hns/nbh/config"/>
			</xsl:when>

			<xsl:when test="sw:param('disable_service')='1'">
				<xsl:variable name="command" select="local:get-services-status-command(false())"/>
				<xsl:call-template name="local:action">
					<xsl:with-param name="command" select="$command"/>
					<xsl:with-param name="msg-ok"
						select="sw:text('The name-based hosting services have been successfully disabled.')"/>
					<xsl:with-param name="msg-error"
						select="sw:text('Failed to disable the name-based hosting services.')"/>
				</xsl:call-template>
				<ui:redirect location="/vz/cp/vzdir/infrman/hns/nbh/config"/>
			</xsl:when>

			<xsl:when test="sw:param('remove_service')='1'">
				<xsl:variable name="command" select="local:get-services-remove-command()"/>
				<xsl:call-template name="local:action">
					<xsl:with-param name="command" select="$command"/>
					<xsl:with-param name="msg-ok"
						select="sw:text('The name-based hosting services have been successfully removed.')"/>
					<xsl:with-param name="msg-error"
						select="sw:text('Failed to remove the name-based hosting services.')"/>
				</xsl:call-template>
				<ui:redirect location="/vz/cp/vzdir/infrman/hns/nbh/config"/>
			</xsl:when>

			<xsl:when test="sw:param('service')='1'">
				<xsl:variable name="command" select="local:get-service-command()"/>
				<xsl:variable name="services" select="nbh:get-services()"/>

				<xsl:variable name="old-id" select="($command/service/id)[1]"/>
				<xsl:variable name="ip" select="string($command/service/external_ip)"/>

				<!-- check port -->
				<xsl:for-each select="$command/service/port">
					<xsl:call-template name="local:check-service-ip-port">
						<xsl:with-param name="port" select="string(number(.))"/>
						<xsl:with-param name="ip" select="$ip"/>
						<xsl:with-param name="services" select="$services[id!=$old-id]"/>
					</xsl:call-template>
				</xsl:for-each>

				<!-- check name (as unique and valid file name) -->
				<xsl:for-each select="$command[name()='set']/service/id">
					<xsl:call-template name="local:check-service-name">
						<xsl:with-param name="name" select="string(.)"/>
						<xsl:with-param name="services" select="$services[id!=$old-id]"/>
					</xsl:call-template>
				</xsl:for-each>

				<xsl:choose>
					<xsl:when test="error:has-errors()">
						<xsl:if test="sw:sesput('nbh-control-data', $command[name()='set']/service)"/>
						<ui:redirect
							location="/vz/cp/vzdir/infrman/hns/nbh/config-service?id={sw:base64-encode($old-id)}"
						/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="local:action">
							<xsl:with-param name="command" select="$command"/>
							<xsl:with-param name="msg-ok"
								select="sw:text('The name-based hosting service configuration has been successfully set.')"/>
							<xsl:with-param name="msg-error"
								select="sw:text('Failed to set the name-based hosting service configuration.')"/>
						</xsl:call-template>
						<ui:redirect location="/vz/cp/vzdir/infrman/hns/nbh/config"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>

			<!-- add new service -->
			<xsl:when test="sw:param('add_service')='1'">
				<xsl:variable name="command" select="local:get-add-service-command()"/>
				<xsl:variable name="services" select="nbh:get-services()"/>

				<xsl:variable name="ip" select="string($command/service/external_ip)"/>

				<!-- check port -->
				<xsl:for-each select="$command/service/port">
					<xsl:call-template name="local:check-service-ip-port">
						<xsl:with-param name="port" select="string(number(.))"/>
						<xsl:with-param name="ip" select="$ip"/>
						<xsl:with-param name="services" select="$services"/>
					</xsl:call-template>
				</xsl:for-each>

				<!-- check name (as unique and valid file name) -->
				<xsl:for-each select="$command/service/id">
					<xsl:call-template name="local:check-service-name">
						<xsl:with-param name="name" select="string(.)"/>
						<xsl:with-param name="services" select="$services"/>
					</xsl:call-template>
				</xsl:for-each>

				<xsl:choose>
					<xsl:when test="error:has-errors()">
						<xsl:if test="sw:sesput('nbh-control-data', $command/service)"/>
						<ui:redirect location="/vz/cp/vzdir/infrman/hns/nbh/add-service"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="local:action">
							<xsl:with-param name="command" select="$command"/>
							<xsl:with-param name="msg-ok"
								select="sw:text('The name-based hosting service has been successfully created.')"/>
							<xsl:with-param name="msg-error"
								select="sw:text('Failed to create the name-based hosting service.')"/>
						</xsl:call-template>
						<ui:redirect location="/vz/cp/vzdir/infrman/hns/nbh/config"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>


			<!-- Unknown post -->
			<xsl:otherwise>
				<ui:redirect location="/vz/cp/vzdir/infrman/hns/nbh/config"/>
			</xsl:otherwise>

		</xsl:choose>
	</xsl:template>

	<xsl:template name="local:check-service-name">
		<xsl:param name="name"/>
		<xsl:param name="services"/>
		
		<xsl:variable name="name-pattern" select="voc:get-pattern(
			env:make-platform-ref(sw:hn-eid()), 'pattern.vesampleconfig'
		)"/>
		<xsl:variable name="name-error"
			select="check:get-voc-pattern-match-error(env:make-platform-ref(sw:hn-eid()), $name, 'pattern.vesampleconfig')"/>

		<xsl:choose>
			<!-- check name presence -->
			<xsl:when test="$name-error and $name-error[name()='short']">
				<xsl:value-of select="error:put(sw:text('You should specify the service name.'),'','name')"
				/>
			</xsl:when>
			<!-- check name for max.length -->
			<xsl:when test="$name-error and $name-error[name()='long']">
				<xsl:variable name="err-msg">
					<sw:text>
						<xsl:with-param name="max" select="$name-pattern/max"
						/>
						A service name cannot be longer than %max characters.
					</sw:text>
				</xsl:variable>
				<xsl:value-of select="error:put($err-msg,'','name')"/>
			</xsl:when>
			<!-- check name for valid chars -->
			<xsl:when test="$name-error">
				<xsl:value-of
					select="error:put(sw:text('The specifed service name contains invalid characters.'),'','name')"
				/>
			</xsl:when>
			<!-- check name for uniq -->
			<xsl:when test="$services[id=$name]">
				<xsl:if
					test="error:put(sw:text('The submitted name is already used for another service. Please specify another name.'),'','name')"
				/>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="local:check-service-ip-port">
		<xsl:param name="port"/>
		<xsl:param name="ip"/>
		<xsl:param name="services"/>

		<xsl:if test="$port='NaN' or $port &lt; 0 or $port &gt; 65535">
			<xsl:if
				test="error:put(sw:text('A port number must be an integer number ranging from 0 to 65535.'), '', 'port')"
			/>
		</xsl:if>
		<xsl:if test="$port!='NaN' and $services[external_ip=$ip and port=$port]">
			<xsl:variable name="details">
				<sw:text>
					<xsl:with-param name="id" select="$services[port=$port]/id"/>
					<xsl:with-param name="port" select="$port"
					/>
					Port %port is assigned to NBH service ''%id''. Please choose another IP address or port number.
				</sw:text>
			</xsl:variable>
			<xsl:if test="error:put(sw:text('The port is already in use.'), $details, 'port')"/>
		</xsl:if>
	</xsl:template>


	<func:function name="local:get-services-remove-command">
		<xsl:variable name="old" select="nbh:get-services()"/>
		<xsl:variable name="ids" select="sw:param('id')"/>

		<xsl:variable name="res">
			<del>
				<xsl:for-each select="$ids">
					<service>
						<id>
							<xsl:value-of select="."/>
						</id>
					</service>
				</xsl:for-each>
			</del>
			<restart/>
		</xsl:variable>
		<func:result select="exsl:node-set($res)/*"/>
	</func:function>

	<func:function name="local:get-services-status-command">
		<xsl:param name="enabled"/>

		<xsl:variable name="new-status" select="sw:if($enabled, 0, 1)"/>

		<xsl:variable name="old" select="nbh:get-services()"/>
		<xsl:variable name="ids" select="sw:param('id')"/>

		<xsl:variable name="res">
			<set>
				<xsl:for-each select="$old">
					<xsl:sort select="protocol"/>
					<service>
						<xsl:copy-of select="id|protocol"/>
						<disabled>
							<xsl:value-of select="sw:if(string(id)=$ids, $new-status, disabled)"/>
						</disabled>
						<xsl:if test="protocol!='SMTP'">
							<xsl:copy-of select="external_ip|port"/>
						</xsl:if>
					</service>
				</xsl:for-each>
			</set>
			<restart/>
		</xsl:variable>
		<func:result select="exsl:node-set($res)/*"/>
	</func:function>

	<func:function name="local:get-service-command">
		<xsl:variable name="id" select="sw:param('id')"/>

		<xsl:variable name="res">
			<del>
				<service>
					<id>
						<xsl:value-of select="$id"/>
					</id>
				</service>
			</del>
			<xsl:copy-of select="local:get-service()"/>
			<restart/>

		</xsl:variable>
		<func:result select="exsl:node-set($res)/*"/>
	</func:function>

	<func:function name="local:get-add-service-command">

		<xsl:variable name="res">
			<xsl:copy-of select="local:get-service()"/>
			<restart/>
		</xsl:variable>
		<func:result select="exsl:node-set($res)/*"/>
	</func:function>

	<func:function name="local:get-service">
		<xsl:variable name="name" select="sw:param('name')"/>
		<xsl:variable name="protocol" select="sw:param('protocol')"/>
		<xsl:variable name="enabled" select="sw:param('enabled')"/>

		<xsl:variable name="res">
			<set>
				<service>
					<id>
						<xsl:value-of select="$name"/>
					</id>
					<disabled>
						<xsl:value-of select="sw:if(not(string($enabled)=''), '0', '1')"/>
					</disabled>
					<protocol>
						<xsl:value-of select="$protocol"/>
					</protocol>
					<xsl:if test="$protocol!='SMTP'">
						<external_ip>
							<xsl:value-of select="sw:param('external_ip')"/>
						</external_ip>
						<port>
							<xsl:value-of select="sw:param('port')"/>
						</port>
					</xsl:if>
				</service>
			</set>
		</xsl:variable>
		<func:result select="exsl:node-set($res)/*"/>
	</func:function>


	<xsl:template name="local:action">
		<xsl:param name="command"/>
		<xsl:param name="msg-ok"/>
		<xsl:param name="msg-error"/>

		<xsl:choose>
			<xsl:when test="error:has-errors()">
				<ui:redirect location="/vz/cp/vzdir/infrman/hns/nbh/config"/>
			</xsl:when>
			<xsl:when test="not($command)">
				<xsl:if test="error:is-empty()">
					<xsl:if test="sw:sesput('msg', $msg-ok)"/>
				</xsl:if>
				<ui:redirect location="/vz/cp/vzdir/infrman/hns/nbh/config"/>
			</xsl:when>
			<xsl:when test="exsl:object-type($command)='string'">
				<xsl:call-template name="local:action">
					<xsl:with-param name="command" select="local:string-to-node-set($command)"/>
					<xsl:with-param name="msg-ok" select="$msg-ok"/>
					<xsl:with-param name="msg-error" select="$msg-error"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="res" select="nbh:command(sw:hn-eid(), $command[1])"/>

				<xsl:variable name="errors" select="$res[name()='error']"/>
				<xsl:if test="$errors">
					<xsl:variable name="error">
						<xsl:for-each select="$errors">
							<sw:text>
								<xsl:with-param name="code" select="code"
								/>
								VZAgent returned error #%{code}.
							</sw:text>
							<br/>
							<xsl:value-of select="html:plain2html(sw:if(message, message, .))"
								disable-output-escaping="yes"/>
						</xsl:for-each>
					</xsl:variable>
					<xsl:if test="error:put($msg-error, $error, '')"/>
				</xsl:if>

				<xsl:call-template name="local:action">
					<xsl:with-param name="command" select="$command[position() &gt; 1]"/>
					<xsl:with-param name="msg-ok" select="$msg-ok"/>
					<xsl:with-param name="msg-error" select="$msg-error"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<func:function name="local:string-to-node-set">
		<xsl:param name="value"/>
		<xsl:variable name="rtf">
			<xsl:element name="{$value}"/>
		</xsl:variable>
		<func:result select="exsl:node-set($rtf)/*"/>
	</func:function>

	<!-- credentials -->
	<sw:include href="/lib/vza/nbh.xsl"/>
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>

	<sw:include href="/lib/globals.xsl"/>
	<sw:include href="/lib/common.xsl"/>
</xsl:stylesheet>
