<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
	extension-element-prefixes="sw cred swa-mailer envm" 
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred" 
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:swa-mailer="http://www.swsoft.com/xsl/cp/swa-mailer"
	xmlns:envm="http://www.swsoft.com/xsl/cp/envm"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
>

	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/swa/envm.xsl"/>
	<sw:include href="/lib/swa/swa-mailer.xsl"/>

	<xsl:param name="access-denied" 
		select="not(cred:check-hw('vzcp.hn.manage.config.email',sw:hn-eid()))"/>

	<xsl:template mode="screen" match="/">
		<xsl:variable name="hn-env" select="env:eid2info(sw:hn-eid())"/>	
		<xsl:variable name="email-relay" select="swa-mailer:get-relay($hn-env/eid)"/>
		<xsl:variable name="vzconfig" select="envm:get-vt-settings($hn-env/eid)"/>
		
		<ui:screen id="03.02.01.32.22" icon="network_config">
			<ui:properties>
				<ui:form-get/>
				<ui:description mandatory="yes">
				 <sw:text>
				  On this screen you can view and change the IP address of the email relay server on the Hardware Node.
				  <br/>This server is used to deliver notifications and other service mail, including password reminders.
				 </sw:text>
				</ui:description>      
			</ui:properties>
			
			<ui:tab-bar id="vzhn" current-tab="network" current-subtab="proxy"/>
			<ui:content>
				<ui:block>
					
					<ui:rows title="{sw:text('Email Proxy')}">
						<ui:row>
							<ui:cell-label>
								<sw:text>SMTP Relay Server IP Address</sw:text>
							</ui:cell-label>
							<ui:cell-text value="{$email-relay/relay}">
								<xsl:choose>
									<xsl:when test="not($email-relay/relay != '')">
										<sw:text>Not specified</sw:text>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="$email-relay/relay"/>
									</xsl:otherwise>
								</xsl:choose>
							</ui:cell-text>
						</ui:row>
					</ui:rows>
	
					<xsl:if test="$hn-env/linux 
						and cred:check-hw('vzcp.hn.manage.config.network',sw:hn-eid())">
						<ui:rows title="{sw:text('Proxy Settings')}">
							<ui:row>
								<ui:cell-label>
									<sw:text>Proxy Server</sw:text>
								</ui:cell-label>
								<ui:cell-text>
									<xsl:choose>
										<xsl:when test="not($vzconfig/parameter[id='http_proxy']/value != '')">
											<sw:text>Not specified</sw:text>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="$vzconfig/parameter[id='http_proxy']/value"/>
										</xsl:otherwise>
									</xsl:choose>
								</ui:cell-text>
							</ui:row>
						</ui:rows>
					</xsl:if>
					
					<ui:buttons>
						<ui:button tip="configure_vzhn_network_proxy" sandclock="false" icon="preferences" type="ok"
							submit-href="{$baseurl}/vzdir/infrman/hns/proxy/config"
						>
							<sw:text>Configure</sw:text>
						</ui:button>
					</ui:buttons>
					
				</ui:block>
				
			</ui:content>
		</ui:screen>
	</xsl:template>

	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/screen.xsl"/>
</xsl:stylesheet>
