<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred"
	xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsi				="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:ui				="http://www.swsoft.com/xsl/cp/ui"
	xmlns:sw				="http://www.swsoft.com/xsl/cp"
	xmlns:browse		="http://www.swsoft.com/xsl/cp/browse"
	xmlns:cred			="http://www.swsoft.com/xsl/cp/cred"
	xmlns:exsl			="http://exslt.org/common"
	xmlns:redirect	="http://www.swsoft.com/xsl/cp/redirect"
>

	<sw:include href="/lib/vz/vzhn-redirects.xsl"/>

	<xsl:variable name="hn-eid" select="sw:hn-eid()"/>
	<xsl:param name="access-denied"
		select="not(cred:check-hw('vzcp.hn.manage.config.network',$hn-eid))"/>
		
	<xsl:variable name="offline-services" select="redirect:load($hn-eid)"/>

	<xsl:template mode="screen" match="/">
		<xsl:variable name="filter_init_">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="redirect" url="/vzdir/infrman/hns/redirects/index"
						item-url="/vzdir/infrman/hns/redirects/redirect"/>
					<ui:cols sorting-col="id">
						<ui:column id="id"			title="{sw:text('Name')}"
							filter="auto" for-url="yes" show-url="yes" for-select="yes" select-id="id"
						/>
						<ui:column id="dst"	title="{sw:text('Destination Container ID')}" filter="auto"/>
						<ui:column id="port"	title="{sw:text('Redirected Port')}" filter="auto"/>
						<ui:column id="service-is-default"		title="{sw:text('Global')}"		apply-templates="yes" filter="select">
							<ui:filter-option title="{sw:text('Yes')}"	value="1"/>
							<ui:filter-option title="{sw:text('No')}"		value="0"/>
						</ui:column>
					</ui:cols>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="filter">
			<xsl:call-template name="browse:fill-filter">
				<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
				<xsl:with-param name="rows">
					<ui:browse-rows>
						<xsl:for-each select="$offline-services/service">
							<ui:row>
								<id>
									<xsl:value-of select="id"/>
								</id>
								<port>
									<xsl:value-of select="port"/>
								</port>
								<dst>
									<xsl:value-of select="dst"/>
								</dst>
								<service-is-default>
									<xsl:value-of select="sw:if(default=1,1,0)"/>
								</service-is-default>
							</ui:row>
						</xsl:for-each>
					</ui:browse-rows>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<ui:screen id="03.02.01.32.30">
			<ui:properties>
				<ui:description width="full">
					<sw:text>On this screen you can configure the offline management settings of the Hardware Node. Offline management makes it possible to manage the Containers of the current Hardware Node by means of Parallels Power Panel whatever the Containers state.</sw:text>
				</ui:description>
				<ui:form-get/>
			</ui:properties>
			<ui:tab-bar id="vzhn" current-tab="network" current-subtab="redirects"/>
			<ui:content>
				<ui:block width="full">
					<ui:browse>
						<xsl:attribute name="title">
							<sw:text>Offline Services</sw:text>
						</xsl:attribute>
						<ui:filter>
							<xsl:copy-of select="$filter"/>
						</ui:filter>
						<ui:browse-js-one>
							<ui:warn>
								<sw:text>To perform any action on the offline service on this list, you have to select it first.</sw:text>
							</ui:warn>
						</ui:browse-js-one>
						<ui:browse-js-many>
							<ui:warn>
								<sw:text>To perform any action on one or more offline services on this list, you have to select them first.</sw:text>
							</ui:warn>
						</ui:browse-js-many>
						<ui:browse-buttons>
							<ui:button icon="offline_service" submit-href="{$baseurl}/vzdir/infrman/hns/redirects/redirect"
								new-obj-title="{sw:text('Offline Service')}"
								sandclock="false" tip="hn_redirect_new" require-items="false">
								<sw:text>New Offline Service</sw:text>								
							</ui:button>
							<ui:button type="list-selection" tip="hn_redirect_set_default" icon="set_default" 
								submit-href="{$baseurl}/vzdir/infrman/hns/redirects/control"
								script="if (!atLeastOne()) return false;" name="redirect-set-default" auxiliary="true">
								<sw:text>Enable Globally</sw:text>
							</ui:button>
							<ui:button type="list-selection" tip="hn_redirect_unset_default" icon="unset_default" 
								script="if (!atLeastOne()) return false;" name="redirect-unset-default" auxiliary="true"
								submit-href="{$baseurl}/vzdir/infrman/hns/redirects/control">
								<sw:text>Disable Globally</sw:text>
							</ui:button>
							<ui:button type="list-selection" tip="hn_redirect_delete" icon="delete"
								confirmation="{sw:text('Are you sure you want to delete the selected offline services?')}"
								script="if (!atLeastOne()) return false;" name="redirect-delete" auxiliary="true"
								submit-href="{$baseurl}/vzdir/infrman/hns/redirects/control">
								<sw:text>Delete</sw:text>
							</ui:button>						
						</ui:browse-buttons>
						<ui:browse-empty-msg>
							<sw:text>No offline services have been found.</sw:text>
						</ui:browse-empty-msg>
					</ui:browse>
				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/core/browse-filter-raw.xsl" />
</xsl:stylesheet>
