<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl	="http://exslt.org/common"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
  xmlns:error	="http://www.swsoft.com/xsl/cp/error"
  xmlns:wiz		="http://www.swsoft.com/xsl/cp/wiz"
  xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
  xmlns:func	="http://exslt.org/functions"
	xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
 >

  <xsl:param name="wiz_code" 					select="'hn-redirect'"/>
  
	<xsl:variable name="step_data"			select="wiz:getStep()"/>
	<xsl:variable name="step"						select="$step_data/@id"/>
	<xsl:variable name="screen-id"			select="$step_data/@screen-id"/>
	<xsl:variable name="screen-title"		select="$step_data/@screen-title"/>
	<xsl:variable name="path-id"				select="string(wiz:getSteps()/step[1]/@screen-id)"/>

  <xsl:variable name="form" 					select="sw:sesget($wiz_data)"/>

	<xsl:param name="access-denied" 
		select="not(cred:check-context($step_data/@cred,$step_data/@security-obj-type))"/>

  <xsl:template name="edit-one-redirect">
  	<ui:screen path-id="{$path-id}" id="{$screen-id}" title="{$screen-title}">
  		<ui:properties>
				<ui:refresh-type>none</ui:refresh-type>
	      <ui:description  mandatory="yes">
	        <sw:text>
						<xsl:with-param name="action" select="sw:if($step='new',sw:text('add'),sw:text('edit'))"/>
						On this screen you can %{action} an offline service.
	        </sw:text>
	      </ui:description>      
	      <ui:form-get/>
	    </ui:properties>
	    
	    <ui:content>
	      <ui:hidden name="step" value="{$step}"/>
	      <ui:block mode="edit">
	      	
					<ui:rows title="{sw:text('Offline Service')}" separate-tables="true">
            <xsl:choose>
              <xsl:when test="$step = 'new'">					
                <ui:row>
                  <ui:cell-label>
                    <sw:text>Name</sw:text>
                  </ui:cell-label>
                  <ui:cell-input required="true" id="id" maxlength="256" width="16">
                  	<xsl:attribute name="value"><xsl:value-of select="$form/service/id"/></xsl:attribute>
                  </ui:cell-input>
		            </ui:row>
							</xsl:when>
							<xsl:otherwise>
								<ui:hidden name="id" value="{sw:base64-encode($form/service/id)}"/>
							</xsl:otherwise>
						</xsl:choose>
		   			<ui:row>
		   				<ui:cell-label>
			        	<sw:text>Destination Container ID</sw:text>
							</ui:cell-label>
							<ui:cell-input required="true" id="dst" maxlength="16" width="16">
								<xsl:attribute name="value"><xsl:value-of select="$form/service/dst"/></xsl:attribute>
							</ui:cell-input>
						</ui:row>
		   			<ui:row>
		   				<ui:cell-label>
			        	<sw:text>Redirected Port</sw:text>
							</ui:cell-label>
							<ui:cell-input required="true" id="port" maxlength="256" width="32">
								<xsl:attribute name="value"><xsl:value-of select="$form/service/port"/></xsl:attribute>
							</ui:cell-input>
						</ui:row>
		   			<ui:row>
		   				<ui:cell-label>
			        	<sw:text>Use Globally for All Containers</sw:text>
							</ui:cell-label>
							<ui:cell-check id="default" checked="{$form/service/default = 1}"/>
						</ui:row>
					</ui:rows>
					<ui:buttons>
		    		<xsl:call-template name="wiz:showButtons"/>
		  	  </ui:buttons>
	    	</ui:block>
	  	</ui:content>   
	  </ui:screen>
	</xsl:template>

	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
		<xsl:call-template name="edit-one-redirect"/>
	</xsl:template>
	
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>
 	
</xsl:stylesheet>
