<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl cred hwm wiz func env"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl	="http://exslt.org/common"
	xmlns:date	="http://exslt.org/dates-and-times"
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:top		="http://www.swsoft.com/xsl/cp/top"
	xmlns:env		="http://www.swsoft.com/xsl/cp/env"
	xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:hwm		="http://www.swsoft.com/xsl/cp/hwm"
	xmlns:hn		="http://www.swsoft.com/xsl/cp/hn"
	xmlns:wiz		="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:show	="http://www.swsoft.com/xsl/cp/show"
	xmlns:func	="http://exslt.org/functions"
	xmlns:local	="http://www.swsoft.com/xsl/cp/local"
	xmlns:voc		="http://www.swsoft.com/xsl/cp/voc"
>

	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vza/hwm.xsl"/>
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/get_top.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/core/browse-filter-raw.xsl" />
	<sw:include href="/lib/vzdir/infrman/hns/resources.xsl"/>
	<sw:include href="/lib/meter.xsl"/>
	<sw:include href="/lib/show-resource.xsl"/>
	<sw:include href="/lib/utils/format-resusage.xsl"/>
	
	<xsl:param		name="wiz_code" 	select="'get-top'"/>
	<xsl:variable name="step_data"	select="wiz:getStep()"/>
	<xsl:variable name="step" 			select="string($step_data/@id)"/>
	<xsl:variable name="screenid"		select="$step_data/@screenid"/>
	<xsl:variable name="form"				select="sw:sesget($wiz_data)"/>

	<!-- check permissions -->
	<xsl:param name="access-denied" select="not(cred:check-context('vzcp.hn.view', 'hn.vz.vt'))"/>
	
	<xsl:variable name="screen-desc" select="exsl:node-set(top:return-init-structure())"/>
	<xsl:variable name="records-list-rtf">
		<records>
			<xsl:value-of select="10"/>
		</records>
		<records>
			<xsl:value-of select="25"/>
		</records>
		<records>
			<xsl:value-of select="50"/>
		</records>
	</xsl:variable>
	<xsl:variable name="records-list" select="exsl:node-set($records-list-rtf)"/>
	<xsl:variable name="records" select="$form/top:query/records"/>

	<!-- main screen template -->
	<xsl:template mode="screen" match="/">
		<xsl:variable name="cur-screen-info" select="$screen-desc/top[step = $step]"/>
		<xsl:variable name="data" select="local:prepare-data(/packet/data/res_log/top|/packet/cookie/data/res_log/top, $form)"/>
		<xsl:variable name="absolute" select="$form/top:view/mode = 'absolute'"/>
		<xsl:variable name="selector" select="sw:if($form/top:view/mode = 'absolute', 'absolute', 'relative')"/>

		<xsl:variable name="filter_init_">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="top-stat" url="/vzdir/infrman/hns/resources-adv" hide-filter-controls="true" stripes="yes" 
						items-title="{sw:text('Containers')}" item-url="/vzdir/infrman/envs/env"/>
					<ui:cols>
						<ui:column id="id" for-url="yes" hidden="yes" sorting="no"/>
						<ui:column id="id-int" show-url="yes" data-type="int" title="{sw:text('ID')}"
							custom-hidden="yes" sorting="no"/>
						<ui:column id="env-eid-link" show-url="yes" apply-templates="yes" title="{sw:text('Container')}"
							sorting="no" width="30%" nav-type="title"/>
						<ui:column id="data" title="{sw:text('Usage Graph')}" width="150" apply-templates="yes" sorting="no">
							<xsl:attribute name="align"><xsl:value-of select="sw:if($absolute,'left','center')"/></xsl:attribute>
						</ui:column>
						<xsl:choose>
							<xsl:when test="$absolute">
								<ui:column id="value" title="{$cur-screen-info/absolute}"  sorting="no" align="right" data-type="str"/>
								<ui:column id="relative-value" title="{$cur-screen-info/relative}"  sorting="no" align="right" data-type="str"/>
							</xsl:when>
							<xsl:otherwise>
								<ui:column id="relative-value" title="{$cur-screen-info/relative}" sorting="no" align="right" data-type="str"/>
								<ui:column id="value" title="{$cur-screen-info/absolute}" sorting="no" align="right" data-type="str"/>
							</xsl:otherwise>
						</xsl:choose>
					</ui:cols>
				</xsl:with-param>
				<xsl:with-param name="no-limit" select="true()"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="filter">
			<xsl:call-template name="browse:fill-filter">
				<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
				<xsl:with-param name="rows">
					<xsl:variable name="envs" select="env:get-env($data/eid)/env"/>
					<ui:browse-rows>
						<xsl:for-each select="$data">
							<ui:row>
								<pos>
									<xsl:value-of select="position()"/>
								</pos>
								<xsl:variable name="id" select="eid"/>
								<id><xsl:value-of select="$id"/></id>
								<id-int><xsl:value-of select="$envs[eid=$id]/virtual_config/veid"/></id-int>
								<env-eid-link><xsl:value-of select="eid"/></env-eid-link>
								<data>
									<xsl:choose>
										<xsl:when test="$absolute">
											<ui:bar fraction="{bar-value}" mcolor="#90F090" hide-zero="yes"/>
										</xsl:when>
										<xsl:otherwise>
											<ui:meter width="100" fraction="{bar-value}" mcolor="#90F090"/>
										</xsl:otherwise>
									</xsl:choose>
								</data>
								<xsl:copy-of select="value|relative-value"/>
							</ui:row>
						</xsl:for-each>
					</ui:browse-rows>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>
		<ui:screen id="{$screenid}">
			<ui:properties>
				<ui:refresh-type>POST</ui:refresh-type>
				<ui:description width="full">
					<xsl:value-of select="$cur-screen-info/title"/>
				</ui:description>
				<ui:form-get/>
			</ui:properties>
			<ui:tab-bar id="vzhn" current-tab="res" current-subtab="{$cur-screen-info/tab}"/>
			<ui:content>
				<!-- show resource usage summary -->
				<xsl:variable name="resources-rtf">
					<xsl:call-template name="hn:get-resource-summary">
						<xsl:with-param name="resource-id" select="$cur-screen-info/hn-resource-name"/>
						<xsl:with-param name="hn-eid" select="sw:hn-eid()"/>
					</xsl:call-template>
				</xsl:variable>

				<ui:block>
					<xsl:apply-templates select="exsl:node-set($resources-rtf)/resources/group" mode="resource"/>
				</ui:block>
				<!-- end of resource usage summary -->
				<ui:block width="full">
					<ui:rows title="{sw:text('Top Resource Consumers')}">
						<ui:browse>
							<xsl:attribute name="title">
								<xsl:value-of select="$cur-screen-info/msg/present"/>
							</xsl:attribute>
							<ui:filter>
								<xsl:copy-of select="$filter"/>
							</ui:filter>
							<ui:browse-empty-msg>
								<xsl:value-of select="$cur-screen-info/msg/not-present"/>
							</ui:browse-empty-msg>
						</ui:browse>
					</ui:rows>
				</ui:block>
				<xsl:call-template name="local:create-controls">
					<xsl:with-param name="screen-info" select="$cur-screen-info"/>
				</xsl:call-template>
			</ui:content>
		</ui:screen>
	</xsl:template>
	
	<xsl:template name="local:create-controls">
		<xsl:param name="screen-info"/>
		<ui:block width="full">
			<ui:rows mode="view"  title="{sw:text('View Properties')}">
				<ui:row>
					<xsl:choose>
						<xsl:when test="$screen-info/group">
							<xsl:call-template name="local:create-resource-selector">
								<xsl:with-param name="screen-info" select="$screen-info"/>
							</xsl:call-template>
						</xsl:when>
						<xsl:otherwise>
							<ui:hidden name="step" value="{$screen-info/step}"/>
						</xsl:otherwise>
					</xsl:choose>
				</ui:row>
				<ui:row>
					<ui:cell-label>
						<nobr>
							<sw:text>Interval</sw:text>
						</nobr>
					</ui:cell-label>
					<ui:cell-list id="interval" style="width:60pt;" value="{$form/top:query/interval}">
						<xsl:for-each select="top:get-interval-reference()">
							<xsl:if test="value &gt;= $form/top:view/min-interval or (value=0 and $form/top:counter/instant)">
								<ui:list-item id="{value}" title="{title}"/>									
							</xsl:if>
						</xsl:for-each>
					</ui:cell-list>
				</ui:row>
				<ui:row>
					<ui:cell-label>
						<nobr>
							<sw:text>Show top</sw:text>
						</nobr>
					</ui:cell-label>
					<ui:cell-list id="records" style="width:30pt" value="{$form/top:query/records}" close="no">
						<xsl:for-each select="$records-list/records">
							<ui:list-item id="{.}" title="{.}"/>
						</xsl:for-each>
					</ui:cell-list>
					<ui:cell open="no">
						&#160;<sw:text>Containers</sw:text>
					</ui:cell>
				</ui:row>
				<ui:row>
					<ui:cell-label>
						<nobr>
							<sw:text>Set scale to</sw:text>
						</nobr>
					</ui:cell-label>
					<ui:cell-list id="mode" value="{$form/top:view/mode}" align="left" style="width:180pt">
						<ui:list-item id="absolute" title="{sw:text('Maximum amount consumed')}"/>
						<ui:list-item id="relative" title="{sw:text('Total amount consumed')}"/>						
					</ui:cell-list>
				</ui:row>
			</ui:rows>
		</ui:block>
		<ui:block width="full">
			<ui:buttons>
				<ui:button id="ok" type="ok" tip="refresh" name="next" sandclock="true">
					<xsl:value-of select="sw:text('Refresh')"/>
				</ui:button>
			</ui:buttons>
		</ui:block>
	</xsl:template>
	
	<xsl:template name="local:create-resource-selector">
		<xsl:param name="screen-info"/>
		<ui:cell-label>
			<sw:text>Show</sw:text>
		</ui:cell-label>
		<ui:cell-list id="step" value="{$screen-info/step}">
			<xsl:for-each select="$screen-desc/top[group=$screen-info/group]">
				<ui:list-item id="{step}" title="{details}"/>
			</xsl:for-each>
		</ui:cell-list>
	</xsl:template>

	<func:function name="local:prepare-data">
		<xsl:param name="data"/>
		<xsl:param name="form"/>
		
		<xsl:variable name="total" select="$data/total"/>
		<xsl:variable name="res">
			<xsl:for-each select="$data/set">
				<set>
					<xsl:copy-of select="eid"/>
					<value>
						<xsl:value-of select="top:format-value(value, $form/top:view/measure)"/>
					</value>
					<relative-value>
						<xsl:value-of select="top:format-value(value div $total * 100, 'percent')"/>
					</relative-value>					
					<bar-value>
						<xsl:choose>
							<xsl:when test="value &lt;= 0">
								0
							</xsl:when>	
							<xsl:when test="$form/top:view/mode='relative'">
								<xsl:value-of select="value div $total"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="value div $data/set[1]/value"/>
							</xsl:otherwise>
						</xsl:choose>
					</bar-value>
				</set>
			</xsl:for-each>
		</xsl:variable>
		<func:result select="exsl:node-set($res)/set"/>
	</func:function>
	
</xsl:stylesheet>
