<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred voc env"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl	="http://exslt.org/common"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
  xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
	xmlns:env		="http://www.swsoft.com/xsl/cp/env"
	xmlns:voc		="http://www.swsoft.com/xsl/cp/voc"	
>
  
  <sw:include href="/lib/vt/env-core.xsl"/>
  
  <xsl:variable name="showform"		select="not(sw:sesgetstr('hn-ssh-login')) or  not(sw:sesgetstr('hn-ssh-password'))"/>
	<xsl:variable name="java-mode"	select="sw:sesgetstr('java_mode')"/>
	<xsl:variable name="js-mode"		select="sw:sesgetstr('js_mode')"/>
	<xsl:variable name="hn-eid"			select="sw:hn-eid()"/>
	<xsl:param name="access-denied" select="not(cred:check-hw('vzcp.hn.view',$hn-eid))"/>

  <xsl:template mode="screen" match="/">
		<ui:screen id="03.02.01.27.10" icon="connect">
			<ui:properties>
			  <ui:width value="fixed"/>
			  <ui:description mandatory="yes">
					<xsl:choose>
						<xsl:when test="($java-mode = 'notdef') and ($js-mode != 0)">
							<!-- try activeX -->
					    <sw:text>
					      You are going to open an SSH terminal in the browser window. <br/>
								 The SSH window will pop up after the login and password are submitted. 
								 To view this window, you need IE 5.0 or higher with Javascript and ActiveX support enabled. <br/>
								 As an alternative, you can use your favorite standalone SSH client.
							</sw:text>
						</xsl:when>
						<xsl:when test="($java-mode = 'enabled') and ($js-mode != 0)">
							<!-- try java plugin -->
					    <sw:text>
					      You are going to open an SSH terminal in the browser window. <br/>
					      The SSH window will pop up after the login and password are submitted.
					      To view this window, you need the Mozilla or Opera browsers with Javascript and Java enabled.
					      As an alternative, you can use your favorite standalone SSH client.
							</sw:text>						
						</xsl:when>
						<xsl:when test="($java-mode = 'disabled') or ($js-mode = 0)">
					    <sw:text>
					      You are going to open an SSH terminal in the browser window.
							</sw:text>						
						</xsl:when>
					</xsl:choose>	                                                                                                                      
			  </ui:description>      
			  <ui:form-get/>
			</ui:properties>
		  
    <xsl:if test="$showform">
			<xsl:variable name="oper-problem" select="voc:check-operation('ssh','','',$hn-eid)"/>
      <ui:content>
        <xsl:choose>
					<xsl:when test="$java-mode = 'disabled'">
            <!-- no activeX, no java -->
						<ui:stop-sign>
              <sw:text>
                The Java plugin is probably not installed properly or Java is disabled in your browser.<br/>
								Install the Java plugin, enable Java support in your browser, log in, and try again.
								As an alternative, you can use your favorite standalone SSH client.
  	        	</sw:text>
    	    	</ui:stop-sign>
          </xsl:when>					
					<xsl:when test="$js-mode = 0">
            <!-- no js -->
						<ui:stop-sign>
							<sw:text>
								Cannot connect to the Container via SSH. Javascript is probably disabled in your browser.<br/> Log out of Parallels Infrastructure Manager, enable Javascript, log in, and try again. As an alternative, you can use your favorite standalone SSH client.
							</sw:text>
    	    	</ui:stop-sign>
          </xsl:when>					
          <xsl:when test="$oper-problem!=''">
        		<ui:block>
				    	<ui:operation-problem>
				    		<xsl:copy-of select="$oper-problem"/>
								<ui:descr><sw:text>Unable to connect to this Hardware Node via SSH.</sw:text></ui:descr>
							</ui:operation-problem>
						</ui:block>
					</xsl:when>
          <xsl:otherwise>
            <ui:block mode="edit">
            	<ui:rows>
            		<ui:row>
            			<ui:cell-label><sw:text>Login</sw:text></ui:cell-label>
              		<ui:cell-input id="login" value="{sw:sesgetstr('hn-ssh-login')}"/>
              	</ui:row>
              	<ui:row>
              		<ui:cell-label><sw:text>Password</sw:text></ui:cell-label>
	              	<ui:cell-input mode-password="true" id="password"/>
	              </ui:row>
	            </ui:rows>
	            <ui:buttons>
	            	<ui:button type="ok" name="_submit" sandclock="false" tip="hn_ssh_open_window">
		           		<xsl:attribute name="onclick">openSSH();return false;</xsl:attribute>
	            		<sw:text>Login</sw:text>
	            	</ui:button>
	            </ui:buttons>
            </ui:block>
          </xsl:otherwise>            
        </xsl:choose>
<ui:java-script>
		if (this.name == 'topFrame')
   		this.location = '<xsl:value-of select="$baseurl"/>/panel/plesk/top';
<![CDATA[
    function openSSH(){
    	top.sshPopupLogin = document.defaultForm.login.value;
      top.sshPopupPassword = document.defaultForm.password.value;
			if ((top.sshPopupLogin == '') || (top.sshPopupPassword == '')) {
				alert(']]><sw:text select="'Empty login or password !'"/><![CDATA[');
				return;
			} 
     	if (is.ie && !is.ie4 && !is.opera) {
				window.open(']]><xsl:value-of select="$baseurl"/><![CDATA[/vzdir/infrman/hns/services/ssh-popup','_blank','width=700,height=500,toolbar=no,status=no,resizable=yes,menubar=no,location=no,directories=no');
      } else {
				window.open(']]><xsl:value-of select="$baseurl"/><![CDATA[/vzdir/infrman/hns/services/ssh-popup-java','_blank','width=700,height=500,toolbar=no,status=no,resizable=yes,menubar=no,location=no,directories=no');
			}
		}
]]>
</ui:java-script>

      </ui:content>
    </xsl:if>
      
    <xsl:if test="not($showform)">
      <ui:content>
		<!-- Javascript moved to the form -->
		<ui:hidden name="password" value="{sw:sesget('hn-ssh-login')}"/>
		<ui:hidden name="password" value="{sw:sesget('hn-ssh-password')}"/>
      </ui:content>
    </xsl:if>    
    </ui:screen>
  </xsl:template>

  <sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>
	
</xsl:stylesheet>
