<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func cred vzasupport"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl	="http://exslt.org/common"
	xmlns:func  ="http://exslt.org/functions"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
  xmlns:ui	="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
	xmlns:vzasupport   ="http://www.swsoft.com/xsl/cp/vzasupport"
	xmlns:local ="http://www.swsoft.com/xsl/cp/local"
 >
	<sw:include href="/lib/vza/vzasupport.xsl"/>

  <xsl:variable name="screenid"   			select="'03.02.01.29.00'"/>
	<xsl:variable name="hn-eid"						select="sw:hn-eid()"/>	

	<!-- check detail permissions to req -->
	<xsl:variable name="cr-lim"						select="cred:check-context('vzcp.support.troubleshooting','hn.vz.vt')"/>	
	<xsl:param name="access-denied"				select="not($cr-lim)"/>

  <xsl:template mode="screen" match="/">
  	
  	<xsl:variable name="channel-res" select="vzasupport:get-support-channel($hn-eid)"/>
  	<xsl:variable name="channel-on" select="$channel-res/vzasupport/channel_status='0'"/>
  	<xsl:variable name="key-installed" select="vzasupport:is-support-channel-key($hn-eid)"/>
  	
  	<xsl:variable name="img-on">
  		<img src="/{$theme}/icons/check_green_32.gif" width="32" height="32" border="0"/>
  	</xsl:variable>
  	<xsl:variable name="img-off">
  		<img src="/{$theme}/icons/stop_sign_32.gif" width="32" height="32" border="0"/>
  	</xsl:variable>
  	<xsl:variable name="img-error">
  		<img src="/{$theme}/icons/exclamation_32.gif" width="32" height="32" border="0"/>
  	</xsl:variable>
  	
  	<ui:screen id="{$screenid}" title="{sw:text('Support Channel')}">
      
			<ui:properties>
				<ui:form-get/>
				<ui:description mandatory="yes">
					<sw:text>
						The Virtuozzo support channel allows you to establish a private secure channel to the Parallels support server. After establishing such a channel, the support team will be able to quickly and safely connect to your Node to diagnose and solve your problem.
					</sw:text>
				</ui:description>
			</ui:properties>

      <ui:content>
				<ui:block>
					
					<ui:rows>
						<xsl:choose>
							<xsl:when test="$key-installed">
								<xsl:attribute name="title">Support Certificate</xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="title">Support Certificate</xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
						<ui:row>
							<xsl:choose>
								<xsl:when test="$channel-on and $key-installed">
									<ui:cell>
										<xsl:copy-of select="$img-on"/>
									</ui:cell>
									<ui:cell cell-width="100%">
										<sw:text>
											The certificate <b>has been installed</b>, the support channel <b>has been established</b>. <br/> To install a new certificate or remove the existing one, you need to close the current support channel session.</sw:text>
									</ui:cell>
								</xsl:when>
								<xsl:when test="$key-installed">
									<ui:cell>
										<xsl:copy-of select="$img-on"/>
									</ui:cell>
									<ui:cell cell-width="100%">
										<sw:text>The certificate is installed.</sw:text>
									</ui:cell>
								</xsl:when>
								<xsl:otherwise>
									<ui:cell>
										<xsl:copy-of select="$img-off"/>
									</ui:cell>
									<ui:cell cell-width="100%">
										<sw:text>
											The certificate is not installed. You can get the certificate from the Parallels support by following <a target="_blank" href="http://www.swsoft.com/en/support/virtuozzo/certificates">this link</a>.
										</sw:text>
									</ui:cell>
								</xsl:otherwise>
							</xsl:choose>
						</ui:row>
					</ui:rows>
					
					<ui:buttons>
	          <ui:button tip="install_key"
	            name="install_key" width="150" submit-href="{$baseurl}/vzdir/infrman/hns/support/channel-key">
	            <xsl:if test="$channel-on">
	            	<xsl:attribute name="disabled">true</xsl:attribute>
	            </xsl:if>
	            <sw:text>Install New Certificate</sw:text>
	          </ui:button>
	          <ui:button tip="remove_key" sandclock="true"
	            name="remove_key" width="150" confirmation="{sw:text('Are you sure you want to remove the certificate?')}"
	           >
	            <xsl:if test="$channel-on or not($key-installed)">
	            	<xsl:attribute name="disabled">true</xsl:attribute>
	            </xsl:if>
	            <sw:text>Remove Certificate</sw:text>
	          </ui:button>
					</ui:buttons>
					
					<ui:rows title="{sw:text('Support Channel')}">
						<ui:row>
							<xsl:choose>
								<xsl:when test="$channel-res[error|servicem/error]">
									<ui:cell>
										<xsl:copy-of select="$img-error"/>
									</ui:cell>
									<ui:cell cell-width="100%">
										<sw:text>The support channel is misconfigured. Please fix your Virtuozzo configuration.</sw:text>
									</ui:cell>
								</xsl:when>
								<xsl:when test="$channel-on">
									<ui:cell>
										<xsl:copy-of select="$img-on"/>
									</ui:cell>
									<ui:cell cell-width="100%">
										<sw:text>The support channel has been established.</sw:text>
									</ui:cell>
								</xsl:when>
								<xsl:when test="not($key-installed)">
									<ui:cell>
										<xsl:copy-of select="$img-off"/>
									</ui:cell>
									<ui:cell cell-width="100%">
										<sw:text>The establishing of the support channel has been canceled and cannot be established before the certificate is installed.</sw:text>
									</ui:cell>
								</xsl:when>
								<xsl:otherwise>
									<ui:cell>
										<xsl:copy-of select="$img-off"/>
									</ui:cell>
									<ui:cell cell-width="100%">
										<sw:text>The establishing of the support channel has been canceled.</sw:text>
									</ui:cell>
								</xsl:otherwise>
							</xsl:choose>
						</ui:row>
					</ui:rows>
					
					<ui:buttons>
	          <ui:button tip="enable_channel" sandclock="true"
	            name="enable_channel" width="150" confirmation="{sw:text('Are you sure you want to establish the support channel?')}">
	            <xsl:if test="$channel-on or not($key-installed)">
	            	<xsl:attribute name="disabled">true</xsl:attribute>
	            </xsl:if>
	            <sw:text>Establish Channel</sw:text>
	          </ui:button>
	          <ui:button tip="disable_channel" sandclock="true"
	            name="disable_channel" width="150" confirmation="{sw:text('Are you sure you want to close the support channel?')}"
	           >
	            <xsl:if test="not($channel-on)">
	            	<xsl:attribute name="disabled">true</xsl:attribute>
	            </xsl:if>
	            <sw:text>Close Channel</sw:text>
	          </ui:button>
					</ui:buttons>

				</ui:block>
      </ui:content>

    </ui:screen>
  </xsl:template>

	<sw:include href="/lib/screen.xsl"/>

</xsl:stylesheet>
