  <!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred vt envm snapshotm error templates"
  xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl			="http://exslt.org/common"
  xmlns:sw				="http://www.swsoft.com/xsl/cp"
  xmlns:ui				="http://www.swsoft.com/xsl/cp/ui"   
  xmlns:browse		="http://www.swsoft.com/xsl/cp/browse"   
	xmlns:cred			="http://www.swsoft.com/xsl/cp/cred"	
	xmlns:vt				="http://www.swsoft.com/xsl/cp/vt"
	xmlns:envm			="http://www.swsoft.com/xsl/cp/envm"
	xmlns:snapshotm	="http://www.swsoft.com/xsl/cp/snapshotm"
	xmlns:error			="http://www.swsoft.com/xsl/cp/error"
	xmlns:templates	="http://www.swsoft.com/xsl/cp/templates"
 >
	
	<sw:include href="/lib/vzdir/infrman/templates/browse.xsl"/>  
	
	<xsl:variable name="hn-eid" select="sw:hn-eid()"/>
	
	<xsl:param name="access-denied" select="not(cred:check-hw('vzcp.template',$hn-eid))"/>
	
	<!-- Prepare listing type -->  
  <xsl:variable name="app-list-type">
  	<xsl:if test="sw:param('type')">
  		<xsl:variable name="get-var" select="sw:param('type')"/>
	  	<xsl:if test="sw:sesput('app-list-type',sw:if($get-var='os',string($get-var),'app'))"/>
	  </xsl:if>
  	<xsl:value-of select="sw:sesget('app-list-type')"/>
  </xsl:variable>

  <xsl:template mode="screen" match="/">  
    <ui:screen id="{sw:if($app-list-type='os','03.02.01.27.03','03.02.01.27.04')}" >

		<xsl:variable name="filter-rtf" select="templates:make-global-browse-filter(
			$app-list-type, '/vzdir/infrman/hns/templates/index', '/vzdir/infrman/templates/ez/app', $hn-eid
		)"/>
		
		<ui:properties>
			<ui:form-get/>
			<ui:description mandatory="yes">
			 <sw:text>
			  <xsl:with-param name="type-templates" select="sw:if($app-list-type='os',sw:text('OS templates'),sw:text('application templates'))"/>
			  The %{type-templates} listed on this screen are installed on the Hardware Node.
			  <br/>Standard templates carry all the necessary package files inside themselves and have versions.
			  <br/>EZ templates have only information about the necessary packages, and the packages themselves are downloaded from a central repository.
			  <br/>EZ templates do not have versions.
			 </sw:text>
			</ui:description>
		</ui:properties>

		<ui:tab-bar id="vzhn" current-tab="tmpls" current-subtab="{$app-list-type}"/>
		<ui:content>
			<ui:block width="full">

				<ui:browse>
					<xsl:attribute name="title">
						<sw:text>Templates</sw:text>
					</xsl:attribute>

					<ui:browse-js-many>
						<ui:warn>
							<sw:text>Select at least one template!</sw:text>
						</ui:warn>
					</ui:browse-js-many>

					<ui:filter>
						<xsl:copy-of select="$filter-rtf"/>
					</ui:filter>

					<xsl:variable name="submit-href" select="concat('list-control?branch=vz-templates,', sw:if($app-list-type='os', 'hnoses', 'hnapps'))"/>
					
					<ui:browse-buttons>

						<ui:button type="list-selection" tip="add_template" icon="app_tmpl" require-items="false"
							new-obj-title="{sw:text('Template')}"
							submit-href="{$baseurl}/vzdir/infrman/templates/standard/add"
						>
							<sw:text>New Template</sw:text>
						</ui:button>
						
						<ui:button type="list-selection" tip="install_vz_tmpl_hn" 
							icon="installupdate"
							script="if (!atLeastOne()) return false;" name="install"
							submit-href="{$submit-href}">
							<sw:text>Install to HNs</sw:text>
						</ui:button>		
					
						<xsl:if test="$app-list-type='app'">
							<ui:button type="list-selection" tip="install_vz_tmpl_ve" icon="env_reinstall"
								submit-href="{$submit-href}"
								script="if (!atLeastOne()) return false;" name="install-app" sandclock="false">
								<sw:text>Add to Containers</sw:text>
							</ui:button>
						</xsl:if>
					</ui:browse-buttons>
					<xsl:if test="$app-list-type='os'">
						<ui:browse-buttons>
							<ui:button type="list-selection" tip="cache_vz_tmpl" icon="cache_vz_template"
								submit-href="{$submit-href}"
								script="if (!atLeastOne()) return false;" name="cache" sandclock="false"
								hn-platform="linux">
								<sw:text>Cache</sw:text>
							</ui:button>
						</ui:browse-buttons>
					</xsl:if>
					<ui:browse-buttons>
						<ui:button type="list-selection" tip="deinstall_vz_tmpl_hn" icon="delete"
							submit-href="{$submit-href}"
							script="if (!atLeastOne()) return false;" name="deinstall">
							<sw:text>Uninstall</sw:text>
						</ui:button>
					</ui:browse-buttons>
					<ui:browse-buttons>
						<ui:button type="list-selection" tip="update_template" icon="system_updates"
							submit-href="{$baseurl}/vzdir/infrman/templates/standard/update"
							script="if (!atLeastOne()) return false;" name="up2date" 
							cred="vzcp.hn.manage.update" security-obj-type="hn.vz.vt" hn-platform="linux">
							<sw:text>Update</sw:text>
						</ui:button>
					</ui:browse-buttons>
					<ui:browse-empty-msg>
						<sw:text>No templates available.</sw:text>
					</ui:browse-empty-msg>
				</ui:browse>
			</ui:block>
		</ui:content>

    </ui:screen>
  </xsl:template>  

  <sw:include href="/lib/screen.xsl"/>
    
</xsl:stylesheet>
