<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
	extension-element-prefixes="sw exsl cred vznet" xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred" xmlns:exsl="http://exslt.org/common"
	xmlns:vznet="http://www.swsoft.com/xsl/cp/vznet">

	<sw:include href="/lib/vz/vznet-adaptor.xsl"/>

	<xsl:variable name="adaptor-id" select="sw:sesget('vznet-adaptor-id')"/>

	<xsl:template mode="screen" match="/">
		<xsl:variable name="browse-result" select="vznet:get-adaptor-vlans(sw:hn-eid(),$adaptor-id)"/>

		<xsl:variable name="filter_init_">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="netadaptor_vlans" url="/vzdir/infrman/hns/vznet/adaptors"
						item-url="/vzdir/infrman/hns/vznet/vlans/manage"/>
					<ui:cols sorting-col="id">
						<ui:column id="id" for-url="yes" title="{sw:text('Interface Name')}" filter="auto">
							<xsl:if test="cred:check-hw('vzcp.hn.manage.config.network',sw:hn-eid())">
								<xsl:attribute name="show-url">yes</xsl:attribute>
								<xsl:attribute name="for-select">yes</xsl:attribute>
							</xsl:if>
						</ui:column>
						<ui:column id="vlan_id" title="{sw:text('VLAN Tag')}"/>
						<ui:column id="network_id" title="{sw:text('Network')}" filter="auto"/>
					</ui:cols>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="filter">
			<xsl:call-template name="browse:fill-filter">
				<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
				<xsl:with-param name="rows">
					<ui:browse-rows>
						<xsl:for-each select="$browse-result">
							<ui:row>
								<id>
									<xsl:value-of select="id"/>
								</id>
								<vlan_id>
									<xsl:value-of select="vlan_id"/>
								</vlan_id>
								<network_id>
									<xsl:choose>
										<xsl:when test="not(network_id != '')">
											<sw:text>Not assigned</sw:text>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="sw:base64-decode(network_id)"/>
										</xsl:otherwise>
									</xsl:choose>
								</network_id>
							</ui:row>
						</xsl:for-each>
					</ui:browse-rows>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>


		<ui:screen id="03.02.01.32.17" icon="networkadapter">
			<ui:tab-bar id="vzhn" current-tab="network" current-subtab="adaptors"/>
			<ui:properties>
				<ui:no-default-form/>
				<ui:description width="full">
					<sw:text> List of VLANs configured on the adapter. </sw:text>
				</ui:description>
				<ui:form-get/>
			</ui:properties>
			<ui:content>
				<ui:block width="full">
					<ui:browse>
						<xsl:attribute name="title">
							<sw:text>VLANs Attached to Adapter</sw:text>
						</xsl:attribute>
						<ui:filter>
							<xsl:copy-of select="$filter"/>
						</ui:filter>
						<ui:browse-js-many>
							<ui:warn>
								<sw:text> To perform any action on the VLANs in this list, you have to select at
									least one of them. </sw:text>
							</ui:warn>
						</ui:browse-js-many>
						<ui:browse-buttons type="list-selection">
							<ui:button type="list-selection" icon="delete"
								confirmation="{sw:text('Are you sure you want to delete the selected VLANs?')}"
								script="if (!atLeastOne()) return false;" name="delete" width="150">
								<sw:text>Delete</sw:text>
							</ui:button>
						</ui:browse-buttons>
						<ui:form action="vlans-control"/>
						<ui:browse-empty-msg>
							<sw:text>No VLANs are currently configured on the adapter.</sw:text>
						</ui:browse-empty-msg>
					</ui:browse>
				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/core/browse-filter-raw.xsl" />
</xsl:stylesheet>
