<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
	extension-element-prefixes="sw exsl cred vznet"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred" xmlns:exsl="http://exslt.org/common"
	xmlns:vznet="http://www.swsoft.com/xsl/cp/vznet" xmlns:error="http://www.swsoft.com/xsl/cp/error">

	<sw:include href="/lib/vz/vznet-adaptor.xsl"/>

	<xsl:template mode="screen" match="/">
		<xsl:variable name="browse-result" select="vznet:list-adaptors(sw:hn-eid())"/>

		<xsl:if test="$browse-result/error">
			<xsl:if
				test="error:put(sw:text('Failed to fetch a list of network adapters.'),string($browse-result/error/message))"
			/>
		</xsl:if>

		<xsl:variable name="filter_init_">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="netadaptors" url="/vzdir/infrman/hns/vznet/adaptors/index"
						item-url="/vzdir/infrman/hns/vznet/adaptors/adaptor"/>
					<ui:cols sorting-col="id">
						<ui:column id="id" title="{sw:text('ID')}" filter="auto">
							<xsl:if test="cred:check-hw('vzcp.hn.manage.config.network',sw:hn-eid())">
								<xsl:attribute name="for-url">yes</xsl:attribute>
								<xsl:attribute name="show-url">yes</xsl:attribute>
							</xsl:if>
						</ui:column>
						<ui:column id="network-id" title="{sw:text('Network')}" filter="auto"/>
						<ui:column id="mac" title="{sw:text('MAC Address')}"/>
					</ui:cols>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="filter">
			<xsl:call-template name="browse:fill-filter">
				<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
				<xsl:with-param name="rows">
					<ui:browse-rows>
						<xsl:for-each
							select="$browse-result/net_device[sw:split(@xsi:type,':')[last()] = 'net_nicType']">
							<ui:row>
								<id>
									<xsl:value-of select="id"/>
								</id>
								<network-id>
									<xsl:value-of select="sw:if(network_id != '',network_id,sw:text('Not assigned'))"
									/>
								</network-id>
								<mac>
									<xsl:value-of select="mac_address"/>
								</mac>
							</ui:row>
						</xsl:for-each>
					</ui:browse-rows>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<ui:screen id="03.02.01.32.16" icon="networkadapter">
			<ui:tab-bar id="vzhn" current-tab="network" current-subtab="adaptors"/>
			<ui:properties>
				<ui:no-default-form/>
			</ui:properties>
			<ui:content>
				<ui:block width="full">
					<ui:browse>
						<xsl:attribute name="title">
							<sw:text>Network Adapters</sw:text>
						</xsl:attribute>
						<ui:filter>
							<xsl:copy-of select="$filter"/>
						</ui:filter>
						<ui:form action="list-control"/>
						<ui:browse-empty-msg>
							<sw:text>No network adapters have been found.</sw:text>
						</ui:browse-empty-msg>
					</ui:browse>
				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/core/browse-filter-raw.xsl" />
</xsl:stylesheet>
