<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
	extension-element-prefixes="sw exsl cred vznet env"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred" xmlns:exsl="http://exslt.org/common"
	xmlns:vznet="http://www.swsoft.com/xsl/cp/vznet" xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:vza_networkm="http://www.swsoft.com/webservices/vzl/4.0.0/networkm"
	xmlns:vzlt="http://www.swsoft.com/webservices/vzl/4.0.0/types"
	xmlns:env="http://www.swsoft.com/xsl/cp/env">

	<sw:include href="/lib/vz/vznet-adaptor.xsl"/>
	<sw:include href="/lib/vz/vznet-core.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>
	<xsl:variable name="hn-info" select="env:eid2info(sw:hn-eid())"/>
	
	<xsl:param name="access-denied" select="not(cred:check-hw('vzcp.hn.manage.config.network',sw:hn-eid()))"/>

	<xsl:template match="/" mode="rearrange-interfaces">
		<xsl:apply-templates mode="rearrange-interfaces" select="*"/>
	</xsl:template>

	<xsl:template match="net_device[sw:split(@xsi:type,':')[last()] = 'net_nicType']"
		mode="rearrange-interfaces">
		<xsl:variable name="nic_id" select="id"/>
		<xsl:copy>
			<xsl:copy-of select="@*"/>
			<xsl:copy-of select="*"/>
			<xsl:copy-of
				select="../net_device[sw:split(@xsi:type,':')[last()] = 'net_vlanType' 
					and ($hn-info/windows or (not($hn-info/windows) and base_device_id=$nic_id))]"/>
		</xsl:copy>
	</xsl:template>

	<xsl:template name="local:collect-browse-rows">
		<xsl:param name="net_devices"/>
		<xsl:param name="mac_address" select="/.."/>
		<xsl:for-each select="$net_devices/net_device">
			<xsl:sort select="id"/>
			<xsl:variable name="type" select="sw:split(@xsi:type,':')[last()]"/>
			<ui:row>
				<xsl:if test="not($type = 'net_vlanType')">
					<xsl:attribute name="disable-checkbox"/>
				</xsl:if>
				<xsl:attribute name="item-full-url">
					<xsl:value-of
						select="sw:if($type='net_vlanType',
							concat($baseurl,'/vzdir/infrman/hns/vznet/vlans/vlan?id=',sw:base64-encode(id)),
							concat($baseurl,'/vzdir/infrman/hns/vznet/adaptors/adaptor-view?id=',sw:base64-encode(id)))"
					/>
				</xsl:attribute>
				<eth-id>
					<xsl:value-of select="id"/>
				</eth-id>
				<eth-type>
					<xsl:value-of select="sw:if($type = 'net_vlanType',sw:text('VLAN'),sw:text('Physical'))"/>
				</eth-type>
				<vlan-id>
					<xsl:value-of select="sw:if(vlan_id,vlan_id,sw:text('n/a'))"/>
				</vlan-id>
				<network-id>
					<xsl:value-of
						select="sw:if(network_id != '',sw:base64-decode(network_id),sw:text('Not Assigned'))"/>
				</network-id>
				<mac>
					<xsl:value-of select="sw:if(mac_address,mac_address,$mac_address)"/>
				</mac>
				<ips>
					<xsl:choose>
						<xsl:when test="ip_address">
							<xsl:for-each select="ip_address">
								<xsl:if test="position()!=1">,&#160;</xsl:if>
								<xsl:value-of select="ip"/>
							</xsl:for-each>
						</xsl:when>
						<xsl:otherwise>
							<sw:text>None</sw:text>
						</xsl:otherwise>
					</xsl:choose>
				</ips>
				<type>
					<xsl:value-of select="$type"/>
				</type>
			</ui:row>
			<xsl:call-template name="local:collect-browse-rows">
				<xsl:with-param name="net_devices" select="."/>
				<xsl:with-param name="mac_address" select="mac_address"/>
			</xsl:call-template>
		</xsl:for-each>
	</xsl:template>

	<xsl:template mode="screen" match="/">
		<xsl:variable name="cr-manage"
			select="cred:check-hw('vzcp.hn.manage.config.network',sw:hn-eid())"/>
		<xsl:variable name="browse-result-rtf">
			<xsl:choose>
				<xsl:when test="$hn-info/windows">
					<xsl:copy-of select="vznet:list-devices(sw:hn-eid(),/..)"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates mode="rearrange-interfaces"
						select="vznet:list-devices(sw:hn-eid(),/..)"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="browse-result" select="exsl:node-set($browse-result-rtf)"/>

		<xsl:variable name="filter_init_">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="netadaptors" url="/vzdir/infrman/hns/vznet/interfaces/index"/>
					<ui:cols>
						<ui:column id="eth-id" title="{sw:text('Interface')}" sorting="no">
							<xsl:if test="$hn-info/windows">
								<xsl:attribute name="post-apply-templates">
									<xsl:value-of select="sw:if($hn-info/windows,'no','yes')"/>
								</xsl:attribute>
							</xsl:if>
							<xsl:if test="$cr-manage">
								<xsl:attribute name="for-url">yes</xsl:attribute>
								<xsl:attribute name="show-url">yes</xsl:attribute>
								<xsl:attribute name="for-select">
									<xsl:value-of select="sw:if($hn-info/windows = '','no','yes')"/>
								</xsl:attribute>
								<xsl:attribute name="select-id">id</xsl:attribute>
							</xsl:if>
						</ui:column>
						<ui:column id="eth-type" title="{sw:text('Type')}" sorting="no"/>
						<ui:column id="vlan-id" title="{sw:text('VLAN ID')}" sorting="no"/>
						<ui:column id="network-id" title="{sw:text('Virtual Network')}" sorting="no"/>
						<ui:column id="ips" title="{sw:text('IP Addresses')}" sorting="no"/>						
						<ui:column id="mac" title="{sw:text('MAC Address')}" sorting="no"/>
						<ui:column id="type" hidden="yes"/>
					</ui:cols>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="filter">
			<xsl:call-template name="browse:fill-filter">
				<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
				<xsl:with-param name="rows">
					<ui:browse-rows>
						<xsl:call-template name="local:collect-browse-rows">
							<xsl:with-param name="net_devices" select="$browse-result"/>
						</xsl:call-template>
					</ui:browse-rows>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<ui:screen id="03.02.01.32.23" icon="networkadapter">
			<ui:tab-bar id="vzhn" current-tab="network" current-subtab="interfaces"/>
			<ui:properties>
				<ui:no-default-form/>
				<ui:description mandatory="yes">
				 <sw:text>
				  This screen displays a list of network interface cards (NICs) and VLAN adapters currently available on the Hardware Node.
				 </sw:text>
				</ui:description>      
			</ui:properties>
			<ui:content>
				<ui:block width="full">
					<ui:browse>
						<xsl:attribute name="title">
							<sw:text>Network Adapters</sw:text>
						</xsl:attribute>
						<ui:filter>
							<xsl:copy-of select="$filter"/>
						</ui:filter>
						<ui:browse-empty-msg>
							<sw:text>No network adapters have been found.</sw:text>
						</ui:browse-empty-msg>
						<ui:browse-js-many>
							<ui:warn>
								<sw:text>
									To perform any action on the adapters from this list, you have to select at least one of them.
								</sw:text>
							</ui:warn>
						</ui:browse-js-many>
						<ui:form action="{$baseurl}/vzdir/infrman/hns/vznet/adaptors/vlans-control"/>
						<xsl:if test="not($hn-info/windows)">
							<ui:browse-buttons type="list-selection">
								<ui:button tip="add_vlan" icon="vlan"
									submit-href="/vz/cp/vzdir/infrman/hns/vznet/vlans/add"
									new-obj-title="{sw:text('VLAN')}" require-items="false">
									<sw:text>New VLAN Interface</sw:text>
								</ui:button>
								<ui:button type="list-selection" icon="delete"
									confirmation="{sw:text('Are you sure you want to delete the selected adapters?')}"
									script="if (!atLeastOne()) return false;" name="delete">
									<sw:text>Delete</sw:text>
								</ui:button>
							</ui:browse-buttons>
						</xsl:if>
					</ui:browse>
				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/core/browse-filter-raw.xsl" />
</xsl:stylesheet>
