<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
	extension-element-prefixes="sw exsl cred wiz vznet" xmlns:exsl="http://exslt.org/common"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui" xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz" xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:vznet="http://www.swsoft.com/xsl/cp/vznet">

	<sw:include href="/lib/vz/vznet-switch.xsl"/>

	<xsl:template mode="screen" match="/">
		<xsl:variable name="curr-hwid" select="sw:hn-eid()"/>
		<xsl:variable name="switch" select="vznet:get-switch($curr-hwid,sw:sesget('vznet-switch-id'))"/>
		<xsl:variable name="browse-result" select="vznet:switch-attachable($curr-hwid,$switch)"/>

		<xsl:variable name="cr-switch"
			select="cred:check-hw('vzcp.hn.manage.config.network',$curr-hwid)"/>
		<xsl:variable name="filter_init_">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="netswitch_attach_interfaces"
						url="/vzdir/infrman/hns/vznet/switches/attach"
						item-url="/vzdir/infrman/hns/vznet/interfaces/manage"/>
					<ui:cols sorting-col="id">
						<ui:column id="id" for-url="yes" title="{sw:text('Name')}">
							<xsl:if test="$cr-switch">
								<xsl:attribute name="show-url">yes</xsl:attribute>
								<xsl:attribute name="for-select">yes</xsl:attribute>
							</xsl:if>
						</ui:column>
						<ui:column id="network_id" title="{sw:text('Network')}" show-url="no"/>
						<ui:column id="type_name" title="{sw:text('Type')}" show-url="no"/>
						<ui:column id="type" hidden="yes" for-url="yes" show-url="no">
							<xsl:if test="$cr-switch">
								<xsl:attribute name="for-select">yes</xsl:attribute>
							</xsl:if>
						</ui:column>
					</ui:cols>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="filter">
			<xsl:call-template name="browse:fill-filter">
				<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
				<xsl:with-param name="rows">
					<ui:browse-rows>
						<xsl:for-each select="$browse-result/*">
							<ui:row>
								<id>
									<xsl:value-of select="id"/>
								</id>
								<network_id>
									<xsl:choose>
										<xsl:when test="not(network_id != '')">
											<sw:text>Not assigned</sw:text>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="sw:base64-decode(network_id)"/>
										</xsl:otherwise>
									</xsl:choose>
								</network_id>
								<xsl:variable name="xsi_type" select="sw:split(@xsi:type,':')[last()]"/>
								<type_name>
									<xsl:choose>
										<xsl:when test="$xsi_type = 'net_vlanType'">
											<xsl:value-of select="'VLAN'"/>
										</xsl:when>
										<xsl:when test="$xsi_type = 'net_nicType'">
											<xsl:value-of select="'NIC'"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="'Unknown'"/>
										</xsl:otherwise>
									</xsl:choose>
								</type_name>
								<type>
									<xsl:value-of select="$xsi_type"/>
								</type>
							</ui:row>
						</xsl:for-each>
					</ui:browse-rows>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>


		<ui:screen id="03.02.01.32.15">
			<ui:tab-bar id="vzhn" current-tab="network" current-subtab="switches"/>
			<ui:properties>
				<ui:form action="attach-control"/>
				<ui:description width="full">
					<sw:text> List of available network interfaces. </sw:text>
				</ui:description>
				<ui:form-get/>
			</ui:properties>
			<ui:content>
				<ui:block width="full">
					<ui:browse>
						<xsl:attribute name="title">
							<sw:text>Interfaces</sw:text>
						</xsl:attribute>
						<ui:filter>
							<xsl:copy-of select="$filter"/>
						</ui:filter>
						<ui:browse-js-many>
							<ui:warn>
								<sw:text> To perform any action on the interfaces in this list, you have to select
									at least one of them. </sw:text>
							</ui:warn>
						</ui:browse-js-many>
						<!-- <ui:form action="attach-control"/> -->
						<ui:browse-empty-msg>
							<sw:text>No interfaces currently available.</sw:text>
						</ui:browse-empty-msg>
					</ui:browse>
					<ui:buttons type="list-selection">
						<ui:button name="cancel" type="cancel">
							<sw:text>Cancel</sw:text>
						</ui:button>
						<ui:button name="attach" type="ok" script="if (!atLeastOne()) return false;">
							<sw:text>Attach</sw:text>
						</ui:button>
					</ui:buttons>
				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/core/browse-filter-raw.xsl" />
</xsl:stylesheet>
