<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
	extension-element-prefixes="sw exsl cred vznet env"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred" xmlns:exsl="http://exslt.org/common"
	xmlns:vznet="http://www.swsoft.com/xsl/cp/vznet" xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:env="http://www.swsoft.com/xsl/cp/env">

	<sw:include href="/lib/vz/vznet-switch.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>

	<xsl:template mode="screen" match="/">
		<xsl:variable name="curr-hwid" select="sw:hn-eid()"/>
		<xsl:variable name="hn-info" select="env:eid2info($curr-hwid)"/>
		<xsl:variable name="browse-result" select="vznet:list-switches($curr-hwid)"/>

		<xsl:if test="$browse-result/error">
			<xsl:if
				test="error:put(sw:text('Failed to fetch a list of network switches.'),string($browse-result/error/message))"
			/>
		</xsl:if>

		<xsl:variable name="filter_init_">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="netswitches" url="/vzdir/infrman/hns/vznet/switches/index"
						item-url="/vzdir/infrman/hns/vznet/switches/switch"/>
					<ui:cols sorting-col="id">
						<ui:column id="id" title="{sw:text('Name')}" filter="auto">
							<xsl:if test="cred:check-hw('vzcp.hn.manage.config.network',$curr-hwid)">
								<xsl:attribute name="for-select">
									<xsl:value-of select="sw:if($hn-info/windows,'no','yes')"/>
								</xsl:attribute>
								<xsl:attribute name="for-url">yes</xsl:attribute>
								<xsl:attribute name="show-url">yes</xsl:attribute>
							</xsl:if>
						</ui:column>
						<ui:column id="network-id" title="{sw:text('Network')}" filter="auto"/>
					</ui:cols>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="filter">
			<xsl:call-template name="browse:fill-filter">
				<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
				<xsl:with-param name="rows">
					<ui:browse-rows>
						<xsl:for-each
							select="$browse-result/net_device[sw:split(@xsi:type,':')[last()] = 'net_bridgeType']">
							<ui:row>
								<id>
									<xsl:value-of select="id"/>
								</id>
								<network-id>
									<xsl:value-of select="sw:base64-decode(network_id)"/>
								</network-id>
							</ui:row>
						</xsl:for-each>
					</ui:browse-rows>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<ui:screen id="03.02.01.32.11" icon="virtualswitch">
			<ui:tab-bar id="vzhn" current-tab="network" current-subtab="switches"/>
			<ui:properties>
				<ui:no-default-form/>
			</ui:properties>
			<ui:content>
				<ui:block width="full">
					<ui:browse>
						<xsl:attribute name="title">
							<sw:text>Network Switches</sw:text>
						</xsl:attribute>
						<ui:filter>
							<xsl:copy-of select="$filter"/>
						</ui:filter>
						<ui:browse-js-many>
							<ui:warn>
								<sw:text> To perform any action on the switches in this list, you have to select at
									least one of them. </sw:text>
							</ui:warn>
						</ui:browse-js-many>
						<xsl:if test="not($hn-info/windows)">
							<ui:browse-buttons>
								<ui:button  new-obj-title="{sw:text('Switch')}" 
									submit-href="add"
									tip="add_vznet_switch" icon="virtualswitch" require-items="false">
									<sw:text>New Switch</sw:text>
								</ui:button>
								<ui:button icon="delete"
									confirmation="{sw:text('Are you sure you want to delete the selected network switch(es)?')}"
									script="if (!atLeastOne()) return false;" name="delete" width="150">
									<sw:text>Delete</sw:text>
								</ui:button>
							</ui:browse-buttons>
						</xsl:if>
						<ui:form action="list-control"/>
						<ui:browse-empty-msg>
							<sw:text>No network switches have been found.</sw:text>
						</ui:browse-empty-msg>
					</ui:browse>
				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/core/browse-filter-raw.xsl" />
</xsl:stylesheet>
