<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred env"
	xmlns:xsl									="http://www.w3.org/1999/XSL/Transform" 
	xmlns:xsi									="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:exsl								="http://exslt.org/common"
	xmlns:sw									="http://www.swsoft.com/xsl/cp" 
	xmlns:ui									="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred								="http://www.swsoft.com/xsl/cp/cred" 
	xmlns:env									="http://www.swsoft.com/xsl/cp/env"
	xmlns:request							="http://www.swsoft.com/xsl/cp/request"
	xmlns:local								="http://www.swsoft.com/xsl/cp/local"	
	xmlns:vznet								="http://www.swsoft.com/xsl/cp/vznet"		
  xmlns:browse							="http://www.swsoft.com/xsl/cp/browse" 	
>
    	
	<sw:include href="/lib/vz/vznet-core.xsl"/>	
	<sw:include href="/lib/vt/env-list.xsl"/>
		
	<!-- Read context data -->
	<xsl:variable name="hn-eid" select="sw:hn-eid()"/>
	<xsl:variable name="vlan-id" select="sw:sesget('vlan-id')"/>
	<xsl:variable name="vlan-id-base64" select="sw:base64-encode($vlan-id)"/>

	<xsl:variable name="hn-info"	select="env:eid2info($hn-eid)"/>
	<!-- try get description and connection detail for network -->
	<xsl:variable name="all-interfaces" select="vznet:list-devices($hn-eid,/..)"/>
	<xsl:variable name="cur-interface"	select="$all-interfaces[id = $vlan-id]"/>

	<!-- Post screen -->
	<xsl:template mode="screen" match="/">
		<ui:screen id="03.02.01.32.28">
			<ui:properties>
				<ui:description width="full">
					<sw:text>This screen displays the main parameters of the given VLAN network adapter set up on the Hardware Node. You can click 'Configure' to define the Virtuozzo virtual network (i.e. group of Containers in a single subnet) that will use this adapter for external network connectivity.</sw:text>
				</ui:description>
				<ui:form-get/>
			</ui:properties>
			<ui:content>
				<ui:block>
					<ui:rows title="{sw:text('General')}" separate-tables="false">
						<xsl:call-template name="local:show-details"/>
					</ui:rows>
				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<!-- Post Network&HN Info -->
	<xsl:template name="local:show-details">
		<ui:row>
			<ui:cell-label>
				<sw:text>
					Interface
				</sw:text>
			</ui:cell-label>
			<ui:cell-text>
				<xsl:value-of select="$vlan-id"/>
			</ui:cell-text>
		</ui:row>	
		<ui:row>
			<ui:cell-label>
				<sw:text>
					Type 
				</sw:text>
			</ui:cell-label>
			<ui:cell-text>
				<sw:text>VLAN</sw:text>
			</ui:cell-text>
		</ui:row>	
		<ui:row>
			<ui:cell-label>
				<sw:text>
					VLAN ID
				</sw:text>
			</ui:cell-label>						
			<ui:cell-text>
				<xsl:value-of select="$cur-interface/vlan_id"/>
			</ui:cell-text>
		</ui:row>
		<ui:row>
			<ui:cell-label>
				<sw:text>
					Virtual Network
				</sw:text>
			</ui:cell-label>						
			<ui:cell-text>
				<xsl:variable name="assigned-network" select="sw:base64-decode($cur-interface/network_id)"/>
				<xsl:value-of select="sw:if($assigned-network!='',$assigned-network,sw:text('Not Assigned'))"/>
			</ui:cell-text>
		</ui:row>
		<ui:row>
			<ui:cell-label>
				<sw:text>
					IP Addresses
				</sw:text>
			</ui:cell-label>						
			<ui:cell-text>
				<xsl:choose>
					<xsl:when test="$cur-interface/ip_address">
						<xsl:for-each select="$cur-interface/ip_address">
							<xsl:if test="position()!=1">,&#160;</xsl:if>
							<xsl:value-of select="ip"/>
						</xsl:for-each>
					</xsl:when>
					<xsl:otherwise>
						<sw:text>None</sw:text>
					</xsl:otherwise>
				</xsl:choose>
			</ui:cell-text>
		</ui:row>
		<ui:row>
			<ui:cell-label>
				<sw:text>
					MAC Address
				</sw:text>
			</ui:cell-label>						
			<ui:cell-text>
				<xsl:value-of select="$cur-interface/mac_address"/>
			</ui:cell-text>
		</ui:row>

		<ui:row>
			<ui:cell/>
			<ui:cell/>
			<ui:cell-button tip="configure_vlan_interface" sandclock="false" icon="networkadapter" type="ok"
				submit-href="{$baseurl}/vzdir/infrman/hns/vznet/vlans/manage">
				<sw:text>Configure</sw:text>
			</ui:cell-button>		
		</ui:row>
	</xsl:template>

	<sw:include href="/lib/screen.xsl"/>

</xsl:stylesheet>
