<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred vznet"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred" xmlns:exsl="http://exslt.org/common"
	xmlns:server_group="http://www.swsoft.com/xsl/cp/server_group"
	xmlns:vznet="http://www.swsoft.com/xsl/cp/vznet"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
>

	<sw:include href="/lib/swa/server-group.xsl"/>
	<sw:include href="/lib/vz/vznet-core.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>

	<xsl:variable name="hn-eid" select="sw:hn-eid()"/>
	<xsl:param name="access-denied" 
		select="not(cred:check-hw('vzcp.hn.manage.config.network',$hn-eid))"/>
	
	<xsl:variable name="hn-info"  select="env:eid2info($hn-eid)"/>
	<xsl:variable name="all-interfaces" select="vznet:list-devices($hn-eid,/..)"/>
	<xsl:variable name="switches" 			select="vznet:filter-switches-from-all($all-interfaces)"/>
	<xsl:variable name="interfaces"			select="vznet:filter-interfaces-from-all($all-interfaces)"/>
	<!-- Call impersonated version of server_group:get-config as workaround for #85358 --> 
	<xsl:variable name="global-network" select="server_group:get-config(sw:master-eid(),true())/networks"/>
	<xsl:variable name="global-and-local-network"
		select="vznet:merge-global-and-local-network($global-network,$all-interfaces,$switches,$interfaces,$hn-info)"/>

	<xsl:template mode="screen" match="/">
		<xsl:variable name="filter_init_">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="networks" url="/vzdir/infrman/hns/vznet/vns/index"
						item-url="/vzdir/infrman/hns/vznet/vns/vn"/>
					<ui:cols sorting-col="id">
						<ui:column id="id" title="{sw:text('Virtual Network')}" filter="auto" for-url="yes" show-url="yes"/>
						<ui:column id="vn-availability" title="{sw:text('Connection Status')}" apply-templates="yes" filter="select">
							<ui:filter-option title="{sw:text('Connected')}" value="Connected"/>
							<ui:filter-option title="{sw:text('Local')}" value="Local"/>
							<ui:filter-option title="{sw:text('Not Configured')}" value="Not Configured"/>
						</ui:column>											
						<ui:column id="description" title="{sw:text('Network Description')}" filter="auto"/>
						<ui:column id="interfaces" title="{sw:text('Assigned Interface')}" filter="auto"/>
					</ui:cols>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="filter">
			<xsl:call-template name="browse:fill-filter">
				<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
				<xsl:with-param name="rows">
					<ui:browse-rows>
						<xsl:for-each select="$global-and-local-network/network">
							<xsl:variable name="nid" select="id"/>
							<xsl:variable name="network-connection-info" select="vznet:get-network-connection-info($nid,$global-and-local-network,$interfaces,$switches,$hn-info)"/>
							<ui:row>
								<id>
									<xsl:value-of select="sw:base64-decode($nid)"/>
								</id>
								<description>
									<xsl:value-of select="sw:base64-decode(description)"/>
								</description>
								<vn-availability>
									<xsl:copy-of select="$network-connection-info/status/@*"/>
									<xsl:value-of select="$network-connection-info/status"/>
								</vn-availability>
								<interfaces>
									<xsl:value-of select="$network-connection-info/interface"/>
								</interfaces>
							</ui:row>
						</xsl:for-each>
					</ui:browse-rows>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<ui:screen id="03.02.01.32.24" icon="vlan">
			<ui:properties>
				<ui:description width="full">
					<sw:text>Here you can configure the Hardware Node connection to the virtual networks.</sw:text>
				</ui:description>
				<ui:form-get/>
			</ui:properties>
			<ui:tab-bar id="vzhn" current-tab="network" current-subtab="vns"/>
			<ui:content>
				<ui:block width="full">
					<ui:browse>
						<xsl:attribute name="title">
							<sw:text>Connections</sw:text>
						</xsl:attribute>
						<ui:filter>
							<xsl:copy-of select="$filter"/>
						</ui:filter>
						<ui:browse-js-one>
							<ui:warn>
								<sw:text>To perform any action on a virtual network in this list, you have to select one.</sw:text>
							</ui:warn>
						</ui:browse-js-one>
						<ui:browse-js-many>
							<ui:warn>
								<sw:text>To perform any action on the virtual networks in this list, you have to select at least one of them.</sw:text>
							</ui:warn>
						</ui:browse-js-many>
						<ui:browse-buttons>
							<xsl:if test="cred:check('vzcp.virtuozzo_group.network.vnets')">
								<ui:button icon="vlan" submit-href="{$baseurl}/vzdir/infrman/hns/vznet/vns/add"
									new-obj-title="{sw:text('Virtual Network')}"
									sandclock="false" tip="new_virtual_network" require-items="false">
									<sw:text>New Virtual Network</sw:text>
								</ui:button>
							</xsl:if>
						</ui:browse-buttons>
						<ui:browse-empty-msg>
							<sw:text>No virtual networks have been found.</sw:text>
						</ui:browse-empty-msg>
					</ui:browse>
				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/core/browse-filter-raw.xsl" />
</xsl:stylesheet>
