<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred env"
	xmlns:xsl									="http://www.w3.org/1999/XSL/Transform" 
	xmlns:xsi									="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:exsl								="http://exslt.org/common"
	xmlns:sw									="http://www.swsoft.com/xsl/cp" 
	xmlns:ui									="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred								="http://www.swsoft.com/xsl/cp/cred" 
	xmlns:env									="http://www.swsoft.com/xsl/cp/env"
	xmlns:request							="http://www.swsoft.com/xsl/cp/request"
	xmlns:local								="http://www.swsoft.com/xsl/cp/local"	
	xmlns:vznet								="http://www.swsoft.com/xsl/cp/vznet"		
  xmlns:browse							="http://www.swsoft.com/xsl/cp/browse" 	
  xmlns:server_group						="http://www.swsoft.com/xsl/cp/server_group"
>
    	
	<sw:include href="/lib/swa/server-group.xsl"/>
	<sw:include href="/lib/vz/vznet-vn.xsl"/>
	<sw:include href="/lib/vz/vznet-core.xsl"/>	
	<sw:include href="/lib/vt/env-list.xsl"/>
		
	<!-- Read context data -->
	<xsl:variable name="hn-eid" select="sw:hn-eid()"/>
	<xsl:param name="access-denied" 
		select="not(cred:check-hw('vzcp.hn.manage.config.network',$hn-eid))"/>
	
	<xsl:variable name="network-id" select="sw:sesget('vn-id')"/>
	<xsl:variable name="network-id-base64" select="sw:base64-encode(sw:sesget('vn-id'))"/>

	<xsl:variable name="hn-info"	select="env:eid2info($hn-eid)"/>
	<!-- try get description and connection detail for network -->
	<xsl:variable name="all-interfaces" select="vznet:list-devices($hn-eid,/..)"/>

	<xsl:variable name="switches" 			select="vznet:filter-switches-from-all($all-interfaces)"/>
	<xsl:variable name="interfaces"			select="vznet:filter-interfaces-from-all($all-interfaces)"/>
	<!-- Call impersonated version of server_group:get-config as workaround for #85358 -->
	<xsl:variable name="global-network" select="server_group:get-config(sw:master-eid(),true())/networks"/>
	<xsl:variable name="global-and-local-network" select="vznet:merge-global-and-local-network($global-network,$all-interfaces,$switches,$interfaces,$hn-info)"/>
	<xsl:variable name="network-connection-info"
		select="vznet:get-network-connection-info($network-id-base64,$global-and-local-network,$interfaces,$switches,$hn-info)"/>
	
	<!-- Post screen -->
	<xsl:template mode="screen" match="/">
		<ui:screen id="03.02.01.32.27">
			<ui:properties>
				<ui:form-get/>
			</ui:properties>
			<ui:content>
				<ui:block width="full">
					<ui:rows title="{sw:text('General Settings')}" separate-tables="false">
						<xsl:call-template name="local:show-details"/>
					</ui:rows>
					<ui:rows title="{sw:text('Connected Containers')}" separate-tables="true">
						<xsl:call-template name="local:show-ves"/>
					</ui:rows>
				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>
	
	<!-- Post Network&HN Info -->
	<xsl:template name="local:show-details">
		<ui:row>
			<ui:cell-label>
				<sw:text>
					Virtual Network
				</sw:text>
			</ui:cell-label>
			<ui:cell-text>
				<xsl:value-of select="$network-id"/>
			</ui:cell-text>
		</ui:row>	
		<ui:row>
			<ui:cell-label>
				<sw:text>
					Virtual Network Description 
				</sw:text>
			</ui:cell-label>
			<ui:cell-text>
				<xsl:value-of select="sw:base64-decode($global-and-local-network/network[id = $network-id-base64]/description)"/>
			</ui:cell-text>
		</ui:row>	
		<ui:row>
			<ui:cell-label>
				<sw:text>
					Connection Status
				</sw:text>
			</ui:cell-label>						
			<ui:cell-text>
				<xsl:value-of select="$network-connection-info/status"/>
			</ui:cell-text>
		</ui:row>
		<ui:row>
			<ui:cell-label>
				<sw:text>
					Assigned Interface
				</sw:text>
			</ui:cell-label>						
			<ui:cell-text>
				<xsl:value-of select="$network-connection-info/interface"/>
			</ui:cell-text>
		</ui:row>
		<ui:row>
			<ui:cell/>
			<ui:cell/>
			<ui:cell-button tip="configure_virtual_network_connection" sandclock="false" icon="network_config" type="ok"
				submit-href="{$baseurl}/vzdir/infrman/hns/vznet/vns/connect">
				<sw:text>Configure</sw:text>
			</ui:cell-button>		
		</ui:row>
	</xsl:template>

	<!-- Post VEs -->
	<xsl:template name="local:show-ves">
		
		<!-- Init Filter -->
		<xsl:variable name="filter-rtf">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="vznet-vn-ves" 
						url="/vzdir/infrman/hns/vznet/vns/vn" 
						item-url="/vzdir/infrman/envs/env?context=default"						
						items-title="{sw:text('Containers')}"
					>
					</ui:browse-setup>
	        <ui:cols sorting-col="name">
	         	<xsl:call-template name="env:get-browse-cols">
	         		<xsl:with-param name="show-url" select="true()"/>
	         		<xsl:with-param name="ext-cols">
		         		<ui:column id="id" hidden="yes" vza-id="env.eid" nav-type="id"/>
								<ui:column id="network-id" hidden="yes" vza-id="env.vconfig.net_device.network_id">
									<ui:cond expr="="><xsl:value-of select="$network-id"/></ui:cond>
								</ui:column>
	        		</xsl:with-param>
	         	</xsl:call-template>
	        </ui:cols>
				</xsl:with-param>
			</xsl:call-template>
    </xsl:variable>
    
    <!-- Fill Filter -->
		<xsl:variable name="filter-data-rtf">
			<xsl:call-template name="env:fill-filter">
					<xsl:with-param name="filter-rtf" select="$filter-rtf"/>
					<xsl:with-param name="filter-hn-eid" select="$hn-eid"/>
				</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="filter" select="exsl:node-set($filter-data-rtf)"/>
    
    <!-- Show browse-->
		<ui:browse>
			
			<ui:filter>
				<xsl:copy-of select="$filter-data-rtf"/>
			</ui:filter>
			
			<ui:browse-empty-msg>
				<sw:text>No Containers are connected to the virtual network.</sw:text>
			</ui:browse-empty-msg>        
			
		</ui:browse>
    <!-- /Show browse-->
		
		      		
	</xsl:template>

	<sw:include href="/lib/screen.xsl"/>

</xsl:stylesheet>
