<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred global ips"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:global="http://www.swsoft.com/xsl/cp/global"
	xmlns:ips="http://www.swsoft.com/xsl/cp/ips"
>

	<sw:include href="/lib/vz/ips.xsl"/>
	<sw:include href="/lib/core/browse-filter-raw.xsl"/>
	<sw:include href="/lib/vza/global.xsl"/>

	<!-- check permissions to show this page -->
	<xsl:variable name="cr-pool-add" select="cred:check('vzcp.virtuozzo_group.network.ippools')"/>
	<xsl:variable name="cr-pool-allocated" select="$cr-pool-add"/>
	<xsl:variable name="cr-pool-delete" select="$cr-pool-add"/>
	<xsl:param name="access-denied" select="not($cr-pool-add)"/>

	<xsl:template mode="screen" match="/">

		<xsl:variable name="filter_init_">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="ip-ranges" url="/vzdir/infrman/ipranges/index"
						item-url="/vzdir/infrman/ipranges/manage?mode=edit"/>
					<ui:cols sorting-col="start">
						<ui:column id="id" nav-type="id" hidden="yes" for-select="yes"/>
						<ui:column id="start" align="right" show-url="yes" data-type="ip"
							title="{sw:text('First IP Address')}" filter="auto"/>
						<ui:column id="end" align="right" show-url="yes" data-type="ip"
							title="{sw:text('Last IP Address')}" filter="auto"/>
						<ui:column id="assigned" data-type="int" title="{sw:text('Assigned')}" filter="auto"/>
						<ui:column id="free" data-type="int" title="{sw:text('Free')}" filter="auto"/>
						<ui:column id="total" data-type="int" title="{sw:text('Total')}" filter="auto"/>
					</ui:cols>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="ranges" select="ips:ranges()"/>
		<xsl:variable name="all-used" select="ips:all-used($ranges)"/>

		<xsl:variable name="total" select="sum($ranges/range/@total)"/>
		<xsl:variable name="assigned" select="count($all-used/ip[not(@value-num=preceding-sibling::ip/@value-num)])"/>

		<xsl:variable name="filter">
			<xsl:call-template name="browse:fill-filter">
				<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
				<xsl:with-param name="rows">
					<ui:browse-rows>
						<xsl:for-each select="$ranges/range">
							<xsl:variable name="range" select="."/>
							<xsl:variable name="range-assigned"
								select="$all-used/ip[@value-num &gt;=$range/@start-num and @value-num &lt;=$range/@end-num
									and not(@value-num=preceding-sibling::ip/@value-num)]"/>
							<ui:row>
								<id>
									<xsl:value-of select="concat(@start,'-',@end)"/>
								</id>
								<start>
									<xsl:value-of select="@start"/>
								</start>
								<end>
									<xsl:value-of select="@end"/>
								</end>
								<assigned>
									<xsl:value-of select="count($range-assigned)"/>
								</assigned>
								<free>
									<xsl:value-of select="@total - count($range-assigned)"/>
								</free>
								<total>
									<xsl:value-of select="@total"/>
								</total>
							</ui:row>
						</xsl:for-each>
					</ui:browse-rows>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<ui:screen id="03.02.01.37.00">

			<ui:properties>
				<ui:form-get/>
				<ui:no-default-form/>
				<ui:description>
					<sw:text>
						This screen allows you to manage the IP addresses pool for Containers, thus helping you to ensure a unified range of Container IP addresses.
					</sw:text>
				</ui:description>
			</ui:properties>

			<ui:tab-bar id="setup.net" current-tab="ips" current-subtab="ranges"/>

			<ui:content>
				<ui:block>

					<ui:rows title="{sw:text('Pool Summary Information')}">
						<ui:row>
							<ui:cell-label>
								<sw:text>Assigned IP Addresses</sw:text>
							</ui:cell-label>
							<ui:cell-value>
								<xsl:value-of select="$assigned"/>
							</ui:cell-value>
						</ui:row>
						<ui:row>
							<ui:cell-label>
								<sw:text>Free IP Addresses</sw:text>
							</ui:cell-label>
							<ui:cell-value>
								<xsl:value-of select="$total - $assigned"/>
							</ui:cell-value>
						</ui:row>
						<ui:row>
							<ui:cell-label>
								<sw:text>Total IP Addresses</sw:text>
							</ui:cell-label>
							<ui:cell-value>
								<xsl:value-of select="$total"/>
							</ui:cell-value>
						</ui:row>
					</ui:rows>

					<ui:browse>
						<xsl:attribute name="title">
							<sw:text>IP Address Ranges</sw:text>
						</xsl:attribute>

						<ui:browse-js-many>
							<ui:warn>
								<sw:text>Select at least one IP range!</sw:text>
							</ui:warn>
						</ui:browse-js-many>

						<ui:filter>
							<xsl:copy-of select="$filter"/>
						</ui:filter>

						<ui:browse-buttons type="list-selection">

							<ui:button type="list-selection" tip="new_ip_range" icon="ippool" require-items="false"
								new-obj-title="{sw:text('IP Range')}" cred="vzcp.virtuozzo_group.network.ippools"
								submit-href="{$baseurl}/vzdir/infrman/ipranges/manage"
							>
								<sw:text>New IP Range</sw:text>
							</ui:button>

							<xsl:if test="$cr-pool-delete">
								<ui:button type="list-selection" tip="delete_ip_range" icon="delete"
									confirmation="{sw:text('Are you sure you want to delete the selected IP range(s)?')}"
									script="if (!atLeastOne()) return false;" name="delete" width="150">
									<sw:text>Delete</sw:text>
								</ui:button>
							</xsl:if>
						</ui:browse-buttons>

						<!-- form definition for other controls -->
						<ui:form action="list-control"/>

						<ui:browse-empty-msg>
							<sw:text>No IP ranges could be found.</sw:text>
						</ui:browse-empty-msg>

					</ui:browse>
				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<sw:include href="/lib/screen.xsl"/>

</xsl:stylesheet>
