<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred" xmlns:exsl="http://exslt.org/common"
	xmlns:server_group="http://www.swsoft.com/xsl/cp/server_group">

	<sw:include href="/lib/swa/server-group.xsl"/>

	<xsl:param name="access-denied" select="not(cred:check('vzcp.virtuozzo_group.network.vnets'))"/>

	<xsl:template mode="screen" match="/">
		<xsl:variable name="browse-result" select="server_group:get-config()"/>

		<xsl:variable name="filter_init_">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="networks" url="/vzdir/infrman/networks/index"
						item-url="/vzdir/infrman/networks/manage"/>
					<ui:cols sorting-col="id">
						<ui:column id="id" title="{sw:text('Name')}" filter="auto">
							<xsl:if test="cred:check('vzcp.virtuozzo_group.network.vnets')">
								<xsl:attribute name="for-select">yes</xsl:attribute>
								<xsl:attribute name="for-url">yes</xsl:attribute>
								<xsl:attribute name="show-url">yes</xsl:attribute>
							</xsl:if>
						</ui:column>
						<ui:column id="description" title="{sw:text('Description')}"/>
					</ui:cols>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="filter">
			<xsl:call-template name="browse:fill-filter">
				<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
				<xsl:with-param name="rows">
					<ui:browse-rows>
						<xsl:for-each select="$browse-result/networks/network">
							<ui:row>
								<id>
									<xsl:value-of select="sw:base64-decode(id)"/>
								</id>
								<description>
									<xsl:value-of select="sw:base64-decode(description)"/>
								</description>
							</ui:row>
						</xsl:for-each>
					</ui:browse-rows>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<ui:screen id="03.02.01.38.00">
			<ui:properties>
				<ui:form-get/>
				<ui:no-default-form/>
				<ui:description width="full">
					<sw:text>
						This screen presents a list of Virtuozzo virtual networks available to the Hardware Nodes registered in Parallels Infrastructure Manager.
					</sw:text>
				</ui:description>
			</ui:properties>
			<ui:tab-bar id="setup.net" current-tab="networks"/>

			<ui:content>
				<ui:block width="full">
					<ui:browse>
						<xsl:attribute name="title">
							<sw:text>Virtual Networks</sw:text>
						</xsl:attribute>
						<ui:filter>
							<xsl:copy-of select="$filter"/>
						</ui:filter>
						<ui:browse-js-many>
							<ui:warn>
								<sw:text> To perform any action on the virtual networks in this list, you have to select at least one of them. </sw:text>
							</ui:warn>
						</ui:browse-js-many>
						<ui:browse-buttons>
							<ui:button icon="vlan" submit-href="add"
								new-obj-title="{sw:text('Virtual Network')}"
								sandclock="false" tip="new_virtual_network" require-items="false"
							>
								<sw:text>New Virtual Network</sw:text>
							</ui:button>
							<ui:button icon="delete"
								confirmation="{sw:text('Are you sure you want to delete the selected virtual network(s)?')}"
								script="if (!atLeastOne()) return false;" name="delete"
							>
								<sw:text>Delete</sw:text>
							</ui:button>
						</ui:browse-buttons>
						<ui:form action="list-control"/>
						<ui:browse-empty-msg>
							<sw:text>No virtual networks have been found.</sw:text>
						</ui:browse-empty-msg>
					</ui:browse>
				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/core/browse-filter-raw.xsl" />
</xsl:stylesheet>
