<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred tem vzenv func vzapackagem local"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:func		="http://exslt.org/functions"
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"   
	xmlns:browse	="http://www.swsoft.com/xsl/cp/browse"   
	xmlns:cred		="http://www.swsoft.com/xsl/cp/cred"
	xmlns:tem		="http://www.swsoft.com/xsl/cp/tem"
	xmlns:vz		="http://www.swsoft.com/xsl/cp/vz"	
	xmlns:templates	="http://www.swsoft.com/xsl/cp/templates"
	xmlns:vzenv		="http://www.swsoft.com/xsl/cp/vzenv"	
	xmlns:vzapackagem	="http://www.swsoft.com/xsl/cp/vzapackagem"	
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"	
 >
 	<sw:include href="/lib/vz/apps.xsl"/>
	
	<!-- Prepare listing type -->
	<xsl:variable name="app-list-type" select="sw:sesget('app-list-type')" />
	<xsl:variable name="app-id" select="sw:sesget('app-id')" />
	<xsl:variable name="rpm-id" select="sw:sesget('app-rpm-id')"/>
	
	<xsl:variable name="parent-app" select="vzapackagem:id2package($app-id)"/>

	<!-- Prepare Credentions -->
	<xsl:variable name="cr-os"	select="true()"/>
	<!--<xsl:variable name="cr-os"	select="cred:check('/vzdir/infrman/templates/manage')"/>-->
	<xsl:variable name="cr-app"	select="true()"/>
	<!--<xsl:variable name="cr-app"	select="cred:check('/vzdir/infrman/templates/template/manage')"/>-->

	<xsl:variable name="cr-base-detail"	select="($app-list-type = 'os' and $cr-os) or ($app-list-type = 'app' and $cr-app)"/>
		
	<!-- no base detail - no access to screen -->
	<xsl:param name="access-denied" select="not($cr-base-detail)" />
	
	<func:function name="local:screen-id">
		<xsl:choose>
			<xsl:when test="sw:param('mode')='group'">
				<func:result select="sw:if($app-list-type='os', '03.02.01.39.07', '03.02.01.39.08')" />
			</xsl:when>
			<xsl:otherwise>
				<func:result select="'03.02.01.36.04'" />
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<xsl:template mode="screen" match="/">

		<xsl:variable name="data-packet" select="vzapackagem:get-rpm($rpm-id)/packet/data" />
		<xsl:variable name="data" select="$data-packet/vzapackagem/packages/package" />
		
		<xsl:variable name="rpm" select="vzapackagem:id2package($rpm-id)"/>

		<ui:screen id="{local:screen-id()}" title="{$rpm/name}" icon="app_tmpl">
			<ui:properties>
				<ui:form-get/>
			</ui:properties>
			
			<ui:content>
				<ui:hidden name="mode" value="{sw:param('mode')}" />
				<xsl:choose>
					<!-- Error occurred -->
					<xsl:when test="$data-packet/error|$data-packet/vzapackagem/error">
						<xsl:call-template name="templates:show-rpm-error">
							<xsl:with-param name="error" select="$data-packet/error|$data-packet/vzapackagem/error" />
						</xsl:call-template>
					</xsl:when>
					<!-- /Error occurred -->

					<!-- Received data  -->
					<xsl:otherwise>
						<xsl:call-template name="local:show-data">
							<xsl:with-param name="data" select="$data" />
						</xsl:call-template>
					</xsl:otherwise>
					<!-- /Received data-->

				</xsl:choose>
			</ui:content>

		</ui:screen>
	</xsl:template>

	<!-- Show data -->
	<xsl:template name="local:show-data">
		<xsl:param name="data"/>
		
		<ui:block width="full">
			
			<!-- Show Template Info -->		
			<ui:rows title="{sw:text('Information')}">								
				<ui:row>
					<ui:cell-label><sw:text>Name</sw:text></ui:cell-label>
					<ui:cell-value><xsl:value-of select="$data/name"/></ui:cell-value>
				</ui:row>
				<ui:row>
					<ui:cell-label><sw:text>Version</sw:text></ui:cell-label>
					<ui:cell-value>
						<xsl:choose>
							<xsl:when test="$data/version!=''">
								<xsl:value-of select="$data/version"/>
							</xsl:when>
							<xsl:otherwise>
								<sw:text>n/a</sw:text>
							</xsl:otherwise>
						</xsl:choose>
					</ui:cell-value>
				</ui:row>
				<ui:row>
					<ui:cell-label><sw:text>Architecture</sw:text></ui:cell-label>
					<ui:cell-value>
						<xsl:value-of select="$data/arch"/>
					</ui:cell-value>
				</ui:row>
				<ui:row>
					<ui:cell-label><sw:text>Platform</sw:text></ui:cell-label>
					<ui:cell-value>
						<xsl:value-of select="$data/os/platform"/>
					</ui:cell-value>
				</ui:row>
				<ui:row>
					<ui:cell-label><sw:text>Distribution</sw:text></ui:cell-label>
					<ui:cell-value>
						<xsl:value-of 
							select="sw:app-id2title(sw:if(vzapackagem:is-os($parent-app), $parent-app/name, $parent-app/os/name))"/>
					</ui:cell-value>
				</ui:row>
			</ui:rows>	
			<ui:rows title="{sw:text('Description')}">								
				<ui:row>
					<ui:cell colspan="2">
						<xsl:choose>
							<xsl:when test="$data/description!=''">
								<xsl:variable name="lines" select="sw:split($data/description,'&#10;')"/>
								<xsl:for-each select="$lines">
									<xsl:if test="position()!=1"><br/></xsl:if>
									<xsl:value-of select="."/>
								</xsl:for-each>
							</xsl:when>
							<xsl:otherwise>
								<span class="inactive"><sw:text>n/a</sw:text></span>
							</xsl:otherwise>
						</xsl:choose>
					</ui:cell>
				</ui:row>
			</ui:rows>
			<!-- /Show Template Info -->
		</ui:block>
	</xsl:template>
	
	<sw:include href="/lib/screen.xsl"/>

	<sw:include href="/lib/vzaconfig.xsl"/>
	<sw:include href="/lib/vza/vzapackagem.xsl"/>  
	<sw:include href="/lib/vzdir/infrman/templates/browse.xsl"/>
  
	<sw:include href="/lib/vocabulary.xsl"/>

  
</xsl:stylesheet>
