<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred tem vzenv vzapackagem local func"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:func		="http://exslt.org/functions"
	xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"   
	xmlns:browse	="http://www.swsoft.com/xsl/cp/browse"   
	xmlns:cred		="http://www.swsoft.com/xsl/cp/cred"
	xmlns:tem		="http://www.swsoft.com/xsl/cp/tem"
	xmlns:vz		="http://www.swsoft.com/xsl/cp/vz"	
	xmlns:templates	="http://www.swsoft.com/xsl/cp/templates"	
	xmlns:vzenv		="http://www.swsoft.com/xsl/cp/vzenv"	
	xmlns:vzapackagem	="http://www.swsoft.com/xsl/cp/vzapackagem"	
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"	
 >
	<sw:include href="/lib/core/browse-filter-raw.xsl" /> 
	<sw:include href="/lib/vocabulary.xsl"/>
 	<sw:include href="/lib/screen.xsl"/>
	
	<sw:include href="/lib/vza/vzapackagem.xsl"/>  

 	<sw:include href="/lib/vz/apps.xsl"/>
 	<sw:include href="/lib/vzdir/infrman/templates/browse.xsl"/>
	
	<!-- Prepare listing type -->
	<xsl:variable name="app-list-type" select="sw:sesget('app-list-type')"/>
	<xsl:variable name="pkg-type" select="sw:sesget('app-pkg-type')"/>
	<xsl:variable name="app-id" select="sw:sesget('app-id')"/>

	<xsl:variable name="parent-app" select="vzapackagem:id2package($app-id)"/>

	<!-- Prepare Credentions -->
	<xsl:variable name="cr-os"	select="true()"/>
	<!--<xsl:variable name="cr-os"	select="cred:check('/vzdir/infrman/templates/manage')"/>-->
	<xsl:variable name="cr-app"	select="true()"/>
	<!--<xsl:variable name="cr-app"	select="cred:check('/vzdir/infrman/templates/template/manage')"/>-->

	<xsl:variable name="cr-base-detail"	select="($app-list-type = 'os' and $cr-os) or ($app-list-type = 'app' and $cr-app)"/>
		
	<!-- no base detail - no access to screen -->
	<xsl:param name="access-denied" select="not($cr-base-detail)"/>

	<xsl:template name="local:show-tab-bar">
		<xsl:param name="pkg"/>
		<xsl:choose>
			<xsl:when test="sw:param('mode')='group'">
				<xsl:choose>
				<xsl:when test="vt:is-platform-linux(sw:lc($pkg/os/platform))">
					<ui:tab-bar id="group-app-linux" current-tab="rpms"/>
				</xsl:when>
				<xsl:otherwise>
					<ui:tab-bar id="group-app-windows" current-tab="rpms"/>
				</xsl:otherwise>
			</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<ui:tab-bar id="app" current-tab="rpms"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<func:function name="local:screen-id">
		<xsl:choose>
			<xsl:when test="sw:param('mode')='group'">
				<func:result select="sw:if($app-list-type='os','03.02.01.39.05','03.02.01.39.06')" />
			</xsl:when>
			<xsl:otherwise>
				<func:result select="sw:if($app-list-type='os','03.02.01.36.02','03.02.01.36.03')" />
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<xsl:template mode="screen" match="/">
		<xsl:variable name="pkg-packet" select="vzapackagem:list-app-rpms($app-id, sw:hn-eid())" />
		<xsl:variable name="error" select="$pkg-packet/packet/data/error|$pkg-packet/packet/data/vzapackagem/error" />
		<xsl:variable name="pkg" select="$pkg-packet/packet/data/vzapackagem/packages/package" />

		<ui:screen id="{local:screen-id()}" icon="{sw:if($app-list-type='app','app_package','app_package')}">
			<xsl:call-template name="local:show-tab-bar">
				<xsl:with-param name="pkg" select="$parent-app"/>
			</xsl:call-template>
			
			<ui:properties>
				<ui:description width="full">
					<sw:text>List of software packages included in this template.</sw:text>
				</ui:description>
				<ui:form-get/>
			</ui:properties>
						
			<ui:content>
				<ui:hidden name="mode" value="{sw:param('mode')}" />
				<xsl:choose>
					<!-- Error occurred -->
					<xsl:when test="$error">
						<xsl:call-template name="templates:show-error">
							<xsl:with-param name="message">
								<sw:text>Error listing packages</sw:text>
							</xsl:with-param>
							<xsl:with-param name="error" select="$error" />
						</xsl:call-template>
					</xsl:when>
					<!-- /Error occurred -->

					<!-- Received data  -->
					<xsl:otherwise>
						<xsl:call-template name="local:show-data">
							<xsl:with-param name="data" select="$pkg" />
							<xsl:with-param name="show-url" select="sw:is-ez-package($parent-app/name)" />
						</xsl:call-template>
					</xsl:otherwise>
					<!-- /Received data-->
				</xsl:choose>
			</ui:content>

		</ui:screen>
	</xsl:template>

	<!-- Show data -->
	<xsl:template name="local:show-data">
		<xsl:param name="data" />
		<xsl:param name="show-url" />
		
		<xsl:variable name="filter_init_">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="app-rms" url="/vzdir/infrman/templates/ez/app-rpms?mode={sw:param('mode')}">
						<xsl:if test="$show-url">
							<xsl:attribute 
								name="item-url">/vzdir/infrman/templates/ez/app-rpm?mode=<xsl:value-of select="sw:param('mode')"/></xsl:attribute>
						</xsl:if>
					</ui:browse-setup>
					<ui:cols>
						<ui:column id="rpm-id" hidden="yes">
							<xsl:if test="$show-url">
								<xsl:attribute name="nav-type">id</xsl:attribute>
								<xsl:attribute name="for-url">yes</xsl:attribute>
							</xsl:if>
						</ui:column>
						<ui:column id="name" title="{sw:text('Name')}" filter="auto">
							<xsl:if test="$show-url">
								<xsl:attribute name="nav-type">id</xsl:attribute>
							</xsl:if>
						</ui:column>
					</ui:cols>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>


		<xsl:variable name="filter">
			<xsl:call-template name="browse:fill-filter">
				<xsl:with-param name="filter" select="exsl:node-set($filter_init_)" />
				<xsl:with-param name="rows">
					<ui:browse-rows>
						<xsl:for-each select="$data">
							<ui:row>
								<rpm-id><xsl:value-of select="vzapackagem:generate-id(.)"/></rpm-id>								
								<name>
									<xsl:value-of select="name" />
								</name>
							</ui:row>
						</xsl:for-each>
					</ui:browse-rows>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<ui:block width="full">
			<ui:browse>
				<xsl:attribute name="title">
					<sw:text>Packages</sw:text>
				</xsl:attribute>

				<ui:filter>
					<xsl:copy-of select="$filter" />
				</ui:filter>

				<ui:browse-empty-msg>
					<sw:text>No included packages.</sw:text>
				</ui:browse-empty-msg>

			</ui:browse>
		</ui:block>
	</xsl:template>

</xsl:stylesheet>
