<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred tem vzenv vzapackagem local"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"   
	xmlns:browse	="http://www.swsoft.com/xsl/cp/browse"   
	xmlns:cred		="http://www.swsoft.com/xsl/cp/cred"
	xmlns:tem		="http://www.swsoft.com/xsl/cp/tem"
	xmlns:vzenv		="http://www.swsoft.com/xsl/cp/vzenv"	
	xmlns:vzhn		="http://www.swsoft.com/xsl/cp/vzhn"	
	xmlns:vzapackagem	="http://www.swsoft.com/xsl/cp/vzapackagem"	
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"	
	xmlns:vz		="http://www.swsoft.com/xsl/cp/vz"
	xmlns:templates	="http://www.swsoft.com/xsl/cp/templates"
 >
 
	<sw:include href="/lib/vt/hn-list.xsl"/>
	<sw:include href="/lib/vz/vzenv-core.xsl"/>
	<sw:include href="/lib/vzdir/infrman/templates/browse.xsl"/>
	
	<!-- Prepare listing type -->  
  <xsl:variable name="app-list-type" select="sw:sesget('app-list-type')"/>
  <xsl:variable name="app-id" select="sw:sesget('app-id')"/>

	<!-- Prepare Credentions -->
	<xsl:variable name="cr-manage" select="cred:check-context('vzcp.template','hn.vz.vt')"/>
	<xsl:variable name="cr-ve-app"	select="cred:check('vzcp.env.manage.properties.application')"/> 
	<xsl:variable name="cr-ve-list"		select="$activeMode = 'vzcc'"/>
		
	<!-- no base detail - no access to screen -->
	<xsl:param name="access-denied" select="not($cr-manage)"/>

	<xsl:template mode="screen" match="/">

		<!-- Load Template Data -->
		<xsl:variable name="pkg" select="/packet/package" />

		<ui:screen id="{sw:if($app-list-type='os','03.02.01.36.00','03.02.01.36.01')}"
			icon="{sw:if($app-list-type='app','app_tmpl','os_tmpl')}">

			<ui:properties>
				<ui:refresh-type>GET</ui:refresh-type>
				<ui:form-get/>
				<ui:description width="full">
					<xsl:choose>
						<xsl:when test="not(string($pkg/description)='')">
							<xsl:value-of select="$pkg/description" />
						</xsl:when>
						<xsl:when test="$app-list-type='app'">
							<sw:text>Application template.</sw:text>
						</xsl:when>
						<xsl:otherwise>
							<sw:text>OS template.</sw:text>
						</xsl:otherwise>
					</xsl:choose>
				</ui:description>
			</ui:properties>

			<ui:tab-bar id="app" current-tab="gen" />

			<xsl:choose>
				<!-- Error occurred -->
				<xsl:when test="/packet/errors/error">
					<xsl:call-template name="local:show-error">
						<xsl:with-param name="error" select="/packet/errors/error" />
					</xsl:call-template>
				</xsl:when>
				<!-- /Error occurred -->

				<!-- No data  -->
				<xsl:when test="not($pkg)">
					<xsl:call-template name="local:show-error" />
				</xsl:when>
				<!-- /No data-->

				<!-- Received data  -->
				<xsl:otherwise>
					<xsl:call-template name="local:show-data">
						<xsl:with-param name="data" select="$pkg" />
					</xsl:call-template>
				</xsl:otherwise>
				<!-- /Received data-->
			</xsl:choose>
		</ui:screen>
	</xsl:template>

	<!-- Show data -->
	<xsl:template name="local:show-data">
		<xsl:param name="data" />
		<xsl:param name="ve-filter" />

		<ui:content>
			<ui:hidden name="app-id" value="{sw:base64-encode(vzapackagem:generate-id($app-id))}"/>
			<xsl:call-template name="templates:show-summary-block">
				<xsl:with-param name="pkg" select="$data"/>
				<xsl:with-param name="show-cached" select="true()"/>
			</xsl:call-template>
			<!-- /Show Template Info -->
			
			<xsl:if test="$cr-ve-list">
				<ui:block width="full">
					<!-- Show VEs -->
					<xsl:call-template name="templates:list-ves">
						<xsl:with-param name="url" select="'/vzdir/infrman/templates/ez/app'" />
						<xsl:with-param name="hn-eid" select="sw:hn-eid()" />
						<xsl:with-param name="actions" select="'app-control'" />
						<xsl:with-param name="app-id" select="$app-id" />
						<xsl:with-param name="app-type" select="$app-list-type" />
					</xsl:call-template>
	
				</ui:block>
			</xsl:if>
		</ui:content>

	</xsl:template>

	<!-- Show some VZA error -->
	<xsl:template name="local:show-error">
		<xsl:param name="error" select="/.."/>
		
		<ui:content>
			<ui:block>
				<ui:operation-problem>
					<ui:type>vza-error</ui:type>
					<ui:descr>
						<sw:text>Error reading the application information.</sw:text>
					</ui:descr>
					<ui:vza-error>
						<xsl:copy-of select="$error/*"/>
					</ui:vza-error>
					<ui:reason>
						<sw:text>The requested application was removed from the Hardware Node.</sw:text>
					</ui:reason>
					<ui:solution>
						<sw:text>Return to the list of the applications and select another application.</sw:text>
					</ui:solution>
				</ui:operation-problem>
			</ui:block>
		</ui:content>
		
	</xsl:template>
	
	<sw:include href="/lib/screen.xsl"/>

	<sw:include href="/lib/vzaconfig.xsl"/>
	<sw:include href="/lib/vza/vzapackagem.xsl"/>  
  
	<sw:include href="/lib/vocabulary.xsl"/>

  
</xsl:stylesheet>
