  <!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred vt error func local templates units"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:vt="http://www.swsoft.com/xsl/cp/vt"
	xmlns:voc="http://www.swsoft.com/xsl/cp/voc"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:func="http://exslt.org/functions"
	xmlns:templates="http://www.swsoft.com/xsl/cp/templates"
	xmlns:units ="http://www.swsoft.com/xsl/cp/units"

>
	<sw:include href="/lib/core/units-core.xsl"/>

	<sw:include href="/lib/vzdir/infrman/templates/browse.xsl" />

	<!-- Prepare listing type -->
	<xsl:variable name="app-list-type">
		<xsl:variable name="get-var" select="sw:param('type')" />
		<xsl:if test="$get-var">
			<xsl:if test="sw:sesput('app-list-type',sw:if($get-var='os',string($get-var),'app'))" />
		</xsl:if>
		<xsl:value-of select="sw:sesget('app-list-type')" />
	</xsl:variable>

	<xsl:template mode="screen" match="/">

		<!-- Init data -->
		<xsl:variable name="filter-rtf"	select="templates:make-global-browse-filter(
			$app-list-type,'/vzdir/infrman/templates/index', '/vzdir/infrman/templates/ez/group-app'
		)"/>		
		<xsl:variable name="filter" select="exsl:node-set($filter-rtf)"/>
		<!-- /Init Data -->

		<ui:screen id="{sw:if($app-list-type='os','03.02.01.39.01','03.02.01.39.02')}">
			<xsl:call-template name="units:define-unit-toolbars"/>
			<ui:properties>
				<ui:form-get/>
				<ui:description width="full">
					<sw:text>
						<xsl:with-param name="type-templates" select="sw:if($app-list-type='os',sw:text('OS templates'),sw:text('application templates'))"/>
						The %{type-templates} listed on this screen are installed on one or more Hardware Nodes in your datacenter.
						<br/>Standard templates carry all the necessary package files inside themselves and have versions.
						<br/>EZ templates have only information about the necessary packages, and the packages themselves are downloaded from a central repository. EZ templates do not have versions.
					</sw:text>
				</ui:description>
			</ui:properties>

			<ui:tab-bar id="unit" current-tab="tmpls" current-subtab="{$app-list-type}" />
			<ui:content>

				<ui:block width="full">
					<ui:browse>
						<xsl:attribute name="title">
							<sw:text>Templates</sw:text>
						</xsl:attribute>

						<ui:browse-js-many>
							<ui:warn>
								<sw:text>Select at least one template!</sw:text>
							</ui:warn>
						</ui:browse-js-many>

						<ui:filter>
							<xsl:copy-of select="$filter-rtf" />
						</ui:filter>
						
						<xsl:variable name="submit-href" select="concat('list-control?branch=vz-templates,', sw:if($app-list-type='os', 'oses', 'apps'))"/>
						
						<xsl:variable name="has-linux" select="$filter//ui:row[platform-os='Linux']"/>
						
						<ui:browse-buttons>
						
							<ui:button type="list-selection" tip="add_template" icon="app_tmpl" require-items="false"
								new-obj-title="{sw:text('Template')}"
								submit-href="{$baseurl}/vzdir/infrman/templates/standard/add"
							>
								<sw:text>New Template</sw:text>
							</ui:button>
												
							<ui:button type="list-selection" tip="install_vz_tmpl_hn" 
								icon="installupdate"
								script="if (!atLeastOne()) return false;" name="install"
								submit-href="{$submit-href}">
								<sw:text>Install to HNs</sw:text>
							</ui:button>
							<xsl:if test="$app-list-type='app'">
								<ui:button type="list-selection" tip="install_vz_tmpl_ve" 
									icon="env_reinstall"
									script="if (!atLeastOne()) return false;" name="install-app"
									submit-href="{$submit-href}">
									<sw:text>Add to Containers</sw:text>
								</ui:button>
							</xsl:if>
						</ui:browse-buttons>
						<xsl:if test="$app-list-type='os' and $has-linux">
							<ui:browse-buttons>
									<ui:button type="list-selection" tip="cache_vz_tmpl" icon="cache_vz_template"
										script="if (!atLeastOne()) return false;" name="cache"
										submit-href="{$submit-href}">
										<sw:text>Cache on HNs</sw:text>
									</ui:button>
							</ui:browse-buttons>
						</xsl:if>
						<ui:browse-buttons>
							<ui:button type="list-selection" tip="deinstall_vz_tmpl_hn" icon="delete"
								submit-href="{$submit-href}" script="if (!atLeastOne()) return false;"
								name="deinstall">
								<sw:text>Uninstall From HNs</sw:text>
							</ui:button>
						</ui:browse-buttons>

						<!-- form definition for other controls -->
						<ui:browse-empty-msg>
							<sw:text>No templates available.</sw:text>
						</ui:browse-empty-msg>

					</ui:browse>

				</ui:block>
			</ui:content>

		</ui:screen>
	</xsl:template>

	<sw:include href="/lib/screen.xsl" />

</xsl:stylesheet>
