<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet
	version="1.0"
	extension-element-prefixes="sw exsl cred func"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:func="http://exslt.org/functions"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:vzapackagem="http://www.swsoft.com/xsl/cp/vzapackagem"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred">
	
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/vza/vzapackagem.xsl"/>
	<sw:include href="/lib/screen.xsl"/>


	<!-- check permissions to show this page -->
	<xsl:template mode="screen" match="/">
		<xsl:variable name="app-id" select="local:get('app-id')"/>
		<xsl:variable name="hn-eid" select="local:get('hn-eid')"/>

		<xsl:variable name="pkg-packet" select="vzapackagem:get($app-id, $hn-eid)/packet/data"/>
		<xsl:variable name="app" select="$pkg-packet/vzapackagem/packages/package"/>

		<ui:popup-screen id="03.02.01.39.15" icon="apps">
			<ui:properties>
				<ui:refresh-type>none</ui:refresh-type>
			</ui:properties>

			<ui:content>
				<ui:block width="full">
					<xsl:choose>
						<xsl:when test="$app">
							<ui:rows>
								<xsl:apply-templates select="$app"/>
							</ui:rows>
						</xsl:when>
						<xsl:otherwise>
							<sw:text>No templates selected.</sw:text>
						</xsl:otherwise>
					</xsl:choose>
				</ui:block>
			</ui:content>
		</ui:popup-screen>
	</xsl:template>

	<xsl:template match="package[vzapackagem:is-os(.) and sw:is-ez-package(name)]">
		<xsl:attribute name="title">
			<sw:text>
				<xsl:with-param name="app-name" select="sw:app-id2title(name)"/>
				'%{app-name}' OS EZ Template
			</sw:text>
		</xsl:attribute>
		<xsl:call-template name="fields"/>
	</xsl:template>

	<xsl:template match="package[vzapackagem:is-os(.) and not(sw:is-ez-package(name))]">
		<xsl:attribute name="title">
			<sw:text>
				<xsl:with-param name="app-name" select="sw:app-id2title(name)"/>
				'%{app-name}' OS Standard Template
			</sw:text>
		</xsl:attribute>
		<xsl:call-template name="fields"/>
	</xsl:template>

	<xsl:template match="package[not(vzapackagem:is-os(.)) and sw:is-ez-package(name)]">
		<xsl:attribute name="title">
			<sw:text>
				<xsl:with-param name="app-name" select="sw:app-id2title(name)"/>
				'%{app-name}' Application EZ Template
			</sw:text>
		</xsl:attribute>
		<xsl:call-template name="fields"/>
	</xsl:template>

	<xsl:template match="package[not(vzapackagem:is-os(.) or sw:is-ez-package(name))]">
		<xsl:attribute name="title">
			<sw:text>
				<xsl:with-param name="app-name" select="sw:app-id2title(name)"/>
				'%{app-name}' Application Standard Template
			</sw:text>
		</xsl:attribute>
		<xsl:call-template name="fields"/>
	</xsl:template>

	<xsl:template name="fields">
		<ui:row>
			<ui:cell-label>
				<sw:text>Summary</sw:text>
			</ui:cell-label>
			<ui:cell>
				<xsl:value-of select="summary"/>
			</ui:cell>
		</ui:row>
		<ui:row>
			<ui:cell-label>
				<sw:text>Platform</sw:text>
			</ui:cell-label>
			<ui:cell>
				<xsl:value-of select="os/platform"/>
			</ui:cell>
		</ui:row>
		<xsl:if test="arch">
			<ui:row>
				<ui:cell-label>
					<sw:text>Architecture</sw:text>
				</ui:cell-label>
				<ui:cell>
					<xsl:value-of select="sw:if(arch='', sw:text('n/a'), arch)"/>
				</ui:cell>
			</ui:row>
		</xsl:if>
		<xsl:if test="distributive">
			<ui:row>
				<ui:cell-label>
					<sw:text>Distribution</sw:text>
				</ui:cell-label>
				<ui:cell>
					<xsl:value-of select="sw:if(os/name='', sw:text('n/a'), os/name)"/>
				</ui:cell>
			</ui:row>
		</xsl:if>
		<ui:row>
			<ui:cell-label>
				<sw:text>Description</sw:text>
			</ui:cell-label>
			<ui:cell>
				<xsl:value-of select="description"/>
			</ui:cell>
		</ui:row>
	</xsl:template>

	<func:function name="local:get">
		<xsl:param name="name"/>
		<xsl:param name="default" select="''"/>
		<func:result
			select="sw:if(not(string(sw:param($name))=''), sw:base64-decode(sw:param($name)), $default)"/>
	</func:function>

</xsl:stylesheet>
