<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet
	version="1.0"
	extension-element-prefixes="sw exsl func wiz tem cred"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:tem="http://www.swsoft.com/xsl/cp/tem"
	xmlns:here="http://www.swsoft.com/xsl/cp/here"
	xmlns:form="http://www.swsoft.com/xsl/cp/form"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:vt="http://www.swsoft.com/xsl/cp/vt"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:hn="http://www.swsoft.com/xsl/cp/hn"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
>
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/layout/forms-list.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/vt/core.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vt/hn-core.xsl"/>
	<sw:include href="/lib/vt/hn-select.xsl"/>
	<sw:include href="/lib/vza/tem.xsl"/>

	<xsl:param name="wiz_code" select="'app-install'"/>

	<xsl:variable name="step_data" select="wiz:getStep()"/>
	<xsl:variable name="form" select="sw:sesget($wiz_data)"/>
	<xsl:variable name="step" select="$step_data/@id"/>

	<xsl:variable name="screenid" select="$step_data/@screenid"/>
	<xsl:variable name="path-id" select="string(wiz:getSteps()/step[@id = 'gen']/@screenid)"/>
	<xsl:variable name="screen-title" select="$step_data/@title"/>
	<xsl:variable name="app-list-type" select="sw:sesget('app-list-type')"/>

	<!-- check permissions -->
	<xsl:param name="access-denied" select="( $form/gen/hn and not(cred:check-hw('vzcp.template',$form/gen/hn)) ) 
		or ( not($form/gen/hn) and not(cred:check('vzcp.template')) )"/>

	<xsl:template mode="screen" match="/">
		<ui:screen path-id="{$path-id}" id="{$screenid}" title="{$screen-title}">

			<ui:properties>
				<ui:refresh-type>none</ui:refresh-type>
				<ui:description mandatory="yes">
					<sw:text>Here you can install a new template on the Hardware Node.</sw:text>
				</ui:description>
			</ui:properties>

			<ui:content>
				<ui:hidden name="step" value="{$step}"/>
				<ui:block mode="edit">
					<ui:rows title="{sw:text('Upload Template From Your Computer')}">
						<ui:row>
							<ui:cell-label offset="1">
								<sw:text>File</sw:text>
							</ui:cell-label>
							<ui:cell-file id="upload" required="true"/>
						</ui:row>
					</ui:rows>
					
					<ui:rows title="{sw:text('Select Hardware Node')}">
						<ui:row>
							<ui:cell-label offset="1">
								<sw:text>Hardware Node</sw:text>
							</ui:cell-label>
							<ui:cell-selector id="hn" align="left" value="{env:env2title(env:get-env($form/gen/hn)/env)}"
								code-value="{$form/gen/hn}" link-tip="select_hn"
								link-onclick="open_details('{$baseurl}/vt/hns/select-one-popup?id=hn');return false;"
								link-caption="{sw:text('Select...')}"/>
						</ui:row>
					</ui:rows>
					
					<ui:rows title="{sw:text('Specify Installation Options')}">
						<ui:row>
							<ui:cell-label offset="1">
								<sw:text>Template Type</sw:text>
							</ui:cell-label>
							<ui:cell-list id="tmplt_type" value="{$form/gen/type}">
								<ui:list-item id="auto" title="{sw:text('Detect Automatically')}"/>
								<ui:list-item id="ez" title="{sw:text('EZ Template')}"/>
								<ui:list-item id="std" title="{sw:text('Standard Template')}"/>
							</ui:cell-list>
						</ui:row>
						<ui:row>
							<ui:cell-label offset="1" label-for="force">
								<sw:text>Force Installation</sw:text>
							</ui:cell-label>
							<ui:cell-check id="force" checked="{$form/gen/force}"/> 
						</ui:row>
					</ui:rows>

					<ui:buttons>
						<xsl:call-template name="wiz:showButtons"/>
					</ui:buttons>

				</ui:block>

			</ui:content>
		</ui:screen>
	</xsl:template>

</xsl:stylesheet>
