<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred check local update voc date dynamic updateui"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:dynamic="http://www.swsoft.com/xsl/cp/dynamic" xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error" xmlns:check="http://www.swsoft.com/xsl/cp/check"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz" xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:update="http://www.swsoft.com/xsl/cp/update" xmlns:voc="http://www.swsoft.com/xsl/cp/voc"
	xmlns:func="http://exslt.org/functions" xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:updateui="http://www.swsoft.com/xsl/cp/update-screen" 
	xmlns:date="http://exslt.org/dates-and-times"
	xmlns:vzapackagem="http://www.swsoft.com/xsl/cp/vzapackagem"
	xmlns:templates	="http://www.swsoft.com/xsl/cp/templates"
	xmlns:vzhn="http://www.swsoft.com/xsl/cp/vzhn"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui">
	
	<sw:include href="/lib/common.xsl" />
	<sw:include href="/lib/vz/update-screen.xsl" />
	<sw:include href="/lib/vz/vzhn-info.xsl"/>
	<sw:include href="/lib/vza/vzapackagem.xsl" />
	<sw:include href="/lib/vzdir/infrman/templates/browse.xsl"/>

	<xsl:variable name="hn-eid" select="vzhn:set-hn-from-req()"/>
	<!-- check permissions to show this page -->
	<xsl:variable name="cred" select="cred:check-hw('vzcp.hn.manage.update',$hn-eid)"/>
	<xsl:variable name="cred-config" select="$cred"/>
	<xsl:variable name="cred-templates"
		select="$cred"/>
	
	<xsl:param name="access-denied" select="not($cred)"/>
	
	<xsl:variable name="task" select="update:get-task($hn-eid)/id"/>
	<xsl:variable name="task-id" select="string($task)"/>
	
	<xsl:variable name="update-config" select="update:get-config($hn-eid)/connection"/>
	<xsl:variable name="updates-cache" select="update:get-cached-update-list($hn-eid)"/>
	<xsl:variable name="update-error" select="$updates-cache/templates/error"/>
	
	<xsl:variable name="ids">
		<xsl:choose>
			<xsl:when test="sw:param('app-id')">
				<xsl:for-each select="sw:param('app-id')">
					<app-id><xsl:value-of select="substring-before(., '|')"/></app-id>
				</xsl:for-each>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="sw:sesget('update-app-ids')"/>
			</xsl:otherwise>
		</xsl:choose>
		
	</xsl:variable>
	<xsl:variable name="app-ids" select="exsl:node-set($ids)/app-id"/>
	
	<xsl:template name="upd-screen">
		<xsl:if test="sw:sesput('update-app-ids', $app-ids)"/>
		
		<xsl:variable name="templates" select="vzapackagem:vztemplate-packages($app-ids)"/>
		<xsl:variable name="has-problem" select="not($update-config/server) or error:has-errors() or $updates-cache/templates/error" />
		<xsl:variable name="time" select="date:seconds(sw:vzatime2time($updates-cache/timestamp))" />
		
		<xsl:variable name="buttons">
			<id>updates.templates.check.selected</id>
			<id>updates.templates.install</id>
		</xsl:variable>
		
		<ui:screen id="03.02.01.35.06">
			<ui:properties>
				<ui:form-get/>
				<ui:description mandatory="yes">
					<sw:text>
						Find and install updates for your template using the Parallels update repository.
					</sw:text>
					<xsl:if test="$templates and not($task-id!='')">
						<br />
						<br />
						<xsl:call-template name="updateui:update-status">
							<xsl:with-param name="time" select="$time" />
							<xsl:with-param name="url" select="'/vz/cp/vzdir/maintman/updates/check-update-dynamic?type=templates'" />
							<xsl:with-param name="has-problem" select="$has-problem" />
							<xsl:with-param name="disable-buttons-ids" select="exsl:node-set($buttons)/id"/>
						</xsl:call-template>
					</xsl:if>
				</ui:description>
			</ui:properties>

			<ui:content>
				<xsl:choose>
					<xsl:when test="not($templates)">
						<ui:block>
							<ui:rows title="{sw:text('Error')}">
								<ui:row>
									<ui:cell>
										<sw:text>No templates have been selected for update.</sw:text>
									</ui:cell>
								</ui:row>
							</ui:rows>
						</ui:block>
					</xsl:when>
					<xsl:when test="$has-problem">
						<xsl:call-template name="local:has-problem" />
					</xsl:when>
					<xsl:when test="$task-id!=''">
						<xsl:call-template name="local:show-progress" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:variable name="raw-updates"
							select="update:filter-template-updates($updates-cache/update, $templates)"/>
							
						<xsl:variable name="updates" select="$raw-updates[update:is-update(.) 
																			or app_template[update:is-update(.)]]"/>
							
						<!-- show selected templates -->
						<ui:block>
							<ui:rows title="{sw:text('Selected Templates')}">
								<ui:row>
									<ui:cell>
										<xsl:for-each select="$templates">
											<xsl:if test="position() &gt; 1">
												<xsl:text>, </xsl:text>
											</xsl:if>
											<nobr>
												<xsl:call-template name="templates:show-app-name-link">
													<xsl:with-param name="app-id" select="."/>
													<xsl:with-param name="hn-eid" select="$hn-eid"/>
													<xsl:with-param name="show-version" select="false()"/>
												</xsl:call-template>
											</nobr>
										</xsl:for-each>
									</ui:cell>
								</ui:row>
								
							</ui:rows>
						</ui:block>
						
						<!-- show update status -->
						<xsl:variable name="need-update" select="update:template-cache-needs-refresh($updates-cache)" />

						<xsl:choose>
							<xsl:when test="$need-update">
								<xsl:call-template name="local:need-update">
									<xsl:with-param name="time" select="$time" />
								</xsl:call-template>
							</xsl:when>
							<xsl:when test="not($updates)">
								<xsl:call-template name="local:up-to-date">
									<xsl:with-param name="time" select="$time" />
								</xsl:call-template>
							</xsl:when>
							<xsl:otherwise>
								<xsl:call-template name="local:show-updates">
									<xsl:with-param name="time" select="$time"/>
									<xsl:with-param name="updates"
										select="$updates"/>
								</xsl:call-template>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:otherwise>
				</xsl:choose>
			</ui:content>
		</ui:screen>
	</xsl:template>
	
	<xsl:template name="local:show-progress">
		<xsl:call-template name="local:has-problem"/>
	</xsl:template>
	
	<xsl:template name="local:show-updates">
		<xsl:param name="time" select="0" />
		<xsl:param name="updates" select="/.." />

		<xsl:call-template name="local:add-actions">
			<xsl:with-param name="disable-install" select="false()" />
		</xsl:call-template>

		<xsl:call-template name="updateui:show-template-update-list">
			<xsl:with-param name="updates" select="$updates"/>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="local:up-to-date">
		<xsl:param name="time" select="0" />

		<xsl:call-template name="local:add-actions"/>

		<xsl:call-template name="local:up2date-msg"/>
	</xsl:template>

	<xsl:template name="local:need-update">
		<xsl:param name="time" select="0"/>		
		
		<ui:raw>
			<script>get_updates();</script>
		</ui:raw>
		<xsl:call-template name="local:add-actions">
			<xsl:with-param name="disable-check" select="true()"/>
		</xsl:call-template>
	</xsl:template>
		
	<xsl:template name="local:add-actions">
		<xsl:param name="disable-check" select="false()"/>
		<xsl:param name="disable-install" select="true()"/>
		
		<xsl:if test="$disable-check or $disable-install">
			<ui:raw>
				<script>
					<xsl:if test="$disable-check">
						disableToolbarItem('updates.templates.check.selected');
					</xsl:if>
					<xsl:if test="$disable-install">
						disableToolbarItem('updates.templates.install');
					</xsl:if>
				</script>
			</ui:raw>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="local:has-problem">
		<xsl:variable name="update-error"
			select="$updates-cache/templates/error|sw:if(error:has-errors(), error:get(), null)"/>

		<xsl:call-template name="local:add-actions">
			<xsl:with-param name="disable-check" select="not($task-id='')"/>
		</xsl:call-template>

		<ui:block>
			<ui:operation-problem>
				<ui:type>custom</ui:type>

				<ui:descr>
					<sw:text>Virtuozzo cannot check for template updates now.</sw:text>
				</ui:descr>
				<ui:reason>
					<xsl:choose>
						<xsl:when test="not($update-config/server)">
							<sw:text>The updates repository is not configured.</sw:text>
						</xsl:when>
						<xsl:when test="$task-id!=''">
							<sw:text>Virtuozzo update is already running. Please wait for the operation to finish.</sw:text>
						</xsl:when>
						<xsl:when test="$update-error">
							<sw:text>Error checking for updates.</sw:text>
						</xsl:when>
					</xsl:choose>
				</ui:reason>

				<xsl:if test="not($update-config/server)">
					<xsl:choose>
						<xsl:when test="$cred-config">
							<ui:solution>
								<sw:text>
									<xsl:with-param name="aopen"
											>&lt;a onmouseover="callTip('config_update',event)" onmouseout="callTip()"  href="<xsl:value-of
											select="$baseurl"
										/>/vzdir/maintman/setup/updates?branch=vz-update,templates" &gt;</xsl:with-param>
									<xsl:with-param name="aclose"
									>&lt;/a&gt;</xsl:with-param>
									Please %{aopen}configure%{aclose} the repository settings.
								</sw:text>
							</ui:solution>
						</xsl:when>
						<xsl:otherwise>
							<ui:solution>
								<sw:text>Call the Node administrator for support.</sw:text>
							</ui:solution>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:if>

				<xsl:if test="$task-id!=''">
					<xsl:variable name="popup-id" select="concat('tasks_list_',$ticketid)"/>
					<ui:solution>
						<ui:raw>
							<a onmouseover="callTip('open_details',event)" onmouseout="callTip()"
								onclick="open_details('{$baseurl}/core/tasks/details-popup?id={$task-id}'),'{$popup-id}'"
								href="javascript:void(0)">
								<sw:text>Check the update operation status.</sw:text>
							</a>
						</ui:raw>
					</ui:solution>
				</xsl:if>

				<xsl:if test="$update-error">
					<xsl:if test="$cred-config and $update-config/server">
						<ui:solution>
							<sw:text>
								<xsl:with-param name="aopen"
										>&lt;a onmouseover="callTip('config_update',event)" onmouseout="callTip()"  href="<xsl:value-of
										select="$baseurl"
									/>/vzdir/maintman/setup/updates?branch=vz-update,templates" &gt;</xsl:with-param>
								<xsl:with-param name="aclose"
								>&lt;/a&gt;</xsl:with-param>
								Please %{aopen}check%{aclose} the repository settings.
							</sw:text>
						</ui:solution>
					</xsl:if>
					<ui:solution>
						<sw:text>Check the error details and call the Node administrator for support.</sw:text>
						<ui:raw>
							<br/>
							<xsl:call-template name="dynamic:error-reporter">
								<xsl:with-param name="errors" select="$update-error"/>
								<xsl:with-param name="open" select="sw:text('Show Technical Details')"/>
								<xsl:with-param name="hide" select="sw:text('Hide Technical Details')"/>
								<xsl:with-param name="message" select="false()"/>
							</xsl:call-template>
						</ui:raw>
					</ui:solution>

				</xsl:if>
			</ui:operation-problem>
		</ui:block>
		<xsl:if test="update:clear-cached-template-update-list()"/>
	</xsl:template>
	

	<xsl:template name="local:up2date-msg">
		<ui:block mode="view">
			<ui:rows title="{sw:text('Up-to-date Status')}">
				<ui:row>
					<ui:cell-value>
						<ui:raw>
							<xsl:choose>
								<xsl:when test="count($app-ids) &gt; 1">
									<sw:text>
										The templates you have selected are up-to-date.
									</sw:text>
								</xsl:when>
								<xsl:otherwise>
									<sw:text>
										The template you have selected is up-to-date.
									</sw:text>
								</xsl:otherwise>
							</xsl:choose>
						</ui:raw>
					</ui:cell-value>
				</ui:row>
			</ui:rows>
		</ui:block>
	</xsl:template>

	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
		<xsl:call-template name="upd-screen" />
	</xsl:template>
	
</xsl:stylesheet>
