<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl local func dyn update dynamic"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:func="http://exslt.org/functions" xmlns:dyn="http://exslt.org/dynamic"
	xmlns:local="http://www.swsoft.com/xsl/cp/local" xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui" xmlns:update="http://www.swsoft.com/xsl/cp/update"
	xmlns:updateui="http://www.swsoft.com/xsl/cp/update-screen"
	xmlns:vzhn="http://www.swsoft.com/xsl/cp/vzhn"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:dynamic="http://www.swsoft.com/xsl/cp/dynamic">
	
	<sw:include href="/lib/vz/vzhn-core.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vz/update-screen.xsl"/>
	
	<xsl:param name="hn-eid" select="sw:hn-eid()"/>
	
	<!-- check permissions to show this page -->
	<xsl:variable name="cred" select="cred:check-hw('vzcp.hn.manage.update', $hn-eid)"/>
	
	<xsl:param name="access-denied" select="not($cred)"/>
	
	
	<xsl:param name="hn" select="env:eid2info($hn-eid)"/>

	<xsl:template mode="screen" match="/">
		<ui:screen id="03.02.02.01.02">
			<ui:properties>
				<ui:form-get/>
				<ui:description mandatory="yes">
					<sw:text>Set up and test update repository settings.</sw:text>
				</ui:description>
			</ui:properties>
			
			<!-- content part -->
			<xsl:variable name="task" select="update:get-task($hn-eid)/id"/>
			<xsl:variable name="task-id" select="string($task)"/>
			
			<xsl:variable name="img-error">
				<img src="/{$theme}/icons/exclamation_32.gif" width="32" height="32" border="0" />
			</xsl:variable>
			
			<ui:tab-bar id="vzhn.update" current-tab="setup"/>
			
			<xsl:choose>
				<xsl:when test="not($task-id='')">
					<ui:content>
						<ui:block mode="view">
							<ui:rows title="{sw:text('Warning')}">
								<ui:row>
									<ui:cell-text colspan="2">
										<br/>
										<img src="/{$theme}/icons/alert_yellow.gif" width="16" height="16" border="0"/>&#160;<sw:text>
											Virtuozzo is already installing updates. The Virtuozzo updates repository settings are not available now. <br/> <br/> Please wait for the current updates installation to finish.
										</sw:text>
										<br/>
										<br/>
									</ui:cell-text>
								</ui:row>
							</ui:rows>
						</ui:block>
						<xsl:call-template name="updateui:install-templates-progress-ajax">
							<xsl:with-param name="msgid" select="$task-id"/>
						</xsl:call-template>
					</ui:content>
				</xsl:when>
				<xsl:otherwise>
					<ui:content>
						<xsl:variable name="config" select="update:get-config()"/>
						<xsl:apply-templates mode="local:show-service" select="$config"/>
						<xsl:apply-templates mode="local:show-repository" select="$config"/>
						<ui:block>
							<ui:buttons>
								<ui:button name="configure" tip="updates_setup" submit-href="/vz/cp/vzdir/maintman/updates/config-update">
									<sw:text>Configure</sw:text>
								</ui:button>
							</ui:buttons>
						</ui:block>
					</ui:content>
				</xsl:otherwise>
			</xsl:choose>
		</ui:screen>
	</xsl:template>
	
	<xsl:template match="connection[$hn/windows]" mode="local:show-repository">
		<ui:block mode="view">
			<ui:rows title="{sw:text('Proxy Server')}">
				<xsl:choose>
					<xsl:when test="proxy/type/no_proxy">
						<ui:row>
							<ui:cell-label>
								<sw:text>No proxy server is used.</sw:text>
							</ui:cell-label>
						</ui:row>
					</xsl:when>
					<xsl:when test="proxy/type/explorer">
						<ui:row>
							<ui:cell-label>
								<sw:text>The Internet Explorer settings are used.</sw:text>
							</ui:cell-label>
						</ui:row>
					</xsl:when>
					<xsl:when test="proxy/type/custom">
						<ui:row>
							<ui:cell-label>
								<sw:text>Proxy server</sw:text>
							</ui:cell-label>
							<ui:cell-text>
								<xsl:value-of select="proxy/server" />
							</ui:cell-text>
						</ui:row>
					</xsl:when>
				</xsl:choose>
			</ui:rows>
		</ui:block>
	</xsl:template>
	
	<xsl:template match="connection[$hn/linux]" mode="local:show-repository">
		<ui:raw>
			<xsl:call-template name="dynamic:error-reporter-script" />
		</ui:raw>
		
		<ui:block mode="view">
			<ui:rows title="{sw:text('Repository Settings')}">
				<xsl:choose>
					<xsl:when test="not(server)">
						<ui:row>
							<ui:cell>
								<xsl:copy-of select="$img-error" />
							</ui:cell>
							<ui:cell-label cell-width="100%">
								<sw:text>The repository is not configured.</sw:text>
							</ui:cell-label>
						</ui:row>
					</xsl:when>
					<xsl:otherwise>
						<ui:row>
							<ui:cell-label>
								<sw:text>Repository URL</sw:text>
							</ui:cell-label>
							<ui:cell-text>
								<xsl:value-of select="server" />
							</ui:cell-text>
						</ui:row>
						<xsl:if test="proxy/server">
							<ui:row>
								<ui:cell-label>
									<sw:text>Proxy server</sw:text>
								</ui:cell-label>
								<ui:cell-text>
									<xsl:value-of select="proxy/server" />
								</ui:cell-text>
							</ui:row>
						</xsl:if>
					</xsl:otherwise>
				</xsl:choose>
			</ui:rows>
			<xsl:if test="not(string(server)='')">
				<ui:rows title="{sw:text('Test Connection')}">
					<ui:row>
						<ui:cell-value>
							<xsl:call-template name="dynamic:create-ajax-div">
								<xsl:with-param name="init-msg" select="sw:text('Click to test the connection')" />
								<xsl:with-param name="progress-msg"
									select="sw:text('Connecting to update repository...')" />
								<xsl:with-param name="request-url">/vz/cp/vzdir/maintman/setup/repository-dynamic</xsl:with-param>
								<xsl:with-param name="target-id" select="'status'" />
							</xsl:call-template>
							<br /><br />
							<div id="status" />
						</ui:cell-value>
					</ui:row>
				</ui:rows>
			</xsl:if>
		</ui:block>
	</xsl:template>
	
	<xsl:template match="service" mode="local:show-service">
		<ui:block>
			<ui:rows title="{sw:text('Up-to-Date Service')}">
				<ui:row>
					<ui:cell-label>
						<sw:text>Status</sw:text>
					</ui:cell-label>
					<ui:cell-value>
						<xsl:choose>
							<xsl:when test="disabled">
								<sw:text>Disabled</sw:text>
							</xsl:when>
							<xsl:otherwise>
								<sw:text>Enabled</sw:text>
							</xsl:otherwise>
						</xsl:choose>
					</ui:cell-value>
				</ui:row>
				<ui:row>
					<ui:cell-label>
						<sw:text>Check for updates</sw:text>
					</ui:cell-label>
					<ui:cell-value>
						<sw:text>
							<xsl:with-param name="ondays" select="updateui:format-day(name(check_period/*[1]))"/>
							<xsl:with-param name="athour" select="updateui:format-hour(hour)"/>
							%ondays at %athour 
						</sw:text>
					</ui:cell-value>
				</ui:row>
				<ui:row>
					<ui:cell-label>
						<sw:text>Automatic reboot</sw:text>
					</ui:cell-label>
					<ui:cell-value>
						<xsl:choose>
							<xsl:when test="autoreboot">
								<sw:text>Enabled</sw:text>
							</xsl:when>
							<xsl:otherwise>
								<sw:text>Disabled</sw:text>
							</xsl:otherwise>
						</xsl:choose>
					</ui:cell-value>
				</ui:row>
			</ui:rows>
		</ui:block>
	</xsl:template>
	
	<xsl:template match="product" mode="local:show-repository">
		<ui:block>
			<ui:rows title="{name}">
				<ui:row>
					<ui:cell-label>
						<sw:text>Update Mode</sw:text>
					</ui:cell-label>
					<ui:cell-value>
						<xsl:value-of select="update:install-types()[@id=name(current()/install/*[1])]"/>
					</ui:cell-value>
				</ui:row>
				<ui:row>
					<ui:cell-label>
						<sw:text>Repository</sw:text>
					</ui:cell-label>
					<ui:cell-value>
						<xsl:value-of select="sw:base64-decode(source/value)"/><xsl:if 
							test="source/standard and string(source/standard)=string(source/value)">&#160;<sw:text>(default)</sw:text></xsl:if>
					</ui:cell-value>
				</ui:row>
				<ui:row>
					<ui:cell-label>
						<sw:text>Download Location</sw:text>
					</ui:cell-label>
					<ui:cell-value>
						<xsl:value-of select="sw:base64-decode(destination)"/>
					</ui:cell-value>
				</ui:row>
			</ui:rows>
		</ui:block>
	</xsl:template>

	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/screen.xsl" />
	<sw:include href="/lib/update.xsl" />
	<sw:include href="/lib/dynamic.xsl" />
	
</xsl:stylesheet>
