<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred update dynamic local func voc updateui"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:exsl="http://exslt.org/common"
	xmlns:func="http://exslt.org/functions" 
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui" 
	xmlns:dynamic="http://www.swsoft.com/xsl/cp/dynamic"
	xmlns:update="http://www.swsoft.com/xsl/cp/update" 
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:voc="http://www.swsoft.com/xsl/cp/voc" 
	xmlns:local="http://www.swsoft.com/xsl/cp/local" 
	xmlns:error="http://www.swsoft.com/xsl/cp/error" 
	xmlns:updateui="http://www.swsoft.com/xsl/cp/update-screen"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	>

	<sw:include href="/lib/common.xsl" />
	<sw:include href="/lib/vt/env-core.xsl" />

	<!-- check permissions to show this page -->
	<xsl:variable name="hn-eid" select="sw:hn-eid()"/>

	<xsl:template mode="screen" match="/">
		<xsl:choose>
			<xsl:when test="cred:check-context('vzcp.hn.manage.update','hn.vz.vt')">
				<xsl:call-template name="dynamic:create-ajax-handler">
					<xsl:with-param name="request-handler" select="'local:filter-updates'" />
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<span>You have no permission to manage updates on this HN.</span>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>


	<func:function name="local:filter-updates">
		<func:result>
			<result>
				<xsl:choose>
					<xsl:when test="sw:param('type')='templates'">
						<xsl:call-template name="local:list-template-updates" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="local:list-system-updates" />
					</xsl:otherwise>
				</xsl:choose>
			</result>
			<status><xsl:value-of select="sw:if(error:has-errors(), 'error', 'ok')" /></status>
		</func:result>
	</func:function>
	
	<xsl:template name="local:list-system-updates">
		<xsl:variable name="system" select="update:list($update:types/system)"/>
		<xsl:variable name="errors" select="update:get-errors($system)" />
		<xsl:variable name="updates" select="sw:if($errors, /.., $system[update:is-update(.)])"/>
		<xsl:if test="update:cache-major-update-list($system, $hn-eid)" />
		
		<xsl:choose>
			<xsl:when test="$errors">
				<xsl:call-template name="local:return-error">
					<xsl:with-param name="errors" select="$errors" />
					<xsl:with-param name="type" select="'virtuozzo'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="not($updates[category!='vzup2date-update'])">
				<sw:text>Your Virtuozzo installation is up-to-date.</sw:text>
				<br />
				<br />
			</xsl:when>
			<xsl:otherwise>
				<!-- show major update info -->
				<xsl:variable name="major" select="$updates[category='virtuozzo']"/>
				<xsl:variable name="minor"
					select="$updates[category='core'][position()=last()]|$updates[category='tools'][position()=last()]" />

				<xsl:if test="$major">
					<xsl:call-template name="local:show-major-update">
						<xsl:with-param name="update" select="$major" />
						<xsl:with-param name="has-minor" select="$minor" />
					</xsl:call-template>
					<br />
					<br />
				</xsl:if>

				<xsl:if test="$minor">
					<xsl:call-template name="local:show-minor-updates">
						<xsl:with-param name="updates" select="$minor" />
					</xsl:call-template>
					<br />
					<br />
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="local:show-major-update">
		<xsl:param name="update" />
		<xsl:param name="has-minor" select="false()" />

		<span>
			<xsl:choose>
				<xsl:when test="$update/product">
					<sw:text-plural>
						<sw:text-zero/>
						<xsl:with-param name="num" select="count($update)"/>
						<sw:text-single>An update for Virtuozzo is available.</sw:text-single>
						<sw:text-multiple>%{num} Virtuozzo updates are available.</sw:text-multiple>
					</sw:text-plural>
				</xsl:when>
				<xsl:otherwise>
					<sw:text>
						<xsl:with-param name="newver" select="substring-after($update/id, 'MU-')" />
						A newer Virtuozzo version %newver is available.
					</sw:text>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:if test="$has-minor">
				<br />
				<sw:text>
					You may either update Virtuozzo to the latest version or apply the updates for your current installation only.
				</sw:text>
			</xsl:if>
		</span>
		<br />
		<span>
			<a onmouseover="callTip('update_details',event)" onmouseout="callTip()"
				href="javascript:open_details('{$baseurl}/vzdir/maintman/updates/vzupdate-details?type=system&amp;{local:list($update/id, 'id')}')">
				<sw:text>View Details</sw:text>
			</a>&#160;|&#160;<a onmouseover="callTip('install_major',event)" onmouseout="callTip()"
				href="{$baseurl}/vzdir/maintman/updates/install-release">
				<sw:text>Install</sw:text>
			</a>
		</span>
	</xsl:template>
	
	<func:function name="local:list">
		<xsl:param name="data"/>
		<xsl:param name="label"/>

		<func:result>
			<xsl:for-each select="$data">
				<xsl:if test="position() &gt; 1"><xsl:value-of select="'&amp;'" /></xsl:if><xsl:value-of select="concat($label, '=', .)"/>
			</xsl:for-each>
		</func:result>
	</func:function>

	
	<xsl:template name="local:show-minor-updates">
		<xsl:param name="updates" />

		<span>
			<sw:text>
				<xsl:with-param name="oldver" select="exsl:node-set(
					voc:get('vocabulary', env:make-platform-ref($hn-eid))
				)[id = 'vzversion']/data" 
				/>
				Updates for your existing Virtuozzo %oldver installation are available.
			</sw:text>			
		</span>
	</xsl:template>

	<xsl:template name="local:list-template-updates">
		<xsl:variable name="templates" select="update:list-templates($hn-eid)" />
		
		<xsl:variable name="errors" select="update:get-errors($templates)" />
		<xsl:variable name="updates" select="$templates"/>
		
		<xsl:if
			test="update:cache-template-update-list($updates, $hn-eid)" />

		<xsl:choose>
			<xsl:when test="$errors">
				<xsl:call-template name="local:return-error">
					<xsl:with-param name="errors" select="$errors" />
					<xsl:with-param name="type" select="'templates'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="$updates|$updates/app_template">
				<span>
					<sw:text>
						Updates for your OS and application templates are available.
					</sw:text>
				</span>
				<!-- <div>
					<xsl:call-template name="updateui:show-template-update-details">
						<xsl:with-param name="updates" select="$updates-list" />
					</xsl:call-template>
				</div> -->
			</xsl:when>
			<xsl:otherwise>
				<span>
					<sw:text>
						No updates are available for your OS and application templates.
					</sw:text>
				</span>
			</xsl:otherwise>		
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="local:return-error">
		<xsl:param name="errors" />
		<xsl:param name="type" />
		<xsl:if test="update:cache-update-list-errors($errors, $type)"/>
		<span>
			<sw:text>Error getting a list of updates.</sw:text>
		</span>
	</xsl:template>

	<sw:include href="/lib/vz/update-screen.xsl" />
	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
