<!--
	Copyright (c) SWsoft, 1999-2007
	All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred hwm local"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:hwm="http://www.swsoft.com/xsl/cp/hwm"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:updateui="http://www.swsoft.com/xsl/cp/update-screen"
	xmlns:update="http://www.swsoft.com/xsl/cp/update"
>

	<!-- check permissions to show this page -->
	<xsl:variable name="cred" select="cred:check-hw('vzcp.hn.manage.update', sw:hn-eid())"/>

	<xsl:param name="wiz_code" select="'hw-config-update'"/>

	<xsl:variable name="step_data" select="wiz:getStep()"/>
	<xsl:variable name="step" select="$step_data/@id"/>
	<xsl:variable name="path-id" select="string(wiz:getSteps()/step[1]/@screen-id)"/>

	<xsl:param name="access-denied" select="not($cred)"/>

	<xsl:variable name="form" select="sw:sesget($wiz_data)"/>

	<!-- Wizard, General Step  -->
	<xsl:template mode="screen" match="/">
		<ui:screen id="{$step_data/@screen-id}" icon="{$step_data/@screen-icon}">

			<ui:properties>
				<ui:refresh-type>none</ui:refresh-type>
				<ui:form-get/>
				<ui:description mandatory="yes">
					<sw:text>Configure the update repository settings.</sw:text>
				</ui:description>
			</ui:properties>

			<ui:content>
				<ui:hidden name="step" value="gen"/>
				<ui:block mode="edit">
					<xsl:apply-templates mode="local:edit-general-settings" select="$form/gen/config"/>
					<xsl:apply-templates mode="local:edit-settings" select="$form/gen/config"/>

					<ui:buttons>
						<xsl:call-template name="wiz:showButtons"/>
					</ui:buttons>
				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>
	
	
	<!-- Linux connection part -->
	<xsl:template match="connection[$form/hn/linux]" mode="local:edit-settings">
		<ui:rows title="{sw:text('Repository')}">
			<ui:row>
				<ui:cell-label>
					<sw:text>URL</sw:text>
				</ui:cell-label>
				<ui:cell-input width="50" id="up_url" value="{server}"/>
			</ui:row>
			<ui:row>
				<ui:cell-label>
					<sw:text>Login</sw:text>
				</ui:cell-label>
				<ui:cell-input width="12" id="up_user" value="{sw:base64-decode(user)}"/>
			</ui:row>
			<ui:row>
				<ui:cell-label>
					<sw:text>Password</sw:text>
				</ui:cell-label>
				<ui:cell-input mode-password="true" width="12" id="up_passwd"
					value="{sw:base64-decode(password)}"/>
			</ui:row>
		</ui:rows>

		<ui:rows title="{sw:text('Proxy Server')}" id="proxy_settings"
			status-def="{sw:if(proxy/server, 1, 0)}"
			closed-text="{sw:text('Click to configure the proxy server.')}">
			<ui:row>
				<ui:cell-label>
					<sw:text>URL</sw:text>
				</ui:cell-label>
				<ui:cell-input width="50" id="pr_url" value="{proxy/server}"/>
			</ui:row>
			<ui:row>
				<ui:cell/>
				<ui:cell-text>
					<ui:text-disabled><sw:text>Proxy server URL - [protocol://]&amp;lt;host&amp;gt;[:port]</sw:text></ui:text-disabled>
				</ui:cell-text>
			</ui:row>
			<ui:row>
				<ui:cell-label>
					<sw:text>Login</sw:text>
				</ui:cell-label>
				<ui:cell-input width="12" id="pr_user" value="{sw:base64-decode(proxy/user)}"/>
			</ui:row>
			<ui:row>
				<ui:cell-label>
					<sw:text>Password</sw:text>
				</ui:cell-label>
				<ui:cell-input mode-password="true" width="12" id="pr_passwd"
					value="{sw:base64-decode(proxy/password)}"/>
			</ui:row>
		</ui:rows>
	</xsl:template>
	
	<xsl:template name="local:show-proxy-type">
		<xsl:param name="type"/>
		<xsl:param name="selected"/>
		
		<xsl:variable name="auth" select="$type/@auth"/>
		<xsl:variable name="url" select="$type/@url"/>
		
		<ui:cell-radio name="proxy_mode" id="proxy_mode_{$type/@id}" value="{$type/@id}">
			<xsl:if test="string($type/@id)=$selected">
				<xsl:attribute name="checked">true</xsl:attribute>
			</xsl:if>
			<ui:control-slave inverse="{not($url)}">pr_url</ui:control-slave>
			<ui:control-slave inverse="{not($auth)}">pr_user</ui:control-slave>
			<ui:control-slave inverse="{not($auth)}">pr_passwd</ui:control-slave>
			<xsl:value-of select="$type"/>
		</ui:cell-radio>
	</xsl:template>

	<!-- Windows connection part -->
	<xsl:template match="connection[$form/hn/windows]" mode="local:edit-settings">
		<xsl:variable name="type" select="name(proxy/type/*[1])"/>
		<ui:rows title="{sw:text('Proxy Server')}">
			<ui:row>
				<ui:cell-label>
					<sw:text>Proxy type</sw:text>
				</ui:cell-label>
				<xsl:call-template name="local:show-proxy-type">
					<xsl:with-param name="type" select="update:proxy-types()[1]"/>
					<xsl:with-param name="selected" select="$type"/>
				</xsl:call-template>
			</ui:row>
			<xsl:for-each select="update:proxy-types()[position() &gt; 1]">
				<ui:row>
					<ui:cell/>
					<xsl:call-template name="local:show-proxy-type">
						<xsl:with-param name="type" select="."/>
						<xsl:with-param name="selected" select="$type"/>
				</xsl:call-template>
				</ui:row>		
			</xsl:for-each>
			<ui:row>
				<ui:cell-label offset="2">
					<sw:text>URL</sw:text>
				</ui:cell-label>
				<ui:cell-input width="47" id="pr_url" value="{proxy/server}" offset="2"/>
			</ui:row>
			<ui:row>
				<ui:cell/>
				<ui:cell-text offset="2">
					<ui:text-disabled><sw:text>Proxy server URL - [protocol://]&amp;lt;host&amp;gt;[:port]</sw:text></ui:text-disabled>
				</ui:cell-text>
			</ui:row>
			<ui:row>
				<ui:cell-label offset="2">
					<sw:text>Login</sw:text>
				</ui:cell-label>
				<ui:cell-input width="12" id="pr_user" value="{sw:base64-decode(proxy/user)}" offset="2"/>
			</ui:row>
			<ui:row>
				<ui:cell-label offset="2">
					<sw:text>Password</sw:text>
				</ui:cell-label>
				<ui:cell-input mode-password="true" width="12" id="pr_passwd" offset="2"
					value="{sw:base64-decode(proxy/password)}"/>
			</ui:row>
		</ui:rows>
	</xsl:template>
	
	<xsl:template match="service" mode="local:edit-general-settings">
		<ui:rows title="{sw:text('Up-to-Date Service')}">
			<ui:row>
				<ui:cell-label>
					<sw:text>Enable Updates</sw:text>
		        </ui:cell-label>
				<ui:cell-check id="enable_updates" checked="{not(disabled)}"> 
					<ui:control-slave>days</ui:control-slave>
					<ui:control-slave>hour</ui:control-slave>
					<ui:control-slave>enable_reboot</ui:control-slave>
					<xsl:for-each select="../product">
						<xsl:variable name="pid" select="$form/gen/map/product[id=current()/id]/pid"/>
						<ui:control-slave>mode.<xsl:value-of select="$pid"/></ui:control-slave>
						<ui:control-slave>url.<xsl:value-of select="$pid"/></ui:control-slave>
						<ui:control-slave>path.<xsl:value-of select="$pid"/></ui:control-slave>
					</xsl:for-each>
				</ui:cell-check>
			</ui:row>
			<ui:row>
				<ui:cell-label>
					<sw:text>Check for updates</sw:text>
				</ui:cell-label>
				<ui:cell-list id="days" value="{sw:if(check_period, name(check_period/*[1]), 'everyday')}" close="no">
					<xsl:for-each select="updateui:days()">
						<ui:list-item id="{@id}" title="{.}"/>
					</xsl:for-each>
				</ui:cell-list>
				<ui:cell open="no" close="no">
					&#160;<sw:text>at</sw:text>&#160;
				</ui:cell>
				<ui:cell-list id="hour" value="{hour}" width="5%" open="no">
					<xsl:for-each select="updateui:hours()">
						<ui:list-item id="{@id}" title="{.}"/>
					</xsl:for-each>
				</ui:cell-list>
			</ui:row>
			<ui:row>
				<ui:cell-label>
					<sw:text>Automatic reboot</sw:text>
				</ui:cell-label>
				<ui:cell-check id="enable_reboot" checked="{count(autoreboot) &gt; 0}" />
			</ui:row>
		</ui:rows>
	</xsl:template>
	
	<xsl:template match="product" mode="local:edit-settings">
		<xsl:variable name="suffix" select="concat('.', $form/gen/map/product[id=current()/id]/pid)"/>
		<ui:rows title="{name}">
			<ui:row>
				<ui:cell-label>
					<sw:text>Update Mode</sw:text>
				</ui:cell-label>
				<ui:cell-list id="mode{$suffix}" value="{name(install/*[1])}">
					<xsl:for-each select="update:install-types()">
						<ui:list-item id="{@id}" title="{.}"/>
					</xsl:for-each>
				</ui:cell-list>
			</ui:row>
			<ui:row>
				<ui:cell-label>
					<sw:text>Repository</sw:text>
				</ui:cell-label>
				<ui:cell-radio name="repo_mode{$suffix}" id="repo_default{$suffix}" value="default">
					<xsl:if test="source/standard and string(source/standard)='' 
							or string(source/standard)=string(source/value)">
						<xsl:attribute name="checked">true</xsl:attribute>
					</xsl:if>
					<ui:control-slave inverse="true">url<xsl:value-of select="$suffix"/></ui:control-slave>
					<sw:text>Standard location</sw:text>
				</ui:cell-radio>
			</ui:row>
			<ui:row>
				<ui:cell/>
				<ui:cell-radio name="repo_mode{$suffix}" id="repo_custom{$suffix}" value="custom">
					<xsl:if test="not(source/standard) or string(source/standard)!=string(source/value)">
						<xsl:attribute name="checked">true</xsl:attribute>
					</xsl:if>
					<ui:control-slave>url<xsl:value-of select="$suffix"/></ui:control-slave>
					<sw:text>Custom location</sw:text>
				</ui:cell-radio>
			</ui:row>
			<ui:row>
				<ui:cell/>
				<ui:cell-input width="47" id="url{$suffix}" value="{sw:base64-decode(source/value)}" offset="2"/>
			</ui:row>
			<ui:row>
				<ui:cell-label>
					<sw:text>Download Location</sw:text>
				</ui:cell-label>
				<ui:cell-input width="50" id="path{$suffix}" value="{sw:base64-decode(destination)}"/>
			</ui:row>
		</ui:rows>
	</xsl:template>
	

	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/update.xsl"/>
	<sw:include href="/lib/vz/update-screen.xsl"/>

	<sw:include href="/lib/vocabulary.xsl"/>
</xsl:stylesheet>
