<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl browse cred env hn"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:env="http://www.swsoft.com/xsl/cp/env" xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred" xmlns:hn="http://www.swsoft.com/xsl/cp/hn"
	xmlns:update="http://www.swsoft.com/xsl/cp/update" 
	xmlns:vt="http://www.swsoft.com/xsl/cp/vt" 
	>

	<sw:include href="/lib/vt/core.xsl" />
	<sw:include href="/lib/vt/env-core.xsl" />
	<sw:include href="/lib/vt/hn-core.xsl" />	
	<sw:include href="/lib/vt/hn-list.xsl" />
	<sw:include href="/lib/update.xsl" />
	
	<xsl:template mode="screen" match="/">
		<xsl:variable name="item-url"
			select="'/vzdir/maintman/updates/update'"/>

		<ui:screen id="03.02.02.03.02">
			<ui:properties>
				<ui:description width="full">
					<sw:text>Click a Hardware Node name on this list to check if there are available updates for the Virtuozzo software or templates installed on this Node.</sw:text>
				</ui:description>
				<ui:form-get/>
			</ui:properties>
			
			<ui:tab-bar id="vzhn.update.choice" current-tab="hns"/>

			<xsl:variable name="hns" select="update:list-hns()"/>
			
			<ui:content>
				<!-- Prepare Filter -->
				<xsl:variable name="filter-init">

					<xsl:call-template name="browse:init-filter">
						<xsl:with-param name="browse">
							<ui:browse-setup id="hns"
								url="/vzdir/maintman/updates/index{concat('?tab=', sw:param('tab'))}" items-title="{sw:text('HNs')}"
								item-url="{$item-url}">
							</ui:browse-setup>
							<ui:cols sorting-col="hostname">
								<ui:column id="id" hidden="yes" nav-type="id"/>
								<xsl:variable name="show-url" select="true()"/>

								<ui:column id="hostname" nav-type="title" show-url="{sw:if($show-url,'yes','no')}"
									title="{sw:text('Hostname')}" filter="auto"/>
									
								<ui:column id="system-up2date" apply-templates="yes"
									title="{sw:text('Up-to-date Status')}" />
								<ui:column id="last-update-time" title="{sw:text('Last Check Time')}" apply-templates="yes" />
								
								<ui:column id="platform-os" title="{sw:text('Platform')}"  filter="select" 
									filter-uncase="true" apply-templates="yes" align="center"
								>
									<xsl:copy-of select="vt:vza-platform-oses()"/>
								</ui:column>

								<ui:column id="hn-status" apply-templates="yes" align="center" 
									title="{sw:text('Status')}">
								</ui:column>
							</ui:cols>
						</xsl:with-param>
					</xsl:call-template>
				</xsl:variable>

				<!-- Get data -->
				<xsl:variable name="filter-rtf">
					<xsl:call-template name="browse:fill-filter">
						<xsl:with-param name="filter" select="exsl:node-set($filter-init)"/>
						<xsl:with-param name="rows">
							<ui:browse-rows>
								<xsl:for-each select="$hns/hn">
									<ui:row>
										<id><xsl:value-of select="eid"/></id>
										<xsl:copy-of select="hostname"/>
										<env-platform><xsl:value-of select="platform"/></env-platform>
										<platform-os><xsl:value-of select="vt:platform2vza(platform)"/></platform-os>
										<hn-status><xsl:value-of select="status"/></hn-status>
										<xsl:copy-of select="system-up2date|last-update-time"/>
									</ui:row>
								</xsl:for-each>
							</ui:browse-rows>
						</xsl:with-param>
					</xsl:call-template>
				</xsl:variable>

				<xsl:variable name="filter" select="exsl:node-set($filter-rtf)" />

				<ui:block width="full">
					<ui:browse>
						<xsl:attribute name="title">
							<sw:text>Hardware Nodes</sw:text>
						</xsl:attribute>

						<ui:filter>
							<xsl:copy-of select="$filter" />
						</ui:filter>

						<ui:browse-empty-msg>
							<sw:text>There are no available HNs.</sw:text>
						</ui:browse-empty-msg>

					</ui:browse>

				</ui:block>
			</ui:content>

		</ui:screen>

	</xsl:template>

	<sw:include href="/lib/screen.xsl" />

	<sw:include href="/lib/core/browse-filter-raw.xsl" />
	<sw:include href="/lib/vocabulary.xsl" />


</xsl:stylesheet>
