<!--
	Copyright (c) SWsoft, 1999-2007
	All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred hwm local date updateui format"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz" xmlns:hwm="http://www.swsoft.com/xsl/cp/hwm"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui" 
	xmlns:date="http://exslt.org/dates-and-times" xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:func="http://exslt.org/functions" xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:updateui="http://www.swsoft.com/xsl/cp/update-screen"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:format="http://www.swsoft.com/xsl/cp/format"	
>

	<sw:include href="/lib/utils/format-datetime.xsl"/>
	<sw:include href="/lib/utils/format-resusage.xsl"/>

	<!-- check permissions to show this page -->
	<xsl:variable name="cred" select="cred:check-hw('vzcp.hn.manage.update', sw:hn-eid())"/>

	<xsl:param name="wiz_code" select="'install-update'" />

	<xsl:variable name="step_data" select="wiz:getStep()" />
	<xsl:variable name="step" select="$step_data/@id" />
	<xsl:variable name="path-id" select="string(wiz:getSteps()/step[1]/@screen-id)" />

	<xsl:variable name="img-error">
		<img src="/{$theme}/icons/exclamation_32.gif" width="32" height="32" border="0" />
	</xsl:variable>

	<xsl:param name="access-denied" select="not($cred)" />

	<xsl:variable name="form" select="sw:sesget($wiz_data)" />

	<!-- No updates found screen  -->
	<xsl:template name="no-updates">
		<ui:screen path-id="{$path-id}" id="{$step_data/@screen-id}" title="{$step_data/@screen-title}"
			icon="{$step_data/@screen-icon}">
			<ui:properties>
				<ui:refresh-type>none</ui:refresh-type>
				<ui:description mandatory="yes">
					<sw:text>No Virtuozzo version is selected for installation.</sw:text>
				</ui:description>
				<ui:form-get/>
			</ui:properties>
		</ui:screen>
	</xsl:template>

	<!-- Update details listing -->
	<xsl:template name="summary">
		<xsl:variable name="major" select="$form/update" />
		<ui:screen path-id="{$path-id}" id="{$step_data/@screen-id}" title="{$step_data/@screen-title}"
			icon="{$step_data/@screen-icon}">
			<ui:properties>
				<ui:refresh-type>none</ui:refresh-type>
				<ui:description mandatory="yes">
					<sw:text>You are about to install the new Virtuozzo version.</sw:text>
				</ui:description>
				<ui:form-get/>
			</ui:properties>

			<ui:content>
				<ui:hidden name="step" value="{$step}" />

				<ui:block width="max">
					<ui:rows title="Warning!">
						<ui:row>
							<ui:cell cell-width="5%">
								<xsl:copy-of select="$img-error" />
							</ui:cell>
							<ui:cell-value cell-width="95%">
								<xsl:choose>
									<xsl:when test="env:eid2info(sw:hn-eid())/linux">
										<sw:text>
											Please note that the installation of the new Virtuozzo version will automatically reconfigure the bootloader and reboot the Hardware Node. You may disable these actions using the Install Options group.
										</sw:text>
									</xsl:when>
									<xsl:otherwise>
										<sw:text>
											Please note that the installation of the new Virtuozzo version may automatically reboot the Hardware Node.
										</sw:text>
									</xsl:otherwise>
								</xsl:choose>
							</ui:cell-value>
						</ui:row>
					</ui:rows>
				</ui:block>

				<xsl:for-each select="$major">
					<ui:block width="max">
						<xsl:variable name="newver" select="substring-after(id, 'MU-')" />
						<xsl:variable name="title">
							<xsl:choose>
								<xsl:when test="product">
									<xsl:value-of select="sw:base64-decode(name)"/>
								</xsl:when>
								<xsl:otherwise>
									<sw:text>
										<xsl:with-param name="newver" select="$newver"/>
										Virtuozzo Version %newver
									</sw:text>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						<ui:rows title="{$title}">
							<ui:row>
								<ui:cell-label>
									<sw:text>Release Date</sw:text>
								</ui:cell-label>
								<ui:cell-value>
									<xsl:value-of select="updateui:show-date(date)"/>
								</ui:cell-value>
							</ui:row>
							<ui:row>
								<ui:cell-label>
									<sw:text>Download Size</sw:text>
								</ui:cell-label>
								<ui:cell-value>
									<xsl:value-of select="format:int2bytes(size)" />
								</ui:cell-value>
							</ui:row>
							<ui:row>
								<ui:cell-value colspan="2" align="left">
									<ui:link tip="{sw:text('View details')}"
										href="javascript:open_details('{$baseurl}/vzdir/maintman/updates/vzupdate-details?id={id}')">
										<sw:text>View Details</sw:text>
									</ui:link>
								</ui:cell-value>
							</ui:row>
						</ui:rows>
					</ui:block>
				</xsl:for-each>
				
				<xsl:if test="env:eid2info(sw:hn-eid())/linux">
					<xsl:call-template name="updateui:add-advanced-controls">
						<xsl:with-param name="no_boot_loader" select="$form/summary/no_boot_loader"/>
						<xsl:with-param name="no_reboot" select="$form/summary/no_reboot" />
					</xsl:call-template>
				</xsl:if>

				<ui:block width="max">
					<ui:buttons>
						<ui:button tip="{sw:text('Start Installation')}" name="next" id="next" type="ok"
							sandclock="false">
							<sw:text>Install</sw:text>
						</ui:button>
						<ui:button type="cancel" tip="{sw:text('Cancel Installation')}" name="cancel" id="cancel"
							sandclock="false">
							<sw:text>Cancel</sw:text>
						</ui:button>
					</ui:buttons>
				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
		<xsl:choose>
			<xsl:when test="$step='summary'">
				<xsl:call-template name="summary" />
			</xsl:when>
			<xsl:when test="$step='progress'">
				<xsl:variable name="progress-rtf">
					<status>
						<id>4</id>
						<desc>
							<sw:text>An error occurred during the installation of the new Virtuozzo version.</sw:text>
						</desc>
					</status>
					<status>
						<id>3</id>
						<desc>
							<sw:text>The new Virtuozzo version has been successfully installed.</sw:text>
						</desc>
					</status>
					<status>
						<id>2</id>
						<desc>
							<sw:text>
								Installing the new Virtuozzo version. Please wait for the operation to finish.
							</sw:text>
						</desc>
					</status>
				</xsl:variable>

				<xsl:variable name="progress-msg" select="exsl:node-set($progress-rtf)/status" />
				
				<xsl:call-template name="updateui:install-progress">
					<xsl:with-param name="progress-msg" select="$progress-msg" />
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="no-updates" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<sw:include href="/lib/vt/env-core.xsl" />
	<sw:include href="/lib/vz/update-screen.xsl" />
	<sw:include href="/lib/wizard.xsl" />
</xsl:stylesheet>

