<!--
	Copyright (c) SWsoft, 1999-2007
	All rights reserved.
-->

<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl func wiz cred hwm local date show updateui dynamic browse"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:date="http://exslt.org/dates-and-times"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:hwm="http://www.swsoft.com/xsl/cp/hwm"
	xmlns:show="http://www.swsoft.com/xsl/cp/show"
	xmlns:updateui="http://www.swsoft.com/xsl/cp/update-screen"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:func="http://exslt.org/functions"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:set="http://exslt.org/sets"
	xmlns:update="http://www.swsoft.com/xsl/cp/update"
	xmlns:dynamic="http://www.swsoft.com/xsl/cp/dynamic"
>

	<sw:include href="/lib/core/browse-filter-raw.xsl" />
	<sw:include href="/lib/update.xsl"/>

	<xsl:variable name="cred"
		select="cred:check-context('vzcp.hn.manage.update','hn.vz.vt')"/>
	<xsl:param name="access-denied" select="not($cred)"/>

	<xsl:param name="wiz_code" select="'install-templates'"/>
	<xsl:variable name="step_data" select="wiz:getStep()"/>
	<xsl:variable name="step" select="$step_data/@id"/>
	
	<func:function name="local:get-updates">
		<xsl:param name="form"/>
		<xsl:param name="hn-eid"/>
		
		<xsl:choose>
			<xsl:when test="$form/nothing">
				<func:result select="/.."/>
			</xsl:when>
			<xsl:when test="$form/all">
				<func:result select="update:get-cached-update-list($hn-eid)/*[($update:types/ez-os-templates|$update:types/os-templates)=update:type(.)]"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="$form/update"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<xsl:template mode="screen" match="/">
		<xsl:variable name="form" select="sw:sesget($wiz_data)"/>
		<xsl:variable name="updates" select="local:get-updates($form, sw:hn-eid())"/>

		<xsl:choose>
			<xsl:when test="not($updates//id)">
				<xsl:call-template name="local:no-updates"/>
			</xsl:when>
			<xsl:when test="$step='choose'">
				<xsl:call-template name="local:choose-updates">
					<xsl:with-param name="selected" select="$form/selected/*"/>
					<xsl:with-param name="updates" select="$updates"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="$step='summary'">
				<xsl:call-template name="local:summary">
					<xsl:with-param name="templates" select="$form/install/update"/>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<!-- No updates found screen  -->
	<xsl:template name="local:no-updates">
		<ui:screen id="{$step_data/@screen-id}">
			<ui:properties>
				<ui:refresh-type>none</ui:refresh-type>
				<ui:description mandatory="yes">
					<sw:text>Neither OS nor application template updates have been selected for installation.</sw:text>
				</ui:description>
			</ui:properties>
		</ui:screen>
	</xsl:template>

	<xsl:template name="local:choose-updates">
		<xsl:param name="selected"/>
		<xsl:param name="updates"/>

		<ui:screen id="{$step_data/@screen-id}">
			<ui:properties>
				<ui:refresh-type>none</ui:refresh-type>
				<ui:description mandatory="yes">
					<sw:text>Select the OS and application template updates to be installed.</sw:text>
				</ui:description>
				<ui:form-post/>
			</ui:properties>
			<ui:content>
				<ui:hidden name="step" value="choose"/>
				<ui:block width="max">
					<xsl:call-template name="local:show-selector">
						<xsl:with-param name="selected" select="$selected"/>
						<xsl:with-param name="updates" select="$updates"/>
					</xsl:call-template>

					<ui:buttons>
						<xsl:call-template name="wiz:showButtons"/>
					</ui:buttons>
				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>


	<xsl:template name="local:show-selector">
		<xsl:param name="selected"/>
		<xsl:param name="updates"/>

		<ui:rows title="{sw:text('Template Updates')}" separate-tables="true">
			<ui:tree-selector id="id">
				<ui:nodes-selected>
					<xsl:for-each select="$selected">
						<ui:node>
							<ui:id>
								<xsl:value-of select="string(.)"/>
							</ui:id>
						</ui:node>
					</xsl:for-each>
				</ui:nodes-selected>
				<ui:nodes>
					<xsl:for-each select="local:list-oses($updates)">
						<xsl:sort select="."/>
						<xsl:variable name="os" select="string(.)"/>
						<ui:node>
							<ui:id>
								<xsl:value-of select="$os"/>
							</ui:id>
							<ui:title>
								<xsl:value-of select="."/>
							</ui:title>

							<xsl:for-each select="local:list-os-versions($updates, $os)">
								<xsl:variable name="version" select="string(.)"/>
								<ui:node>
									<ui:id>
										<xsl:value-of select="$version"/>
									</ui:id>
									<ui:title>
										<xsl:value-of select="."/>
									</ui:title>

									<xsl:variable name="local-updates"
										select="local:list-updates($updates, $os, $version)"/>
										
									<xsl:for-each select="$local-updates[update:is-update(.)]">
										<ui:node master="true">
											<ui:id>
												<xsl:value-of select="id"/>
											</ui:id>
											<ui:title>
												<ui:raw>
													<b>
														<xsl:value-of select="sw:base64-decode(name)"/>
													</b>
													<br/>
													<span class="inactive">
														<xsl:choose>
															<xsl:when test="update:is-new(.)">
																<sw:text>New OS template.</sw:text>
															</xsl:when>
															<xsl:otherwise>
																<sw:text>OS template update.</sw:text>
															</xsl:otherwise>
														</xsl:choose>
														&#160;<xsl:call-template
															name="local:details-link">
															<xsl:with-param name="id" select="id"/>
														</xsl:call-template>
													</span>
												</ui:raw>
											</ui:title>
											<ui:tip-text>
												<xsl:value-of select="id"/>/<xsl:value-of select="version"/>
											</ui:tip-text>
										</ui:node>
									</xsl:for-each>
									<xsl:for-each select="$local-updates/app_template">
										<xsl:sort select="sw:lc(sw:base64-decode(name))"/>
										<ui:node>
											<ui:id>
												<xsl:value-of select="concat(id, '|', version)"/>
											</ui:id>
											<ui:title>
												<ui:raw>
													<xsl:value-of select="sw:base64-decode(name)"/>
													<br/>
													<span class="inactive">
														<xsl:value-of select="id"/>
														&#160;<xsl:choose>
															<xsl:when test="update:is-new(.)">
																<sw:text>
																	<xsl:with-param name="ver" select="version"
																	/>
																	New application template.
																</sw:text>
															</xsl:when>
															<xsl:otherwise>
																<sw:text>
																	<xsl:with-param name="ver" select="version"
																	/>
																	Update to version %ver.
																</sw:text>
															</xsl:otherwise>
														</xsl:choose>
														&#160;<xsl:call-template
															name="local:details-link">
															<xsl:with-param name="id" select="id"/>
														</xsl:call-template>
													</span>
												</ui:raw>
											</ui:title>
											<ui:tip-text><xsl:value-of select="id"/>/<xsl:value-of select="version"
											/></ui:tip-text>
										</ui:node>
									</xsl:for-each>
								</ui:node>
							</xsl:for-each>
						</ui:node>
					</xsl:for-each>
				</ui:nodes>
			</ui:tree-selector>
		</ui:rows>
	</xsl:template>

	<xsl:template name="local:details-link">
		<xsl:param name="id"/>
		<a onmouseover="callTip('update_details',event)" onmouseout="callTip()"
			href="javascript:open_details('{$baseurl}/vzdir/maintman/updates/vzupdate-details?type=templates&amp;id={$id}')">
			<span class="inactive">
				<sw:text>More Details</sw:text>
			</span>
		</a>
	</xsl:template>

	<func:function name="local:list-oses">
		<xsl:param name="updates"/>
		<func:result select="set:distinct($updates/id)"/>
	</func:function>

	<func:function name="local:list-os-versions">
		<xsl:param name="updates"/>
		<xsl:param name="id"/>
		<xsl:variable name="versions"
			select="$updates[id=$id]/version"/>
		<xsl:variable name="dummy">
			<version>
				<sw:text>Installed Version</sw:text>
			</version>
		</xsl:variable>
		<func:result
			select="sw:if(not($versions), exsl:node-set($dummy)/version, set:distinct($versions))"/>
	</func:function>

	<func:function name="local:list-updates">
		<xsl:param name="updates"/>
		<xsl:param name="os"/>
		<xsl:param name="version"/>

		<func:result
			select="$updates[id=$os and version=$version]"
		/>
	</func:function>


	<xsl:template name="local:summary">
		<xsl:param name="templates"/>
		
		<ui:screen id="{$step_data/@screen-id}">
			<ui:properties>
				<ui:refresh-type>none</ui:refresh-type>
				<ui:description mandatory="yes">
					<sw:text>You have selected the following OS and application templates to be installed to your Virtuozzo system.</sw:text>
				</ui:description>
				<ui:form-post/>
			</ui:properties>
			<ui:content>
				<ui:hidden name="step" value="summary"/>
				<ui:block width="max">
					<xsl:call-template name="local:browse">
						<xsl:with-param name="message" select="sw:text('Selected Template Updates')"/>
						<xsl:with-param name="empty-message"
							select="sw:text('No template updates selected for installation.')"/>
						<xsl:with-param name="data">
							<xsl:for-each select="$templates[update:is-update(.)]">
								<ui:row>
									<name>
										<xsl:value-of select="id"/>
									</name>
									<xsl:copy-of select="version"/>
									<type>
										<sw:text>OS</sw:text>
									</type>
									<description>
										<xsl:value-of select="sw:base64-decode(name)"/>
									</description>
								</ui:row>
							</xsl:for-each>
							<xsl:for-each select="$templates/app_template">
								<ui:row>
									<name>
										<xsl:value-of select="id"/>
									</name>
									<xsl:copy-of select="version"/>
									<type>
										<sw:text>Application</sw:text>
									</type>
									<description>
										<xsl:value-of select="sw:base64-decode(name)"/>
									</description>
								</ui:row>
							</xsl:for-each>
						</xsl:with-param>
					</xsl:call-template>
				</ui:block>

				<ui:block width="max">
					<ui:buttons>
						<xsl:call-template name="wiz:showButtons">
							<xsl:with-param name="submit-title">
								<sw:text>Install</sw:text>
							</xsl:with-param>
							<xsl:with-param name="submit-tip">
								<sw:text>Press this button to install the selected updates.</sw:text>
							</xsl:with-param>
							<xsl:with-param name="disable-submit" select="count($templates)=0"/>
						</xsl:call-template>
					</ui:buttons>
				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<func:function name="local:browse-filter-init">
		<xsl:variable name="filter_init_">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="tmpl_browse"
						url="/vzdir/maintman/updates/install-templates?tab=summary" post-only-rows="true"/>
					<ui:cols>
						<ui:column id="name" show-url="no" apply-templates="yes"
							title="{sw:text('Template Name')}"/>
						<ui:column id="version" show-url="no" apply-templates="yes" title="{sw:text('Version')}"/>
						<ui:column id="type" show-url="no" apply-templates="yes" title="{sw:text('Type')}"
							align="center"/>
						<ui:column id="description" show-url="no" apply-templates="yes"
							title="{sw:text('Description')}" sorting="no"/>
					</ui:cols>
				</xsl:with-param>
				<!--				<xsl:with-param name="no-limit" select="true()" />-->
			</xsl:call-template>
		</xsl:variable>

		<func:result select="exsl:node-set($filter_init_)"/>
	</func:function>

	<func:function name="local:browse-filter">
		<xsl:param name="data"/>

		<func:result>
			<xsl:call-template name="browse:fill-filter">
				<xsl:with-param name="filter" select="local:browse-filter-init()"/>
				<xsl:with-param name="rows">
					<ui:browse-rows>
						<xsl:copy-of select="$data"/>
					</ui:browse-rows>
				</xsl:with-param>
			</xsl:call-template>
		</func:result>
	</func:function>

	<xsl:template name="local:browse">
		<xsl:param name="message"/>
		<xsl:param name="empty-message"/>
		<xsl:param name="data"/>

		<ui:browse title="{$message}">
			<ui:filter>
				<xsl:copy-of select="local:browse-filter($data)"/>
			</ui:filter>
			<ui:browse-empty-msg>
				<xsl:value-of select="$empty-message"/>
			</ui:browse-empty-msg>
		</ui:browse>
	</xsl:template>

	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/vz/update-screen.xsl"/>
</xsl:stylesheet>
