<!--
	Copyright (c) SWsoft, 1999-2007
	All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred hwm local date updateui format"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:date="http://exslt.org/dates-and-times" xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error" xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:hwm="http://www.swsoft.com/xsl/cp/hwm"
	xmlns:updateui="http://www.swsoft.com/xsl/cp/update-screen" xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:local="http://www.swsoft.com/xsl/cp/local" xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:format="http://www.swsoft.com/xsl/cp/format"
	xmlns:set="http://exslt.org/sets"
>

	<sw:include href="/lib/utils/format-datetime.xsl"/>
	<sw:include href="/lib/utils/format-resusage.xsl"/>

	<!-- check permissions to show this page -->
	<xsl:variable name="cred" select="cred:check-hw('vzcp.hn.manage.update',sw:hn-eid())"/>

	<xsl:param name="wiz_code" select="'install-minor-update'" />

	<xsl:variable name="step_data" select="wiz:getStep()" />
	<xsl:variable name="step" select="$step_data/@id" />
	<xsl:variable name="path-id" select="string(wiz:getSteps()/step[1]/@screen-id)" />

	<xsl:variable name="img-error">
		<img src="/{$theme}/icons/exclamation_32.gif" width="32" height="32" border="0" />
	</xsl:variable>

	<xsl:param name="access-denied" select="not($cred)" />

	<xsl:variable name="form" select="sw:sesget($wiz_data)" />

	<xsl:variable name="img-info">
		<img src="/{$theme}/icons/help_16.gif" width="16" height="16" border="0" />
	</xsl:variable>

	<!-- No updates found screen  -->
	<xsl:template name="no-updates">
		<ui:screen path-id="{$path-id}" id="{$step_data/@screen-id}" title="{$step_data/@screen-title}"
			icon="{$step_data/@screen-icon}">
			<ui:properties>
				<ui:refresh-type>none</ui:refresh-type>
				<ui:description mandatory="yes">
					<sw:text>No Virtuozzo updates selected for installation.</sw:text>
				</ui:description>
			</ui:properties>
		</ui:screen>
	</xsl:template>

	<!-- Update details listing -->
	<xsl:template name="summary">
		<ui:screen path-id="{$path-id}" id="{$step_data/@screen-id}" title="{$step_data/@screen-title}"
			icon="{$step_data/@screen-icon}">
			<ui:properties>
				<ui:form-get/>
				<ui:refresh-type>none</ui:refresh-type>
				<ui:description mandatory="yes">
					<xsl:choose>
						<xsl:when test="count($form/update[category='core']) &gt; 1 and not($form/update/product)">
							<sw:text>Review the selected package updates and the installation options.</sw:text>
						</xsl:when>
						<xsl:otherwise>
							<sw:text>Review the selected package updates.</sw:text>
						</xsl:otherwise>
					</xsl:choose>
				</ui:description>
			</ui:properties>

			<ui:content>
				<ui:hidden name="step" value="{$step}" />

				<ui:block width="max">
					<ui:rows title="{sw:text('Warning')}">
						<ui:row>
							<ui:cell>
								<xsl:copy-of select="$img-error" />
							</ui:cell>
							<ui:cell-label cell-width="100%">
								<xsl:choose>
									<xsl:when
										test="count($form/update[category='core']) &gt; 1 and env:eid2info(sw:hn-eid())/linux">
										<sw:text>
											Please note that the installation of the Virtuozzo core update will automatically reconfigure the bootloader and reboot the Hardware Node. You may disable these actions using the Install Options group.
										</sw:text>
									</xsl:when>
									<xsl:otherwise>
										<sw:text>
											Please note that the installation of the packages update may require the restarting of the Virtuozzo services.
										</sw:text>
									</xsl:otherwise>
								</xsl:choose>
							</ui:cell-label>
						</ui:row>
					</ui:rows>
				</ui:block>

				<ui:raw>
					<script>
						<![CDATA[					
						function check(list, pos) {
							pos = pos - 1;
							var on = document.getElementById(list[pos]).checked;
							
							for (i = 0; i < list.length; i++) {
								if (i > pos) {
									document.getElementById(list[i]).checked = false;
								}  else if (i < pos) {
									document.getElementById(list[i]).checked = true;
								}
							}
						}
				  	]]>

					</script>
				</ui:raw>
				<xsl:choose>
					<xsl:when test="$form/update/product">
						<xsl:for-each select="set:distinct($form/update/product)">
							<xsl:call-template name="list-updates">
								<xsl:with-param name="updates" select="$form/update[product=current()]"/>
								<xsl:with-param name="group-id" select="concat('prod', position())"/>
							</xsl:call-template>
						</xsl:for-each>						
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="$form/update[category='core']">
							<xsl:call-template name="list-updates">
								<xsl:with-param name="updates" select="$form/update[category='core']"/>
								<xsl:with-param name="group-id" select="'kuid'"/>
							</xsl:call-template>
						</xsl:if>
						
						<xsl:if test="$form/update[category='tools']">
							<xsl:call-template name="list-updates">
								<xsl:with-param name="updates" select="$form/update[category='tools']"/>
								<xsl:with-param name="group-id" select="'puid'"/>
							</xsl:call-template>
						</xsl:if>
		
						<xsl:if test="$form/update[category='core']">
							<xsl:call-template name="updateui:add-advanced-controls">
								<xsl:with-param name="no_boot_loader" select="$form/summary/no_boot_loader" />
								<xsl:with-param name="no_reboot" select="$form/summary/no_reboot" />
							</xsl:call-template>
						</xsl:if>
					</xsl:otherwise>
				</xsl:choose>

				<ui:block width="max">
					<ui:buttons>
						<ui:button tip="{sw:text('Start Installation')}" name="next" id="next" type="ok"
							sandclock="false">
							<sw:text>Install</sw:text>
						</ui:button>
						<ui:button type="cancel" tip="{sw:text('Cancel Installation')}" name="cancel" id="cancel"
							sandclock="false">
							<sw:text>Cancel</sw:text>
						</ui:button>
					</ui:buttons>
				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>
	
	<func:function name="local:list">
		<xsl:param name="data" />
		<xsl:param name="label" />

		<func:result>
			<xsl:for-each select="$data">
				<xsl:if test="position() &gt; 1"><xsl:value-of select="','" /></xsl:if><xsl:value-of select="concat('&quot;', $label, '_', position(),'&quot;')" />
			</xsl:for-each>
		</func:result>
	</func:function>
	
	<func:function name="local:describe-category">
		<xsl:param name="category"/>
		
		<func:result>
			<xsl:choose>
				<xsl:when test="$category='core'">
					<sw:text>Install Virtuozzo Kernel Update</sw:text>
				</xsl:when>
				<xsl:otherwise>
					<sw:text>Install Virtuozzo Packages Update</sw:text>
				</xsl:otherwise>
			</xsl:choose>
		</func:result>
	</func:function>
	
	<func:function name="local:describe-product">
		<xsl:param name="product"/>
		
		<func:result>
			<sw:text>
				<xsl:with-param name="name" select="$form/product[id=string($product)]/name"/>
				Install %name Update
			</sw:text>
		</func:result>
	</func:function>
	
	<!-- Update listing template  -->
	<xsl:template name="list-updates">
		<xsl:param name="updates"/>
		<xsl:param name="group-id"/>
		
		<xsl:variable name="sid" select="$form/summary/selected/update[.=$updates][position()=last()]/id" />

		<ui:block width="max">
			<ui:raw>
				<script>
					var <xsl:value-of select="$group-id"/>chk = new Array(<xsl:value-of select="local:list($updates, $group-id)" /><![CDATA[);]]>
				</script>
			</ui:raw>
			<ui:rows title="{sw:if($updates/product, 
									local:describe-product($updates[1]/product), 
									local:describe-category($updates[1]/category))}">
				
				
				<ui:row type="head">
					<ui:cell-label cell-width="70%">
						<sw:text>Select Update</sw:text>
					</ui:cell-label>
					<ui:cell-label align="right">
						<nobr>
							<sw:text>Download Size</sw:text>
						</nobr>
					</ui:cell-label>
					<ui:cell-label align="right">
							<nobr>
								<sw:text>Release Date</sw:text>
							</nobr>
					</ui:cell-label>
					<ui:cell-label align="center"><sw:text>Details</sw:text></ui:cell-label>
				</ui:row>
				
				
				<xsl:for-each select="$updates">
					<xsl:variable name="id" select="id" />
					<xsl:variable name="pos" select="position()" />

					<ui:row>
						<ui:cell-check id="{$group-id}_{position()}" close="false" nowrap="1"
							onclick="check({$group-id}chk, {position()})" cell-width="70%"
							checked="{sw:if($sid and not($updates[id=$sid and position() &lt; $pos]), 'true' ,'false')}" value="{id}" />
						<ui:cell-label label-for="{$group-id}_{position()}" open="false">
							<nobr>
								<xsl:value-of select="sw:base64-decode(name)" />
							</nobr>
						</ui:cell-label>

						<ui:cell-value align="right">
							<nobr>
								<xsl:value-of
									select="format:int2bytes(sw:if(category='tools', sum($updates[position() &lt;= $pos]/size), size))" />
							</nobr>
						</ui:cell-value>
<!--						<ui:cell-label align="center" cell-width="5">|</ui:cell-label>-->
					
						<ui:cell-value align="right">
							<nobr>
								<xsl:value-of select="updateui:show-date(date)" />
							</nobr>
						</ui:cell-value>
<!--						<ui:cell-label align="center" cell-width="5">|</ui:cell-label>-->
						<ui:cell-value align="center">
							<ui:link tip="{sw:text('View update details')}"
								href="javascript:open_details('{$baseurl}/vzdir/maintman/updates/vzupdate-details?type=minor&amp;id={id}')">
								<nobr>
									<sw:text>Show More</sw:text>
								</nobr>
							</ui:link>
						</ui:cell-value>
					</ui:row>
				</xsl:for-each>
			</ui:rows>
		</ui:block>
	</xsl:template>

	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
		<xsl:choose>
			<xsl:when test="$step='summary'">
				<xsl:call-template name="summary" />
			</xsl:when>
			<xsl:when test="$step='progress'">
				<xsl:variable name="progress-rtf">
					<status>
						<id>4</id>
						<desc>
							<sw:text>An error occurred during the Virtuozzo updates installation.</sw:text>
						</desc>
					</status>
					<status>
						<id>3</id>
						<desc>
							<sw:text>The Virtuozzo updates installation has been successfully finished.</sw:text>
						</desc>
					</status>
					<status>
						<id>2</id>
						<desc>
							<sw:text>
								Installing the Virtuozzo updates. Please wait for the operation to finish.
							</sw:text>
						</desc>
					</status>
				</xsl:variable>

				<xsl:variable name="progress-msg" select="exsl:node-set($progress-rtf)/status" />
				
				<xsl:call-template name="updateui:install-progress">
					<xsl:with-param name="progress-msg" select="$progress-msg" />
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="no-updates" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<sw:include href="/lib/vz/update-screen.xsl" />
	<sw:include href="/lib/vt/env-core.xsl" />
	<sw:include href="/lib/wizard.xsl" />
</xsl:stylesheet>

