<!--
	Copyright (c) SWsoft, 1999-2007
	All rights reserved.
-->

<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl func date local update updateui hn cred voc dynamic"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz" xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:update="http://www.swsoft.com/xsl/cp/update" xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:date="http://exslt.org/dates-and-times" xmlns:func="http://exslt.org/functions"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse" xmlns:show="http://www.swsoft.com/xsl/cp/show"
	xmlns:local="http://www.swsoft.com/xsl/cp/local" xmlns:voc="http://www.swsoft.com/xsl/cp/voc"
	xmlns:dynamic="http://www.swsoft.com/xsl/cp/dynamic"
	xmlns:updateui="http://www.swsoft.com/xsl/cp/update-screen"
	xmlns:vzhn="http://www.swsoft.com/xsl/cp/vzhn" xmlns:hn="http://www.swsoft.com/xsl/cp/hn"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred">

	<!-- Imports -->
	<sw:include href="/lib/vt/hn-core.xsl"/>
	<sw:include href="/lib/vz/vzhn-info.xsl"/>
	<sw:include href="/lib/vz/vzhn-core.xsl"/>
	<!-- /Imports -->

	<xsl:variable name="hn-eid" select="sw:hn-eid()"/>

	<!-- check permissions to show this page -->
	<xsl:variable name="cred" select="cred:check-hw('vzcp.hn.manage.update',$hn-eid)"/>
	<xsl:param name="access-denied" select="not($cred)"/>

	<xsl:variable name="img-error">
		<img src="/{$theme}/icons/exclamation_32.gif" width="32" height="32" border="0"/>
	</xsl:variable>

	<xsl:variable name="task" select="update:get-task($hn-eid)/id"/>
	<xsl:variable name="task-id" select="string($task)"/>
	
	<xsl:template name="upd-screen-task">
		<ui:screen id="03.02.02.01.01">
			<ui:properties>
				<ui:description mandatory="yes">
					<sw:text>
						Install and update Virtuozzo OS and application templates using the Parallels update repository.
					</sw:text>
				</ui:description>
				<ui:form-get/>
			</ui:properties>
			<ui:tab-bar id="vzhn.update" current-tab="templates"/>
			<ui:content>
				<ui:block mode="view" width="max">
					<ui:rows title="{sw:text('Warning')}">
						<ui:row>
							<ui:cell-text colspan="2">
								<br/>
								<img src="/{$theme}/icons/alert_yellow.gif" width="16" height="16" border="0"/>&#160;<sw:text>
									Virtuozzo is already installing updates. The Virtuozzo template updates are not available now. <br/> <br/> Please wait for the current updates installation to finish.
								</sw:text>
								<br/>
								<br/>
							</ui:cell-text>
						</ui:row>
					</ui:rows>
				</ui:block>
				<xsl:call-template name="local:show-progress"/>
			</ui:content>
		</ui:screen>
	</xsl:template>
	
	<xsl:template name="upd-screen">
		<xsl:variable name="update-config" select="update:get-config($hn-eid)"/>
		<xsl:variable name="updates-cache" select="update:get-cached-update-list($hn-eid)"/>
		
		<xsl:variable name="has-problem"
			select="not($update-config/connection/server) or error:has-errors() or $updates-cache/templates/error"/>
		<xsl:variable name="time" select="date:seconds(sw:vzatime2time($updates-cache/timestamp))"/>
		
		<xsl:variable name="buttons">
			<id>updates.templates.check</id>
			<id>updates.templates.install</id>
		</xsl:variable>
		
		<ui:screen id="03.02.02.01.01">
			<ui:properties>
				<ui:form-get/>
				<ui:description mandatory="yes">
					<sw:text>
						Install and update Virtuozzo OS and application templates using the Parallels update repository.
					</sw:text>

					<xsl:if test="not($task-id)">
						<br/>
						<br/>
						<xsl:call-template name="updateui:update-status">
							<xsl:with-param name="time" select="$time"/>
							<xsl:with-param name="url"
								select="'/vz/cp/vzdir/maintman/updates/check-update-dynamic?type=templates'"/>
							<xsl:with-param name="has-problem" select="$has-problem"/>
							<xsl:with-param name="disable-buttons-ids" select="exsl:node-set($buttons)/id"/>
						</xsl:call-template>
					</xsl:if>
				</ui:description>
			</ui:properties>

			<ui:tab-bar id="vzhn.update" current-tab="templates"/>

			<ui:content>
				<xsl:choose>
					<xsl:when test="$has-problem">
						<xsl:call-template name="local:has-problem">
							<xsl:with-param name="update-config" select="$update-config"/>
							<xsl:with-param name="updates-cache" select="$updates-cache"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:variable name="updates"
							select="$updates-cache/update"/>
						<xsl:variable name="need-update"
							select="update:template-cache-needs-refresh($updates-cache)"/>

						<xsl:choose>
							<xsl:when test="$need-update">
								<xsl:call-template name="local:need-update">
									<xsl:with-param name="time" select="$time"/>
								</xsl:call-template>
							</xsl:when>
							<xsl:when test="not($updates|$updates/app-template)">
								<xsl:call-template name="local:up-to-date">
									<xsl:with-param name="time" select="$time"/>
								</xsl:call-template>
							</xsl:when>
							<xsl:otherwise>
								<xsl:call-template name="local:show-updates">
									<xsl:with-param name="time" select="$time"/>
									<xsl:with-param name="updates" select="$updates"/>
								</xsl:call-template>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:otherwise>
				</xsl:choose>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<xsl:template name="local:show-progress">
		<xsl:call-template name="updateui:install-templates-progress-ajax">
			<xsl:with-param name="msgid" select="$task-id"/>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="local:show-updates">
		<xsl:param name="time" select="0"/>
		<xsl:param name="updates" select="null"/>

		<xsl:call-template name="local:add-actions">
			<xsl:with-param name="disable-install" select="false()"/>
		</xsl:call-template>

		<ui:raw>
			<xsl:call-template name="dynamic:switcher-script"/>
		</ui:raw>
		<xsl:call-template name="updateui:show-template-update-list">
			<xsl:with-param name="updates" select="$updates"/>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="local:up-to-date">
		<xsl:param name="time" select="0"/>

		<xsl:call-template name="local:add-actions"/>

		<ui:block mode="view">
			<ui:rows title="{sw:text('Up-to-date Status')}">
				<ui:row>
					<ui:cell-label>
						<sw:text>Your OS and application templates are up-to-date.</sw:text>
					</ui:cell-label>
				</ui:row>
			</ui:rows>
		</ui:block>

	</xsl:template>

	<xsl:template name="local:need-update">
		<xsl:param name="time" select="0"/>

		<ui:raw>
			<script>get_updates();</script>
		</ui:raw>
		<xsl:call-template name="local:add-actions">
			<xsl:with-param name="disable-check" select="true()"/>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="local:add-actions">
		<xsl:param name="disable-check" select="false()"/>
		<xsl:param name="disable-install" select="true()"/>
		
		<xsl:if test="$disable-check or $disable-install">
			<ui:raw>
				<script>
					<xsl:if test="$disable-check">
						disableToolbarItem('updates.templates.check');
					</xsl:if>
					<xsl:if test="$disable-install">
						disableToolbarItem('updates.templates.install');
					</xsl:if>
				</script>
			</ui:raw>
		</xsl:if>
	</xsl:template>

	<xsl:template name="local:has-problem">
		<xsl:param name="update-config"/>
		<xsl:param name="updates-cache"/>
		
		<xsl:variable name="update-error"
			select="$updates-cache/templates/error|sw:if(error:has-errors(), error:get(), null)"/>

		<xsl:call-template name="local:add-actions">
			<xsl:with-param name="disable-check" select="not($task-id='')"/>
		</xsl:call-template>

		<ui:block width="max">
			<ui:operation-problem>
				<ui:type>custom</ui:type>

				<ui:descr>
					<sw:text>Virtuozzo cannot check for template updates now.</sw:text>
				</ui:descr>
				<ui:reason>
					<xsl:choose>
						<xsl:when test="not($update-config/connection/server)">
							<sw:text>The updates repository is not configured.</sw:text>
						</xsl:when>
						<xsl:when test="$task-id!=''">
							<sw:text>Virtuozzo update is already running. Please wait for the operation to finish.</sw:text>
						</xsl:when>
						<xsl:when test="$update-error">
							<sw:text>Error checking for updates.</sw:text>
						</xsl:when>
					</xsl:choose> 
				</ui:reason>

				<xsl:if test="not($update-config/connection/server)">
					<ui:solution>
						<sw:text>
							<xsl:with-param name="aopen"
									>&lt;a onmouseover="callTip('config_update',event)" onmouseout="callTip()"  href="<xsl:value-of
									select="$baseurl"
								/>/vzdir/maintman/setup/updates?branch=vz-update,templates" &gt;</xsl:with-param>
							<xsl:with-param name="aclose"
							>&lt;/a&gt;</xsl:with-param>
							Please %{aopen}configure%{aclose} the repository settings.
						</sw:text>
					</ui:solution>
					<ui:solution>
						<sw:text>Call the Node administrator for support.</sw:text>
					</ui:solution>
				</xsl:if>

				<xsl:if test="$task-id!=''">
					<xsl:variable name="popup-id" select="concat('tasks_list_',$ticketid)"/>
					<ui:solution>
						<ui:raw>
							<a onmouseover="callTip('open_details',event)" onmouseout="callTip()"
								onclick="open_details('{$baseurl}/core/tasks/details-popup?id={$task-id}'),'{$popup-id}'"
								href="javascript:void(0)">
								<sw:text>Check the update operation status.</sw:text>
							</a>
						</ui:raw>
					</ui:solution>
				</xsl:if>

				<xsl:if test="$update-error">
					<xsl:if test="$update-config/connection/server">
						<ui:solution>
							<sw:text>
								<xsl:with-param name="aopen"
										>&lt;a onmouseover="callTip('config_update',event)" onmouseout="callTip()"  href="<xsl:value-of
										select="$baseurl"
									/>/vzdir/maintman/setup/updates?branch=vz-update,templates" &gt;</xsl:with-param>
								<xsl:with-param name="aclose"
								>&lt;/a&gt;</xsl:with-param>
								Please %{aopen}check%{aclose} the repository settings.
							</sw:text>
						</ui:solution>
					</xsl:if>
					<ui:solution>
						<sw:text>Check the error details and call the Node administrator for support.</sw:text>
						<ui:raw>
							<br/>
							<xsl:call-template name="dynamic:error-reporter">
								<xsl:with-param name="errors" select="$update-error"/>
								<xsl:with-param name="open" select="sw:text('Show Technical Details')"/>
								<xsl:with-param name="hide" select="sw:text('Hide Technical Details')"/>
								<xsl:with-param name="message" select="false()"/>
							</xsl:call-template>
						</ui:raw>
					</ui:solution>

				</xsl:if>
			</ui:operation-problem>
		</ui:block>
		<xsl:if test="update:clear-cached-template-update-list()"/>
	</xsl:template>

	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
		<xsl:choose>
			<xsl:when test="not(string($task-id)='')">
				<xsl:call-template name="upd-screen-task"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="upd-screen"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<sw:include href="/lib/vz/update-screen.xsl"/>
</xsl:stylesheet>
