<!--
	Copyright (c) SWsoft, 1999-2007
	All rights reserved.
-->

<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl func date local update hn cred voc dynamic updateui"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:update="http://www.swsoft.com/xsl/cp/update"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:date="http://exslt.org/dates-and-times"
	xmlns:func="http://exslt.org/functions"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:show="http://www.swsoft.com/xsl/cp/show"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:voc="http://www.swsoft.com/xsl/cp/voc"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:dynamic="http://www.swsoft.com/xsl/cp/dynamic"
	xmlns:updateui="http://www.swsoft.com/xsl/cp/update-screen"
	xmlns:hn="http://www.swsoft.com/xsl/cp/hn"
	xmlns:vzhn="http://www.swsoft.com/xsl/cp/vzhn"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
>

	<!-- Imports -->
	<sw:include href="/lib/vt/env-core.xsl"/>	
	<sw:include href="/lib/vt/hn-core.xsl"/>
	<sw:include href="/lib/vz/vzhn-info.xsl"/>
	<sw:include href="/lib/vz/vzhn-core.xsl"/>
	<!-- /Imports -->

	<sw:include href="/lib/common.xsl"/>

	<xsl:variable name="hn-eid" select="vzhn:set-hn-from-req()"/>	

	<!-- check permissions to show this page -->
	<xsl:variable name="cred" select="cred:check-hw('vzcp.hn.manage.update',$hn-eid)"/>
	<xsl:param name="access-denied" select="not($cred)"/>
	<xsl:variable name="updates-cache" select="update:get-cached-update-list($hn-eid)"/>

	<xsl:variable name="img-error">
		<img src="/{$theme}/icons/exclamation_32.gif" width="32" height="32" border="0"/>
	</xsl:variable>

	<xsl:variable name="task" select="update:get-task($hn-eid)"/>
	<xsl:variable name="task-id" select="string($task/id)"/>
	
	<xsl:template name="upd-screen-task">
		<ui:screen id="03.02.02.01.00">
			<ui:properties>
				<ui:form-get/>
				<ui:description mandatory="yes">
					<sw:text>
						Update your Virtuozzo installation with the latest Virtuozzo packages from the Parallels update repository.
					</sw:text>
				</ui:description>
			</ui:properties>
			<ui:tab-bar id="vzhn.update" current-tab="system"/>
			<ui:content>
				<ui:block mode="view" width="max">
					<ui:rows title="{sw:text('Warning')}">
						<ui:row>
							<ui:cell-text colspan="2">
								<br/>
								<img src="/{$theme}/icons/alert_yellow.gif" width="16" height="16" border="0"/>&#160;<sw:text>
									Virtuozzo is already installing updates. The Virtuozzo updates are not available now. <br/> <br/> Please wait for the current updates installation to finish.
								</sw:text>
								<br/>
								<br/>
							</ui:cell-text>
						</ui:row>
					</ui:rows>
				</ui:block>
				<xsl:call-template name="local:show-progress"/>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<xsl:template name="upd-screen">
		<xsl:variable name="update-config" select="update:get-config()"/>
		<xsl:variable name="has-problem"
			select="not($update-config/connection/server or $update-config/connection/proxy/type) or $updates-cache/virtuozzo/error or error:has-errors()"/>
		<xsl:variable name="time" select="date:seconds(sw:vzatime2time($updates-cache/timestamp))"/>
		
		<xsl:variable name="buttons">
			<id>updates.system.check</id>
			<id>updates.system.major</id>
			<id>updates.system.minor</id>
		</xsl:variable>

		<ui:screen id="03.02.02.01.00" icon="vz_update">
			<ui:properties>
				<ui:description mandatory="yes">
					<sw:text>
						Update your Virtuozzo installation with the latest Virtuozzo packages from the Parallels update repository.
					</sw:text>

					<xsl:if test="not($task/id)">
						<br/>
						<br/>
						<xsl:call-template name="updateui:update-status">
							<xsl:with-param name="time" select="$time"/>
							<xsl:with-param name="url"
								select="'/vz/cp/vzdir/maintman/updates/check-update-dynamic?type=system'"/>
							<xsl:with-param name="has-problem" select="$has-problem"/>
							<xsl:with-param name="disable-buttons-ids" select="exsl:node-set($buttons)/id"/>
						</xsl:call-template>
					</xsl:if>
				</ui:description>
				<ui:form-get/>
			</ui:properties>

			<ui:tab-bar id="vzhn.update" current-tab="system"/>
			
			<ui:content>
				<xsl:choose>
					<xsl:when test="$has-problem">
						<xsl:call-template name="local:has-problem">
							<xsl:with-param name="update-config" select="$update-config"/>
							<xsl:with-param name="updates-cache" select="$updates-cache"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:variable name="updates" select="$updates-cache/update[
									($update:types/system|$update:types/windows)=update:type(.) and update:is-update(.)
								]"/>
						<xsl:variable name="need-update"
							select="update:major-cache-needs-refresh($updates-cache)"/>
						
						<xsl:choose>
							<xsl:when test="$need-update">
								<xsl:call-template name="local:need-update">
									<xsl:with-param name="time" select="$time"/>
								</xsl:call-template>
							</xsl:when>
							<xsl:when test="not($updates/*)">
								<xsl:call-template name="local:up-to-date">
									<xsl:with-param name="time" select="$time"/>
								</xsl:call-template>
							</xsl:when>
							<xsl:otherwise>
								<xsl:call-template name="local:show-updates">
									<xsl:with-param name="time" select="$time"/>
									<xsl:with-param name="updates"
										select="$updates[category!='vzaup2date-update']"/>
								</xsl:call-template>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:otherwise>
				</xsl:choose>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<xsl:template name="local:show-progress">
		<xsl:call-template name="updateui:install-templates-progress-ajax">
			<xsl:with-param name="msgid" select="$task-id"/>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="local:show-updates">
		<xsl:param name="time" select="0"/>
		<xsl:param name="updates" select="null"/>

		<xsl:variable name="major" select="local:major-update($updates)"/>
		<xsl:variable name="minor" select="local:updates($updates)"/>

		<xsl:call-template name="local:add-actions">
			<xsl:with-param name="disable-install-major" select="not($major)"/>
			<xsl:with-param name="disable-install-minor" select="not($minor)"/>
		</xsl:call-template>

		<xsl:if test="$major">
			<ui:block width="max">
				<xsl:variable name="title">
					<sw:text>Latest Virtuozzo Updates</sw:text>
				</xsl:variable>
				<ui:rows title="{$title}">
					<ui:row>
						<ui:cell-text colspan="2">
							<xsl:choose>
								<xsl:when test="$major/product">
									<sw:text-plural>
										<sw:text-zero />
										<xsl:with-param name="num" select="count($major)"/>
										<sw:text-single>An update for Virtuozzo is available.</sw:text-single>
										<sw:text-multiple>%{num} Virtuozzo updates are available.</sw:text-multiple>
									</sw:text-plural>
								</xsl:when>
								<xsl:otherwise>
									<sw:text>
										<xsl:with-param name="newver" select="substring-after($major/id, 'MU-')"/>
										A newer Virtuozzo version %newver is available.
									</sw:text>
								</xsl:otherwise>
							</xsl:choose>
						</ui:cell-text>
					</ui:row>
					<xsl:for-each select="$major">
						<ui:row>
							<ui:cell cell-width="5%" align="right">&#8226;</ui:cell>
							<ui:cell>
								<xsl:choose>
									<xsl:when test="product">
										<xsl:value-of select="sw:base64-decode(name)"/>
									</xsl:when>
									<xsl:otherwise>
										<sw:text>
											<xsl:with-param name="newver" select="substring-after(id, 'MU-')" />
											Virtuozzo version %newver
										</sw:text>
									</xsl:otherwise>
								</xsl:choose>
							</ui:cell>
						</ui:row>
					</xsl:for-each>
					
					<ui:row>
						<ui:cell/>
						<ui:cell-value align="left">
							<ui:link tip="{sw:text('View details')}"
								href="javascript:open_details('{$baseurl}/vzdir/maintman/updates/vzupdate-details?type=system&amp;{local:list($major/id)}')">
								<sw:text>View Details</sw:text>
							</ui:link>
						</ui:cell-value>
					</ui:row>
				</ui:rows>
			</ui:block>
		</xsl:if>

		<xsl:if test="$minor">
			<xsl:variable name="platform-ref" select="env:make-platform-ref(sw:hn-eid())"/>
			<ui:block width="max">
				<xsl:variable name="title">
					<sw:text>
						Updates for Virtuozzo Tools
					</sw:text>
				</xsl:variable>
				<ui:rows title="{$title}">
					<ui:row>
						<ui:cell-text colspan="2">
							<sw:text>
								<xsl:with-param name="oldver"
									select="exsl:node-set(voc:get('vocabulary', $platform-ref ))[id = 'version']/data"
								/>
								The latest available Virtuozzo updates for your existing Virtuozzo %oldver
								installation:
							</sw:text>
						</ui:cell-text>
					</ui:row>

					<xsl:for-each select="$minor">
						<ui:row>
							<ui:cell cell-width="5%" align="right">&#8226;</ui:cell>
							<ui:cell>
								<xsl:value-of select="sw:base64-decode(name)"/>
							</ui:cell>
						</ui:row>
					</xsl:for-each>
					<ui:row>
						<ui:cell/>
						<ui:cell-value align="left">
							<ui:link tip="{sw:text('View details')}"
								href="javascript:open_details('{$baseurl}/vzdir/maintman/updates/vzupdate-details?type=minor&amp;{local:list($minor/id)}')">
								<sw:text>View Details</sw:text>
							</ui:link>
						</ui:cell-value>
					</ui:row>
				</ui:rows>
			</ui:block>
		</xsl:if>
	</xsl:template>
	
	<func:function name="local:list">
		<xsl:param name="data"/>

		<func:result>
			<xsl:for-each select="$data">
				<xsl:if test="position() &gt; 1"><xsl:value-of select="'&amp;'" /></xsl:if><xsl:value-of select="concat('id=', .)"/>
			</xsl:for-each>
		</func:result>
	</func:function>

	<xsl:template name="local:up-to-date">
		<xsl:param name="time" select="0"/>

		<xsl:call-template name="local:add-actions"/>

		<ui:block mode="view" width="max">
			<ui:rows title="{sw:text('Up-to-date Status')}">
				<ui:row>
					<ui:cell-text>
						<sw:text>Your Virtuozzo installation is up-to-date.</sw:text>
					</ui:cell-text>
				</ui:row>
			</ui:rows>
		</ui:block>

	</xsl:template>

	<xsl:template name="local:need-update">
		<xsl:param name="time" select="0"/>

		<ui:raw>
			<script>get_updates();</script>
		</ui:raw>
		<xsl:call-template name="local:add-actions">
			<xsl:with-param name="disable-check" select="true()"/>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="local:add-actions">
		<xsl:param name="disable-check" select="false()"/>
		<xsl:param name="disable-install-major" select="true()"/>
		<xsl:param name="disable-install-minor" select="true()"/>
		
			<xsl:if test="$disable-check or $disable-install-major or $disable-install-minor">
			<ui:raw>
				<script>
					<xsl:if test="$disable-check">
						disableToolbarItem('updates.system.check');
					</xsl:if>
					<xsl:if test="$disable-install-major">
						disableToolbarItem('updates.system.major');
					</xsl:if>
					<xsl:if test="$disable-install-minor">
						disableToolbarItem('updates.system.minor');
					</xsl:if>
				</script>
			</ui:raw>
		</xsl:if>
	</xsl:template>

	<xsl:template name="local:has-problem">
		<xsl:param name="update-config"/>
		<xsl:param name="updates-cache"/>
		
		<xsl:variable name="update-error"
			select="$updates-cache/virtuozzo/error|sw:if(error:has-errors(), error:get(), null)"/>

		<ui:block width="max">
			<xsl:call-template name="local:add-actions">
				<xsl:with-param name="disable-check" select="not($task-id='')"/>
			</xsl:call-template>
			<ui:operation-problem>
				<ui:type>custom</ui:type>

				<ui:descr>
					<sw:text>Virtuozzo cannot check for updates now.</sw:text>
				</ui:descr>
				<ui:reason>
					<xsl:choose>
						<xsl:when test="not($update-config/connection/server)">
							<sw:text>The updates repository is not configured.</sw:text>
						</xsl:when>
						<xsl:when test="$task-id!=''">
							<sw:text>Virtuozzo update is already running. Please wait for the operation to finish.</sw:text>
						</xsl:when>
						<xsl:when test="$update-error">
							<sw:text>Error preparing to check for updates.</sw:text>
						</xsl:when>
					</xsl:choose>
				</ui:reason>

				<xsl:if test="not($update-config/connection/server)">
					<ui:solution>
						<sw:text>
							<xsl:with-param name="aopen"
									>&lt;a onmouseover="callTip('config_update',event)" onmouseout="callTip()"  href="<xsl:value-of
									select="$baseurl"
								/>/vzdir/maintman/setup/updates?branch=vz-update,system" &gt;</xsl:with-param>
							<xsl:with-param name="aclose"
							>&lt;/a&gt;</xsl:with-param>
							Please %{aopen}configure%{aclose} the repository settings.
						</sw:text>
					</ui:solution>
					<ui:solution>
						<sw:text>Call the Node administrator for support.</sw:text>
					</ui:solution>
				</xsl:if>

				<xsl:if test="$task-id!=''">
					<xsl:variable name="popup-id" select="concat('tasks_list_',$ticketid)"/>
					<ui:solution>
						<ui:raw>
							<a onmouseover="callTip('open_details',event)" onmouseout="callTip()"
								onclick="open_details('{$baseurl}/core/tasks/details-popup?id={$task-id}'),'{$popup-id}'"
								href="javascript:void(0)">
								<sw:text>Check the update operation status.</sw:text>
							</a>
						</ui:raw>
					</ui:solution>
				</xsl:if>

				<xsl:if test="$update-error">
					<xsl:if test="$update-config/connection/server">
						<ui:solution>
							<sw:text>
								<xsl:with-param name="aopen"
										>&lt;a onmouseover="callTip('config_update',event)" onmouseout="callTip()"  href="<xsl:value-of
										select="$baseurl"
									/>/vzdir/maintman/setup/updates?branch=vz-update,system" &gt;</xsl:with-param>
								<xsl:with-param name="aclose"
								>&lt;/a&gt;</xsl:with-param>
								Please %{aopen}check%{aclose} the repository settings.
							</sw:text>
						</ui:solution>
					</xsl:if>
					<ui:solution>
						<sw:text>Check the error details and call the Node administrator for support.</sw:text>
						<ui:raw>
							<br/>
							<xsl:call-template name="dynamic:error-reporter">
								<xsl:with-param name="errors" select="$update-error"/>
								<xsl:with-param name="open" select="sw:text('Show Technical Details')"/>
								<xsl:with-param name="hide" select="sw:text('Hide Technical Details')"/>
								<xsl:with-param name="message" select="false()"/>
							</xsl:call-template>
						</ui:raw>
					</ui:solution>
				</xsl:if>
			</ui:operation-problem>
		</ui:block>
		<xsl:if test="update:clear-cached-major-update-list()"/>
	</xsl:template>

	<func:function name="local:major-update">
		<xsl:param name="updates"/>
		<func:result select="$updates[category='virtuozzo']"/>
	</func:function>

	<func:function name="local:updates">
		<xsl:param name="updates"/>
		<func:result select="$updates[category='tools']|$updates[category='core']"/>
	</func:function>

	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
		<xsl:choose>
			<xsl:when test="not(string($task-id)='')">
				<xsl:call-template name="upd-screen-task"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="upd-screen"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<sw:include href="/lib/vz/update-screen.xsl"/>

	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
