<!--
	Copyright (c) SWsoft, 1999-2007
	All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func cred update date local dynamic updateui format"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" 
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:update="http://www.swsoft.com/xsl/cp/update" 
	xmlns:updateui="http://www.swsoft.com/xsl/cp/update-screen" 
	xmlns:local="http://www.swsoft.com/xsl/cp/local" 
	xmlns:dynamic="http://www.swsoft.com/xsl/cp/dynamic"
	xmlns:func="http://exslt.org/functions" 
	xmlns:date="http://exslt.org/dates-and-times"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:format="http://www.swsoft.com/xsl/cp/format"
>

	<sw:include href="/lib/utils/format-datetime.xsl"/>
	<sw:include href="/lib/utils/format-resusage.xsl"/>

	<!-- check permissions to show this page -->
	<xsl:variable name="cred" select="cred:check-hw('vzcp.hn.manage.update', sw:hn-eid())"/>
	<xsl:param name="access-denied" select="not($cred)" />

	<xsl:template mode="screen" match="/">
		<xsl:variable name="updates-list" select="update:get-cached-update-list(sw:hn-eid())" />
		<xsl:variable name="uid" select="sw:param('id')" />

		<ui:popup-screen id="{'03.02.02.02.00'}" title="{sw:text('Update Information')}">
			<ui:properties>
				<ui:refresh-type>none</ui:refresh-type>
				<ui:form-get/>
			</ui:properties>

			<ui:content>
				<xsl:choose>
					<xsl:when test="sw:param('type')='templates'">
						<ui:raw>
							<xsl:call-template name="dynamic:switcher-script" />
						</ui:raw>
						
						<xsl:call-template name="updateui:show-template-update-details">
							<xsl:with-param name="updates"
								select="updateui:filter-template-updates-by-uid($updates-list/update, $uid)" />
						</xsl:call-template>
					</xsl:when>
					<xsl:when test="sw:param('type')='minor'">
						<xsl:call-template name="local:show-minor">
							<xsl:with-param name="updates"
								select="$updates-list/update[(category='core' or category='tools') and id=$uid]" />
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="local:show-major">
							<xsl:with-param name="update"
								select="$updates-list/update[category='virtuozzo' and id=$uid]" />
						</xsl:call-template>
					</xsl:otherwise>
				</xsl:choose>
			</ui:content>
		</ui:popup-screen>
	</xsl:template>

	<xsl:template name="local:show-major">
		<xsl:param name="update" />
		
		<ui:block width="full">
			<xsl:for-each select="$update">
				<xsl:variable name="title">
				<xsl:choose>
					<xsl:when test="product">
						<xsl:value-of select="sw:base64-decode(name)"/>
					</xsl:when>
					<xsl:otherwise>
						<sw:text>
							<xsl:with-param name="newver" select="substring-after($update/id, 'MU-')"/>
							New Virtuozzo version %newver.
						</sw:text>
					</xsl:otherwise>
				</xsl:choose>
				</xsl:variable>
				<ui:rows title="{$title}">
					<xsl:variable name="size" select="size"/>
					
					<ui:row>
						<ui:cell-value>
							<ul>
								<li>
									<b><sw:text>Release date:</sw:text></b>&#160;<xsl:value-of select="updateui:show-date(date)"/>
								</li>
								<li>
									<b><sw:text>Download Size:</sw:text></b>&#160;<xsl:value-of select="format:int2bytes($size)" />
								</li>
							</ul>
							<xsl:call-template name="local:show-description">
								<xsl:with-param name="desc" select="description"/>
							</xsl:call-template>
						</ui:cell-value>
					</ui:row>
				</ui:rows>
			</xsl:for-each>
		</ui:block>
	</xsl:template>
	
	<xsl:template name="local:show-description">
		<xsl:param name="desc" />
		<xsl:choose>
			<xsl:when test="$desc">
				<pre>
					<xsl:value-of select="sw:base64-decode($desc)" />
				</pre>
			</xsl:when>
			<xsl:otherwise>
				<pre>
					<sw:text>No description is provided.</sw:text>
				</pre>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="local:show-minor">
		<xsl:param name="updates" />
		
		<xsl:for-each select="$updates">
			<xsl:sort select="concat(category, sw:base64-decode(name))" />
		
			<ui:block width="full">
				<ui:rows title="{sw:base64-decode(name)}">
					<ui:row>
						<ui:cell-value>
							<ul>
								<li>
									<b><sw:text>Release date:</sw:text></b>&#160;<xsl:value-of select="updateui:show-date(date)" />
								</li>
								<li>
									<b><sw:text>Download Size:</sw:text></b>&#160;<xsl:value-of select="format:int2bytes(size)" />
								</li>
							</ul>
							<xsl:call-template name="local:show-description">
								<xsl:with-param name="desc" select="description" />
							</xsl:call-template>
						</ui:cell-value>
					</ui:row>
				</ui:rows>
			</ui:block>
		</xsl:for-each>
	</xsl:template>
	
	<sw:include href="/lib/vz/update-screen.xsl" />

</xsl:stylesheet>

