 <!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl cred hwm wiz date math format"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:date="http://exslt.org/dates-and-times"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:hwm="http://www.swsoft.com/xsl/cp/hwm"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:svg="http://www.w3.org/TR/2001/REC-SVG-20010904/DTD/svg10.dtd"
	xmlns:math="http://exslt.org/math"
	xmlns:format="http://www.swsoft.com/xsl/cp/format"
>

	<sw:include href="/lib/utils/format-resusage.xsl"/>

	<xsl:variable name="screenid" select="traffic-graph" />

	<xsl:variable name="unit"
		select="$request/http_request/get/parameter[name = 'unit']/value" />
	<xsl:variable name="period"
		select="$request/http_request/get/parameter[name = 'period']/value" />
	<xsl:variable name="data"
		select="$request/http_request/get/parameter[name = 'data']/value" />

	<xsl:variable name="split" select="sw:split($data, ',')" />
	
	<xsl:variable name="units-rtf">
		<unit>
			<id>byte</id>
			<label>
				<xsl:value-of select="sw:text('Byte')" />
			</label>
			<scale>1</scale>
		</unit>
		<unit>
			<id>kbyte</id>
			<label>
				<xsl:value-of select="sw:text('KB')" />
			</label>
			<scale>1024</scale>
		</unit>
		<unit>
			<id>mbyte</id>
			<label>
				<xsl:value-of select="sw:text('MB')" />
			</label>
			<scale>
				<xsl:value-of select="1024 * 1024" />
			</scale>
		</unit>
		<unit>
			<id>gbyte</id>
			<label>
				<xsl:value-of select="sw:text('Gb')" />
			</label>
			<scale>
				<xsl:value-of select="1024 * 1024 * 1024" />
			</scale>
		</unit>
	</xsl:variable>

	<xsl:variable name="format" select="sw:if($unit = 'byte','#,##0','#,##0.00')" />

	<xsl:variable name="units" select="exsl:node-set($units-rtf)" />

	<!-- traffic Wizard, Step 'get traffic' -->
	<xsl:template name="traffic-graph">
		<xsl:variable name="traffic-rtf">
			<all>
				<xsl:call-template name="parse-traffic-records">
					<xsl:with-param name="node" select="$split[2]" />
				</xsl:call-template>
			</all>
		</xsl:variable>

		<xsl:variable name="traffic" select="exsl:node-set($traffic-rtf)/all" />

		<ui:binary type="image/png">
			<ui:image-svg>
				<xsl:variable name="max-total">
					<value>
						<xsl:value-of select="math:max($traffic/transfer/input)" />
					</value>
					<value>
						<xsl:value-of select="math:max($traffic/transfer/output)" />
					</value>
				</xsl:variable>

				<xsl:variable name="max-value" select="math:max(exsl:node-set($max-total)/value)" />
				<xsl:variable name="scale">
					<xsl:value-of select="$units/unit[id=$unit]/scale" />
				</xsl:variable>

				<xsl:variable name="graph-config-rtf">
					<graph>
						<max>
							<xsl:choose>
								<xsl:when test="$max-value = '' or $max-value &lt;= 0">
									<xsl:value-of select="$scale * 10" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="$max-value" />
								</xsl:otherwise>
							</xsl:choose>
						</max>
						<scale>
							<xsl:value-of select="$scale" />
						</scale>
					</graph>
				</xsl:variable>

				<xsl:variable name="graph-config" select="exsl:node-set($graph-config-rtf)" />


				<xsl:variable name="ticks-ref">
					<ticks>
						<xsl:call-template name="create-ticks">
							<xsl:with-param name="config" select="$graph-config" />
						</xsl:call-template>
					</ticks>
				</xsl:variable>

				<xsl:variable name="ticks" select="exsl:node-set($ticks-ref)" />

				<xsl:variable name="width" select="700" />
				<xsl:variable name="height" select="300" />


				<svg width="{$width}" height="{$height}">

					<xsl:variable name="x-offset"
						select="5 + string-length(format:int2bytes($ticks/ticks/tick[last()], $unit,'no', $format)) * 7" />
					<xsl:variable name="y-offset" select="$height * 5 div 100" />

					<xsl:variable name="legend-space" select="0" />
					<xsl:variable name="label-space" select="25" />

					<xsl:variable name="w" select="$width - $x-offset - 10" />
					<xsl:variable name="h" select="$height - $y-offset - $label-space - $legend-space" />

					<!--  Gradients declarations -->
					<defs id="defs644">
						<linearGradient id="GR60860" x1="0.9" y1="0.9" x2="0.1" y2="0.1">
							<stop offset="0" style="stop-color:#FCE0C6" id="stop646" />
							<stop offset="1" style="stop-color:#F3811B" id="stop647" />
						</linearGradient>
					</defs>
					<defs id="defs653">
						<linearGradient id="GR60861" x1="0.9" y1="0.9" x2="0.1" y2="0.1">
							<stop offset="0" style="stop-color:#D1C6FC" id="stop655" />
							<stop offset="1" style="stop-color:#481AF4" id="stop656" />
						</linearGradient>
					</defs>

					<defs id="defs662">
						<linearGradient id="GR60862" x1="0.9" y1="0.9" x2="0.1" y2="0.1">
							<stop offset="0" style="stop-color:#C6FCCC" id="stop664" />
							<stop offset="1" style="stop-color:#1AF434" id="stop665" />
						</linearGradient>
					</defs>

					<g transform="translate({$x-offset}, {$y-offset})">

						<g style="font-size: 10;font-family:serif;text-anchor:end;stroke:black"
							shape-rendering="crispEdges">

							<xsl:call-template name="draw-ticks">
								<xsl:with-param name="ticks" select="$ticks" />
								<xsl:with-param name="x" select="0" />
								<xsl:with-param name="y" select="$h" />
								<xsl:with-param name="config" select="$graph-config" />
								<xsl:with-param name="w" select="$w" />
								<xsl:with-param name="h" select="$h" />
								<xsl:with-param name="unit" select="$unit" />
								<xsl:with-param name="format" select="$format" />
							</xsl:call-template>
						</g>


						<g shape-rendering="crispEdges"
							style="font-family:serif;font-size:10;font-style:normal;text-anchor:middle">
							<xsl:call-template name="traffic-records">
								<xsl:with-param name="nodes" select="$traffic/transfer" />
								<xsl:with-param name="max" select="$ticks/ticks/tick[last()]" />
								<xsl:with-param name="width" select="$w" />
								<xsl:with-param name="height" select="$h" />
							</xsl:call-template>
						</g>

						<g style="fill:none;stroke:black" shape-rendering="crispEdges">
							<line x1="0" x2="0" y1="0" y2="{$h}" style="stroke-width:2" />
							<line x1="0" x2="{$w}" y1="{$h}" y2="{$h}" style="stroke-width:2" />
						</g>
						<line x1="0" x2="{$w}" y1="0" y2="{0}" style="stroke-width:1; stroke:#f0f0f0" />
						<line x1="{$w}" x2="{$w}" y1="0" y2="{$h}" style="stroke-width:1; stroke:#f0f0f0" />
					</g>
				</svg>
			</ui:image-svg>
		</ui:binary>
	</xsl:template>

	<xsl:template name="draw-ticks">
		<xsl:param name="ticks" select="." />
		<xsl:param name="x" select="0" />
		<xsl:param name="y" select="0" />
		<xsl:param name="config" />
		<xsl:param name="w" select="1" />
		<xsl:param name="h" select="1" />

		<xsl:variable name="max">
			<xsl:value-of select="$ticks/ticks/tick[last()]" />
		</xsl:variable>
		<xsl:variable name="scale">
			<xsl:value-of select="$config/graph/scale" />
		</xsl:variable>
		<xsl:for-each select="$ticks/ticks/tick">
			<xsl:variable name="value" select="." />
			<xsl:variable name="d" select="$value * $h div $max" />

			<xsl:element name="line">
				<xsl:attribute name="x1">
					<xsl:value-of select="$x" />
				</xsl:attribute>
				<xsl:attribute name="x2">
					<xsl:value-of select="$x - 5" />
				</xsl:attribute>
				<xsl:attribute name="y1">
					<xsl:value-of select="$y - $d" />
				</xsl:attribute>
				<xsl:attribute name="y2">
					<xsl:value-of select="$y - $d" />
				</xsl:attribute>
				<xsl:if test="@major">
					<xsl:attribute name="style">stroke-width:2</xsl:attribute>
				</xsl:if>
			</xsl:element>

			<xsl:element name="line">
				<xsl:attribute name="x1">
					<xsl:value-of select="$x" />
				</xsl:attribute>
				<xsl:attribute name="x2">
					<xsl:value-of select="$x + $w" />
				</xsl:attribute>
				<xsl:attribute name="y1">
					<xsl:value-of select="$y - $d" />
				</xsl:attribute>
				<xsl:attribute name="y2">
					<xsl:value-of select="$y - $d" />
				</xsl:attribute>
				<xsl:attribute name="style">
					<xsl:text>stroke-width:1;</xsl:text>
					<xsl:choose>
						<xsl:when test="@major">stroke:#909090</xsl:when>
						<xsl:otherwise>stroke:#d0d0d0</xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</xsl:element>

			<text x="{$x - 10}" y="{$y - $d + 3}" style="stroke:none;">
				<tspan>
					<xsl:value-of select="format:int2bytes($value, $unit,'no', $format)" />
				</tspan>
			</text>
		</xsl:for-each>
	</xsl:template>

	<xsl:template name="create-ticks">
		<xsl:param name="index" select="0" />
		<xsl:param name="config" />
		<xsl:param name="step" select="0" />
		<xsl:param name="major-step" select="0" />

		<xsl:variable name="max">
			<xsl:value-of select="$config/graph/max" />
		</xsl:variable>
		<xsl:variable name="scale">
			<xsl:value-of select="$config/graph/scale" />
		</xsl:variable>

		<xsl:variable name="local-max" select="$max div $scale" />

		<xsl:variable name="pow" select="sw:if($local-max &gt; 0, floor(math:log($local-max) div math:log(10)) - 1, 1)" />

		<xsl:variable name="base" select="sw:if($pow &gt; -2, math:power(10, $pow), 1)" />

		<xsl:variable name="t" select="$local-max div $base" />
		<xsl:variable name="st">
			<xsl:choose>
				<xsl:when test="$step &gt; 0">
					<xsl:value-of select="$step" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:choose>
						<xsl:when test="$t &lt; 15">
							<xsl:value-of select="1" />
						</xsl:when>
						<xsl:when test="$t &gt;= 15 and $t &lt; 25">
							<xsl:value-of select="2" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="5" />
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<xsl:variable name="mst">
			<xsl:choose>
				<xsl:when test="$step &gt; 0">
					<xsl:value-of select="$major-step" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:choose>
						<xsl:when test="$t &lt; 15">
							<xsl:value-of select="5" />
						</xsl:when>
						<xsl:when test="$t &gt;= 15 and $t &lt; 25">
							<xsl:value-of select="5" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="2" />
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<xsl:if test="($index - 1) * $st * $base &lt; $local-max">
			<xsl:element name="tick">
				<xsl:if test="$index mod $mst = 0">
					<xsl:attribute name="major">1</xsl:attribute>
				</xsl:if>
				<xsl:attribute name="index">
					<xsl:value-of select="$index" />
				</xsl:attribute>
				<xsl:value-of select="$index * $base * $step * $scale" />
			</xsl:element>

			<xsl:call-template name="create-ticks">
				<xsl:with-param name="index" select="$index + 1" />
				<xsl:with-param name="step" select="$st" />
				<xsl:with-param name="major-step" select="$mst" />
				<xsl:with-param name="config" select="$config" />
			</xsl:call-template>
		</xsl:if>

	</xsl:template>

	<xsl:template name="parse-traffic-records">
		<xsl:param name="node" />

		<xsl:for-each select="$node">
			<transfer>
				<input>
					<xsl:value-of select="." />
				</input>
				<output>
					<xsl:value-of select="following-sibling::*[1]" />
				</output>
				<label>
					<xsl:value-of select="following-sibling::*[2]" />
				</label>
			</transfer>
			<xsl:if test="following-sibling::*[3]">
				<xsl:call-template name="parse-traffic-records">
					<xsl:with-param name="node" select="following-sibling::*[3]" />
				</xsl:call-template>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>

	<xsl:template name="traffic-records">
		<xsl:param name="nodes" />
		<xsl:param name="index" select="1" />

		<xsl:param name="max" />

		<xsl:param name="offset" select="0" />
		<xsl:param name="width" />
		<xsl:param name="height" />

		<xsl:variable name="w" select="$width div count($nodes) div 7 * 2" />
		<xsl:variable name="h" select="$height" />

		<xsl:variable name="x" select="$offset" />
		<xsl:variable name="y" select="$height" />


		<xsl:variable name="input" select="sum($nodes[$index]/input)" />
		<xsl:variable name="output" select="sum($nodes[$index]/output)" />

		<xsl:variable name="scaled-input" select="sw:if($input='', 0, $input div $max * $h)" />
		<xsl:variable name="scaled-output" select="sw:if($output='', 0, $output div $max * $h)" />


		<xsl:if test="$index &lt;= count($nodes)">
			<xsl:choose>
				<xsl:when test="$input &gt; 0 or $output &gt; 0">
					<g style="fill-rule:evenodd;stroke:black; stroke-width:0.5;" shape-rendering="crispEdges">
						<rect style="fill:url(#GR60861)" width="{$w}" height="-{$scaled-input}" x="{$x + $w div 2}"
							y="{$y}" />
						<rect style="fill:url(#GR60862)" width="{$w}" height="-{$scaled-output}" x="{$x + 2 * $w}"
							y="{$y}" />
					</g>

				</xsl:when>
				<xsl:otherwise>
					<!-- <rect style="fill:gray;fill-opacity:0.1"
						width="{$w * 7 div 2}" height="-{$h}" x="{$x}" y="{$y}" /> -->
				</xsl:otherwise>
			</xsl:choose>
			
			<line style="stroke:black; stroke-width:1" x1="{$x + 7 * $w div 4}" x2="{$x + 7 * $w div 4}" y1="{$y}" y2="{$y + 4}" />
			<line style="stroke-width:1; stroke:#b0b0b0" x1="{$x + 7 * $w div 2}" x2="{$x + 7 * $w div 2}" y1="0"
				y2="{$y}" />
				
			<g transform="translate({$x + 7 * $w div 4}, {$y + 15})">
				<!--<g transform="rotate(45)">	-->
				<text x="0" y="0" style="fill:black;stroke:none" xml:space="preserve">
					<tspan>
						<xsl:value-of select="$nodes[$index]/label" />
					</tspan>
				</text>
				<!-- </g> -->
			</g>

			<xsl:call-template name="traffic-records">
				<xsl:with-param name="nodes" select="$nodes" />
				<xsl:with-param name="index" select="$index + 1" />
				<xsl:with-param name="offset" select="$offset + 7 * $w div 2" />
				<xsl:with-param name="max" select="$max" />
				<xsl:with-param name="width" select="$width" />
				<xsl:with-param name="height" select="$height" />
			</xsl:call-template>
		</xsl:if>
	</xsl:template>

	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
		<xsl:call-template name="traffic-graph" />
	</xsl:template>

	<sw:include href="/lib/vza/hwm.xsl" />
	<sw:include href="/lib/screen.xsl" />

</xsl:stylesheet>
