<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred hwm wiz date math func local format"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl	="http://exslt.org/common"
	xmlns:date	="http://exslt.org/dates-and-times"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
  xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
	xmlns:hwm   ="http://www.swsoft.com/xsl/cp/hwm"
	xmlns:wiz   ="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:svg   ="http://www.w3.org/TR/2001/REC-SVG-20010904/DTD/svg10.dtd"
	xmlns:math  ="http://exslt.org/math"
	xmlns:local	="http://www.swsoft.com/xsl/cp/local"
	xmlns:func	="http://exslt.org/functions"
	xmlns:format="http://www.swsoft.com/xsl/cp/format"
  >

	<sw:include href="/lib/utils/format-datetime.xsl"/>
	<sw:include href="/lib/utils/format-resusage.xsl"/>

  <xsl:param name="wiz_code" select="'get-traffic'"/>
	<xsl:variable name="step_data"  select="wiz:getStep()"/>
  <xsl:variable name="step"       select="$step_data/@id"/>
  <xsl:variable name="step-cred"	select="$step_data/@cred"/>
  <xsl:variable name="screenid"   select="'03.02.01.22.01'"/>

  <xsl:variable name="form" select="sw:sesget($wiz_data)"/>

	<!-- check permissions -->
	<xsl:param name="access-denied" select="not(cred:check-context('vzcp.log.list','ve.vz.vt'))"/>

	<xsl:variable name="period-object-rtf">
		<period>
			<id>day</id>
			<column><xsl:value-of select="sw:text('Hour')"/></column>
		</period>
		<period>
			<id>month</id>
			<column><xsl:value-of select="sw:text('Date')"/></column>
		</period>
		<period>
			<id>year</id>
			<column><xsl:value-of select="sw:text('Date')"/></column>
		</period>
		<period>
			<id>from-to</id>
			<column><xsl:value-of select="sw:text('Date')"/></column>
		</period>		
	</xsl:variable>
	<xsl:variable name="period-object" select="exsl:node-set($period-object-rtf)"/>

	<xsl:variable name="units-rtf">
  	<unit>
    	<id>byte</id>
      <label><xsl:value-of select="sw:text('Byte')"/></label>
      	<scale>1</scale>
    </unit>
    <unit>
      <id>kbyte</id>
      <label><xsl:value-of select="sw:text('KB')"/></label>
      <scale>1024</scale>
    </unit>
    <unit>
      <id>mbyte</id>
      <label><xsl:value-of select="sw:text('MB')"/></label>
      <scale><xsl:value-of select="1024 * 1024"/></scale>
    </unit>
    <unit>
      <id>gbyte</id>
      <label><xsl:value-of select="sw:text('GB')"/></label>
      <scale><xsl:value-of select="1024 * 1024 * 1024"/></scale>
    </unit>
  </xsl:variable>

	<xsl:variable name="current-unit" select="$form/traffic/unit"/>
  
  <xsl:variable name="format" select="sw:if($current-unit = 'byte','#,##0','#,##0.00')"/>
  
  <xsl:variable name="units" select="exsl:node-set($units-rtf)"/>

	<xsl:variable name="traffic-message-rtf">
		<xsl:choose>
			<xsl:when test="$form/traffic/netcounters/range"> 
				<traffic-not-present>
					<sw:text>No traffic for the selected period and class.</sw:text>
				</traffic-not-present>
				<traffic-present>
					<sw:text>Traffic for selected period and class</sw:text>
				</traffic-present>
			</xsl:when>
			<xsl:otherwise>
				<traffic-not-present>
					<sw:text>No traffic for the selected period.</sw:text>
				</traffic-not-present>
				<traffic-present>
					<sw:text>This screen displays the statistical information on the traffic used by the Container over a certain period of time. You can define this period as well as the traffic measurement unit on the drop-down menus at the bottom of the screen.</sw:text>
				</traffic-present>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
  <xsl:variable name="traffic-message" select="exsl:node-set($traffic-message-rtf)"/>

	<xsl:variable name="selected-class-node" select="$form/traffic/selected-class-node"/>
	
	<!-- traffic Wizard, Step 'get traffic' -->
  <xsl:template name="get-traffic">
		<xsl:variable name="curent-units-label" select="$units/unit[id = $current-unit]/label"/>
		<xsl:variable name="filter_init_">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="traffic" url="/vzdir/monitman/traffic" post-only-rows="true" />
					<ui:cols>
						<xsl:variable name="column-title"
							select="$period-object/period[id = $form/traffic/period]/column" />
						<ui:column id="period" title="{$column-title}" apply-templates="yes" />
						<ui:column data-type="int" display-type="size/byte"
							display-unit="{$current-unit}" id="input"
							title="{sw:text('Incoming')} ({$curent-units-label})" />
						<ui:column data-type="int" display-type="size/byte"
							display-unit="{$current-unit}" id="output"
							title="{sw:text('Outgoing')} ({$curent-units-label})" />
					</ui:cols>
				</xsl:with-param>
				<xsl:with-param name="no-limit" select="true()" />
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="filter">
			
    	<xsl:call-template name="browse:fill-filter">
				<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
				<xsl:with-param name="rows">					
	        <ui:browse-rows>
						<xsl:for-each select="/packet/cookie/one-log-record">
							<ui:row>
								<period><xsl:value-of select="date:seconds(start_time)"/></period>
								<period-for-show>
									<xsl:call-template name="time-label">
										<xsl:with-param name="period" select="$form/traffic/period"/>
									</xsl:call-template>
								</period-for-show>
								<input>
									<xsl:choose>
										<xsl:when test="not(data/class/instance/counter)">
											<xsl:value-of select="'--'"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="local:get-traffic-grouped-by-class(data,$selected-class-node,'counter_net_incoming_bytes')"/>
										</xsl:otherwise>
									</xsl:choose>
								</input>
								<output>
									<xsl:choose>
										<xsl:when test="not(data/class/instance/counter)">
											<xsl:value-of select="'--'"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="local:get-traffic-grouped-by-class(data,$selected-class-node,'counter_net_outgoing_bytes')"/>
										</xsl:otherwise>
									</xsl:choose>
								</output>								
							</ui:row>
						</xsl:for-each>
        	</ui:browse-rows>
					<xsl:if test="$form/traffic/period != 'from-to'">
						<ui:bottom-rows>
							<ui:row>
								<period/>
								<period-for-show>
									<xsl:value-of select="sw:text('Total')"/>
								</period-for-show>								
								<input>
									<xsl:value-of select="concat(format:int2bytes(local:get-traffic-grouped-by-class(/packet/cookie/one-log-record/data,$selected-class-node,'counter_net_incoming_bytes'),$current-unit,'no',$format),' (',$curent-units-label,')')"/>
								</input>
								<output>
									<xsl:value-of select="concat(format:int2bytes(local:get-traffic-grouped-by-class(/packet/cookie/one-log-record/data,$selected-class-node,'counter_net_outgoing_bytes'),$current-unit,'no',$format),' (',$curent-units-label,')')"/>
								</output>
							</ui:row>
  	        </ui:bottom-rows>
					</xsl:if>
        </xsl:with-param>        					
			</xsl:call-template>
    </xsl:variable>
    
  	<ui:screen id="{$screenid}" icon="traffic_log">
			<ui:tab-bar id="vzve" current-tab="network" current-subtab="traffic"/>

			<ui:properties>
				<ui:form-get/>
				<ui:contains-date-control/>
				<ui:description	mandatory="yes" width="max">
					<sw:text select="$traffic-message/traffic-present"/>
				</ui:description>
			</ui:properties>      

			<ui:content>
				<ui:hidden name="step" value="traffic"/>    


				<!-- Image settings -->
				<xsl:variable name="data">
					<xsl:for-each select="/packet/cookie/one-log-record">
						<xsl:text>,</xsl:text>
						<xsl:value-of select="format-number(local:get-traffic-grouped-by-class(data,$selected-class-node,'counter_net_incoming_bytes'),'#')"/>
						<xsl:text>,</xsl:text>
						<xsl:value-of select="format-number(local:get-traffic-grouped-by-class(data,$selected-class-node,'counter_net_outgoing_bytes'),'#')"/>
						<xsl:text>,</xsl:text>
						<xsl:call-template name="time-label">
							<xsl:with-param name="period"
								select="$form/traffic/period" />
							<xsl:with-param name="period-subtype"
								select="'short'" />
						</xsl:call-template>
					</xsl:for-each>
				</xsl:variable>

				<!-- Image block -->
				<xsl:if test="count(/packet/cookie/one-log-record) and $form/traffic/period != 'from-to'">
					<ui:block width="max">
						<ui:rows title="{sw:text('Usage Graph')}">
							<ui:row>
								<ui:cell align="center" colspan="3" width="100%">
									<xsl:call-template name="local:describe-graph"/>
								</ui:cell>
							</ui:row>
							<ui:row>
								<ui:cell colspan="3">
									<sw:text>Traffic</sw:text>, <xsl:value-of select="$curent-units-label"/>
								</ui:cell>
							</ui:row>
							<ui:row>
								<ui:cell colspan="3">
									<ui:raw>
										<img
											src="/vz/cp/vzdir/monitman/traffic-graph?noframesetredirect=1&amp;unit={$current-unit}&amp;period={$form/traffic/period}&amp;data={$data}"/>
									</ui:raw>
								</ui:cell>
							</ui:row>
							<ui:row>
								<ui:cell align="right" colspan="3">
									<xsl:value-of select="$period-object/period[id = $form/traffic/period]/column"/>
								</ui:cell>
							</ui:row>
							<ui:row>
								<ui:cell-label>
									<sw:text>Legend:</sw:text>
								</ui:cell-label>
								<ui:cell>
									<img src="/{$theme}/images/legend_in.gif" 
										width="32" height="16" border="0"/>&#160;<sw:text>Incoming Traffic</sw:text>
								</ui:cell>
								<ui:cell>
									<img src="/{$theme}/images/legend_out.gif" 
										width="32" height="16" border="0"/>&#160;<sw:text>Outgoing Traffic</sw:text>
								</ui:cell>
							</ui:row>
						</ui:rows>
					</ui:block>
				</xsl:if>

				<ui:block width="max">
					<ui:rows>
						<ui:row>
							<ui:cell-text cell-width="100">
								<sw:text>Show traffic for</sw:text>
							</ui:cell-text>
							<ui:cell type="traffic" value="{$form/traffic/start-date}" from-date="{$form/traffic/from-date}" to-date="{$form/traffic/to-date}" one-date="{$form/traffic/one-date}" selector="{$form/traffic/period}"/>
						</ui:row>
						<xsl:choose>
							<xsl:when test="$form/traffic/netcounters/range">
								<ui:row>
									<ui:cell-text>
										<sw:text>Traffic class</sw:text>
									</ui:cell-text>
									<ui:cell-list value="{$form/traffic/class}" class="FlatSelectFlow" style="width:120px;" id="class">
										<xsl:for-each select="$form/traffic/netcounters/range">
											<ui:list-item id="{class_id}" title="{title}"/>
										</xsl:for-each>
									</ui:cell-list>
								</ui:row>
							</xsl:when>
							<xsl:otherwise>
								<ui:hidden name="class" value="''"/>
							</xsl:otherwise>	
						</xsl:choose>
						<ui:row>
							<ui:cell-text>
								<sw:text>Traffic unit</sw:text>
							</ui:cell-text>
							<ui:cell-list value="{$form/traffic/unit}" class="FlatSelectFlow" style="width:65px;" id="unit">
								<xsl:for-each select="$units/unit">
									<ui:list-item id="{id}" title="{label}"/>
								</xsl:for-each>
							</ui:cell-list>
						</ui:row>
					</ui:rows>
					
					<ui:buttons>
						<ui:button id="ok" type="ok" tip="refresh" name="next" sandclock="true">
							<xsl:value-of select="sw:text('Update')" />
						</ui:button>
					</ui:buttons>

					<ui:browse>
						<xsl:attribute name="title"><xsl:value-of select="$traffic-message/traffic-present"/></xsl:attribute>
						<ui:filter>
							<xsl:copy-of select="$filter"/>
						</ui:filter>       
						<ui:browse-empty-msg stop-sign="yes">
		    	    <xsl:value-of select="$traffic-message/traffic-not-present"/>
		      	</ui:browse-empty-msg>
	      	</ui:browse>
				</ui:block>
    	</ui:content>          
		</ui:screen>
  </xsl:template>  
  
  <xsl:template name="local:describe-graph">
    	<xsl:variable name="from" select="date:seconds(/packet/cookie/one-log-record[1]/start_time)"/>
    	<xsl:variable name="to" select="date:seconds(date:add(/packet/cookie/one-log-record[last()]/end_time,'-P1D'))"/>
    	
    	<xsl:choose>
    		<xsl:when test="$form/traffic/period='year'">
    			<sw:text>
    				<xsl:with-param name="title" select="sw:sesget('vzenv-title')"/>
    				<xsl:with-param name="from" select="format:date-date($from)"/>
    				<xsl:with-param name="to" select="format:date-date($to)"/>
    				Traffic usage for Container %{title} <br/><small>from %{from} through %{to} (by months).</small></sw:text>
    		</xsl:when>
    		<xsl:when test="$form/traffic/period='month'">
    			<sw:text>
    				<xsl:with-param name="title" select="sw:sesget('vzenv-title')"/>
    				<xsl:with-param name="from" select="format:date-date($from)"/>
    				<xsl:with-param name="to" select="format:date-date($to)"/>
    				Traffic usage for Container %{title} <br/><small>from %{from} through %{to} (by days).</small></sw:text>
    		</xsl:when>
    		<xsl:when test="$form/traffic/period='day'">
    			<sw:text>
    				<xsl:with-param name="title" select="sw:sesget('vzenv-title')"/>
    				<xsl:with-param name="from" select="format:date-date($from)"/>
    				Traffic usage for Container %{title} <br/><small>during %{from} (by hours).</small></sw:text>
    		</xsl:when>
    		<xsl:otherwise>
    			<sw:text>
    				<xsl:with-param name="title" select="sw:sesget('vzenv-title')"/>
    				Traffic usage for Container %{title}.
    			</sw:text>
    		</xsl:otherwise>
    	</xsl:choose>
    </xsl:template>
  
  <xsl:template name="time-label">
  	<xsl:param name="node" select="." />
  	<xsl:param name="start-seconds" select="date:seconds(start_time)" />
  	<xsl:param name="end-seconds"
  		select="date:seconds(date:add(end_time,'-P1D'))" />
  	<xsl:param name="period" />
  	<xsl:param name="period-subtype" select="normal" />

  	<xsl:choose>
  		<xsl:when test="$period = 'day'">
  			<xsl:choose>
  				<xsl:when test="$period-subtype = 'normal'">
  					<xsl:value-of
  						select="concat(sw:strftime($start-seconds,'%H:%M'),' - ',sw:strftime($end-seconds,'%H:%M'))" />
  				</xsl:when>
  				<xsl:otherwise>
  					<xsl:value-of
  						select="sw:strftime($start-seconds,'%H')" />
  				</xsl:otherwise>
  			</xsl:choose>
  		</xsl:when>
  		<xsl:when test="$period = 'month'">
  			<xsl:choose>
  				<xsl:when test="$period-subtype = 'normal'">
  					<xsl:value-of
  						select="format:date-date($start-seconds)" />
  				</xsl:when>
  				<xsl:otherwise>
  					<xsl:value-of
  						select="sw:strftime($start-seconds,'%d')" />
  				</xsl:otherwise>
  			</xsl:choose>
  		</xsl:when>
  		<xsl:when test="$period = 'year'">
  			<xsl:choose>
  				<xsl:when test="$period-subtype = 'normal'">
  					<xsl:value-of
  						select="sw:strftime($start-seconds,'%b %Y')" />
  				</xsl:when>
  				<xsl:otherwise>
  					<xsl:value-of
  						select="sw:strftime($start-seconds,'%b')" />
  				</xsl:otherwise>
  			</xsl:choose>
  		</xsl:when>
  		<xsl:when test="$period = 'from-to'">
  			<xsl:value-of
  				select="concat(format:date-date($start-seconds),' - ',format:date-date($end-seconds))" />
  		</xsl:when>
  	</xsl:choose>
  </xsl:template>

	<func:function name="local:get-traffic-grouped-by-class">
		<xsl:param name="data"/>
		<xsl:param name="selected-class-node"/>
		<xsl:param name="class"/>		
		<func:result select="sum($data/class/instance[(name = $selected-class-node/class_id) or (string($selected-class-node/class_id) = -1)]/counter[name = $class]/value/avg)"/>
	</func:function>

   <!-- main document handler -->
	<xsl:template mode="screen" match="/">  
		<xsl:choose>
			<xsl:when test="$step = 'traffic'">
				<xsl:call-template name="get-traffic"/>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
                                      
	<sw:include href="/lib/vza/hwm.xsl"/>
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/core/browse-filter-raw.xsl" />

</xsl:stylesheet>
